@@ -3,7 +3,7 @@
         'name' => 'nextcloud/3rdparty',
         'pretty_version' => 'dev-master',
         'version' => 'dev-master',
-        'reference' => '4b599a26731b0399c231c33a200cc12cb2e2031e',
+        'reference' => '17019bea3f47a54511a0d21bb6f79a8f51917ac1',
         'type' => 'library',
         'install_path' => __DIR__ . '/../',
         'aliases' => array(),
@@ -155,18 +155,18 @@
             'dev_requirement' => false,
         ),
         'giggsey/libphonenumber-for-php' => array(
-            'pretty_version' => '8.12.25',
-            'version' => '8.12.25.0',
-            'reference' => '7d397cbd2e01e78cf79ff347e40a403dbc4c22fa',
+            'pretty_version' => '8.12.38',
+            'version' => '8.12.38.0',
+            'reference' => '0a6293c57de9256f4bd0d673280fbfbfd1e47533',
             'type' => 'library',
             'install_path' => __DIR__ . '/../giggsey/libphonenumber-for-php',
             'aliases' => array(),
             'dev_requirement' => false,
         ),
         'giggsey/locale' => array(
-            'pretty_version' => '1.9',
-            'version' => '1.9.0.0',
-            'reference' => 'b07f1eace8072ccc61445ad8fbd493ff9d783043',
+            'pretty_version' => '2.1',
+            'version' => '2.1.0.0',
+            'reference' => '8d324583b5899e6280a875c43bf1fc9658bc6962',
             'type' => 'library',
             'install_path' => __DIR__ . '/../giggsey/locale',
             'aliases' => array(),
@@ -209,9 +209,9 @@
             'dev_requirement' => false,
         ),
         'icewind/searchdav' => array(
-            'pretty_version' => 'v2.0.0',
-            'version' => '2.0.0.0',
-            'reference' => 'c69806d900c2c9a5954bfabc80178d6eb0d63df4',
+            'pretty_version' => 'v3.0.1',
+            'version' => '3.0.1.0',
+            'reference' => '52c8cfc21bd69271f224671c4924d260b0a8d4fb',
             'type' => 'library',
             'install_path' => __DIR__ . '/../icewind/searchdav',
             'aliases' => array(),
@@ -271,15 +271,6 @@
             'aliases' => array(),
             'dev_requirement' => false,
         ),
-        'mlocati/ip-lib' => array(
-            'pretty_version' => '1.18.0',
-            'version' => '1.18.0.0',
-            'reference' => 'c77bd0b1f3e3956c7e9661e75cb1f54ed67d95d2',
-            'type' => 'library',
-            'install_path' => __DIR__ . '/../mlocati/ip-lib',
-            'aliases' => array(),
-            'dev_requirement' => false,
-        ),
         'mtdowling/jmespath.php' => array(
             'pretty_version' => '2.6.1',
             'version' => '2.6.1.0',
@@ -292,7 +283,7 @@
         'nextcloud/3rdparty' => array(
             'pretty_version' => 'dev-master',
             'version' => 'dev-master',
-            'reference' => '4b599a26731b0399c231c33a200cc12cb2e2031e',
+            'reference' => '17019bea3f47a54511a0d21bb6f79a8f51917ac1',
             'type' => 'library',
             'install_path' => __DIR__ . '/../',
             'aliases' => array(),
@@ -434,9 +425,9 @@
             'dev_requirement' => false,
         ),
         'pimple/pimple' => array(
-            'pretty_version' => 'v3.4.0',
-            'version' => '3.4.0.0',
-            'reference' => '86406047271859ffc13424a048541f4531f53601',
+            'pretty_version' => 'v3.5.0',
+            'version' => '3.5.0.0',
+            'reference' => 'a94b3a4db7fb774b3d78dad2315ddc07629e1bed',
             'type' => 'library',
             'install_path' => __DIR__ . '/../pimple/pimple',
             'aliases' => array(),
@@ -581,63 +572,63 @@
             ),
         ),
         'sabre/dav' => array(
-            'pretty_version' => '4.1.5',
-            'version' => '4.1.5.0',
-            'reference' => 'c1afdc77a95efea6ee40c03c45f57c3c0c80ec22',
+            'pretty_version' => '4.4.0',
+            'version' => '4.4.0.0',
+            'reference' => 'b65362abc926520eda2c57e219f022a6c288069d',
             'type' => 'library',
             'install_path' => __DIR__ . '/../sabre/dav',
             'aliases' => array(),
             'dev_requirement' => false,
         ),
         'sabre/event' => array(
-            'pretty_version' => '5.1.2',
-            'version' => '5.1.2.0',
-            'reference' => 'c120bec57c17b6251a496efc82b732418b49d50a',
+            'pretty_version' => '5.1.4',
+            'version' => '5.1.4.0',
+            'reference' => 'd7da22897125d34d7eddf7977758191c06a74497',
             'type' => 'library',
             'install_path' => __DIR__ . '/../sabre/event',
             'aliases' => array(),
             'dev_requirement' => false,
         ),
         'sabre/http' => array(
-            'pretty_version' => '5.1.1',
-            'version' => '5.1.1.0',
-            'reference' => 'd0aafede6961df6195ce7a8dad49296b0aaee22e',
+            'pretty_version' => '5.1.6',
+            'version' => '5.1.6.0',
+            'reference' => '9976ac34ced206bd6579b7b37b401de9fac98dae',
             'type' => 'library',
             'install_path' => __DIR__ . '/../sabre/http',
             'aliases' => array(),
             'dev_requirement' => false,
         ),
         'sabre/uri' => array(
-            'pretty_version' => '2.2.1',
-            'version' => '2.2.1.0',
-            'reference' => 'f502edffafea8d746825bd5f0b923a60fd2715ff',
+            'pretty_version' => '2.2.2',
+            'version' => '2.2.2.0',
+            'reference' => '7cb0f489578afad5006e85cd60f18ff33f2d440d',
             'type' => 'library',
             'install_path' => __DIR__ . '/../sabre/uri',
             'aliases' => array(),
             'dev_requirement' => false,
         ),
         'sabre/vobject' => array(
-            'pretty_version' => '4.3.5',
-            'version' => '4.3.5.0',
-            'reference' => 'd8a0a9ae215a8acfb51afc29101c7344670b9c83',
+            'pretty_version' => '4.4.3',
+            'version' => '4.4.3.0',
+            'reference' => '2a043b994fa8d8a655c3d50d73c1ad443d31d677',
             'type' => 'library',
             'install_path' => __DIR__ . '/../sabre/vobject',
             'aliases' => array(),
             'dev_requirement' => false,
         ),
         'sabre/xml' => array(
-            'pretty_version' => '2.2.3',
-            'version' => '2.2.3.0',
-            'reference' => 'c3b959f821c19b36952ec4a595edd695c216bfc6',
+            'pretty_version' => '2.2.5',
+            'version' => '2.2.5.0',
+            'reference' => 'a6af111850e7536d200d9637c34885cd3c77a86c',
             'type' => 'library',
             'install_path' => __DIR__ . '/../sabre/xml',
             'aliases' => array(),
             'dev_requirement' => false,
         ),
         'scssphp/scssphp' => array(
-            'pretty_version' => 'v1.4.1',
-            'version' => '1.4.1.0',
-            'reference' => 'ba86c963b94ec7ebd6e19d90cdab90d89667dbf7',
+            'pretty_version' => 'v1.8.1',
+            'version' => '1.8.1.0',
+            'reference' => '5e37759a63caf54392a4b709358a39ac7425a69f',
             'type' => 'library',
             'install_path' => __DIR__ . '/../scssphp/scssphp',
             'aliases' => array(),
@@ -689,9 +680,9 @@
             'dev_requirement' => false,
         ),
         'symfony/deprecation-contracts' => array(
-            'pretty_version' => 'v2.5.1',
-            'version' => '2.5.1.0',
-            'reference' => 'e8b495ea28c1d97b5e0c121748d6f9b53d075c66',
+            'pretty_version' => 'v2.5.0',
+            'version' => '2.5.0.0',
+            'reference' => '6f981ee24cf69ee7ce9736146d1c57c2780598a8',
             'type' => 'library',
             'install_path' => __DIR__ . '/../symfony/deprecation-contracts',
             'aliases' => array(),
