@@ -30,6 +30,7 @@ OC.L10N.register(
     "Push" : "រុញ",
     "Activity" : "សកម្មភាព",
     "Notifications" : "ការ​ជូន​ដំណឹង",
+    "This application enables users to view a log of activities about them or about files." : "កម្មវិធីនេះអនុញ្ញាតឱ្យអ្នកប្រើប្រាស់មើលកំណត់ហេតុនៃសកម្មភាពអំពីពួកគេ ឬអំពីឯកសារផ្សេងៗ។",
     "Send email" : "ផ្ញើ​អ៊ីមែល",
     "You need to set up your email address before you can receive notification emails." : "អ្នក​ចាំបាច់​ត្រូវតែដំឡើង​អាសយដ្ឋាន​អ៊ីមែលរបស់អ្នកមុនពេល​ដែលអ្នកអាចទទួលបានការជូន​ដំណឹង​ទៅកាន់​អ៊ីមែល ។",
     "As soon as possible" : "កាន់តែឆាប់តាមដែលអាចធ្វើបាន",
@@ -52,10 +53,11 @@ OC.L10N.register(
     "Personal notification settings" : "ការកំណត់ផ្ទាល់ខ្លួនលើការជូនដំណឹង",
     "No more events to load" : "គ្មាន​ព្រឹត្តិការណ៍​ច្រើនទៀតសម្រាប់ទាញយកមកទេ",
     "Activity notification for %s" : "ការជូនដំណឹងអំពីសកម្មភាពសម្រាប់ %s",
-    "This application enables users to view a log of activities about them or about files." : "កម្មវិធីនេះអនុញ្ញាតឱ្យអ្នកប្រើប្រាស់មើលកំណត់ហេតុនៃសកម្មភាពអំពីពួកគេ ឬអំពីឯកសារផ្សេងៗ។",
-    "activities" : "សកម្មភាពផ្សេងៗ",
     "Configure the default notification settings." : "កែការកំណត់លំនាំដើមនៃការជូនដំណឹង",
-    "Send activity emails:" : "ផ្ញើអ៊ីម៉ែលអំពីសកម្មភាព",
-    "Settings" : "ការកំណត់"
+    "Send notification emails:" : "ផ្ញើអ៊ីម៉ែលជូនដំណឹង",
+    "Settings" : "ការកំណត់",
+    "Personal Activity Settings" : "ការកំណត់ «សកម្មភាពផ្ទាល់ខ្លួន»",
+    "activities" : "សកម្មភាពផ្សេងៗ",
+    "Send activity emails:" : "ផ្ញើអ៊ីម៉ែលអំពីសកម្មភាព"
 },
 "nplurals=1; plural=0;");
