@@ -26,8 +26,7 @@ OC.L10N.register(
     "Mail" : "စာ",
     "Activity" : "လုပ်ဆောင်မှု",
     "No activity yet" : "လုပ်ဆောင်မှုမရှိသေး",
-    "An error occurred while loading activities" : "ဆောင်ရွက်မှုများ လုပ်ဆောင်နေစဉ် ပြဿနာတစ်ခု ကြုံတွေ့ခဲ့သည်",
-    "Load more activities" : "လုပ်ဆောင်မှုများ ပိုမိုပြသရန်",
+    "Activities" : "လုပ်ဆောင်မှုများ",
     "Activity notification for %s" : "%sအတွက် လုပ်ဆောင်မှု အသိပေးချက်"
 },
 "nplurals=1; plural=0;");
