@@ -19,7 +19,6 @@ OC.L10N.register(
     "Your settings have been updated." : "您的設定已更新。",
     "Settings have been updated." : "設定已更新。",
     "Recent activity" : "近期活動",
-    "More activities" : "更多活動",
     "Daily activity summary for %s" : "%s 的每日活動摘要",
     "_and %n more _::_and %n more _" : ["以及其餘 %n 項"],
     "All activities" : "所有活動",
@@ -33,8 +32,8 @@ OC.L10N.register(
     "Push" : "推送",
     "Activity" : "活動",
     "Notifications" : "通知",
-    "This application enables people to view a log of activities about them, their files or other data." : "此應用程式讓人們可以檢視關於他們、他們的檔案或是其他資料的活動紀錄。",
-    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "此應用程式讓人們可以檢視與他們在 Nextcloud 中的檔案與其他資料相關的動作。\n\t\t每個人都可以在他們的個人設定中設定自己的個人活動紀錄設定，\n\t\t選擇要推送到手機或透過電子郵件傳送的活動\n\t\t或是否每天早上傳送每日摘要。\n\t\t可在活動應用程式的文件中找到更多資訊。",
+    "This application enables users to view a log of activities about them or about files." : "本應用程式可以讓使用者檢視有關自己或檔案的活動記錄。",
+    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "此應用程式讓使用者能夠在 Nextcloud 中查看與其檔案相關的操作。\n\t\t啟用後，使用者將在其選單中看到一個「活動」新圖示。\n\t\t點選後，將顯示一個新頁面，以供使用者追蹤與文件相關的活動 ─ 包含新增檔案、已刪除檔案、移動、重新命名、更新和分享活動。\n\t\t使用者可以在其個人選單中配置其各自的活動設定。\n\t\t此設定了想要記錄的活動類型，以及使用者是否可看到自己的活動，\n\t\t並是否僅為線上提供，以及是否定期收到電子郵件摘要。\n\t\t活動說明文件中提供了更多訊息。",
     "Activity notification configuration" : "活動通知設定",
     "Send email" : "傳送電子郵件",
     "Send push notification" : "傳送推播通知",
@@ -55,7 +54,7 @@ OC.L10N.register(
     "Activities" : "活動",
     "No activities" : "無活動",
     "Default settings" : "預設設定",
-    "Configure the default notification settings for new accounts." : "設定新帳號的預設通知設定。",
+    "Configure the default notification settings for new users." : "為新使用者設定預設的通知設定。",
     "Unable to save the settings" : "無法儲存設定",
     "Activity feed" : "活動摘要",
     "Activity settings" : "活動設定",
@@ -64,12 +63,11 @@ OC.L10N.register(
     "Personal notification settings" : "個人通知設定",
     "No more events to load" : "已載入所有事件",
     "Activity notification for %s" : "%s 的活動通知",
-    "This application enables users to view a log of activities about them or about files." : "本應用程式可以讓使用者檢視有關自己或檔案的活動記錄。",
-    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "此應用程式讓使用者能夠在 Nextcloud 中查看與其檔案相關的操作。\n\t\t啟用後，使用者將在其選單中看到一個「活動」新圖示。\n\t\t點選後，將顯示一個新頁面，以供使用者追蹤與文件相關的活動 ─ 包含新增檔案、已刪除檔案、移動、重新命名、更新和分享活動。\n\t\t使用者可以在其個人選單中配置其各自的活動設定。\n\t\t此設定了想要記錄的活動類型，以及使用者是否可看到自己的活動，\n\t\t並是否僅為線上提供，以及是否定期收到電子郵件摘要。\n\t\t活動說明文件中提供了更多訊息。",
-    "activities" : "活動",
     "Configure the default notification settings." : "設定預設的通知設定。",
-    "Send activity emails:" : "傳送事件電子郵件：",
+    "Send notification emails:" : "透過電子郵件接收通知",
     "Settings" : "設定",
-    "Configure the default notification settings for new users." : "為新使用者設定預設的通知設定。"
+    "Personal Activity Settings" : "個人活動設定",
+    "activities" : "活動",
+    "Send activity emails:" : "傳送事件電子郵件："
 },
 "nplurals=1; plural=0;");
