@@ -92,7 +92,7 @@ OC.L10N.register(
     "Circle Invite" : "Einladung zu Kreis",
     "Federated" : "Federated",
     "Mount point" : "Einhängepunkt",
-    "Nextcloud Account" : "Nextcloud-Konto",
+    "Nextcloud User" : "Nextcloud-Benutzer",
     "Nextcloud Group" : "Nextcloud-Gruppe",
     "Email Address" : "E-Mail-Adresse",
     "Contact" : "Kontakt",
@@ -128,8 +128,10 @@ OC.L10N.register(
     "Adding local users and moderators" : "Lokale Benutzer und Moderatoren werden hinzugefügt",
     "Circle not found" : "Kreis nicht gefunden",
     "Circle not found " : "Kreis nicht gefunden",
+    "A circle with that name exists" : "Ein Kreis mit diesem Namen existiert bereits",
+    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Du kannst die Kreise-App nicht verwenden, solange dein Administrator nicht wenigstens einen Kreis-Typ zulässt",
     "This member does not exist" : "Dieses Mitglied existiert nicht",
-    "This account is already a member of the circle" : "Dieses Konto ist bereits Mitglied dieses Kreises",
+    "This user is already a member of the circle" : "Dieser Benutzer ist bereits Mitglied dieses Kreises",
     "Federated link not found" : "Federated-Verknüpfung nicht gefunden",
     "This feature is not available for personal circles" : "Diese Funktion steht für persönliche Kreise nicht zur Verfügung",
     "The circle is not federated" : "Der Kreis ist nicht cloud übergreifend",
@@ -140,8 +142,8 @@ OC.L10N.register(
     "Level cannot be changed for this type of member" : "Berechtigungsstufe kann für diesen Mitgliedstyp nicht geändert werden",
     "You are already a member of this circle" : "Du bist bereits Mitglied dieses Kreises",
     "You have been blocked from this circle" : "Du wurdest für diesen Kreis blockiert",
-    "The account is already a member of this circle" : "Dieses Konto ist bereits Mitglied dieses Kreises",
-    "The account has already been invited into this circle" : "Dieser Benutzer wurde bereits zu diesem Kreis eingeladen.",
+    "The user is already a member of this circle" : "Dieser Benutzer ist bereits Mitglied dieses Kreises ",
+    "The user has already been invited into this circle" : "Benutzer wurde bereits zu diesem Kreis eingeladen",
     "%s (Circle owned by %s)" : "%s (Kreis im Besitz von%s)",
     "You are now a member of the Circle \"%2$s\"" : "Du bist jetzt ein Mitglied des Kreises \"%2$s\"",
     "You have been invited by %1$s into the Circle \"%2$s\"" : "Du wurdest von %1$s zum Kreis \"%2$s\" eingeladen",
@@ -153,7 +155,6 @@ OC.L10N.register(
     "Personal Circle" : "Persönlicher Kreis",
     "%s owned by %s" : "%s gehört %s",
     "You need a specify a type of circle" : "Du benötigst einen bestimmten Kreis-Typ",
-    "A circle with that name exists" : "Ein Kreis mit diesem Namen existiert bereits",
     "This member is not the owner of the circle" : "Dieses Mitglied ist nicht der Besitzer des Kreises",
     "This member is not an admin of the circle" : "Dieses Mitglied ist nicht der Administrator des Kreises ",
     "Group contains too many members" : "Gruppe hat zu viele Mitglieder",
@@ -162,7 +163,7 @@ OC.L10N.register(
     "You cannot edit level in a personal circle" : "Du kannst das Level in einem persönlichen Kreis nicht bearbeiten",
     "Group cannot be set as owner of a circle" : "Eine Gruppe kann nicht Besitzer eines Kreises sein",
     "now" : "jetzt",
-    "This account does not exist" : "Dieses Konto existiert nicht",
+    "This user does not exist" : "Dieser Benutzer existiert nicht",
     "Email format is not valid" : "Das E-Mail-Format ist ungültig",
     "This contact is not available" : "Dieser Kontakt ist nicht verfügbar",
     "You have no permission to create a new circle" : "Du hast keine Berechtigung, einen neuen Kreis zu erstellen",
@@ -173,20 +174,13 @@ OC.L10N.register(
     "Password to access content shared with you by %1$s" : "Passwort für den Zugriff auf den Inhalt, der von %1$s mit dir geteilt wurde.",
     "Password to access content" : "Passwort für den Zugriff auf den Inhalt",
     "This item is already shared with this circle" : "Dieses Element wird bereits mit diesem Kreis geteilt",
+    "Could not find share" : "Freigabe konnte nicht gefunden werden",
     "Bring cloud-users closer together." : "Bringe Cloudnutzer näher zueinander.",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Mit Kreisen können deine Benutzer ihre eigenen Gruppen von Benutzern/Kollegen/Freunden erstellen.\nDiese Benutzergruppen (oder \"Kreise\") können dann von jeder anderen App zum Zweck der gemeinsamen Nutzung verwendet werden.",
+    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "Mit Kreisen können deine Benutzer ihre eigenen Gruppen von Benutzern/Kollegen/Freunden erstellen.\nDiese Benutzergruppen (oder \"Kreise\") können dann von jeder anderen App zum Zweck der gemeinsamen Nutzung verwendet werden.",
     "No files in here" : "Keine Dateien vorhanden",
     "No entries found in this folder" : " Keine Einträge in diesem Ordner gefunden ",
     "Name" : "Name",
     "Size" : "Größe",
-    "Modified" : "Geändert",
-    "Nextcloud User" : "Nextcloud-Benutzer",
-    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Du kannst die Kreise-App nicht verwenden, solange dein Administrator nicht wenigstens einen Kreis-Typ zulässt",
-    "This user is already a member of the circle" : "Dieser Benutzer ist bereits Mitglied dieses Kreises",
-    "The user is already a member of this circle" : "Dieser Benutzer ist bereits Mitglied dieses Kreises ",
-    "The user has already been invited into this circle" : "Benutzer wurde bereits zu diesem Kreis eingeladen",
-    "This user does not exist" : "Dieser Benutzer existiert nicht",
-    "Could not find share" : "Freigabe konnte nicht gefunden werden",
-    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "Mit Kreisen können deine Benutzer ihre eigenen Gruppen von Benutzern/Kollegen/Freunden erstellen.\nDiese Benutzergruppen (oder \"Kreise\") können dann von jeder anderen App zum Zweck der gemeinsamen Nutzung verwendet werden."
+    "Modified" : "Geändert"
 },
 "nplurals=2; plural=(n != 1);");
