@@ -92,7 +92,7 @@ OC.L10N.register(
     "Circle Invite" : "Invitar al círculo",
     "Federated" : "Federado",
     "Mount point" : "Punto de montaje",
-    "Nextcloud Account" : "Cuenta de Nextcloud",
+    "Nextcloud User" : "Usuario de Nextcloud",
     "Nextcloud Group" : "Grupo de Nextcloud",
     "Email Address" : "Dirección de correo electrónico",
     "Contact" : "Contacto",
@@ -128,8 +128,10 @@ OC.L10N.register(
     "Adding local users and moderators" : "Añadiendo usuarios y moderadores locales",
     "Circle not found" : "No se ha encontrado el círculo",
     "Circle not found " : "Círculo no encontrado",
+    "A circle with that name exists" : "Ya existe un círculo con ese nombre",
+    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "No puedes usar la app Círculos hasta que el administrador haya permitido al menos un tipo de círculos",
     "This member does not exist" : "Este miembro no existe",
-    "This account is already a member of the circle" : "Esta cuenta ya es miembro del círculo",
+    "This user is already a member of the circle" : "Este usuario ya es miembro de este círculo",
     "Federated link not found" : "Enlace federado no encontrado",
     "This feature is not available for personal circles" : "Esta funcionalidad no está disponible para círculos personales",
     "The circle is not federated" : "El círculo no está federado",
@@ -140,8 +142,8 @@ OC.L10N.register(
     "Level cannot be changed for this type of member" : "No se puede cambiar el nivel para este tipo de miembro",
     "You are already a member of this circle" : "Ya es miembro de éste círculo",
     "You have been blocked from this circle" : "Has sido bloqueado de este círculo",
-    "The account is already a member of this circle" : "La cuenta ya es miembro de este círculo",
-    "The account has already been invited into this circle" : "La cuenta ya ha sido invitada a este círculo",
+    "The user is already a member of this circle" : "El usuario ya es miembro de este círculo",
+    "The user has already been invited into this circle" : "El usuario ya ha sido invitado a este círculo",
     "%s (Circle owned by %s)" : "%s (Círculo que pertenece a %s)",
     "You are now a member of the Circle \"%2$s\"" : "Ahora ya eres miembro del Círculo  \"%2$s\"",
     "You have been invited by %1$s into the Circle \"%2$s\"" : "Has sido invitado por %1$s al Círculo \"%2$s\"",
@@ -153,7 +155,6 @@ OC.L10N.register(
     "Personal Circle" : "Círculo Personal",
     "%s owned by %s" : "%s propiedad de %s",
     "You need a specify a type of circle" : "Necesitas especificar un tipo de círculo",
-    "A circle with that name exists" : "Ya existe un círculo con ese nombre",
     "This member is not the owner of the circle" : "Este miebro no es el dueño del círculo",
     "This member is not an admin of the circle" : "Este miembro no es un administrador del círculo",
     "Group contains too many members" : "El grupo contiene demasiados miembros",
@@ -162,7 +163,7 @@ OC.L10N.register(
     "You cannot edit level in a personal circle" : "No puedes editar el nivel en un círculo personal",
     "Group cannot be set as owner of a circle" : "Un grupo no puede ser configurado como duelo de un círculo",
     "now" : "ahora",
-    "This account does not exist" : "Esta cuenta no existe",
+    "This user does not exist" : "El usuario no existe",
     "Email format is not valid" : "El formato del correo no es válido",
     "This contact is not available" : "Este contacto no está disponible",
     "You have no permission to create a new circle" : "No tienes permiso para crear un nuevo círculo",
@@ -173,20 +174,13 @@ OC.L10N.register(
     "Password to access content shared with you by %1$s" : "Contraseña para acceder a los archivos compartidos contigo por %1$s",
     "Password to access content" : "Contraseña para acceder al contenido",
     "This item is already shared with this circle" : "Este elemento ya ha sido compartido en este círculo",
+    "Could not find share" : "No se ha podido encontrar el recurso compartido",
     "Bring cloud-users closer together." : "Acerca a los usuarios de nubes.",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Los círculos permiten a tus usuarios crear sus propios grupos de usuarios/compañeros/amigos.\nEstos grupos de usuarios (o \"círculos\") pueden ser utilizados por cualquier otra aplicación con el propósito de compartir información.",
+    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "Los círculos permiten a tus usuarios crear sus propios grupos de usuarios/compañeros/amigos.\nEstos grupos de usuarios (o \"círculos\") pueden ser utilizados por cualquier otra aplicación para compartir.",
     "No files in here" : "No hay archivos aquí",
     "No entries found in this folder" : "No se han encontrado entradas en esta carpeta",
     "Name" : "Nombre",
     "Size" : "Tamaño",
-    "Modified" : "Modificado",
-    "Nextcloud User" : "Usuario de Nextcloud",
-    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "No puedes usar la app Círculos hasta que el administrador haya permitido al menos un tipo de círculos",
-    "This user is already a member of the circle" : "Este usuario ya es miembro de este círculo",
-    "The user is already a member of this circle" : "El usuario ya es miembro de este círculo",
-    "The user has already been invited into this circle" : "El usuario ya ha sido invitado a este círculo",
-    "This user does not exist" : "El usuario no existe",
-    "Could not find share" : "No se ha podido encontrar el recurso compartido",
-    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "Los círculos permiten a tus usuarios crear sus propios grupos de usuarios/compañeros/amigos.\nEstos grupos de usuarios (o \"círculos\") pueden ser utilizados por cualquier otra aplicación para compartir."
+    "Modified" : "Modificado"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
