@@ -92,7 +92,7 @@ OC.L10N.register(
     "Circle Invite" : "Meghívás körbe",
     "Federated" : "Föderált",
     "Mount point" : "Csatolási pont",
-    "Nextcloud Account" : "Nextcloud-fiók",
+    "Nextcloud User" : "Nextcloud felhasználó",
     "Nextcloud Group" : "Nextcloud csoport",
     "Email Address" : "E-mail-cím",
     "Contact" : "Névjegy",
@@ -128,8 +128,10 @@ OC.L10N.register(
     "Adding local users and moderators" : "Helyi felhasználók és moderátorok hozzáadása",
     "Circle not found" : "A Kör nem található",
     "Circle not found " : "A Kör nem található ",
+    "A circle with that name exists" : "Már van ilyen nevű kör",
+    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "A Körök alkalmazás nem használható, amíg a rendszergazda legalább egy körtípust nem engedélyez.",
     "This member does not exist" : "Ez a tag nem létezik",
-    "This account is already a member of the circle" : "A fiók már tagja a körnek",
+    "This user is already a member of the circle" : "Ez a felhasználó már tagja a körnek",
     "Federated link not found" : "A föderált kapcsolat nem található",
     "This feature is not available for personal circles" : "Ez a szolgáltatás nem elérhető a személyes köröknél",
     "The circle is not federated" : "A kör nem föderált",
@@ -140,8 +142,8 @@ OC.L10N.register(
     "Level cannot be changed for this type of member" : "Az ilyen típusú tag szintje nem változtatható meg",
     "You are already a member of this circle" : "Ön már tagja ennek a körnek",
     "You have been blocked from this circle" : "Kizárták ebből a körből",
-    "The account is already a member of this circle" : "A fiók már tagja e körnek",
-    "The account has already been invited into this circle" : "A fiók már meg lett hívva a körbe",
+    "The user is already a member of this circle" : "A felhasználó már tagja a körnek",
+    "The user has already been invited into this circle" : "A felhasználó már meg lett hívva a körbe",
     "%s (Circle owned by %s)" : "%s (A kör tulajdonosa %s)",
     "You are now a member of the Circle \"%2$s\"" : "Ön most már a(z) „%2$s” kör tagja",
     "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s meghívta Önt a (z) „\"%2$s” körbe",
@@ -153,7 +155,6 @@ OC.L10N.register(
     "Personal Circle" : "Személyes kör",
     "%s owned by %s" : "a(z) %s tulajdonosa %s",
     "You need a specify a type of circle" : "Meg kell adnia egy körtípust",
-    "A circle with that name exists" : "Már van ilyen nevű kör",
     "This member is not the owner of the circle" : "Ez a tag nem a kör tulajdonosa",
     "This member is not an admin of the circle" : "Ez a tag nem a kör adminisztrátora",
     "Group contains too many members" : "A csoport túl sok tagot tartalmaz",
@@ -162,7 +163,7 @@ OC.L10N.register(
     "You cannot edit level in a personal circle" : "A szint nem szerkeszthető egy személyes körnél",
     "Group cannot be set as owner of a circle" : "Csoport nem lehet kör tulajdonosa",
     "now" : "most",
-    "This account does not exist" : "A fiók nem létezik",
+    "This user does not exist" : "Ez a felhasználó nem létezik",
     "Email format is not valid" : "Az e-mail formátum érvénytelen",
     "This contact is not available" : "A névjegy nem érhető el",
     "You have no permission to create a new circle" : "Nincs jogosultsága arra, hogy új kört hozzon létre",
@@ -173,20 +174,13 @@ OC.L10N.register(
     "Password to access content shared with you by %1$s" : "Jelszó a(z) %1$s által megosztott tartalom eléréséhez",
     "Password to access content" : "Jelszó a tartalom eléréséhez",
     "This item is already shared with this circle" : "Ez az elem már megosztásra került ezzel a körrel",
+    "Could not find share" : "A megosztás nem található",
     "Bring cloud-users closer together." : "Közelebb hozza a felhőfelhasználókat.",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "A Körök lehetővé teszi, hogy az emberek létrehozzák a saját köreiket a felhasználóinak/kollégáinak/barátaiknak.\nEzeket a csoportokat (vagy „köröket”) aztán bármely más alkalmazás használhatja megosztási célokra.",
+    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "A Körök lehetővé teszi, hogy a felhasználók létrehozzák a saját köreiket a felhasználóknak/kollégáknak/barátoknak.\nEzeket a felhasználói csoportokat (vagy „körök”) aztán bármely más alkalmazás használhatja megosztási célokra.",
     "No files in here" : "Itt nincsenek fájlok",
     "No entries found in this folder" : "Nincsenek bejegyzések ebben a mappában",
     "Name" : "Név",
     "Size" : "Méret",
-    "Modified" : "Módosítva",
-    "Nextcloud User" : "Nextcloud felhasználó",
-    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "A Körök alkalmazás nem használható, amíg a rendszergazda legalább egy körtípust nem engedélyez.",
-    "This user is already a member of the circle" : "Ez a felhasználó már tagja a körnek",
-    "The user is already a member of this circle" : "A felhasználó már tagja a körnek",
-    "The user has already been invited into this circle" : "A felhasználó már meg lett hívva a körbe",
-    "This user does not exist" : "Ez a felhasználó nem létezik",
-    "Could not find share" : "A megosztás nem található",
-    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "A Körök lehetővé teszi, hogy a felhasználók létrehozzák a saját köreiket a felhasználóknak/kollégáknak/barátoknak.\nEzeket a felhasználói csoportokat (vagy „körök”) aztán bármely más alkalmazás használhatja megosztási célokra."
+    "Modified" : "Módosítva"
 },
 "nplurals=2; plural=(n != 1);");
