@@ -39,13 +39,34 @@ use OCA\Circles\Model\Circle;
  * @package OCA\Circles
  */
 interface IFederatedUser extends IFederatedModel {
+
+	/**
+	 * @return string
+	 */
 	public function getSingleId(): string;
 
+	/**
+	 * @return string
+	 */
 	public function getUserId(): string;
 
+	/**
+	 * @return int
+	 */
 	public function getUserType(): int;
 
+	/**
+	 * @return string
+	 */
 	public function getDisplayName(): string;
 
-	public function getBasedOn(): ?Circle;
+	/**
+	 * @return Circle
+	 */
+	public function getBasedOn(): Circle;
+
+	/**
+	 * @return bool
+	 */
+	public function hasBasedOn(): bool;
 }
