@@ -32,14 +32,18 @@ declare(strict_types=1);
 namespace OCA\Circles\Service;
 
 use Exception;
-use OCA\Circles\Tools\Traits\TStringTools;
 use OCA\Circles\Db\ShareWrapperRequest;
 use OCA\Circles\Exceptions\RequestBuilderException;
 use OCA\Circles\Exceptions\ShareWrapperNotFoundException;
 use OCA\Circles\Model\FederatedUser;
 use OCA\Circles\Model\Probes\CircleProbe;
 use OCA\Circles\Model\ShareWrapper;
+use OCA\Circles\Tools\Exceptions\InvalidItemException;
+use OCA\Circles\Tools\Traits\TDeserialize;
+use OCA\Circles\Tools\Traits\TStringTools;
 use OCP\Files\NotFoundException;
+use OCP\ICache;
+use OCP\ICacheFactory;
 use OCP\Share\IShare;
 
 /**
@@ -49,18 +53,27 @@ use OCP\Share\IShare;
  */
 class ShareWrapperService {
 	use TStringTools;
+	use TDeserialize;
+
+	public const CACHE_SHARED_WITH = 'circles/getSharedWith';
+	public const CACHE_SHARED_WITH_TTL = 900;
 
 
 	/** @var ShareWrapperRequest */
 	private $shareWrapperRequest;
 
+	private ICache $cache;
+
 
 	/**
 	 * ShareWrapperService constructor.
 	 *
+	 * @param ICacheFactory $cacheFactory
 	 * @param ShareWrapperRequest $shareWrapperRequest
 	 */
-	public function __construct(ShareWrapperRequest $shareWrapperRequest) {
+	public function __construct(ICacheFactory $cacheFactory, ShareWrapperRequest $shareWrapperRequest) {
+		$this->cache = $cacheFactory->createDistributed(self::CACHE_SHARED_WITH);
+
 		$this->shareWrapperRequest = $shareWrapperRequest;
 	}
 
@@ -84,6 +97,7 @@ class ShareWrapperService {
 	 * @throws NotFoundException
 	 */
 	public function save(IShare $share): void {
+		$this->cache->clear('');
 		$this->shareWrapperRequest->save($share);
 	}
 
@@ -92,6 +106,7 @@ class ShareWrapperService {
 	 * @param ShareWrapper $shareWrapper
 	 */
 	public function update(ShareWrapper $shareWrapper): void {
+		$this->cache->clear('');
 		$this->shareWrapperRequest->update($shareWrapper);
 	}
 
@@ -100,17 +115,23 @@ class ShareWrapperService {
 	 * @param ShareWrapper $shareWrapper
 	 */
 	public function delete(ShareWrapper $shareWrapper): void {
+		$this->cache->clear('');
 		$this->shareWrapperRequest->delete((int)$shareWrapper->getId());
 	}
 
 	/**
 	 * @param string $circleId
+	 * @param string $initiator
+	 * @param bool $force
+	 *
+	 * @throws Exception
 	 */
 	public function deleteUserSharesToCircle(string $circleId, string $initiator): void {
 		if ($initiator === '') {
 			throw new Exception('$initiator cannot be empty');
 		}
 
+		$this->cache->clear('');
 		$this->shareWrapperRequest->deleteSharesToCircle($circleId, $initiator);
 	}
 
@@ -119,6 +140,7 @@ class ShareWrapperService {
 	 * @param string $circleId
 	 */
 	public function deleteAllSharesToCircle(string $circleId): void {
+		$this->cache->clear('');
 		$this->shareWrapperRequest->deleteSharesToCircle($circleId, '');
 	}
 
@@ -197,7 +219,22 @@ class ShareWrapperService {
 		int $nodeId,
 		?CircleProbe $probe
 	): array {
-		return $this->shareWrapperRequest->getSharedWith($federatedUser, $nodeId, $probe);
+		$key = $this->generateSharedWithCacheKey($federatedUser, $nodeId, $probe->getChecksum());
+
+		$cachedData = $this->cache->get($key);
+		try {
+			if (!is_string($cachedData)) {
+				throw new InvalidItemException();
+			}
+
+			return $this->deserializeList($cachedData, ShareWrapper::class);
+		} catch (InvalidItemException $e) {
+		}
+
+		$shares = $this->shareWrapperRequest->getSharedWith($federatedUser, $nodeId, $probe);
+		$this->cache->set($key, json_encode($shares), self::CACHE_SHARED_WITH_TTL);
+
+		return $shares;
 	}
 
 
@@ -217,13 +254,13 @@ class ShareWrapperService {
 		FederatedUser $federatedUser,
 		int $nodeId,
 		bool $reshares,
-		int $limit,
 		int $offset,
+		int $limit,
 		bool $getData = false,
 		bool $completeDetails = false
 	): array {
 		return $this->shareWrapperRequest->getSharesBy(
-			$federatedUser, $nodeId, $reshares, $limit, $offset, $getData, $completeDetails
+			$federatedUser, $nodeId, $reshares, $offset, $limit, $getData, $completeDetails
 		);
 	}
 
@@ -260,6 +297,11 @@ class ShareWrapperService {
 	}
 
 
+	public function clearCache(string $singleId): void {
+		$this->cache->clear($singleId);
+	}
+
+
 	/**
 	 * @param FederatedUser $federatedUser
 	 * @param IShare $share
@@ -270,9 +312,28 @@ class ShareWrapperService {
 	 * @throws RequestBuilderException
 	 */
 	private function createChild(IShare $share, FederatedUser $federatedUser): ShareWrapper {
+		$this->cache->clear('');
 		$share->setSharedWith($federatedUser->getSingleId());
 		$childId = $this->shareWrapperRequest->save($share, (int)$share->getId());
 
 		return $this->getShareById($childId, $federatedUser);
 	}
+
+
+	/**
+	 * @param FederatedUser $federatedUser
+	 * @param int $nodeId
+	 * @param string $probeSum
+	 *
+	 * @return string
+	 */
+	private function generateSharedWithCacheKey(
+		FederatedUser $federatedUser,
+		int $nodeId,
+		string $probeSum
+	): string {
+		return $federatedUser->getSingleId() . '#'
+			   . $nodeId . '#'
+			   . $probeSum;
+	}
 }
