@@ -27,16 +27,6 @@ OC.L10N.register(
     "An error occurred while trying to delete the comment" : "אירעה שגיאה בניסיון למחוק את התגובה",
     "An error occurred while trying to create the comment" : "אירעה שגיאה בניסיון ליצור את התגובה",
     "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "אוזכרת ב־„{file}”, בתגובה של משתמש שנמחק בינתיים.",
-    "{user} mentioned you in a comment on “{file}”" : "אוזכרת על ידי „{user}” בתגובה על „{file}”",
-    "New comment …" : "תגובה חדשה",
-    "Post" : "פרסום",
-    "Cancel" : "ביטול",
-    "[Deleted user]" : "[משתמשים מוסרים]",
-    "More comments …" : "תגובות נוספות…",
-    "Save" : "שמירה",
-    "Allowed characters {count} of {max}" : "תווים מותרים {count} מתוך {max}",
-    "Error occurred while retrieving comment with ID {id}" : "אירעה שגיאה בעת קבלת התגובה עם המזהה {id}",
-    "Error occurred while updating comment with id {id}" : "שגיאה אירעה כאשר עודכנה תגובה עם מספר זיהוי {id}",
-    "Error occurred while posting comment" : "אירעה שגיאה בזמן פרסום תגובה"
+    "{user} mentioned you in a comment on “{file}”" : "אוזכרת על ידי „{user}” בתגובה על „{file}”"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
