@@ -15,15 +15,6 @@ OC.L10N.register(
     "No comments yet, start the conversation!" : "Il ha nulle commentarios ancora, initia le conversation!",
     "_%n unread comment_::_%n unread comments_" : ["%n commentario non legite","%n commentarios non legite"],
     "Comment" : "Commentario",
-    "{user} mentioned you in a comment on “{file}”" : "{user} mentionava tu in un commentario in “{file}”",
-    "New comment …" : "Nove commentario ...",
-    "Post" : "Publicar",
-    "Cancel" : "Cancellar",
-    "[Deleted user]" : "[Usator delite]",
-    "More comments …" : "Plus commentarios ...",
-    "Save" : "Salveguardar",
-    "Allowed characters {count} of {max}" : "{count} characteres permittite de {max}",
-    "Error occurred while updating comment with id {id}" : "Un error occurreva durante le actualisation del commentario identificate per {id}",
-    "Error occurred while posting comment" : "Un error occurreva durante le publication del commentario"
+    "{user} mentioned you in a comment on “{file}”" : "{user} mentionava tu in un commentario in “{file}”"
 },
 "nplurals=2; plural=(n != 1);");
