@@ -16,15 +16,6 @@ OC.L10N.register(
     "Retry" : "Mēģināt vēlreiz",
     "_%n unread comment_::_%n unread comments_" : ["%n nelasīti komentāri","%n nelasīti komentāri","%n nelasīti komentāri"],
     "Comment" : "Komentārs",
-    "{user} mentioned you in a comment on “{file}”" : "{user} minēja jūs komentārā “{file}”",
-    "New comment …" : "Jauns komentārs...",
-    "Post" : "Pievienot",
-    "Cancel" : "Atcelt",
-    "[Deleted user]" : "[Dzēsts lietotājs]",
-    "More comments …" : "Vairāk komentāri...",
-    "Save" : "Saglabāt",
-    "Allowed characters {count} of {max}" : "Atļautās zīmes {count} no {max}",
-    "Error occurred while updating comment with id {id}" : "Kļūda atjauninot komentāru ar id {id}",
-    "Error occurred while posting comment" : "Notika kļūda pievienojot komentāru"
+    "{user} mentioned you in a comment on “{file}”" : "{user} minēja jūs komentārā “{file}”"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
