@@ -13,11 +13,15 @@ OC.L10N.register(
     "Files app plugin to add comments to files" : "Tillegg for å legge til kommentarer til filer",
     "Edit comment" : "Rediger kommentar",
     "Delete comment" : "Slett kommentar",
+    "Cancel edit" : "Avbryt endring",
+    "Post comment" : "Send kommentar",
     "No comments yet, start the conversation!" : "Ingen kommentarer enda, start diskusjonen!",
+    "No more messages" : "Ingen flere meldinger",
     "Retry" : "Prøv igjen",
     "_%n unread comment_::_%n unread comments_" : ["%n ulest kommentar","%n uleste kommentarer"],
     "_1 new comment_::_{unread} new comments_" : ["[uleste] nye kommentarer","{uleste} nye kommentarer"],
     "Comment" : "Kommentar",
+    "Comment deleted" : "Kommentar slettet",
     "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Du ble nevnte på \"{file}\", i en kommentar av en bruker som siden har blitt slettet",
     "{user} mentioned you in a comment on “{file}”" : "{user} nevnte deg i en kommentar på “{file}”"
 },
