@@ -6,6 +6,7 @@ OC.L10N.register(
     "Customize" : "Personalizuoti",
     "Edit widgets" : "Taisyti valdiklius",
     "Get more widgets from the App Store" : "Parsisiųsti įskiepių iš App Store",
+    "Change background image" : "Keisti foninį paveikslą",
     "Weather service" : "Orų tarnyba",
     "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Dėl jūsų privatumo, orų duomenys yra jūsų vardu užklausiami jūsų Nextcloud serverio, todėl orų tarnyba negauna jokios asmeninės informacijos.",
     "Weather data from Met.no" : "Orų duomenys iš Met.no",
@@ -21,11 +22,11 @@ OC.L10N.register(
     "Good evening, {name}" : "Labas vakaras, {name}",
     "Hello" : "Sveiki",
     "Hello, {name}" : "Sveiki, {name},",
-    "Show something" : "Ką nors rodyti",
-    "Change background image" : "Keisti foninį paveikslą",
     "Pick from Files" : "Pasirinkti iš Failų",
-    "Default images" : "Numatytieji paveikslai",
+    "Default image" : "Numatytasis paveikslas",
     "Plain background" : "Vientisas fonas",
-    "Insert from {productName}" : "Įterpti iš {productName}"
+    "Insert from {productName}" : "Įterpti iš {productName}",
+    "Show something" : "Ką nors rodyti",
+    "Default images" : "Numatytieji paveikslai"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
