@@ -24,9 +24,10 @@ OC.L10N.register(
     "Hello" : "Witaj",
     "Hello, {name}" : "Witaj, {name}",
     "Pick from Files" : "Wybierz z Plików",
-    "Default images" : "Obrazy domyślne",
+    "Default image" : "Obraz domyślny",
     "Plain background" : "Zwykłe tło",
     "Insert from {productName}" : "Wstaw z {productName}",
-    "Show something" : "Pokaż coś"
+    "Show something" : "Pokaż coś",
+    "Default images" : "Obrazy domyślne"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
