@@ -6,6 +6,7 @@ OC.L10N.register(
     "Customize" : "自定义",
     "Edit widgets" : "编辑小部件",
     "Get more widgets from the App Store" : "从应用商店获取更多小部件",
+    "Change background image" : "更改背景图片",
     "Weather service" : "天气服务",
     "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "为了您的隐私，天气数据由您的 Nextcloud 服务器为您获取，这样天气服务就无法获得您的个人信息。",
     "Weather data from Met.no" : "天气数据获取自 Met.no",
@@ -21,11 +22,10 @@ OC.L10N.register(
     "Good evening, {name}" : "晚上好，{name}",
     "Hello" : "你好",
     "Hello, {name}" : "你好， {name}",
-    "Show something" : "显示信息",
-    "Change background image" : "更改背景图片",
     "Pick from Files" : "从文件中挑选",
-    "Default images" : "默认图片",
     "Plain background" : "纯色背景",
-    "Insert from {productName}" : "从 {productName} 插入"
+    "Insert from {productName}" : "从 {productName} 插入",
+    "Show something" : "显示信息",
+    "Default images" : "默认图片"
 },
 "nplurals=1; plural=0;");
