@@ -3,7 +3,7 @@ OC.L10N.register(
     {
     "Dashboard" : "儀表板",
     "Dashboard app" : "儀表板應用程式",
-    "Show something" : "顯示一些東西",
+    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "開始您新的一天\n\nNextcloud 儀表板是您一天的起點，為您提供\n您即將到來的約會概覽、緊急電郵、聊天訊息、\n新到的工單、最新的推文以及更多！用戶可以新增\n他們喜愛的小工具與變更他們喜愛的背景。",
     "Customize" : "自訂",
     "Edit widgets" : "編輯小工具",
     "Get more widgets from the App Store" : "從 App Store 取得更多小工具",
@@ -24,9 +24,10 @@ OC.L10N.register(
     "Hello" : "哈囉",
     "Hello, {name}" : "哈囉，{name}",
     "Pick from Files" : "從檔案選取",
-    "Default images" : "默認圖像",
+    "Default image" : "默認圖像",
     "Plain background" : "簡單背景",
-    "Insert from {productName}" : "插入自 {productName}",
-    "Get more widgets from the app store" : "從應用商店取得更多小工具"
+    "Insert from {productName}" : "自 {productName} 插入",
+    "Show something" : "顯示一些東西",
+    "Default images" : "默認圖像"
 },
 "nplurals=1; plural=0;");
