@@ -31,10 +31,8 @@ OC.L10N.register(
     "{actor} updated event {event} in calendar {calendar}" : "Ο {actor} ενημέρωσε το γεγονός {event} στο ημερολόγιο {calendar}",
     "You updated event {event} in calendar {calendar}" : "Ενημερώσατε το συμβάν {event} στο ημερολόγιο {calendar}",
     "Busy" : "Απασχολημένος",
-    "Calendar, contacts and tasks" : "Ημερολόγιο, επαφές και εργασίες",
     "A <strong>calendar</strong> was modified" : "Τροποποιήθηκε ένα <strong>ημερολόγιο</strong> ",
     "A calendar <strong>event</strong> was modified" : "Τροποποιήθηκε ένα <strong>γεγονός</strong> του ημερολογίου",
-    "A calendar <strong>to-do</strong> was modified" : "Τροποποιήθηκε μια <strong>εκκρεμότητα</strong> ημερολογίου",
     "Contact birthdays" : "Γενέθλια επαφών",
     "Death of %s" : "Θάνατος του %s",
     "Calendar:" : "Ημερολόγιο:",
@@ -67,7 +65,6 @@ OC.L10N.register(
     "More options …" : "Περισσότερες επιλογές...",
     "More options at %s" : "Περισσότερες επιλογές στο %s",
     "Contacts" : "Επαφές",
-    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Τροποποιήθηκε μια <strong>επαφή</strong> ή ένα <strong>βιβλίο διευθύνσεων</strong>",
     "System is in maintenance mode." : "Το σύστημα βρίσκεται σε λειτουργία συντήρησης.",
     "Upgrade needed" : "Απαιτείται αναβάθμιση",
     "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Το %s θα πρέπει να ρυθμιστεί για να χρησιμοποιεί HTTPS  για την χρήση του CalDAV και του CardDAV με το iOS/macOS.",
@@ -93,7 +90,6 @@ OC.L10N.register(
     "Friday" : "Παρασκευή",
     "Saturday" : "Σάββατο",
     "Sunday" : "Κυριακή",
-    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Ορισμός αυτόματα της κατάστασης χρήστη σε \"Μην ενοχλείτε\" εκτός διαθεσιμότητας για σίγαση όλων των ειδοποιήσεων.",
     "Save" : "Αποθήκευση",
     "Failed to load availability" : "Αποτυχία φόρτωσης της διαθεσιμότητας",
     "Failed to save availability" : "Αποτυχία αποθήκευσης της διαθεσιμότητας",
