@@ -2,7 +2,6 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "Kalendar",
-    "Todos" : "Zadaci",
     "Personal" : "Osobno",
     "{actor} created calendar {calendar}" : "{actor} je stvorio kalendar {calendar}",
     "You created calendar {calendar}" : "Stvorili ste kalendar {calendar}",
@@ -25,6 +24,7 @@ OC.L10N.register(
     "{actor} shared calendar {calendar} with group {group}" : "{actor} dijeli kalendar {calendar} s grupom {group}",
     "You unshared calendar {calendar} from group {group}" : "Više ne dijelite kalendar {calendar} s grupom {group}",
     "{actor} unshared calendar {calendar} from group {group}" : "{actor} više ne dijeli kalendar {calendar} s grupom {group}",
+    "Untitled event" : "Događaj bez naslova",
     "{actor} created event {event} in calendar {calendar}" : "{actor} je stvorio događaj {event} u kalendaru {calendar}",
     "You created event {event} in calendar {calendar}" : "Stvorili ste događaj {event} u kalendaru {calendar}",
     "{actor} deleted event {event} from calendar {calendar}" : "{actor} je izbrisao događaj {event} iz kalendara {calendar}",
@@ -34,27 +34,15 @@ OC.L10N.register(
     "{actor} restored event {event} of calendar {calendar}" : "{actor} je vratio događaj {event} kalendara {calendar}",
     "You restored event {event} of calendar {calendar}" : "Vratili ste događaj {event} kalendara {calendar}",
     "Busy" : "Zauzeto",
-    "{actor} created todo {todo} in list {calendar}" : "{actor} je stvorio zadatak {todo} u popisu {calendar}",
-    "You created todo {todo} in list {calendar}" : "Stvorili ste zadatak {todo} u popisu {calendar}",
-    "{actor} deleted todo {todo} from list {calendar}" : "{actor} je izbrisao zadatak {todo} s popisa {calendar}",
-    "You deleted todo {todo} from list {calendar}" : "Izbrisali ste zadatak {todo} s popisa {calendar}",
-    "{actor} updated todo {todo} in list {calendar}" : "{actor} je ažurirao zadatak {todo} u popisu {calendar}",
-    "You updated todo {todo} in list {calendar}" : "Ažurirali ste zadatak {todo} u popisu {calendar}",
-    "{actor} solved todo {todo} in list {calendar}" : "{actor} je izvršio zadatak {todo} u popisu {calendar}",
-    "You solved todo {todo} in list {calendar}" : "Izvršili ste zadatak {todo} u popisu {calendar}",
-    "{actor} reopened todo {todo} in list {calendar}" : "{actor} je ponovno otvorio zadatak {todo} u popisu {calendar}",
-    "You reopened todo {todo} in list {calendar}" : "Ponovno ste otvorili zadatak {todo} u popisu {calendar}",
     "Calendar, contacts and tasks" : "Kalendar, kontakti i zadaci",
     "A <strong>calendar</strong> was modified" : "Izmijenjen je <strong>kalendar</strong>",
     "A calendar <strong>event</strong> was modified" : "Izmijenjen je <strong>događaj</strong> u kalendaru",
-    "A calendar <strong>todo</strong> was modified" : "Izmijenjen je <strong>zadatak</strong> u kalendaru",
     "Contact birthdays" : "Rođendani kontakata",
     "Death of %s" : "Smrt %s",
     "Calendar:" : "Kalendar:",
     "Date:" : "Datum:",
     "Where:" : "Gdje:",
     "Description:" : "Opis:",
-    "Untitled event" : "Događaj bez naslova",
     "_%n year_::_%n years_" : ["%n godina","%n godina","%n godina"],
     "_%n month_::_%n months_" : ["%n mjesec","%n mjeseci","%n mjeseci"],
     "_%n day_::_%n days_" : ["%n dan","%n dana","%n dana"],
@@ -151,6 +139,18 @@ OC.L10N.register(
     "Tentative" : "Uvjetno",
     "Number of guests" : "Broj gostiju",
     "Comment" : "Komentar",
-    "Your attendance was updated successfully." : "Vaša je prisutnost uspješno ažurirana."
+    "Your attendance was updated successfully." : "Vaša je prisutnost uspješno ažurirana.",
+    "Todos" : "Zadaci",
+    "{actor} created todo {todo} in list {calendar}" : "{actor} je stvorio zadatak {todo} u popisu {calendar}",
+    "You created todo {todo} in list {calendar}" : "Stvorili ste zadatak {todo} u popisu {calendar}",
+    "{actor} deleted todo {todo} from list {calendar}" : "{actor} je izbrisao zadatak {todo} s popisa {calendar}",
+    "You deleted todo {todo} from list {calendar}" : "Izbrisali ste zadatak {todo} s popisa {calendar}",
+    "{actor} updated todo {todo} in list {calendar}" : "{actor} je ažurirao zadatak {todo} u popisu {calendar}",
+    "You updated todo {todo} in list {calendar}" : "Ažurirali ste zadatak {todo} u popisu {calendar}",
+    "{actor} solved todo {todo} in list {calendar}" : "{actor} je izvršio zadatak {todo} u popisu {calendar}",
+    "You solved todo {todo} in list {calendar}" : "Izvršili ste zadatak {todo} u popisu {calendar}",
+    "{actor} reopened todo {todo} in list {calendar}" : "{actor} je ponovno otvorio zadatak {todo} u popisu {calendar}",
+    "You reopened todo {todo} in list {calendar}" : "Ponovno ste otvorili zadatak {todo} u popisu {calendar}",
+    "A calendar <strong>todo</strong> was modified" : "Izmijenjen je <strong>zadatak</strong> u kalendaru"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
