@@ -2,7 +2,6 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "カレンダー",
-    "Todos" : "ToDo",
     "Personal" : "個人",
     "{actor} created calendar {calendar}" : "{actor}はカレンダー {calendar} を作成しました",
     "You created calendar {calendar}" : "カレンダー {calendar} を作成しました",
@@ -25,6 +24,7 @@ OC.L10N.register(
     "{actor} shared calendar {calendar} with group {group}" : " {actor}がカレンダー{calendar} を グループ{group} と共有しました",
     "You unshared calendar {calendar} from group {group}" : "グループ{group}からカレンダー{calendar}の共有を解除しました",
     "{actor} unshared calendar {calendar} from group {group}" : "{actor}がグループ{group}からカレンダー{calendar}の共有を解除しました",
+    "Untitled event" : "無題のイベント",
     "{actor} created event {event} in calendar {calendar}" : "{actor}はカレンダー {calendar} のイベント{event}を作成しました",
     "You created event {event} in calendar {calendar}" : "カレンダー {calendar} のイベント{event}を作成しました",
     "{actor} deleted event {event} from calendar {calendar}" : "{actor}はカレンダー {calendar} のイベント{event}を削除しました",
@@ -34,27 +34,15 @@ OC.L10N.register(
     "{actor} restored event {event} of calendar {calendar}" : "{actor}はカレンダー {calendar}のイベント {event}を復元しました",
     "You restored event {event} of calendar {calendar}" : "カレンダー {calendar} のイベント {event}を復元しました",
     "Busy" : "ビジー",
-    "{actor} created todo {todo} in list {calendar}" : "{actor}はリスト{calendar}のtodo {todo}を作成しました",
-    "You created todo {todo} in list {calendar}" : "リスト {calendar} にtodo {todo} を作成しました",
-    "{actor} deleted todo {todo} from list {calendar}" : "{actor}リスト{カレンダー}からtodo {todo}を削除しました",
-    "You deleted todo {todo} from list {calendar}" : "あなたはtodo {todo}を{calendar}のリストから削除しました。",
-    "{actor} updated todo {todo} in list {calendar}" : "{actor}リスト{calendar}のtodo {todo}を更新しました",
-    "You updated todo {todo} in list {calendar}" : "リスト{calendar}のtodo {todo}を更新しました。",
-    "{actor} solved todo {todo} in list {calendar}" : "{actor}リスト{calendar}のtodo {todo}を解決しました",
-    "You solved todo {todo} in list {calendar}" : "リスト{calendar}のtodo {todo}を解決しました。",
-    "{actor} reopened todo {todo} in list {calendar}" : "{actor}リスト{calendar}のToDo {todo}を再開しました",
-    "You reopened todo {todo} in list {calendar}" : "リスト{calendar}のtodo {todo}を再開しました",
     "Calendar, contacts and tasks" : "カレンダー、連絡帳とタスク",
     "A <strong>calendar</strong> was modified" : "<strong>カレンダー</strong>が変更されたとき",
     "A calendar <strong>event</strong> was modified" : "カレンダーの<strong>イベント</strong>が変更されたとき",
-    "A calendar <strong>todo</strong> was modified" : "カレンダーの<strong>ToDo</strong>が変更されたとき",
     "Contact birthdays" : "誕生日",
     "Death of %s" : "%sの命日",
     "Calendar:" : "カレンダー:",
     "Date:" : "日付:",
     "Where:" : "場所:",
     "Description:" : "説明:",
-    "Untitled event" : "無題のイベント",
     "_%n year_::_%n years_" : ["%n年"],
     "_%n month_::_%n months_" : ["%nヶ月"],
     "_%n day_::_%n days_" : ["%n日"],
@@ -108,6 +96,23 @@ OC.L10N.register(
     "{actor} updated contact {card} in address book {addressbook}" : "{actor}がアドレス帳 {addressbook}の連絡先 {card}を更新しました",
     "You updated contact {card} in address book {addressbook}" : "アドレス帳 {addressbook}の連絡先 {card}を更新しました",
     "A <strong>contact</strong> or <strong>address book</strong> was modified" : "連絡先やアドレス帳が変更されたとき",
+    "File is not updatable: %1$s" : "ファイルが更新できません:%1$s",
+    "Could not write to final file, canceled by hook" : "最終ファイルへの書き込みができなかったため、フックによりキャンセルされた",
+    "Could not write file contents" : "ファイルの内容を書き込むことができませんでした",
+    "_%n byte_::_%n bytes_" : ["%n bytes"],
+    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "ファイルをコピー先へコピー中にエラーが発生しました (コピー済: %1$s, 想定ファイルサイズ: %2$s)",
+    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Nextcloudクライアントからの想定ファイルサイズは、%1$s ですが、Nextcloudストレージへの書き込みファイルサイズは %2$s でした。送信側のネットワークの問題またはサーバー側のストレージへの書き込みに問題がある可能性があります。",
+    "Could not rename part file to final file, canceled by hook" : "最終ファイルの名前の変更が出来なかったため、フックによりキャンセルされました",
+    "Could not rename part file to final file" : "最終ファイルの名前の変更が出来ませんでした",
+    "Failed to check file size: %1$s" : "ファイルサイズの確認に失敗: %1$s",
+    "Could not open file" : "ファイルを開くことができませんでした",
+    "Encryption not ready: %1$s" : "暗号化の準備が出来ていません: %1$s",
+    "Failed to open file: %1$s" : "ファイルを開くのに失敗: %1$s",
+    "Failed to unlink: %1$s" : "リンクの解除に失敗: %1$s",
+    "Invalid chunk name" : "無効なチャンク名",
+    "Could not rename part file assembled from chunks" : "チャンクから構成されている部分ファイルの名前の変更ができませんでした",
+    "Failed to write file contents: %1$s" : "ファイルの内容の書き込みに失敗: %1$s",
+    "File not found: %1$s" : "ファイルが見つかりません: %1$s",
     "System is in maintenance mode." : "システムはメンテナンスモードです。",
     "Upgrade needed" : "アップグレードが必要です",
     "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "iOS / macOSでCalDAVおよびCardDAVを使用するには、%sにHTTPSを設定する必要があります。",
@@ -119,9 +124,18 @@ OC.L10N.register(
     "Completed on %s" : "%sに完了",
     "Due on %s by %s" : "期限日%s が%sにより設定",
     "Due on %s" : "期限日：%s",
+    "Migrated calendar (%1$s)" : "カレンダーを移行しました (%1$s)",
+    "Calendars including events, details and attendees" : "カレンダーには、イベント、イベントの詳細及び出席者が含まれます",
+    "Contacts and groups" : "連絡先とグループ",
     "WebDAV" : "WebDAV",
     "WebDAV endpoint" : "WebDAVエンドポイント",
+    "Availability" : "応対可能日時",
+    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "勤務時間を設定すると、他のユーザが会議を予約する際に、あなたがいつ不在であるかがわかります。",
     "Time zone:" : "時間帯：",
+    "to" : "宛先",
+    "Delete slot" : "スロットを削除",
+    "No working hours set" : "勤務時間未設定",
+    "Add slot" : "スロットを追加",
     "Monday" : "月曜日",
     "Tuesday" : "火曜日",
     "Wednesday" : "水曜日",
@@ -130,6 +144,9 @@ OC.L10N.register(
     "Saturday" : "土曜日",
     "Sunday" : "日曜日",
     "Save" : "保存",
+    "Failed to load availability" : "可用性の読み込みに失敗",
+    "Saved availability" : "可用性を保存しました",
+    "Failed to save availability" : "可用性を保存しました",
     "Calendar server" : "カレンダーサーバー",
     "Send invitations to attendees" : "参加者に招待状を送信する",
     "Automatically generate a birthday calendar" : "自動的に誕生日カレンダーを生成する",
@@ -137,6 +154,8 @@ OC.L10N.register(
     "Hence they will not be available immediately after enabling but will show up after some time." : "したがって、有効にした直後は利用できませんが、しばらくしてから表示されます。",
     "Send notifications for events" : "イベントの通知を送信",
     "Notifications are sent via background jobs, so these must occur often enough." : "通知はバックグラウンドジョブを介して送信されるため、十分な頻度で発生します。",
+    "Send reminder notifications to calendar sharees as well" : "カレンダー共有にもリマインダー通知を送信する",
+    "Reminders are always sent to organizers and attendees." : "リマインダーを常に作成者と出席者に送信します。",
     "Enable notifications for events via push" : "イベントのプッシュ通知を有効にする",
     "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "{calendarappstoreopen}カレンダーアプリ{linkclose}、または{calendardocopen}を同期させるためにデスクトップとモバイルを接続する ↗{linkclose}もインストールしてください。",
     "Please make sure to properly set up {emailopen}the email server{linkclose}." : "{emailopen}メールサーバー{linkclose}を正しく設定してください。",
@@ -144,8 +163,20 @@ OC.L10N.register(
     "Please contact the organizer directly." : "主催者に直接お問い合わせください。",
     "Are you accepting the invitation?" : "招待を受け入れていますか？",
     "Tentative" : "暫定的",
+    "Number of guests" : "ゲスト数",
     "Comment" : "コメント",
     "Your attendance was updated successfully." : "出席は正常に更新されました。",
-    "Calendar and tasks" : "カレンダーとタスク"
+    "Todos" : "ToDo",
+    "{actor} created todo {todo} in list {calendar}" : "{actor}はリスト{calendar}のtodo {todo}を作成しました",
+    "You created todo {todo} in list {calendar}" : "リスト {calendar} にtodo {todo} を作成しました",
+    "{actor} deleted todo {todo} from list {calendar}" : "{actor}リスト{カレンダー}からtodo {todo}を削除しました",
+    "You deleted todo {todo} from list {calendar}" : "あなたはtodo {todo}を{calendar}のリストから削除しました。",
+    "{actor} updated todo {todo} in list {calendar}" : "{actor}リスト{calendar}のtodo {todo}を更新しました",
+    "You updated todo {todo} in list {calendar}" : "リスト{calendar}のtodo {todo}を更新しました。",
+    "{actor} solved todo {todo} in list {calendar}" : "{actor}リスト{calendar}のtodo {todo}を解決しました",
+    "You solved todo {todo} in list {calendar}" : "リスト{calendar}のtodo {todo}を解決しました。",
+    "{actor} reopened todo {todo} in list {calendar}" : "{actor}リスト{calendar}のToDo {todo}を再開しました",
+    "You reopened todo {todo} in list {calendar}" : "リスト{calendar}のtodo {todo}を再開しました",
+    "A calendar <strong>todo</strong> was modified" : "カレンダーの<strong>ToDo</strong>が変更されたとき"
 },
 "nplurals=1; plural=0;");
