@@ -2,7 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "Calendário",
-    "Todos" : "Tarefas",
+    "To-dos" : "Tarefas",
     "Personal" : "Pessoal",
     "{actor} created calendar {calendar}" : "{actor} criou o calendário {calendar}",
     "You created calendar {calendar}" : "Você criou o calendário {calendar}",
@@ -25,41 +25,45 @@ OC.L10N.register(
     "{actor} shared calendar {calendar} with group {group}" : "{actor} compartilhou o calendário {calendar} com o grupo {group}",
     "You unshared calendar {calendar} from group {group}" : "Você descompartilhou o calendário {calendar} do grupo {group}",
     "{actor} unshared calendar {calendar} from group {group}" : "{actor} descompartilhou o calendário {calendar} do grupo {group}",
+    "Untitled event" : "Evento sem título",
     "{actor} created event {event} in calendar {calendar}" : "{actor} criou o evento {event} no calendário {calendar}",
     "You created event {event} in calendar {calendar}" : "Você criou o evento {event} no calendário {calendar}",
     "{actor} deleted event {event} from calendar {calendar}" : "{actor} excluiu o evento {event} do calendário {calendar}",
     "You deleted event {event} from calendar {calendar}" : "Você excluiu o evento {event} do calendário {calendar}",
     "{actor} updated event {event} in calendar {calendar}" : "{actor} atualizou o evento {event} no calendário {calendar}",
     "You updated event {event} in calendar {calendar}" : "Você atualizou o evento {event} no calendário {calendar}",
+    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} moveu o evento {event} do calendario {sourceCalendar} para o calendario {targetCalendar}",
+    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Você moveu o evento {event} do calendario {sourceCalendar} para o calendario {targetCalendar}",
     "{actor} restored event {event} of calendar {calendar}" : "{actor} restaurou o evento {event} do calendário {calendar}",
     "You restored event {event} of calendar {calendar}" : "Você restaurou o evento {event} do calendário {calendar}",
     "Busy" : "Ocupado",
-    "{actor} created todo {todo} in list {calendar}" : "{actor} criou a tarefa {todo} na lista {calendar}",
-    "You created todo {todo} in list {calendar}" : "Você criou a tarefa {todo} na lista {calendar}",
-    "{actor} deleted todo {todo} from list {calendar}" : "{actor} excluiu a tarefa {todo} da lista {calendar}",
-    "You deleted todo {todo} from list {calendar}" : "Você excluiu a tarefa {todo} da lista {calendar}",
-    "{actor} updated todo {todo} in list {calendar}" : "{actor} atualizou a tarefa {todo} na lista {calendar}",
-    "You updated todo {todo} in list {calendar}" : "Você atualizou a tarefa {todo} na lista {calendar}",
-    "{actor} solved todo {todo} in list {calendar}" : "{actor} tarefa resolvida {todo} na lista {calendar}",
-    "You solved todo {todo} in list {calendar}" : "Você terminou a tarefa  {todo} na lista {calendar}",
-    "{actor} reopened todo {todo} in list {calendar}" : "{actor} reabriu tarefa {todo} na lista {calendar}",
-    "You reopened todo {todo} in list {calendar}" : "Você reabriu a terefa {todo} na lista {calendar}",
+    "{actor} created to-do {todo} in list {calendar}" : "{actor} criou tarefa {todo} na lista {calendar}",
+    "You created to-do {todo} in list {calendar}" : "Você criou a tarefa {todo} na lista {calendar}",
+    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} excluiu a tarefa {todo} da lista {calendar}",
+    "You deleted to-do {todo} from list {calendar}" : "Você excluiu a tarefa {todo} da lista {calendar}",
+    "{actor} updated to-do {todo} in list {calendar}" : "{actor} atualizou a tarefa {todo} na lista {calendar}",
+    "You updated to-do {todo} in list {calendar}" : "Você atualizou a tarefa {todo} na lista {calendar}",
+    "{actor} solved to-do {todo} in list {calendar}" : "{actor} resolveu a tarefa {todo} na lista {calendar}",
+    "You solved to-do {todo} in list {calendar}" : "Você resolveu a tarefa {todo} na lista {calendar}",
+    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} reabriu a tarefa {todo} na lista {calendar}",
+    "You reopened to-do {todo} in list {calendar}" : "Você reabriu a tarefa {todo} na lista {calendar}",
+    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} moveu a tarefa {todo} da lista {sourceCalendar} para a lista {targetCalendar}",
+    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Você moveu a tarefa {todo} da lista {sourceCalendar} para a lista {targetCalendar}",
     "Calendar, contacts and tasks" : "Calendário, contatos e tarefas",
     "A <strong>calendar</strong> was modified" : "Um <strong>calendário</strong> foi modificado",
     "A calendar <strong>event</strong> was modified" : "Um <strong>evento</strong> do calendário foi modificado",
-    "A calendar <strong>todo</strong> was modified" : "Uma <strong>tarefa</strong> do calendário foi modificada",
+    "A calendar <strong>to-do</strong> was modified" : "Um calendário <strong>tarefa</strong> foi modificado",
     "Contact birthdays" : "Aniversário dos contatos",
     "Death of %s" : "Morte de %s",
     "Calendar:" : "Calendário:",
     "Date:" : "Data:",
     "Where:" : "Onde:",
     "Description:" : "Descrição:",
-    "Untitled event" : "Evento sem título",
-    "_%n year_::_%n years_" : ["%n ano","%n anos"],
-    "_%n month_::_%n months_" : ["%n mês","%n meses"],
-    "_%n day_::_%n days_" : ["%n dia","%n dias"],
-    "_%n hour_::_%n hours_" : ["%n hora","%n horas"],
-    "_%n minute_::_%n minutes_" : ["%n minuto","%n minutos"],
+    "_%n year_::_%n years_" : ["%n ano","%n anos","%n anos"],
+    "_%n month_::_%n months_" : ["%n mês","%n meses","%n meses"],
+    "_%n day_::_%n days_" : ["%n dia","%n dias","%n dias"],
+    "_%n hour_::_%n hours_" : ["%n hora","%n horas","%n horas"],
+    "_%n minute_::_%n minutes_" : ["%n minuto","%n minutos","%n minutos"],
     "%s (in %s)" : "%s (em %s)",
     "%s (%s ago)" : "%s (%s atrás)",
     "Calendar: %s" : "Calendário: %s",
@@ -111,7 +115,7 @@ OC.L10N.register(
     "File is not updatable: %1$s" : "O arquivo não é atualizável: %1$s",
     "Could not write to final file, canceled by hook" : "Não foi possível gravar no arquivo final, cancelado pelo gancho",
     "Could not write file contents" : "Não foi possível gravar o conteúdo do arquivo",
-    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
+    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
     "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Erro ao copiar o arquivo para o local de destino (copiado: %1$s, tamanho de arquivo esperado: %2$s)",
     "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Tamanho de arquivo esperado de %1$s mas lido (do cliente Nextcloud) e gravado (no armazenamento Nextcloud) %2$s. Pode ser um problema de rede no lado de envio ou um problema de gravação no armazenamento no lado do servidor.",
     "Could not rename part file to final file, canceled by hook" : "Não foi possível renomear o arquivo de parte para o arquivo final, cancelado pelo gancho",
@@ -155,7 +159,11 @@ OC.L10N.register(
     "Friday" : "Sexta-feira",
     "Saturday" : "Sábado ",
     "Sunday" : "Domingo",
+    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Defina automaticamente o status do usuário como \"Não perturbe\" fora de disponibilidade para silenciar todas as notificações.",
     "Save" : "Salvar",
+    "Failed to load availability" : "Falha ao carregar a disponibilidade",
+    "Saved availability" : "Disponibilidade salva",
+    "Failed to save availability" : "Falha ao salvar a disponibilidade",
     "Calendar server" : "Servidor de calendário",
     "Send invitations to attendees" : "Enviar convites aos participantes",
     "Automatically generate a birthday calendar" : "Gerar um calendário de aniversários automaticamente",
@@ -174,6 +182,18 @@ OC.L10N.register(
     "Tentative" : "Tentativa",
     "Number of guests" : "Número de convidados",
     "Comment" : "Comentário",
-    "Your attendance was updated successfully." : "Sua presença foi atualizada com sucesso."
+    "Your attendance was updated successfully." : "Sua presença foi atualizada com sucesso.",
+    "Todos" : "Tarefas",
+    "{actor} created todo {todo} in list {calendar}" : "{actor} criou a tarefa {todo} na lista {calendar}",
+    "You created todo {todo} in list {calendar}" : "Você criou a tarefa {todo} na lista {calendar}",
+    "{actor} deleted todo {todo} from list {calendar}" : "{actor} excluiu a tarefa {todo} da lista {calendar}",
+    "You deleted todo {todo} from list {calendar}" : "Você excluiu a tarefa {todo} da lista {calendar}",
+    "{actor} updated todo {todo} in list {calendar}" : "{actor} atualizou a tarefa {todo} na lista {calendar}",
+    "You updated todo {todo} in list {calendar}" : "Você atualizou a tarefa {todo} na lista {calendar}",
+    "{actor} solved todo {todo} in list {calendar}" : "{actor} tarefa resolvida {todo} na lista {calendar}",
+    "You solved todo {todo} in list {calendar}" : "Você terminou a tarefa  {todo} na lista {calendar}",
+    "{actor} reopened todo {todo} in list {calendar}" : "{actor} reabriu tarefa {todo} na lista {calendar}",
+    "You reopened todo {todo} in list {calendar}" : "Você reabriu a terefa {todo} na lista {calendar}",
+    "A calendar <strong>todo</strong> was modified" : "Uma <strong>tarefa</strong> do calendário foi modificada"
 },
-"nplurals=2; plural=(n > 1);");
+"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
