@@ -165,7 +165,7 @@ class SharesPlugin extends \Sabre\DAV\ServerPlugin {
 			// if we already cached the folder this file is in we know there are no shares for this file
 			if (array_search($parentPath, $this->cachedFolders) === false) {
 				try {
-					$node = $this->userFolder->get($sabreNode->getPath());
+					$node = $sabreNode->getNode();
 				} catch (NotFoundException $e) {
 					return [];
 				}
@@ -201,18 +201,7 @@ class SharesPlugin extends \Sabre\DAV\ServerPlugin {
 				!is_null($propFind->getStatus(self::SHAREES_PROPERTYNAME))
 			)
 		) {
-			try {
-				$folderNode = $this->userFolder->get($sabreNode->getPath());
-			} catch (NotFoundException $e) {
-				// If the folder can't be properly found just return
-				return;
-			}
-
-			if (!($folderNode instanceof Folder)) {
-				// Safety check
-				return;
-			}
-
+			$folderNode = $sabreNode->getNode();
 			$this->cachedFolders[] = $sabreNode->getPath();
 			$childShares = $this->getSharesFolder($folderNode);
 			foreach ($childShares as $id => $shares) {
