@@ -5,7 +5,7 @@ OC.L10N.register(
     "Please repeat the recovery key password" : "Введіть ще раз пароль для ключа відновлення",
     "Repeated recovery key password does not match the provided recovery key password" : "Введені паролі ключа відновлення не співпадають",
     "Recovery key successfully enabled" : "Ключ відновлення підключено",
-    "Could not enable recovery key. Please check your recovery key password!" : "Не вдалося застосувати ключ відновлення. Будь ласка, перевірте пароль ключа відновлення!",
+    "Could not enable recovery key. Please check your recovery key password!" : "Не вдалося підключити ключ відновлення. Будь ласка, перевірте пароль свого ключа відновлення!",
     "Recovery key successfully disabled" : "Ключ відновлення відключено",
     "Could not disable recovery key. Please check your recovery key password!" : "Не вдалося відключити ключ відновлення. Будь ласка, перевірте пароль ключа відновлення!",
     "Missing parameters" : "Відсутні параметри",
@@ -16,26 +16,22 @@ OC.L10N.register(
     "Could not change the password. Maybe the old password was not correct." : "Не вдалося змінити пароль. Можливо ви неправильно ввели старий пароль.",
     "Recovery Key disabled" : "Ключ відновлення відключений",
     "Recovery Key enabled" : "Відновлення ключа увімкнено",
-    "Could not enable the recovery key, please try again or contact your administrator" : "Не вдалося застосувати ключ відновлення, будь ласка, перевірте пароль ключа відновлення або сконтактуйте з адміністратором!",
+    "Could not enable the recovery key, please try again or contact your administrator" : "Не вдалося підключити ключ відновлення, будь ласка, перевірте пароль ключа відновлення!",
     "Could not update the private key password." : "Не вдалося оновити пароль секретного ключа.",
     "The old password was not correct, please try again." : "Старий пароль введено не вірно, спробуйте ще раз.",
     "The current log-in password was not correct, please try again." : "Невірний пароль входу, будь ласка, спробуйте ще раз.",
     "Private key password successfully updated." : "Пароль секретного ключа оновлено.",
     "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Недійсний закритий ключ для програми шифрування. Щоб відновити доступ до зашифрованих файлів, оновіть пароль приватного ключа в особистих налаштуваннях.",
-    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Застосунок шифрування увімкнено, але ваші ключі не ініціалізовано. Будь ласка, вийдіть з системи та увійдіть знову. ",
-    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Для використання модуля шифрування, будь ласка, увімкніть шифрування на стороні сервера в налаштуваннях адміністратора.",
     "Encryption app is enabled and ready" : "Програма для шифрування ввімкнена та готова",
     "Bad Signature" : "Погана сиґнатура",
     "Missing Signature" : "Відсутній підпис",
     "one-time password for server-side-encryption" : "одноразовий пароль для шифрування на сервері",
-    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Не вдається розшифрувати цей файл, ймовірно, він знаходиться у спільному доступі. Будь ласка, зверніться до власника файлу з проханням надати вам доступ до нього.",
-    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Не вдається прочитати цей файл, ймовірно, це файл із загальним доступом. Будь ласка, попросіть власника файлу надати вам спільний доступ до нього. ",
     "Default encryption module" : "Типовий модуль шифрування",
     "Default encryption module for server-side encryption" : "Типовий модуль шифрування для шифрування на стороні сервера",
     "The share will expire on %s." : "Спільний доступ закінчиться %s.",
     "Cheers!" : "Будьмо!",
     "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Програму для шифрування ввімкнено, але ваші ключі не ініціалізовано. Будь ласка, вийдіть із системи та увійдіть знову",
-    "Encrypt the home storage" : "Зашифрувати домашній каталог",
+    "Encrypt the home storage" : "Зашифрувати домашню теку",
     "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Увімкнення цього параметра шифрує всі файли, що зберігаються в основній пам’яті, інакше будуть зашифровані лише файли на зовнішній пам’яті",
     "Enable recovery key" : "Увімкнути ключ відновлення",
     "Disable recovery key" : "Вимкнути ключ відновлення",
