@@ -6,11 +6,6 @@ OC.L10N.register(
     "Remote share password" : "Fjerndrev adgangskode",
     "Cancel" : "Annuller",
     "Add remote share" : "Tilføj ekstern deling",
-    "Copy" : "Kopiér",
-    "Copied!" : "Kopieret!",
-    "Not supported!" : "Ikke understøttet!",
-    "Press ⌘-C to copy." : "Tryk ⌘-C for kopiering.",
-    "Press Ctrl-C to copy." : "Tryk Ctrl-C for at kopiere.",
     "Invalid Federated Cloud ID" : "Ugyldigt Federated Cloud ID",
     "Server to server sharing is not enabled on this server" : "Server til serverdeling er ikke slået til på denne server",
     "Couldn't establish a federated share." : "Kunne ikke skabe forbindelse til føderal deling ",
@@ -45,13 +40,20 @@ OC.L10N.register(
     "Search global and public address book for users" : "Søg global og offentlig adresse bog for brugere",
     "Allow users to publish their data to a global and public address book" : "Tillad brugere at offentliggøre deres data til en global adressebog ",
     "Federated Cloud" : "Federated Cloud",
-    "Open documentation" : "Åbn dokumentation",
     "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Du kan dele med alle, der bruger en Nextcloud-server eller andre Open Cloud Mesh (OCM)-kompatible servere og tjenester! Indsæt blot deres Federated Cloud ID i delingsdialogen. Det ligner person@cloud.example.com",
     "Your Federated Cloud ID:" : "Din Federated Cloud ID:",
     "Share it so your friends can share files with you:" : "Del så dine venner kan dele filer med dig:",
+    "Twitter" : "Twitter",
     "Add to your website" : "Tilføj til dit websted",
     "Share with me via Nextcloud" : "Del med mig gennem Nextcloud",
     "HTML Code:" : "HTMLkode:",
+    "Copy to clipboard" : "Kopier til udklipsholder",
+    "Copy" : "Kopiér",
+    "Copied!" : "Kopieret!",
+    "Not supported!" : "Ikke understøttet!",
+    "Press ⌘-C to copy." : "Tryk ⌘-C for kopiering.",
+    "Press Ctrl-C to copy." : "Tryk Ctrl-C for at kopiere.",
+    "Open documentation" : "Åbn dokumentation",
     "Adjust how people can share between servers." : "Juster hvordan folk kan dele mellem servere."
 },
 "nplurals=2; plural=(n != 1);");
