@@ -6,11 +6,6 @@ OC.L10N.register(
     "Remote share password" : "Passwort für die externe Freigabe",
     "Cancel" : "Abbrechen",
     "Add remote share" : "Externe Freigabe hinzufügen",
-    "Copy" : "Kopieren",
-    "Copied!" : "Kopiert!",
-    "Not supported!" : "Nicht unterstützt!",
-    "Press ⌘-C to copy." : "⌘-C zum Kopieren drücken.",
-    "Press Ctrl-C to copy." : "Zum Kopieren Strg-C drücken.",
     "Invalid Federated Cloud ID" : "Ungültige Federated-Cloud-ID",
     "Server to server sharing is not enabled on this server" : "Das Server-zu-Server-Teilen ist auf diesem Server nicht aktiviert",
     "Couldn't establish a federated share." : "Federated-Share konnte nicht aufgebaut werden",
@@ -46,13 +41,25 @@ OC.L10N.register(
     "Allow users to publish their data to a global and public address book" : "Erlaube Benutzern, ihre Daten in einem globalen und öffentlichen Adressbuch zu veröffentlichen",
     "Unable to update federated files sharing config" : "Einstellungen zum Federated-Teilen konnten nicht aktualisiert werden",
     "Federated Cloud" : "Federated Cloud",
-    "Open documentation" : "Dokumentation öffnen",
     "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Sie können mit jedem teilen, der einen Nextcloud-Server oder andere Open Cloud Mesh (OCM) kompatible Server und Dienste verwendet! Geben Sie einfach deren Federated-Cloud-ID in den Teilen-Dialog ein. Diese sieht wie folgt aus: person@cloud.example.com",
     "Your Federated Cloud ID:" : "Ihre Federated-Cloud-ID:",
     "Share it so your friends can share files with you:" : "Teilen Sie es, so dass Ihre Freunde Dateien mit Ihnen teilen können:",
+    "Facebook" : "Facebook",
+    "Twitter" : "Twitter",
+    "Diaspora" : "Diaspora",
     "Add to your website" : "Zu Ihrer Webseite hinzufügen",
     "Share with me via Nextcloud" : "Teilen Sie mit mir über Nextcloud",
     "HTML Code:" : "HTML-Code:",
+    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Teilen Sie mit mir über meine #Nextcloud Federated-Cloud-ID, siehe {url}",
+    "Cloud ID copied to the clipboard" : "Cloud-ID wurde in die Zwischenablage kopiert",
+    "Copy to clipboard" : "In die Zwischenablage kopieren",
+    "Clipboard is not available" : "Zwischenablage ist nicht verfügbar",
+    "Copy" : "Kopieren",
+    "Copied!" : "Kopiert!",
+    "Not supported!" : "Nicht unterstützt!",
+    "Press ⌘-C to copy." : "⌘-C zum Kopieren drücken.",
+    "Press Ctrl-C to copy." : "Zum Kopieren Strg-C drücken.",
+    "Open documentation" : "Dokumentation öffnen",
     "Adjust how people can share between servers." : "Definiere wie die Benutzer Inhalte mit anderen Servern teilen können."
 },
 "nplurals=2; plural=(n != 1);");
