@@ -6,11 +6,6 @@ OC.L10N.register(
     "Remote share password" : "Συνθηματικό απομακρυσμένου κοινόχρηστου φακέλου",
     "Cancel" : "Άκυρο",
     "Add remote share" : "Προσθήκη απομακρυσμένου κοινόχρηστου φακέλου",
-    "Copy" : "Αντιγραφή",
-    "Copied!" : "Αντιγράφτηκε!",
-    "Not supported!" : "Δεν υποστηρίζεται!",
-    "Press ⌘-C to copy." : "Για αντιγραφή πατήστε ⌘-C.",
-    "Press Ctrl-C to copy." : "Για αντιγραφή πατήστε Ctrl-C.",
     "Invalid Federated Cloud ID" : "Μη έγκυρο Federated Cloud ID",
     "Server to server sharing is not enabled on this server" : "Ο διαμοιρασμός μεταξύ διακομιστών δεν έχει ενεργοποιηθεί σε αυτόν το διακομιστή",
     "Couldn't establish a federated share." : "Αδυναμία επίτευξης ομόσπονδου κοινόχρηστου φακέλου",
@@ -43,13 +38,20 @@ OC.L10N.register(
     "Search global and public address book for users" : "Αναζήτηση σε γενικό και δημόσιο βιβλίο διευθύνσεων για χρήστες",
     "Allow users to publish their data to a global and public address book" : "Επιτρέψτε στους χρήστες να δημοσιεύουν τα δεδομένα τους σε ένα γενικό και δημόσιο βιβλίο διευθύνσεων",
     "Federated Cloud" : "Federated Cloud",
-    "Open documentation" : "Άνοιγμα τεκμηρίωσης",
     "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Μπορείτε να διαμοιράζεστε με οποιονδήποτε χρησιμοποιεί Nextcloud ή άλλο συμβατό διακομιστή και υπηρεσιών Open Cloud Mesh (OCM)! Απλά προσθέστε το Federated Cloud ID στο πλαίσιο διαλόγου διαμοιρασμού. Θα μοιάζει με person@cloud.example.com",
     "Your Federated Cloud ID:" : "Το ID σας στο Federated Cloud:",
     "Share it so your friends can share files with you:" : "Διαμοιραστείτε το ώστε οι φίλοι σας να μπορούν να διαμοιράζονται αρχεία με εσάς:",
+    "Twitter" : "Twitter",
     "Add to your website" : "Προσθήκη στην ιστοσελίδα σας",
     "Share with me via Nextcloud" : "Διαμοιραστείτε με εμένα μέσω του Nextcloud",
     "HTML Code:" : "Κώδικας HTML:",
+    "Copy to clipboard" : "Αντιγραφή στο πρόχειρο",
+    "Copy" : "Αντιγραφή",
+    "Copied!" : "Αντιγράφτηκε!",
+    "Not supported!" : "Δεν υποστηρίζεται!",
+    "Press ⌘-C to copy." : "Για αντιγραφή πατήστε ⌘-C.",
+    "Press Ctrl-C to copy." : "Για αντιγραφή πατήστε Ctrl-C.",
+    "Open documentation" : "Άνοιγμα τεκμηρίωσης",
     "Adjust how people can share between servers." : "Προσαρμόστε το πως τα άτομα θα διαμοιράζονται μεταξύ των διακομιστών"
 },
 "nplurals=2; plural=(n != 1);");
