@@ -27,8 +27,8 @@ OC.L10N.register(
     "Accept" : "Accepter",
     "Decline" : "Refuser",
     "Federated Cloud Sharing" : "Partage Cloud Fédéré",
-    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Partagez avec moi grâce à mon ID de Cloud Fédéré #Nextcloud %s",
-    "Share with me through my #Nextcloud Federated Cloud ID" : "Partagez avec moi grâce à mon ID de Cloud Fédéré #Nextcloud",
+    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Partagez avec moi grâce à mon identifiant de Cloud Fédéré #Nextcloud %s",
+    "Share with me through my #Nextcloud Federated Cloud ID" : "Partagez avec moi grâce à mon identifiant de Cloud Fédéré #Nextcloud",
     "Sharing" : "Partage",
     "Federated file sharing" : "Partage de fichiers fédéré",
     "Provide federated file sharing across servers" : "Fourni un partage de fichiers fédéré entre plusieurs serveurs",
@@ -39,26 +39,21 @@ OC.L10N.register(
     "Allow users on this server to receive group shares from other servers" : "Autoriser les utilisateurs de ce serveur à recevoir des partages de groupe depuis d'autres serveurs",
     "Search global and public address book for users" : "Rechercher dans le carnet d'adresse global et public pour les utilisateurs",
     "Allow users to publish their data to a global and public address book" : "Autoriser les utilisateurs à publier leurs données dans un carnet d'adresse global et public",
-    "Unable to update federated files sharing config" : "Impossible de mettre à jour la configuration du partage fédéré de fichiers ",
     "Federated Cloud" : "Cloud Fédéré",
-    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Vous pouvez partager avec quiconque utilise un serveur Nextcloud ou un serveur ou service compatible Open Cloud Mesh (OCM). Renseignez simplement son ID de Cloud Fédéré sur une instance fédérée dans la boîte de dialogue de partage. Cela ressemble à utilisateur@cloud.exemple.com.",
-    "Your Federated Cloud ID:" : "Votre ID de Cloud Fédéré :",
+    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Vous pouvez partager avec quiconque utilise un serveur Nextcloud ou un serveur ou service compatible Open Cloud Mesh (OCM). Renseignez simplement son identifiant sur une instance fédérée dans la boîte de dialogue de partage. Cela prend la forme de utilisateur@cloud.exemple.com.",
+    "Your Federated Cloud ID:" : "Votre identifiant de Cloud Fédéré :",
     "Share it so your friends can share files with you:" : "Partagez-le afin que vos amis puissent partager des fichiers avec vous :",
-    "Facebook" : "Facebook",
     "Twitter" : "Twitter",
-    "Diaspora" : "Diaspora",
     "Add to your website" : "Ajouter à votre site web",
     "Share with me via Nextcloud" : "Partagez avec moi via Nextcloud",
     "HTML Code:" : "Code HTML :",
-    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Partagez avec moi grâce à mon ID de Cloud Fédéré #Nextcloud, voir {url}.",
-    "Cloud ID copied to the clipboard" : "ID de Cloud Fédéré copié dans le presse-papiers",
     "Copy to clipboard" : "Copier dans le presse-papiers",
-    "Clipboard is not available" : "Le presse-papiers n'est pas disponible",
     "Copy" : "Copier",
     "Copied!" : "Copié !",
     "Not supported!" : "Non supporté!",
     "Press ⌘-C to copy." : "Appuyez sur ⌘-C pour copier.",
     "Press Ctrl-C to copy." : "Appuyez sur Ctrl-C pour copier.",
-    "Open documentation" : "Voir la documentation"
+    "Open documentation" : "Voir la documentation",
+    "Adjust how people can share between servers." : "Réglez comment les personnes peuvent partager entre les serveurs."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
