@@ -6,11 +6,6 @@ OC.L10N.register(
     "Remote share password" : "დისტანციური გაზიარების პაროლი",
     "Cancel" : "გაუქმება",
     "Add remote share" : "დისტანციური გაზიარების დამატება",
-    "Copy" : "კოპირება",
-    "Copied!" : "კოპირებულია!",
-    "Not supported!" : "არაა მხარდაჭერილი!",
-    "Press ⌘-C to copy." : "კოპირებისთვის დააჭირეთ ⌘-C.",
-    "Press Ctrl-C to copy." : "კოპირებისთვის დააჭირეთ Ctrl-C-ს.",
     "Invalid Federated Cloud ID" : "არასწორი ფედერალური ქლაუდ ID",
     "Server to server sharing is not enabled on this server" : "ამ სერვერზე სერვერიდან სერვერზე გაზიარება არაა ჩართული",
     "Couldn't establish a federated share." : "ფედერალური გაზიარება ვერ დამყარდა.",
@@ -33,12 +28,19 @@ OC.L10N.register(
     "Search global and public address book for users" : "მოძებნეთ გლობალური და ღია მომხმარებლების მისამართების წიგნები",
     "Allow users to publish their data to a global and public address book" : "დართეთ ნება მომხმარებლებს გამოაქყვეყნონ მათი მონაცემები გლობალურ და საზოგადო მისამართების წიგნებში",
     "Federated Cloud" : "ფედერალური ქლაუდი",
-    "Open documentation" : "ღია დოკუმენტაცია",
     "Your Federated Cloud ID:" : "თქვენი ფედერალური ქლაუდ ID:",
     "Share it so your friends can share files with you:" : "გააზიარეთ, რომ თქვენმა მეგობრებმაც შეძლონ ფაილების გაზიარება თქვენთან:",
+    "Twitter" : "Twitter-ი",
     "Add to your website" : "საიტზე დამატება",
     "Share with me via Nextcloud" : "გამიზიარე Nextcloud-ის მეშვეობით",
     "HTML Code:" : "HTML კოდი:",
+    "Copy to clipboard" : "კოპირება ბუფერში",
+    "Copy" : "კოპირება",
+    "Copied!" : "კოპირებულია!",
+    "Not supported!" : "არაა მხარდაჭერილი!",
+    "Press ⌘-C to copy." : "კოპირებისთვის დააჭირეთ ⌘-C.",
+    "Press Ctrl-C to copy." : "კოპირებისთვის დააჭირეთ Ctrl-C-ს.",
+    "Open documentation" : "ღია დოკუმენტაცია",
     "Adjust how people can share between servers." : "განაგეთ თუ როგორ შეუძლიათ ადამიანებს სერვერებს შორის მოახდინონ გაზიარება."
 },
 "nplurals=2; plural=(n!=1);");
