@@ -6,11 +6,6 @@ OC.L10N.register(
     "Remote share password" : "Nuotolinio viešinio slaptažodis",
     "Cancel" : "Atsisakyti",
     "Add remote share" : "Pridėti nuotolinį viešinį",
-    "Copy" : "Kopijuoti",
-    "Copied!" : "Nukopijuota!",
-    "Not supported!" : "Nepalaikoma!",
-    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
-    "Press Ctrl-C to copy." : "Paspauskite Vald-C, norėdami nukopijuoti.",
     "Invalid Federated Cloud ID" : "Neteisingas federacinės debesijos ID",
     "Server to server sharing is not enabled on this server" : "Dalinimasis tarp serverių yra neleidžiamas šiame serveryje",
     "Couldn't establish a federated share." : "Nepavyko užmegzti federacinio viešinio.",
@@ -31,7 +26,6 @@ OC.L10N.register(
     "Share with me through my #Nextcloud Federated Cloud ID" : "Bendrinti su manimi per mano #Nextcloud federacinės debesijos ID",
     "Sharing" : "Duomenų bendrinimas",
     "Federated file sharing" : "Federacinis failų bendrinimas",
-    "Open documentation" : "Atverti dokumentaciją",
     "Allow users on this server to receive shares from other servers" : "Leisti naudotojams šiame serveryje gauti viešinius iš kitų serverių",
     "Allow users on this server to send shares to groups on other servers" : "Leisti naudotojams šiame serveryje siųsti viešinius į grupes kituose serveriuose",
     "Allow users on this server to receive group shares from other servers" : "Leisti naudotojams šiame serveryje gauti grupių viešinius iš kitų serverių",
@@ -40,7 +34,15 @@ OC.L10N.register(
     "Federated Cloud" : "Federacinė debesija",
     "Your Federated Cloud ID:" : "Jūsų federacinės debesijos ID:",
     "Share it so your friends can share files with you:" : "Pasidalinkite juo, kad jūsų draugai galėtų bendrinti failus kartu su jumis:",
+    "Twitter" : "Twitter",
     "HTML Code:" : "HTML kodas:",
+    "Copy to clipboard" : "Kopijuoti į iškarpinę",
+    "Copy" : "Kopijuoti",
+    "Copied!" : "Nukopijuota!",
+    "Not supported!" : "Nepalaikoma!",
+    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
+    "Press Ctrl-C to copy." : "Paspauskite Vald-C, norėdami nukopijuoti.",
+    "Open documentation" : "Atverti dokumentaciją",
     "Adjust how people can share between servers." : "Derinkite kaip žmonės gali bendrinti tarp serverių."
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
