@@ -6,11 +6,6 @@ OC.L10N.register(
     "Remote share password" : "远程共享密码",
     "Cancel" : "取消",
     "Add remote share" : "添加远程共享",
-    "Copy" : "复制",
-    "Copied!" : "已复制！",
-    "Not supported!" : "不支持！",
-    "Press ⌘-C to copy." : "请按 ⌘-C 键复制",
-    "Press Ctrl-C to copy." : "请按 Ctrl-C 键复制",
     "Invalid Federated Cloud ID" : "联合云 ID 不正确",
     "Server to server sharing is not enabled on this server" : "此服务器未启用服务器到服务器共享功能",
     "Couldn't establish a federated share." : "无法建立一个联合云共享",
@@ -45,13 +40,20 @@ OC.L10N.register(
     "Search global and public address book for users" : "在全局和公开地址簿中寻找用户",
     "Allow users to publish their data to a global and public address book" : "允许用户将其数据发布到全球和公共通讯录",
     "Federated Cloud" : "联合云",
-    "Open documentation" : "打开文档",
     "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "您可以和使用了 Nextcloud 服务器或其他兼容 Open Cloud Mesh（OCM）的服务器和服务的任何人共享！只需将他们的联合云 ID 放在共享对话框中。联合云 ID 看起来像 person@cloud.example.com",
     "Your Federated Cloud ID:" : "您的联合云 ID：",
     "Share it so your friends can share files with you:" : "使用共享，以便您的朋友可以与您共享文件：",
+    "Twitter" : "推特",
     "Add to your website" : "添加到您的网站",
     "Share with me via Nextcloud" : "通过联合云与我共享",
     "HTML Code:" : "HTML 代码：",
+    "Copy to clipboard" : "复制到剪贴板",
+    "Copy" : "复制",
+    "Copied!" : "已复制！",
+    "Not supported!" : "不支持！",
+    "Press ⌘-C to copy." : "请按 ⌘-C 键复制",
+    "Press Ctrl-C to copy." : "请按 Ctrl-C 键复制",
+    "Open documentation" : "打开文档",
     "Adjust how people can share between servers." : "调整人们如何在服务器之间共享。"
 },
 "nplurals=1; plural=0;");
