@@ -29,7 +29,6 @@ use OC\OCS\DiscoveryService;
 use OCA\DAV\CardDAV\SyncService;
 use OCP\AppFramework\Http;
 use OCP\OCS\IDiscoveryService;
-use Psr\Log\LoggerInterface;
 
 class SyncFederationAddressBooks {
 
@@ -42,18 +41,18 @@ class SyncFederationAddressBooks {
 	/** @var  DiscoveryService */
 	private $ocsDiscoveryService;
 
-	/** @var LoggerInterface */
-	private $logger;
-
+	/**
+	 * @param DbHandler $dbHandler
+	 * @param SyncService $syncService
+	 * @param IDiscoveryService $ocsDiscoveryService
+	 */
 	public function __construct(DbHandler $dbHandler,
 								SyncService $syncService,
-								IDiscoveryService $ocsDiscoveryService,
-								LoggerInterface $logger
+								IDiscoveryService $ocsDiscoveryService
 	) {
 		$this->syncService = $syncService;
 		$this->dbHandler = $dbHandler;
 		$this->ocsDiscoveryService = $ocsDiscoveryService;
-		$this->logger = $logger;
 	}
 
 	/**
@@ -72,7 +71,6 @@ class SyncFederationAddressBooks {
 			$addressBookUrl = isset($endPoints['system-address-book']) ? trim($endPoints['system-address-book'], '/') : 'remote.php/dav/addressbooks/system/system/system';
 
 			if (is_null($sharedSecret)) {
-				$this->logger->error('Shared secret is null');
 				continue;
 			}
 			$targetBookId = $trustedServer['url_hash'];
@@ -84,16 +82,10 @@ class SyncFederationAddressBooks {
 				$newToken = $this->syncService->syncRemoteAddressBook($url, $cardDavUser, $addressBookUrl, $sharedSecret, $syncToken, $targetBookId, $targetPrincipal, $targetBookProperties);
 				if ($newToken !== $syncToken) {
 					$this->dbHandler->setServerStatus($url, TrustedServers::STATUS_OK, $newToken);
-				} else {
-					$this->logger->info('Token unchanged from previous sync.');
 				}
 			} catch (\Exception $ex) {
 				if ($ex->getCode() === Http::STATUS_UNAUTHORIZED) {
 					$this->dbHandler->setServerStatus($url, TrustedServers::STATUS_ACCESS_REVOKED);
-					$this->logger->error('Server sync failed because of revoked access.');
-				} else {
-					$this->dbHandler->setServerStatus($url, TrustedServers::STATUS_FAILURE);
-					$this->logger->error('Server sync failed.');
 				}
 				$callback($url, $ex);
 			}
