@@ -8,9 +8,6 @@ OC.L10N.register(
     "Move or copy" : "Премести или копирай",
     "Download" : "Изтегли",
     "Delete" : "Изтрий",
-    "Tags" : "Етикети",
-    "Show list view" : "Показване с изглед на списък",
-    "Show grid view" : "Показване в решетъчен изглед",
     "Home" : "Домашен",
     "Close" : "Затвори",
     "Favorites" : "Любими",
@@ -36,7 +33,6 @@ OC.L10N.register(
     "Move" : "Преместване",
     "Copy" : "Копирай",
     "Choose target folder" : "Избор на папка",
-    "Edit locally" : "Локално редактиране",
     "Open" : "Отвори",
     "Delete file" : "Изтриване на файл",
     "Delete folder" : "Изтриване на папка",
@@ -45,6 +41,8 @@ OC.L10N.register(
     "Could not load info for file \"{file}\"" : "Информацията за файла \"{file}\" не може да бъде заредена",
     "Files" : "Файлове",
     "Details" : "Подробности",
+    "Show list view" : "Показване с изглед на списък",
+    "Show grid view" : "Показване в решетъчен изглед",
     "Please select tag(s) to add to the selection" : "Моля, изберете етикет(и), който да добавите към селекцията",
     "Apply tag(s) to selection" : "Прилагане на етикет(и) към селекцията",
     "Select directory \"{dirName}\"" : "Избор на директория „{dirName}“",
@@ -60,7 +58,6 @@ OC.L10N.register(
     "Could not copy \"{file}\"" : "Файлът \"{file}\" не може да бъде копиран",
     "Copied {origin} inside {destination}" : "Копирано {origin} в {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Копирано {origin} и {nbfiles} други файлове в {destination}",
-    "Failed to redirect to client" : "Неуспешно пренасочване към клиент",
     "{newName} already exists" : "{newName} вече съществува",
     "Could not rename \"{fileName}\", it does not exist any more" : "Файлът \"{fileName}\" не може да бъде преименуван защото не съществува",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Името \"{targetName}\" се ползва в директорията \"{dir}\". Моля, изберете друго име.",
@@ -180,6 +177,7 @@ OC.L10N.register(
     "Invalid path selected" : "Предоставен е невалиден път до файл.",
     "Ownership transfer request sent" : "Изпратена заявка за прехвърляне на собствеността",
     "Cannot transfer ownership of a file or folder you do not own" : "Не можете да прехвърляте собственост върху файл или папка, които не притежавате",
+    "Tags" : "Етикети",
     "Unable to change the favourite state of the file" : "Не може да се промени състоянието за предпочитане на файла",
     "Error while loading the file data" : "Грешка при зареждането на файловете.",
     "Pick a template for {name}" : "Избор на шаблон за {name}",
@@ -223,6 +221,7 @@ OC.L10N.register(
     "You don’t have permission to upload or create files here" : "Нямаш разрешение да създаваш или качваш файлове тук.",
     "New" : "Създай",
     "Cannot transfer ownership of a file or folder you don't own" : "Не можете да прехвърляте собственост върху файл или папка, които не притежавате",
+    "%s%% of %s used" : "%s%% от %s използвани",
     "Settings" : "Настройки"
 },
 "nplurals=2; plural=(n != 1);");
