@@ -8,24 +8,20 @@ OC.L10N.register(
     "Move or copy" : "Mou o copia",
     "Download" : "Baixa",
     "Delete" : "Suprimeix",
-    "Tags" : "Etiquetes",
-    "Show list view" : "Mostra en vista de llista",
-    "Show grid view" : "Mostra en vista de graella",
     "Home" : "Inici",
     "Close" : "Tanca",
     "Favorites" : "Preferits",
     "Could not create folder \"{dir}\"" : "No s'ha pogut crear la carpeta «{dir}»",
     "This will stop your current uploads." : "Això aturarà les pujades actuals.",
     "Upload cancelled." : "S'ha cancel·lat la pujada.",
-    "Processing files …" : "S'estan processant els fitxers …",
+    "Processing files …" : "S'estan processant els fitxers...",
     "…" : "…",
     "Unable to upload {filename} as it is a directory or has 0 bytes" : "No s'ha pogut pujar {filename} perquè és una carpeta o té 0 bytes",
     "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hi ha prou espai lliure, esteu pujant {size1} però només teniu {size2} lliures",
     "Target folder \"{dir}\" does not exist any more" : "La carpeta de destinació «{dir}» ja no existeix",
     "Not enough free space" : "No hi ha prou espai lliure",
     "An unknown error has occurred" : "S'ha produït un error desconegut",
-    "File could not be uploaded" : "No s'ha pogut pujar el fitxer",
-    "Uploading …" : "S'està pujant …",
+    "Uploading …" : "S'està pujant...",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "No s'admet la pujada aquest element",
     "Target folder does not exist any more" : "La carpeta de destinació ja no existeix",
@@ -36,7 +32,6 @@ OC.L10N.register(
     "Move" : "Mou",
     "Copy" : "Copia",
     "Choose target folder" : "Trieu la carpeta de destinació",
-    "Edit locally" : "Edició local",
     "Open" : "Obre",
     "Delete file" : "Suprimeix el fitxer",
     "Delete folder" : "Suprimeix la carpeta",
@@ -45,6 +40,8 @@ OC.L10N.register(
     "Could not load info for file \"{file}\"" : "No s'ha pogut carregar la informació del fitxer «{file}»",
     "Files" : "Fitxers",
     "Details" : "Detalls",
+    "Show list view" : "Mostra en vista de llista",
+    "Show grid view" : "Mostra en vista de graella",
     "Please select tag(s) to add to the selection" : "Seleccioneu les etiquetes que voleu afegir a la selecció",
     "Apply tag(s) to selection" : "Aplica les etiquetes a la selecció",
     "Select directory \"{dirName}\"" : "Selecciona la carpeta «{dirName}»",
@@ -52,7 +49,7 @@ OC.L10N.register(
     "Pending" : "Pendent",
     "Unable to determine date" : "No s'ha pogut determinar la data",
     "This operation is forbidden" : "Aquesta operació no està permesa",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Aquest directori no està disponible. Consulteu els registres o contacteu amb l'administrador",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Aquesta carpeta no està disponible. Consulteu els registres o poseu-vos en contacte amb l'administrador.",
     "Could not move \"{file}\", target exists" : "No s'ha pogut desplaçar «{file}», el fitxer de destinació ja existeix",
     "Could not move \"{file}\"" : "No s'ha pogut desplaçar «{file}»",
     "copy" : "còpia",
@@ -60,7 +57,6 @@ OC.L10N.register(
     "Could not copy \"{file}\"" : "No s'ha pogut copiar «{file}»",
     "Copied {origin} inside {destination}" : "S'ha copiat {origin} a {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "S'han copiat {origin} i {nbfiles} fitxers més a {destination}",
-    "Failed to redirect to client" : "No s'ha pogut redirigir al client",
     "{newName} already exists" : "{newName} ja existeix",
     "Could not rename \"{fileName}\", it does not exist any more" : "No s'ha pogut canviar el nom de «{fileName}», ja no existeix",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nom «{targetName}» ja està en ús en la carpeta «{dir}». Trieu un nom diferent.",
@@ -81,9 +77,7 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["incloent-hi %n element ocult","incloent-hi %n elements ocults"],
     "You do not have permission to upload or create files here" : "No teniu permís per a pujar o crear fitxers aquí",
     "_Uploading %n file_::_Uploading %n files_" : ["S'està pujant %n fitxer","S'estan pujant %n fitxers"],
-    "New file/folder menu" : "Nou menú fitxer/carpeta",
     "Select file range" : "Selecciona un interval de fitxers",
-    "{used}%" : "{used}%",
     "{used} of {quota} used" : "{used} de {quota} en ús",
     "{used} used" : "{used} en ús",
     "\"{name}\" is an invalid file name." : "«{name}» no és un nom de fitxer vàlid.",
@@ -180,6 +174,7 @@ OC.L10N.register(
     "Invalid path selected" : "El camí seleccionat no és vàlid",
     "Ownership transfer request sent" : "S'ha enviat la sol·licitud de transferència de propietat",
     "Cannot transfer ownership of a file or folder you do not own" : "No es pot transferir la propietat d'un fitxer o carpeta que no és vostre",
+    "Tags" : "Etiquetes",
     "Unable to change the favourite state of the file" : "No s'ha pogut canviar l'estat de preferit del fitxer",
     "Error while loading the file data" : "S'ha produït un error en carregar la informació del fitxer",
     "Pick a template for {name}" : "Trieu una plantilla per a {name}",
@@ -193,9 +188,7 @@ OC.L10N.register(
     "Templates" : "Plantilles",
     "Unable to initialize the templates directory" : "No s'ha pogut inicialitzar la carpeta de plantilles",
     "%s used" : "%s en ús",
-    "%s%%" : "%s%%",
     "%1$s of %2$s used" : "%1$s de %2$s en ús",
-    "Files settings" : "Paràmetres dels fitxers",
     "Show hidden files" : "Mostra els fitxers ocults",
     "Crop image previews" : "Retalla les previsualitzacions de les imatges",
     "WebDAV" : "WebDAV",
@@ -223,6 +216,7 @@ OC.L10N.register(
     "You don’t have permission to upload or create files here" : "No teniu permís per a pujar o crear fitxers aquí",
     "New" : "Nou",
     "Cannot transfer ownership of a file or folder you don't own" : "No es pot transferir la propietat d'un fitxer o carpeta que no és vostre",
+    "%s%% of %s used" : "%s%% de %s en ús",
     "Settings" : "Paràmetres"
 },
 "nplurals=2; plural=(n != 1);");
