@@ -30,6 +30,7 @@ OC.L10N.register(
     "Error when assembling chunks, status code {status}" : "Fejl ved montering af klumper, statuskode {status}",
     "Actions" : "Handlinger",
     "Rename" : "Omdøb",
+    "Move" : "Flyt",
     "Copy" : "Kopier",
     "Choose target folder" : "Vælg destinationsmappe",
     "Open" : "Åbn",
@@ -77,7 +78,9 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["%n skujlte inkluderet","%n skujlte inkluderet"],
     "You do not have permission to upload or create files here" : "Du har ikke tilladelse til at uploade eller oprette filer her",
     "_Uploading %n file_::_Uploading %n files_" : ["Uploader %n fil","Uploader %n filer"],
+    "New file/folder menu" : "Ny fil/mappe menu",
     "Select file range" : "Vælg filområde",
+    "{used}%" : "{used}%",
     "{used} of {quota} used" : "{used} af {quota} brugt",
     "{used} used" : "{used} brugt",
     "\"{name}\" is an invalid file name." : "'{name}' er et ugyldigt filnavn.",
@@ -188,8 +191,9 @@ OC.L10N.register(
     "Templates" : "Skabeloner",
     "Unable to initialize the templates directory" : "Kan ikke initialisere skabelonmappen",
     "%s used" : "%s brugt",
-    "%s%% of %s used" : "%s%% af %s brugt",
+    "%s%%" : "%s%%",
     "%1$s of %2$s used" : "%1$s af %2$s brugt",
+    "Files settings" : "indstillinger for filer",
     "Show hidden files" : "Vis skjulte filer",
     "Crop image previews" : "Beskær forhåndsvisninger af billeder",
     "WebDAV" : "WebDAV",
@@ -217,6 +221,7 @@ OC.L10N.register(
     "You don’t have permission to upload or create files here" : "Du har ikke tilladelse til at uploade eller oprette filer her",
     "New" : "Ny",
     "Cannot transfer ownership of a file or folder you don't own" : "Kan ikke overføre ejerskab af en fil eller mappe, du ikke ejer",
+    "%s%% of %s used" : "%s%% af %s brugt",
     "Settings" : "Indstillinger"
 },
 "nplurals=2; plural=(n != 1);");
