@@ -8,9 +8,6 @@ OC.L10N.register(
     "Move or copy" : "Verschieben oder kopieren",
     "Download" : "Herunterladen",
     "Delete" : "Löschen",
-    "Tags" : "Tags",
-    "Show list view" : "Listenansicht anzeigen",
-    "Show grid view" : "Rasteransicht anzeigen",
     "Home" : "Home",
     "Close" : "Schließen",
     "Favorites" : "Favoriten",
@@ -36,7 +33,6 @@ OC.L10N.register(
     "Move" : "Verschieben",
     "Copy" : "Kopieren",
     "Choose target folder" : "Zielordner auswählen",
-    "Edit locally" : "Lokal bearbeiten",
     "Open" : "Öffnen",
     "Delete file" : "Datei löschen",
     "Delete folder" : "Ordner löschen",
@@ -45,6 +41,8 @@ OC.L10N.register(
     "Could not load info for file \"{file}\"" : "Die Informationen zur Datei \"{file}\" konnten nicht geladen werden",
     "Files" : "Dateien",
     "Details" : "Details",
+    "Show list view" : "Listenansicht anzeigen",
+    "Show grid view" : "Rasteransicht anzeigen",
     "Please select tag(s) to add to the selection" : "Bitte wählen Sie das/die Schlagwort(e) aus, das/die Sie zur Auswahl hinzufügen möchten",
     "Apply tag(s) to selection" : "Schlagwort(e) auf die Auswahl anwenden",
     "Select directory \"{dirName}\"" : "Ordner \"{dirName}\" auswählen",
@@ -60,7 +58,6 @@ OC.L10N.register(
     "Could not copy \"{file}\"" : "\"{file}\" konnte nicht kopiert werden",
     "Copied {origin} inside {destination}" : "{origin} wurde nach {destination} kopiert",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} und {nbfiles} weitere Dateien wurden nach {destination} kopiert",
-    "Failed to redirect to client" : "Umleitung zum Client fehlgeschlagen",
     "{newName} already exists" : "{newName} existiert bereits",
     "Could not rename \"{fileName}\", it does not exist any more" : "Die Datei \"{fileName}\" konnte nicht umbenannt werden, da sie nicht mehr existiert",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name „{targetName}“ wird bereits im Ordner „{dir}“ benutzt. Bitte wählen Sie einen anderen Namen.",
@@ -180,6 +177,7 @@ OC.L10N.register(
     "Invalid path selected" : "Ungültiger Pfad ausgewählt",
     "Ownership transfer request sent" : "Anforderung für die Besitzübertragung versendet",
     "Cannot transfer ownership of a file or folder you do not own" : "Sie können den Besitz von Dateien oder Ordnern, die Sie nicht besitzen, nicht übertragen",
+    "Tags" : "Tags",
     "Unable to change the favourite state of the file" : "Der favorisierte Status der Datei kann nicht geändert werden",
     "Error while loading the file data" : "Fehler beim Laden der Datei-Daten",
     "Pick a template for {name}" : "Eine Vorlage für {name} wählen",
@@ -203,7 +201,7 @@ OC.L10N.register(
     "Toggle %1$s sublist" : "Unterliste %1$s umschalten",
     "Toggle grid view" : "Rasteransicht umschalten",
     "No files in here" : "Keine Dateien vorhanden",
-    "Upload some content or sync with your devices!" : "Laden Sie Inhalte hoch oder mit Ihren Geräten synchronisieren!",
+    "Upload some content or sync with your devices!" : "Laden Sie Inhalte hoch oder synchronisieren Sie mit Ihren Geräten!",
     "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
     "Select all" : "Alle auswählen",
     "Upload too large" : "Der Upload ist zu groß",
@@ -223,6 +221,7 @@ OC.L10N.register(
     "You don’t have permission to upload or create files here" : "Sie haben keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
     "New" : "Neu",
     "Cannot transfer ownership of a file or folder you don't own" : "Der Besitz einer Datei oder eines Ordners, den Sie nicht besitzen, kann nicht übertragen werden",
+    "%s%% of %s used" : "%s%% von %s verwendet",
     "Settings" : "Einstellungen"
 },
 "nplurals=2; plural=(n != 1);");
