@@ -8,9 +8,6 @@ OC.L10N.register(
     "Move or copy" : "Μετακίνηση ή αντιγραφή",
     "Download" : "Λήψη",
     "Delete" : "Διαγραφή",
-    "Tags" : "Ετικέτες",
-    "Show list view" : "Προβολή λίστας",
-    "Show grid view" : "Προβολή πλέγματος",
     "Home" : "Αρχική",
     "Close" : "Κλείσιμο",
     "Favorites" : "Αγαπημένα",
@@ -36,7 +33,6 @@ OC.L10N.register(
     "Move" : "Μετακίνηση",
     "Copy" : "Αντιγραφή",
     "Choose target folder" : "Επιλογή φακέλου προορισμού",
-    "Edit locally" : "Επεξεργασία τοπικά",
     "Open" : "Άνοιγμα",
     "Delete file" : "Διαγραφή αρχείου",
     "Delete folder" : "Διαγραφή φακέλου",
@@ -60,8 +56,7 @@ OC.L10N.register(
     "Could not copy \"{file}\"" : "Αδυναμία αντιγραφής του \"{file}\"",
     "Copied {origin} inside {destination}" : "Αντιγράφτηκε το {origin} στο {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Αντιγράφτηκε το {origin} και {nbfiles} άλλα αρχεία στο {destination}",
-    "Failed to redirect to client" : "Αποτυχία ανακατεύθυνσης στον πελάτη",
-    "{newName} already exists" : "Το {newName} υπάρχει ήδη",
+    "{newName} already exists" : "Το {newname} υπάρχει ήδη",
     "Could not rename \"{fileName}\", it does not exist any more" : "Αδυναμία μετονομασίας του \"{fileName}\", το αρχείο δεν υπάρχει πια.",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Το όνομα \"{targetName}\" χρησιμοποιείται ήδη στον φάκελο\"{dir}\". Παρακαλούμε διαλέξτε ένα διαφορετικό όνομα.",
     "Could not rename \"{fileName}\"" : "Αδυναμία μετονομασίας του \"{fileName}\"",
@@ -81,9 +76,7 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["περιλαμβάνεται %n κρυφό","περιλαμβάνονται %n κρυφά"],
     "You do not have permission to upload or create files here" : "Δεν έχετε δικαιώματα μεταφόρτωσης ή δημιουργίας αρχείων εδώ",
     "_Uploading %n file_::_Uploading %n files_" : ["Μεταφόρτωση %n αρχείου","Μεταφόρτωση %n αρχείων"],
-    "New file/folder menu" : "Μενού νέου αρχείου/φακέλου",
     "Select file range" : "Επιλέξτε εύρος αρχείων",
-    "{used}%" : "{used}%",
     "{used} of {quota} used" : "Χρήση {used} από {quota} ",
     "{used} used" : "Σε χρήση {used}",
     "\"{name}\" is an invalid file name." : "Το \"{name}\" δεν είναι έγκυρο όνομα αρχείου.",
@@ -180,6 +173,7 @@ OC.L10N.register(
     "Invalid path selected" : "Επιλέχθηκε μη έγκυρη διαδρομή",
     "Ownership transfer request sent" : "Αποστολή αίτησης μεταβίβασης κυριότητας",
     "Cannot transfer ownership of a file or folder you do not own" : "Δεν είναι δυνατή η μεταβίβαση της κυριότητας ενός αρχείου ή φακέλου που δε σας ανήκει",
+    "Tags" : "Ετικέτες",
     "Unable to change the favourite state of the file" : "Αδυναμία αλλαγής αγαπημένης κατάστασης αρχείου",
     "Error while loading the file data" : "Σφάλμα κατά την φόρτωση αρχείου δεδομένων",
     "Pick a template for {name}" : "Επιλέξτε ένα πρότυπο για {name}",
@@ -193,9 +187,7 @@ OC.L10N.register(
     "Templates" : "Πρότυπα",
     "Unable to initialize the templates directory" : "Δεν είναι δυνατή η προετοιμασία του καταλόγου προτύπων",
     "%s used" : "%s σε χρήση",
-    "%s%%" : "%s%%",
     "%1$s of %2$s used" : "χρησιμοποιούνται %1$s από %2$s",
-    "Files settings" : "Ρυθμίσεις αρχείων",
     "Show hidden files" : "Εμφάνιση κρυφών αρχείων",
     "Crop image previews" : "Περικοπή προεπισκόπησης εικόνας",
     "WebDAV" : "WebDAV",
@@ -223,6 +215,7 @@ OC.L10N.register(
     "You don’t have permission to upload or create files here" : "Δεν έχετε δικαιώματα μεταφόρτωσης ή δημιουργίας αρχείων εδώ",
     "New" : "Νέο",
     "Cannot transfer ownership of a file or folder you don't own" : "Δεν μπορεί να μεταβιβαστεί η κυριότητα αρχείου ή φακέλου που δεν σας ανήκει",
+    "%s%% of %s used" : "%s%% από %s σε χρήση",
     "Settings" : "Ρυθμίσεις"
 },
 "nplurals=2; plural=(n != 1);");
