@@ -8,8 +8,6 @@ OC.L10N.register(
     "Move or copy" : "Movi aŭ kopii",
     "Download" : "Elŝuti",
     "Delete" : "Forigi",
-    "Tags" : "Etikedoj",
-    "Show list view" : "Montri listan vidon",
     "Home" : "Hejmo",
     "Close" : "Fermi",
     "Favorites" : "Pliŝatataj",
@@ -33,7 +31,6 @@ OC.L10N.register(
     "Move" : "Movi",
     "Copy" : "Kopii",
     "Choose target folder" : "Elekti celan dosierujon",
-    "Edit locally" : "Redakti loke",
     "Open" : "Malfermi",
     "Delete file" : "Forigi dosieron",
     "Delete folder" : "Forigi dosierujon",
@@ -70,7 +67,6 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["inkluzive %n kaŝita","inkluzive %n kaŝita(j)"],
     "_Uploading %n file_::_Uploading %n files_" : ["Alŝutatas %n dosiero","Alŝutatas %n dosieroj"],
     "Select file range" : "Elekti dosierintervalon",
-    "{used}%" : "{used}%",
     "{used} of {quota} used" : "{used} uzataj el {quota}",
     "{used} used" : "{used} uzataj",
     "\"{name}\" is an invalid file name." : "„{name}“ estas nevalida dosiernomo.",
@@ -133,14 +129,11 @@ OC.L10N.register(
     "in %s" : "en %s",
     "File Management" : "Dosieradministrado",
     "Change" : "Ŝanĝi",
-    "New owner" : "Nova posedanto",
-    "Search users" : "Serĉi uzantojn",
+    "Tags" : "Etikedoj",
     "Unable to change the favourite state of the file" : "Ne eblas ŝanĝi la staton pri pliŝatataĵo de la dosiero",
     "Error while loading the file data" : "Eraro dum ŝargo de la dosierdatumoj",
     "Cancel" : "Nuligi",
     "Create" : "Krei",
-    "Creating file" : "Kreante dosieron",
-    "Templates" : "Ŝablonoj",
     "%s used" : "%s uzataj",
     "%1$s of %2$s used" : "%1$s uzataj el %2$s",
     "Show hidden files" : "Montri kaŝitajn dosierojn",
@@ -165,6 +158,7 @@ OC.L10N.register(
     "Select" : "Elekti",
     "You don’t have permission to upload or create files here" : "Vi ne permesatas alŝuti aŭ krei dosierojn ĉi tie",
     "New" : "Nova",
+    "%s%% of %s used" : "%s%% el %s uzataj",
     "Settings" : "Agordo"
 },
 "nplurals=2; plural=(n != 1);");
