@@ -30,6 +30,7 @@ OC.L10N.register(
     "Error when assembling chunks, status code {status}" : "Virhe koottaessa lohkoja, tilakoodi {status}",
     "Actions" : "Toiminnot",
     "Rename" : "Nimeä uudelleen",
+    "Move" : "Siirrä",
     "Copy" : "Kopioi",
     "Choose target folder" : "Valitse kohdekansio",
     "Open" : "Avaa",
@@ -77,7 +78,9 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["Sisältäen %n piilotetun","Sisältäen %n piilotettua"],
     "You do not have permission to upload or create files here" : "Käyttöoikeutesi eivät riitä tiedostojen lähettämiseen tai luomiseen tähän sijaintiin",
     "_Uploading %n file_::_Uploading %n files_" : ["Lähetetään %n tiedosto","Lähetetään %n tiedostoa"],
+    "New file/folder menu" : "Uusi tiedosto/kansio -valikko",
     "Select file range" : "Valitse tiedostojoukko",
+    "{used}%" : "{used} %",
     "{used} of {quota} used" : "{used}/{quota} käytetty",
     "{used} used" : "{used} käytetty",
     "\"{name}\" is an invalid file name." : "\"{name}\" on virheellinen tiedostonimi.",
@@ -188,8 +191,9 @@ OC.L10N.register(
     "Templates" : "Mallipohjat",
     "Unable to initialize the templates directory" : "Mallipohjien kansiota ei voitu alustaa",
     "%s used" : "%s käytetty",
-    "%s%% of %s used" : "%s%% / %s käytetty",
+    "%s%%" : "%s%%",
     "%1$s of %2$s used" : "%1$s/%2$s käytetty",
+    "Files settings" : "Tiedostojen asetukset",
     "Show hidden files" : "Näytä piilotetut tiedostot",
     "Crop image previews" : "Rajaa kuvien esikatseluja",
     "WebDAV" : "WebDAV",
@@ -216,6 +220,7 @@ OC.L10N.register(
     "You don’t have permission to upload or create files here" : "Käyttöoikeutesi eivät riitä tiedostojen lähettämiseen tai kansioiden luomiseen tähän sijaintiin",
     "New" : "Uusi",
     "Cannot transfer ownership of a file or folder you don't own" : "Et voi siirtää sellaisen tiedoston tai kansion omistajuutta, jota et itse omista",
+    "%s%% of %s used" : "%s%% / %s käytetty",
     "Settings" : "Asetukset"
 },
 "nplurals=2; plural=(n != 1);");
