@@ -8,9 +8,6 @@ OC.L10N.register(
     "Move or copy" : "移動またはコピー",
     "Download" : "ダウンロード",
     "Delete" : "削除",
-    "Tags" : "タグ",
-    "Show list view" : "リストビューで表示",
-    "Show grid view" : "グリッドビューで表示",
     "Home" : "ホーム",
     "Close" : "閉じる",
     "Favorites" : "お気に入り",
@@ -36,7 +33,6 @@ OC.L10N.register(
     "Move" : "移動",
     "Copy" : "コピー",
     "Choose target folder" : "ターゲットフォルダーを選択",
-    "Edit locally" : "ローカルで編集",
     "Open" : "開く",
     "Delete file" : "ファイルを削除",
     "Delete folder" : "フォルダーを削除",
@@ -45,6 +41,8 @@ OC.L10N.register(
     "Could not load info for file \"{file}\"" : "\"{file}\" ファイルの情報を読み込めませんでした",
     "Files" : "ファイル",
     "Details" : "詳細",
+    "Show list view" : "リストビューで表示",
+    "Show grid view" : "グリッドビューで表示",
     "Please select tag(s) to add to the selection" : "選択項目に付与するタグを選択してください",
     "Apply tag(s) to selection" : "選択項目にタグを適用",
     "Select directory \"{dirName}\"" : "ディレクトリを選択: \"{dirName}\"",
@@ -60,7 +58,6 @@ OC.L10N.register(
     "Could not copy \"{file}\"" : "\"{file}\"をコピーできませんでした",
     "Copied {origin} inside {destination}" : "コピー先{origin} {destination}内",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "コピー先{origin}と{nbfiles}他のファイル{destination}",
-    "Failed to redirect to client" : "クライアントへリダイレクトできませんでした",
     "{newName} already exists" : "{newName} はすでに存在します",
     "Could not rename \"{fileName}\", it does not exist any more" : "ファイルが存在しないため,\"{fileName}\"の名前変更ができませんでした",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" はフォルダー \"{dir}\" ですでに使われています。別の名前を選択してください。",
@@ -180,6 +177,7 @@ OC.L10N.register(
     "Invalid path selected" : "無効なパスが選択されました",
     "Ownership transfer request sent" : "所有権転送のリクエストを送信しました",
     "Cannot transfer ownership of a file or folder you do not own" : "所有していないファイルまたはフォルダーの所有権を譲渡することはできません",
+    "Tags" : "タグ",
     "Unable to change the favourite state of the file" : "ファイルのお気に入りの状態を変更できません",
     "Error while loading the file data" : "ファイルデータの読み込み中にエラーが発生しました",
     "Pick a template for {name}" : "{name} のテンプレートを選択してください",
@@ -223,6 +221,7 @@ OC.L10N.register(
     "You don’t have permission to upload or create files here" : "ここにファイルをアップロードまたは作成する権限がありません",
     "New" : "新規作成",
     "Cannot transfer ownership of a file or folder you don't own" : "所有していないファイルまたはフォルダーの所有権を譲渡することはできません",
+    "%s%% of %s used" : "%s%% 使用中、全体は%s",
     "Settings" : "設定"
 },
 "nplurals=1; plural=0;");
