@@ -8,9 +8,6 @@ OC.L10N.register(
     "Move or copy" : "이동이나 복사",
     "Download" : "다운로드",
     "Delete" : "삭제",
-    "Tags" : "태그",
-    "Show list view" : "리스트 보기",
-    "Show grid view" : "모눈 보기",
     "Home" : "홈",
     "Close" : "닫기",
     "Favorites" : "즐겨찾기",
@@ -24,7 +21,6 @@ OC.L10N.register(
     "Target folder \"{dir}\" does not exist any more" : "대상 폴더 \"{dir}\"이(가) 더 이상 존재하지 않습니다",
     "Not enough free space" : "남은 공간이 부족함",
     "An unknown error has occurred" : "알 수 없는 에러 발생",
-    "File could not be uploaded" : "파일을 업로드할 수 없음",
     "Uploading …" : "업로드 중…",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize}/{totalSize}({bitrate})",
     "Uploading that item is not supported" : "이 항목의 업로드를 지원하지 않습니다",
@@ -46,8 +42,6 @@ OC.L10N.register(
     "Details" : "자세한 정보",
     "Please select tag(s) to add to the selection" : "선택한 항목에 추가할 태그를 고르세요",
     "Apply tag(s) to selection" : "선택한 항목에 태그 적용하기",
-    "Select directory \"{dirName}\"" : "디렉터리 \"{dirName}\" 선택",
-    "Select file \"{fileName}\"" : "파일 \"{fileName}\" 선택",
     "Pending" : "대기 중",
     "Unable to determine date" : "날짜를 결정할 수 없음",
     "This operation is forbidden" : "이 작업이 금지됨",
@@ -77,9 +71,7 @@ OC.L10N.register(
     "_%n file_::_%n files_" : ["파일 %n개"],
     "{dirs} and {files}" : "{dirs} 그리고 {files}",
     "_including %n hidden_::_including %n hidden_" : ["%n개의 숨겨진 파일 포함"],
-    "You do not have permission to upload or create files here" : "여기에 파일을 업로드하거나 만들 권한이 없습니다",
     "_Uploading %n file_::_Uploading %n files_" : ["파일 %n개 업로드 중"],
-    "New file/folder menu" : "새 파일/폴더 메뉴",
     "{used} of {quota} used" : "{quota} 중 {used} 사용함",
     "{used} used" : "{used} 사용함",
     "\"{name}\" is an invalid file name." : "\"{name}\"은(는) 잘못된 파일 이름입니다.",
@@ -175,7 +167,7 @@ OC.L10N.register(
     "Transfer {path} to {userid}" : "{path}을(를) {userid}에게 이전하기",
     "Invalid path selected" : "잘못된 경로가 선택됨",
     "Ownership transfer request sent" : "소유권 이전 요청이 전송됨",
-    "Cannot transfer ownership of a file or folder you do not own" : "내가 소유하지 않은 파일이나 폴더의 소유권을 이전할 수 없음",
+    "Tags" : "태그",
     "Unable to change the favourite state of the file" : "파일의 즐겨찾기 상태를 변경할 수 없음",
     "Error while loading the file data" : "파일 데이터를 불러오는 중 오류 발생",
     "Pick a template for {name}" : "{name}을(를) 위한 템플릿 선택",
@@ -187,10 +179,8 @@ OC.L10N.register(
     "Unable to create new file from template" : "템플릿으로 새 파일을 만들 수 없음",
     "Set up templates folder" : "템플릿 폴더 설정",
     "Templates" : "템플릿",
-    "Unable to initialize the templates directory" : "템플릿 디렉터리를 설정할 수 없음",
     "%s used" : "%s 사용함",
     "%1$s of %2$s used" : "%2$s 중 %1$s 사용됨",
-    "Files settings" : "파일 설정",
     "Show hidden files" : "숨김 파일 보이기",
     "WebDAV" : "WebDAV",
     "Use this address to access your Files via WebDAV" : "이 주소를 사용하여 WebDAV를 통해 내 파일에 접근하십시오",
