@@ -8,9 +8,6 @@ OC.L10N.register(
     "Move or copy" : "Mover ou copiar",
     "Download" : "Baixar",
     "Delete" : "Excluir",
-    "Tags" : "Etiquetas",
-    "Show list view" : "Mostrar visualização em lista",
-    "Show grid view" : "Mostrar visualização em grade",
     "Home" : "Início",
     "Close" : "Fechar",
     "Favorites" : "Favoritos",
@@ -36,7 +33,6 @@ OC.L10N.register(
     "Move" : "Mover",
     "Copy" : "Copiar",
     "Choose target folder" : "Escolher pasta destino",
-    "Edit locally" : "Editar localmente",
     "Open" : "Abrir",
     "Delete file" : "Excluir arquivo",
     "Delete folder" : "Excluir pasta",
@@ -45,6 +41,8 @@ OC.L10N.register(
     "Could not load info for file \"{file}\"" : "Não foi possível carregar informações para o arquivo \"{file}\" ",
     "Files" : "Arquivos",
     "Details" : "Detalhes",
+    "Show list view" : "Mostrar visualização em lista",
+    "Show grid view" : "Mostrar visualização em grade",
     "Please select tag(s) to add to the selection" : "Selecione a(s) etiquetas(s) para adicionar à seleção ",
     "Apply tag(s) to selection" : "Aplicar as etiqueta(s) a seleção",
     "Select directory \"{dirName}\"" : "Selecione o diretório \"{dirName}\"",
@@ -60,7 +58,6 @@ OC.L10N.register(
     "Could not copy \"{file}\"" : "Não foi possível copiar \"{file}\"",
     "Copied {origin} inside {destination}" : "{origin} foi copiado para {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} e outros {nbfiles} arquivos foram copiados para {destination}",
-    "Failed to redirect to client" : "Falha ao redirecionar para o cliente",
     "{newName} already exists" : "{newName} já existe",
     "Could not rename \"{fileName}\", it does not exist any more" : "Não foi possível renomear \"{fileName}\" pois ele não existe mais",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome \"{targetName}\" já está sendo usado na pasta  \"{dir}\". Por favor escolha um nome diferente.",
@@ -83,7 +80,6 @@ OC.L10N.register(
     "_Uploading %n file_::_Uploading %n files_" : ["Enviando %n arquivo","Enviando %n arquivos","Enviando %n arquivos"],
     "New file/folder menu" : "Novo menu de arquivo/pasta",
     "Select file range" : "Selecionar o intervalo de arquivos",
-    "{used}%" : "{used}%",
     "{used} of {quota} used" : "{used} de {quota} usados",
     "{used} used" : "{used} usados",
     "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de arquivo inválido.",
@@ -180,6 +176,7 @@ OC.L10N.register(
     "Invalid path selected" : "Caminho inválido selecionado",
     "Ownership transfer request sent" : "Solicitação de transferência de propriedade enviada",
     "Cannot transfer ownership of a file or folder you do not own" : "Não é possível transferir a propriedade de um arquivo ou pasta que você não possui",
+    "Tags" : "Etiquetas",
     "Unable to change the favourite state of the file" : "Não foi possível alterar o estado favorito do arquivo",
     "Error while loading the file data" : "Erro ao carregar os dados do arquivo",
     "Pick a template for {name}" : "Escolha um modelo para {name}",
@@ -193,7 +190,6 @@ OC.L10N.register(
     "Templates" : "Modelos ",
     "Unable to initialize the templates directory" : "Não foi possível inicializar o diretório de modelos ",
     "%s used" : "%s usado",
-    "%s%%" : "%s%%",
     "%1$s of %2$s used" : "%1$s usados de %2$s",
     "Files settings" : "Configurações de arquivos",
     "Show hidden files" : "Mostrar arquivos ocultos",
@@ -212,7 +208,7 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Suas pastas e arquivos favoritos serão exibidos aqui.",
     "Deleted files" : "Arquivos apagados",
     "Shares" : "Compartilhamentos",
-    "Shared with others" : "Compartilhado com os outros",
+    "Shared with others" : "Compartilhado com outros",
     "Shared with you" : "Compartilhado com você",
     "Shared by link" : "Compartilhado via link",
     "Deleted shares" : "Compartilhamentos apagados",
@@ -223,6 +219,7 @@ OC.L10N.register(
     "You don’t have permission to upload or create files here" : "Você não tem permissão para enviar ou criar arquivos aqui",
     "New" : "Novo",
     "Cannot transfer ownership of a file or folder you don't own" : "Não é possível transferir a propriedade de um arquivo ou pasta que você não possui",
+    "%s%% of %s used" : "%s%% usados de %s",
     "Settings" : "Configurações"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
