@@ -114,4 +114,4 @@ OC.L10N.register(
     "Allow users to mount external storage" : "Permitir a los usuarios montar almacenamiento externo",
     "Delete" : "Borrar"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
