@@ -17,7 +17,7 @@ OC.L10N.register(
     "Never" : "Niciodată",
     "Once every direct access" : "O dată la fiecare acces direct",
     "Read only" : "Doar citire",
-    "Delete" : "Șterge",
+    "Disconnect" : "Deconectare",
     "Admin defined" : "Administrator definit",
     "Saved" : "Salvat",
     "Saving …" : "Se salvează",
@@ -78,8 +78,6 @@ OC.L10N.register(
     "Available for" : "Disponibil pentru",
     "Add storage" : "Adauga stocare",
     "Advanced settings" : "Setări avansate",
-    "(group)" : "(grup)",
-    "SMB / CIFS" : "SMB / CIFS",
-    "SMB / CIFS using OC login" : "SMB / CIFS folosind autentificare OC"
+    "Delete" : "Șterge"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
