@@ -7,22 +7,27 @@ OC.L10N.register(
     "Grant access" : "Дозволити доступ",
     "Error configuring OAuth1" : "Помилка з конфігуруванням OAuth1",
     "Please provide a valid app key and secret." : "Будь ласка, надайте дійсний ключ застосунку та пароль.",
+    "Error configuring OAuth2" : "Помилка налаштування OAuth2",
     "Generate keys" : "Створити ключі",
     "Error generating key pair" : "Помилка створення ключової пари",
     "All users. Type to select user or group." : "Всі користувачі. Введіть ім'я користувача або групи.",
     "(Group)" : "(група)",
+    "Compatibility with Mac NFD encoding (slow)" : "Сумісність із кодуванням Mac NFD (повільно)",
     "Enable encryption" : "Увімкнути шифрування",
     "Enable previews" : "Увімкнути попередній перегляд",
     "Enable sharing" : "Увімкнути спільний доступ",
     "Check for changes" : "Перевірити на зміни",
     "Never" : "Ніколи",
+    "Once every direct access" : "Один раз при кожному прямому доступі",
     "Read only" : "Тільки читання",
     "Disconnect" : "Від'єднати",
+    "Admin defined" : "Визначено адміністратором",
     "Delete storage?" : "Вилучити сховище?",
     "Saved" : "Збережено",
     "Saving …" : "Збереження ..",
     "Save" : "Зберегти",
     "Empty response from the server" : "Отримано порожню відповідь від сервера",
+    "Couldn't get the list of external mount points: {type}" : "Не вдалося отримати список зовнішніх точок підключення: {type}",
     "There was an error with message: " : "Сповіщення про помилку:",
     "External mount error" : "Помилка з приєднанням зовнішнього ресурсу",
     "external-storage" : "зовнішнє сховище",
@@ -34,8 +39,14 @@ OC.L10N.register(
     "Credentials saving failed" : "Помилка зі збереженням даних авторизації",
     "Credentials required" : "Потрібно зазначити дані авторизації",
     "Storage with ID \"%d\" not found" : "Сховище з ідентифікатором \"%d\" не знайдено",
+    "Invalid backend or authentication mechanism class" : "Недійсний сервер або клас механізму автентифікації",
     "Invalid mount point" : "Невірна точка монтування",
+    "Objectstore forbidden" : "Objectstore заборонено",
     "Invalid storage backend \"%s\"" : "Невірне сховище \"%s\"",
+    "Not permitted to use backend \"%s\"" : "Не дозволено використовувати бекенд \"%s\"",
+    "Not permitted to use authentication mechanism \"%s\"" : "Не дозволено використовувати механізм автентифікації \"%s\"",
+    "Unsatisfied backend parameters" : "Незадоволені параметри серверної частини",
+    "Unsatisfied authentication mechanism parameters" : "Незадоволені параметри механізму автентифікації",
     "Insufficient data: %s" : "Недостатні дані: %s",
     "%s" : "%s ",
     "Storage with ID \"%d\" is not user editable" : "У користувачів відсутній доступ на запис до сховища з ідентифікатором \"%d\"",
@@ -43,11 +54,16 @@ OC.L10N.register(
     "Secret key" : "Пароль",
     "Builtin" : "Вбудовано",
     "None" : "Жоден",
+    "OAuth1" : "OAuth1",
     "App key" : "Ключ застосунку",
     "App secret" : "Секретний ключ застосунку",
+    "OAuth2" : "OAuth2",
     "Client ID" : "Ідентифікатор клієнта",
     "Client secret" : "Ключ клієнта",
+    "Tenant name" : "Ім'я орендаря",
+    "Identity endpoint URL" : "URL кінцевої точки ідентифікації",
     "Domain" : "Домен",
+    "Rackspace" : "Rackspace",
     "API key" : "ключ API",
     "Global credentials" : "Системні дані авторизації",
     "Log-in credentials, save in database" : "Дані авторизації у системі, зберегти у базі даних",
@@ -55,6 +71,7 @@ OC.L10N.register(
     "Log-in credentials, save in session" : "Дані авторизації у системі, зберегти у сесії",
     "Global credentials, user entered" : "Системні дані авторизації, зазначені користувачем",
     "User entered, store in database" : "Зазначено користувачем, зберегти у базі даних",
+    "RSA public key" : "Відкритий ключ RSA",
     "Public key" : "Відкритий ключ",
     "Private key" : "Приватний ключ",
     "Amazon S3" : "Amazon S3",
@@ -68,18 +85,24 @@ OC.L10N.register(
     "URL" : "URL",
     "Remote subfolder" : "Віддалена підтека",
     "Secure https://" : "Захищений https://",
+    "FTP" : "FTP",
     "Host" : "Хост",
     "Secure ftps://" : "Захищений ftps://",
     "Local" : "Локально",
     "Location" : "Місце",
     "Nextcloud" : "Nextcloud",
+    "SFTP" : "SFTP",
     "Root" : "Початкова тека",
+    "SFTP with secret key login" : "SFTP із секретним ключем входу",
     "Share" : "Поділитися",
     "Show hidden files" : "Показати приховані файли",
     "Timeout" : "Час вичерпано",
     "Username as share" : "Ім'я для відкритого доступу",
     "OpenStack Object Storage" : "OpenStack Object Storage",
     "Service name" : "Назва служби",
+    "Request timeout (seconds)" : "Час очікування запиту (секунди)",
+    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Підтримку cURL у PHP не ввімкнено або не встановлено. Монтаж %s неможливий. Будь ласка, попросіть свого системного адміністратора встановити його.",
+    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Підтримка FTP у PHP не ввімкнена або не встановлена. Монтаж %s неможливий. Будь ласка, попросіть свого системного адміністратора встановити його.",
     "Name" : "Ім'я",
     "Storage type" : "Тип сховища",
     "Scope" : "Область",
