@@ -2,7 +2,8 @@ OC.L10N.register(
     "files_rightclick",
     {
     "Unselect" : "Zrušiť výber",
-    "Share " : "Sprístupniť",
+    "Share folder" : "Zdieľať priečinok",
+    "Share file" : "Zdieľať súbor",
     "Select" : "Vybrať",
     "Copied !" : "Skopírované!",
     "Right click" : "Pravý klik",
