@@ -69,10 +69,8 @@ OC.L10N.register(
     "A file or folder was shared from <strong>another server</strong>" : "Un archivo o carpeta fue compartido desde <strong>otro servidor</strong>",
     "Files" : "Archivos",
     "A file or folder has been <strong>shared</strong>" : "Un archivo o carpeta ha sido <strong>compartido</strong>",
-    "Wrong share ID, share doesn't exist" : "ID del elemento compartido equivocado, el elemento compartido no existe",
     "Could not delete share" : "No fue posible borrar el elemento compartido",
     "Please specify a file or folder path" : "Por favor especifica un archivo o ruta de carpeta",
-    "Wrong path, file/folder doesn't exist" : "La ruta es incorrecta, el archivo/carpeta no existe",
     "Could not create share" : "No fue posible crear el elemento compartido",
     "Please specify a valid user" : "Por favor especifica un usuario válido",
     "Group sharing is disabled by the administrator" : "Compartir en grupos está deshabilitado por el administrador",
@@ -87,16 +85,22 @@ OC.L10N.register(
     "Not a directory" : "No es una carpeta",
     "Could not lock path" : "No fue posible bloquear la ruta",
     "Wrong or no update parameter given" : "El parametro de actualización está erróneo o falta",
+    "Cannot increase permissions" : "No es posible incrementar los permisos",
     "shared by %s" : "compartido por %s",
     "Direct link" : "Enlace directo",
     "Share API is disabled" : "El API para compartir está deshabilitado",
     "File sharing" : "Compartir archivos",
     "Accept" : "Aceptar",
     "Sharing" : "Compartiendo",
+    "Reset" : "Restablecer",
+    "Unknown error" : "Error desconocido",
     "Allow editing" : "Permitir edición",
     "Read only" : "Sólo lectura",
     "Allow upload and editing" : "Permitir carga y edición",
     "File drop (upload only)" : "Permitir carga",
+    "Read" : "Leer",
+    "Upload" : "Cargar",
+    "Edit" : "Editar",
     "Allow resharing" : "Permitir volver a compartir",
     "Set expiration date" : "Establecer fecha de expiración",
     "Unshare" : "Dejar de compartir",
@@ -119,7 +123,6 @@ OC.L10N.register(
     "Name" : "Nombre",
     "Share time" : "Compartido desde",
     "Expiration date" : "Fecha de expiración",
-    "Sorry, this link doesn’t seem to work anymore." : "Lo sentimos, parece que este enlace ya no funciona. ",
     "Reasons might be:" : "Las causas podrían ser:",
     "the item was removed" : "el elemento fue eliminado",
     "the link expired" : "el enlace caducó",
@@ -130,8 +133,8 @@ OC.L10N.register(
     "Select or drop files" : "Selecciona o suelta los archivos",
     "Uploaded files:" : "Archivos cargados:",
     "Add to your Nextcloud" : "Agregar a tu Nextcloud",
-    "invalid permissions" : "permisos inválidos",
-    "Can't change permissions for public share links" : "No es posible cambiar los permisos para enlaces  públicos compartidos",
-    "Download %s" : "Descargar %s"
+    "Wrong share ID, share doesn't exist" : "ID del elemento compartido equivocado, el elemento compartido no existe",
+    "Wrong path, file/folder doesn't exist" : "La ruta es incorrecta, el archivo/carpeta no existe",
+    "Sorry, this link doesn’t seem to work anymore." : "Lo sentimos, parece que este enlace ya no funciona. "
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
