@@ -41,7 +41,7 @@ OC.L10N.register(
     "No expiration date set" : "Ei vanhenemispäivää asetettu",
     "Shared by" : "Jakanut",
     "File shares" : "Tiedostojaot",
-    "Downloaded via public link" : "Ladattu julkista linkkiä käyttäen",
+    "Downloaded via public link" : "Ladattu julkista linkkiä käyttäen",
     "Downloaded by {email}" : "Ladannut {email}",
     "{file} downloaded via public link" : "{file} ladattu julkisen linkin kautta",
     "{email} downloaded {file}" : "{email} latasi tiedoston {file}",
@@ -50,8 +50,8 @@ OC.L10N.register(
     "{actor} shared with group {group}" : "{actor} jakoi ryhmälle {group}",
     "{actor} removed share for group {group}" : "{actor} lopetti jakamisen ryhmälle {group}",
     "Share for group {group} expired" : "Jako ryhmälle {group} vanhentui",
-    "You shared {file} with group {group}" : "Jaoit kohteen {file} ryhmälle {group}",
-    "You removed group {group} from {file}" : "Poistit ryhmän {group} kohteen {file} käyttöoikeudet",
+    "You shared {file} with group {group}" : "Jaoit kohteen {file} ryhmälle {group}",
+    "You removed group {group} from {file}" : "Poistit ryhmän {group} tiedostosta {file}",
     "{actor} shared {file} with group {group}" : "{actor} jakoi kohteen {file} ryhmälle {group}",
     "{actor} removed group {group} from {file}" : "{actor} poisti ryhmän {group} kohteen {file} käyttöoikeudet",
     "Share for file {file} with group {group} expired" : "Tiedoston {file} jako ryhmän {group} kanssa on päättynyt",
@@ -98,10 +98,10 @@ OC.L10N.register(
     "Files" : "Tiedostot",
     "A file or folder has been <strong>shared</strong>" : "Tiedosto tai kansio on <strong>jaettu</strong>",
     "Shared link" : "Jaettu linkki",
-    "Wrong share ID, share doesn't exist" : "Väärä jakotunniste, jakoa ei ole olemassa",
-    "Could not delete share" : "Jaon poistaminen epäonnistui",
+    "Wrong share ID, share does not exist" : "Väärä jaon ID, jakoa ei ole olemassa",
+    "Could not delete share" : "Jaon poistaminen epäonnistui",
     "Please specify a file or folder path" : "Määritä tiedoston tai kansion polku",
-    "Wrong path, file/folder doesn't exist" : "Väärä polku, tiedostoa tai kansiota ei ole olemassa",
+    "Wrong path, file/folder does not exist" : "Väärä polku, tiedostoa/kansiota ei ole olemassa",
     "Could not create share" : "Jaon luominen epäonnistui",
     "Invalid permissions" : "Virheelliset käyttöoikeudet",
     "Please specify a valid user" : "Määritä kelvollinen käyttäjä",
@@ -115,13 +115,17 @@ OC.L10N.register(
     "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Kohteen %1$s jakaminen epäonnistui, koska tietovarasto ei salli %2$s tyyppisiä jakoja",
     "You cannot share to a Circle if the app is not enabled" : "Et voi jakaa piiriin, jos sovellusta ei ole aktivoitu",
     "Please specify a valid circle" : "Määritä kelvollinen piiri",
+    "Sharing %s failed because the back end does not support room shares" : "Kohteen %s jakaminen epäonnistui, koska taustaosa ei tue huonejakoja",
     "Unknown share type" : "Tuntematon jaon tyyppi",
     "Not a directory" : "Ei hakemisto",
+    "Could not lock node" : "Solmua ei voitu lukita",
     "Could not lock path" : "Polun lukitseminen ei onnistunut",
     "Wrong or no update parameter given" : "Päivitettävä parametri puuttuu tai on väärin",
-    "shared by %s" : "%s jakama",
+    "Cannot increase permissions" : "Oikeuksien lisääminen ei onnistu",
+    "shared by %s" : "käyttäjän %s jakama",
     "Download all files" : "Lataa kaikki tiedostot",
     "Direct link" : "Suora linkki",
+    "Add to your %s" : "Lisää %siisi",
     "Share API is disabled" : "Jakamisrajapinta on poistettu käytöstä",
     "File sharing" : "Tiedostonjako",
     "Share will expire tomorrow" : "Jako vanhenee huomenna",
@@ -133,6 +137,8 @@ OC.L10N.register(
     "Sharing" : "Jakaminen",
     "Accept user and group shares by default" : "Hyväksy käyttäjä- ja ryhmäjaot oletuksena",
     "Set default folder for accepted shares" : "Aseta oletuskansio hyväksytyille jaoille",
+    "Reset" : "Palauta",
+    "Reset folder to system default" : "Palauta kansio järjestelmän oletukseksi",
     "Choose a default folder for accepted shares" : "Valitse oletuskansio hyväksytyille jaoille",
     "Invalid path selected" : "Virheellinen polku valittu",
     "Unknown error" : "Tuntematon virhe",
@@ -140,6 +146,10 @@ OC.L10N.register(
     "Read only" : "Vain luku",
     "Allow upload and editing" : "Salli lähetys ja muokkaus",
     "File drop (upload only)" : "Tiedostojen pudotus (vain lähetys)",
+    "Custom permissions" : "Mukautetut oikeudet",
+    "Read" : "Lue",
+    "Upload" : "Lähetä",
+    "Edit" : "Muokkaa",
     "Allow creating" : "Salli luominen",
     "Allow deleting" : "Salli poistaminen",
     "Allow resharing" : "Salli uudelleenjakaminen",
@@ -174,6 +184,8 @@ OC.L10N.register(
     "Share label" : "Jaon nimi",
     "Hide download" : "Piilota lataus",
     "Password protect" : "Suojaa salasanalla",
+    "Password expires {passwordExpirationTime}" : "Salasana vanhenee {passwordExpirationTime}",
+    "Password expired" : "Salasana vanheni",
     "Video verification" : "Videovarmistus",
     "Enter a note for the share recipient" : "Lisää muistiinpano jaon vastaanottajalle",
     "Add another link" : "Lisää toinen linkki",
@@ -214,14 +226,15 @@ OC.L10N.register(
     "Name" : "Nimi",
     "Share time" : "Jakamisen ajankohta",
     "Expiration date" : "Vanhenemispäivä",
-    "Sorry, this link doesn’t seem to work anymore." : "Valitettavasti linkki ei vaikuta enää toimivan.",
+    "Sorry, this link does not seem to work anymore." : "Valitettavasti tämä linkki ei vaikuta enää toimivan.",
     "Reasons might be:" : "Mahdollisia syitä saattavat olla:",
     "the item was removed" : "kohde poistettiin",
     "the link expired" : "linkki vanheni",
     "sharing is disabled" : "jakaminen on poistettu käytöstä",
     "For more info, please ask the person who sent this link." : "Kysy lisätietoja henkilöltä, jolta sait linkin.",
     "Share note" : "Jaa muistiinpano",
-    "Toggle grid view" : "Ruudukkonäkymä päälle/pois",
+    "Show list view" : "Näytä listanäkymä",
+    "Show grid view" : "Näytä ruudukkonäkymä",
     "Upload files to %s" : "Lähetä tiedostoja käyttäjälle %s",
     "Note" : "Huomio",
     "Select or drop files" : "Valitse tai pudota tiedostoja",
@@ -229,8 +242,10 @@ OC.L10N.register(
     "Uploaded files:" : "Lähetetyt tiedostot:",
     "By uploading files, you agree to the %1$sterms of service%2$s." : "Tiedostoja lähettämällä hyväksyt %1$skäyttöehdot%2$s.",
     "Add to your Nextcloud" : "Lisää Nextcloudiisi",
-    "invalid permissions" : "vialliset oikeudet",
-    "Can't change permissions for public share links" : "Julkisten jakolinkkien käyttöoikeuksia ei voi muuttaa",
-    "Download %s" : "Lataa %s"
+    "Wrong share ID, share doesn't exist" : "Väärä jakotunniste, jakoa ei ole olemassa",
+    "Wrong path, file/folder doesn't exist" : "Väärä polku, tiedostoa tai kansiota ei ole olemassa",
+    "Cannot change permissions for public share links" : "Julkisten jakolinkkien oikeuksia ei voi muuttaa",
+    "Sorry, this link doesn’t seem to work anymore." : "Valitettavasti linkki ei vaikuta enää toimivan.",
+    "Toggle grid view" : "Ruudukkonäkymä päälle/pois"
 },
 "nplurals=2; plural=(n != 1);");
