@@ -30,17 +30,20 @@ use OCA\Files_Trashbin\Capabilities;
 use OCA\Files_Trashbin\Expiration;
 use OCA\Files_Trashbin\Trash\ITrashManager;
 use OCA\Files_Trashbin\Trash\TrashManager;
-use OCP\App\IAppManager;
+use OCA\Files_Trashbin\UserMigration\TrashbinMigrator;
 use OCP\AppFramework\App;
 use OCP\AppFramework\Bootstrap\IBootContext;
 use OCP\AppFramework\Bootstrap\IBootstrap;
 use OCP\AppFramework\Bootstrap\IRegistrationContext;
+use OCP\App\IAppManager;
 use OCP\ILogger;
 use OCP\IServerContainer;
 
 class Application extends App implements IBootstrap {
+	public const APP_ID = 'files_trashbin';
+
 	public function __construct(array $urlParams = []) {
-		parent::__construct('files_trashbin', $urlParams);
+		parent::__construct(self::APP_ID, $urlParams);
 	}
 
 	public function register(IRegistrationContext $context): void {
@@ -50,6 +53,8 @@ class Application extends App implements IBootstrap {
 		$context->registerServiceAlias(ITrashManager::class, TrashManager::class);
 		/** Register $principalBackend for the DAV collection */
 		$context->registerServiceAlias('principalBackend', Principal::class);
+
+		$context->registerUserMigrator(TrashbinMigrator::class);
 	}
 
 	public function boot(IBootContext $context): void {
@@ -65,10 +70,10 @@ class Application extends App implements IBootstrap {
 		\OCP\Util::connectHook('OC_Filesystem', 'delete', 'OCA\Files_Trashbin\Trashbin', 'ensureFileScannedHook');
 
 		\OCA\Files\App::getNavigationManager()->add(function () {
-			$l = \OC::$server->getL10N('files_trashbin');
+			$l = \OC::$server->getL10N(self::APP_ID);
 			return [
 				'id' => 'trashbin',
-				'appname' => 'files_trashbin',
+				'appname' => self::APP_ID,
 				'script' => 'list.php',
 				'order' => 50,
 				'name' => $l->t('Deleted files'),
