@@ -46,7 +46,6 @@ use OC\Files\Search\SearchQuery;
 use OC_User;
 use OC\Files\Filesystem;
 use OC\Files\View;
-use OCA\Files_Sharing\SharedMount;
 use OCA\Files_Versions\AppInfo\Application;
 use OCA\Files_Versions\Command\Expire;
 use OCA\Files_Versions\Events\CreateVersionEvent;
@@ -176,6 +175,7 @@ class Storage {
 	 * store a new version of a file.
 	 */
 	public static function store($filename) {
+
 		// if the file gets streamed we need to remove the .part extension
 		// to get the right target
 		$ext = pathinfo($filename, PATHINFO_EXTENSION);
@@ -188,54 +188,33 @@ class Storage {
 			return false;
 		}
 
-		// since hook paths are always relative to the "default filesystem view"
-		// we always use the owner from there to get the full node
-		$uid = Filesystem::getView()->getOwner('');
+		[$uid, $filename] = self::getUidAndFilename($filename);
 
-		/** @var IRootFolder $rootFolder */
-		$rootFolder = \OC::$server->get(IRootFolder::class);
-		$userFolder = $rootFolder->getUserFolder($uid);
+		$files_view = new View('/'.$uid .'/files');
 
 		$eventDispatcher = \OC::$server->get(IEventDispatcher::class);
-		try {
-			$file = $userFolder->get($filename);
-		} catch (NotFoundException $e) {
-			return false;
-		}
-
-		$mount = $file->getMountPoint();
-		if ($mount instanceof SharedMount) {
-			$ownerFolder = $rootFolder->getUserFolder($mount->getShare()->getShareOwner());
-			$ownerNodes = $ownerFolder->getById($file->getId());
-			if (count($ownerNodes)) {
-				$file = current($ownerNodes);
-				$uid = $mount->getShare()->getShareOwner();
+		$fileInfo = $files_view->getFileInfo($filename);
+		$id = $fileInfo->getId();
+		$nodes = \OC::$server->get(IRootFolder::class)->getUserFolder($uid)->getById($id);
+		foreach ($nodes as $node) {
+			$event = new CreateVersionEvent($node);
+			$eventDispatcher->dispatch('OCA\Files_Versions::createVersion', $event);
+			if ($event->shouldCreateVersion() === false) {
+				return false;
 			}
 		}
 
-		/** @var IUserManager $userManager */
-		$userManager = \OC::$server->get(IUserManager::class);
-		$user = $userManager->get($uid);
-
-		if (!$user) {
-			return false;
-		}
-
 		// no use making versions for empty files
-		if ($file->getSize() === 0) {
-			return false;
-		}
-
-		$event = new CreateVersionEvent($file);
-		$eventDispatcher->dispatch('OCA\Files_Versions::createVersion', $event);
-		if ($event->shouldCreateVersion() === false) {
+		if ($fileInfo->getSize() === 0) {
 			return false;
 		}
 
 		/** @var IVersionManager $versionManager */
 		$versionManager = \OC::$server->get(IVersionManager::class);
+		$userManager = \OC::$server->get(IUserManager::class);
+		$user = $userManager->get($uid);
 
-		$versionManager->createVersion($user, $file);
+		$versionManager->createVersion($user, $fileInfo);
 	}
 
 
@@ -356,6 +335,7 @@ class Storage {
 	 * @return bool
 	 */
 	public static function rollback(string $file, int $revision, IUser $user) {
+
 		// add expected leading slash
 		$filename = '/' . ltrim($file, '/');
 
@@ -493,21 +473,11 @@ class Storage {
 					$filename = $pathparts['filename'];
 					if ($filename === $versionedFile) {
 						$pathparts = pathinfo($entryName);
-						$timestamp = substr($pathparts['extension'] ?? '', 1);
-						if (!is_numeric($timestamp)) {
-							\OC::$server->get(LoggerInterface::class)->error(
-								'Version file {path} has incorrect name format',
-								[
-									'path' => $entryName,
-									'app' => 'files_versions',
-								]
-							);
-							continue;
-						}
+						$timestamp = substr($pathparts['extension'], 1);
 						$filename = $pathparts['filename'];
 						$key = $timestamp . '#' . $filename;
 						$versions[$key]['version'] = $timestamp;
-						$versions[$key]['humanReadableTimestamp'] = self::getHumanReadableTimestamp((int)$timestamp);
+						$versions[$key]['humanReadableTimestamp'] = self::getHumanReadableTimestamp($timestamp);
 						if (empty($userFullPath)) {
 							$versions[$key]['preview'] = '';
 						} else {
@@ -573,9 +543,10 @@ class Storage {
 		});
 
 		foreach ($versions as $version) {
-			\OC_Hook::emit('\OCP\Versions', 'preDelete', ['path' => $version->getInternalPath(), 'trigger' => self::DELETE_TRIGGER_RETENTION_CONSTRAINT]);
+			$internalPath = $version->getInternalPath();
+			\OC_Hook::emit('\OCP\Versions', 'preDelete', ['path' => $internalPath, 'trigger' => self::DELETE_TRIGGER_RETENTION_CONSTRAINT]);
 			$version->delete();
-			\OC_Hook::emit('\OCP\Versions', 'delete', ['path' => $version->getInternalPath(), 'trigger' => self::DELETE_TRIGGER_RETENTION_CONSTRAINT]);
+			\OC_Hook::emit('\OCP\Versions', 'delete', ['path' => $internalPath, 'trigger' => self::DELETE_TRIGGER_RETENTION_CONSTRAINT]);
 		}
 	}
 
@@ -585,7 +556,7 @@ class Storage {
 	 * @param int $timestamp
 	 * @return string for example "5 days ago"
 	 */
-	private static function getHumanReadableTimestamp(int $timestamp): string {
+	private static function getHumanReadableTimestamp($timestamp) {
 		$diff = time() - $timestamp;
 
 		if ($diff < 60) { // first minute
