@@ -22,10 +22,8 @@ OC.L10N.register(
     "Sync tasks from various devices with your Nextcloud and edit them online." : "藉由 Nextcloud 從不同裝置同步任務並且線上編輯它們。",
     "App recommendation: Deck" : "推薦功能：Deck",
     "Kanban style organization for personal planning and team projects." : "以看板風格組織您的個人計劃和團隊專案。",
-    "App recommendation: Forms" : "推薦應用程式：Forms",
-    "Simple surveys and questionnaires, self-hosted" : "📝 自託管的簡單調查和問卷",
-    "App recommendation: Recognize" : "推薦應用程式：Recognize",
-    "Smart media tagging for Nextcloud" : "Nextcloud 的智能媒體標記",
+    "App recommendation: Notes" : "推薦功能：Notes",
+    "Distraction-free notes and writing." : "無干擾的筆記與寫作。",
     "App recommendation: Group folders" : "推薦功能：Group folders",
     "Admin-configured folders shared by everyone in a group." : "管理員設定的資料夾，與群組中的所有人分享。",
     "About" : "關於",
@@ -59,8 +57,8 @@ OC.L10N.register(
     "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "您想要取得 Nextcloud 特定的改進嗎？您有找到問題嗎？你想要幫忙翻譯，推動或是寫 Nextcloud 文件嗎？",
     "Become part of the Community" : "成為社群的一份子",
     "Enterprise support" : "企業支援",
-    "If you run Nextcloud in a mission critical environment where security and compliance are important, you need the certainty of Nextcloud Enterprise." : "如果您在安全性和合規性很重要的關鍵任務環境中運行 Nextcloud，則需要 Nextcloud Enterprise 的額外保護。",
-    "Learn more about Nextcloud Enterprise" : "了解更多關於 Nextcloud Enterprise",
+    "If you run Nextcloud in a mission critical environment with large numbers of users and big amounts of data and need the certainty of support from the experts behind the Nextcloud technology, an Enterprise Subscription from Nextcloud is available with email and phone support." : "如果您在有大量用戶與大量資料的關鍵任務環境中執行 Nextcloud，且需要 Nextcloud 技術背後的專家支援的話，則可以透過電子郵件與電話支援取得 Nextcloud 的企業訂閱。",
+    "Get enterprise support" : "獲得企業級支援",
     "Get more information" : "取得更多資訊",
     "The Nextcloud documentation for home users:" : "家居用戶的 Nextcloud 文件：",
     "User manual" : "用戶手冊",
@@ -68,6 +66,7 @@ OC.L10N.register(
     "Developer manual" : "開發人員使用手冊",
     "You can also ask for help in our community support channels:" : "您也可以在我們的社群支援頻道尋求協助",
     "the Nextcloud forums" : "Nextcloud論壇",
+    "the Nextcloud IRC chat channel on freenode.net" : "在freenode.net 上的 Nextcloud IRC 聊天頻道",
     "A safe home for all your data" : "您資料的安全屋",
     "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud 在您觸手可及的地方放置您的資料，在您的控制下。存放您的文件，日曆，聯絡人及相片在您公司，家中，任一個我們的提供者或是任何您知道的資料中心的伺服器上。",
     "Host your data and files where you decide" : "在您決定的位置存放您的資料與檔案",
@@ -82,11 +81,7 @@ OC.L10N.register(
     "Server address" : "伺服器位址",
     "Use this link to connect your apps and desktop client to this server:" : "使用此連結來連接您的應用程式及桌面客戶端到這伺服器：",
     "Copy link" : "複製連結",
-    "App recommendation: Notes" : "推薦功能：Notes",
-    "Distraction-free notes and writing." : "無干擾的筆記與寫作。",
-    "If you run Nextcloud in a mission critical environment with large numbers of users and big amounts of data and need the certainty of support from the experts behind the Nextcloud technology, an Enterprise Subscription from Nextcloud is available with email and phone support." : "如果您在有大量用戶與大量資料的關鍵任務環境中執行 Nextcloud，且需要 Nextcloud 技術背後的專家支援的話，則可以透過電子郵件與電話支援取得 Nextcloud 的企業訂閱。",
-    "Get enterprise support" : "獲得企業級支援",
-    "the Nextcloud IRC chat channel on freenode.net" : "在freenode.net 上的 Nextcloud IRC 聊天頻道",
+    "Android app" : "Android 應用程式",
     "Open Standards and Interoperability" : "開放標準及相互合作",
     "100%% Open Source & community-focused" : "100%% 專注於開源與社群"
 },
