@@ -30,4 +30,4 @@ OC.L10N.register(
     "Download logs" : "Télécharger les journaux",
     "Load log file …" : "Charger un fichier journal..."
 },
-"nplurals=2; plural=(n > 1);");
+"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
