@@ -3,6 +3,9 @@ OC.L10N.register(
     {
     "Nextcloud announcements" : "Anuncios do Nextcloud",
     "Nextcloud announcement" : "Anuncio do Nextcloud",
+    "Read more" : "Ler máis",
+    "Disable announcements" : "Desactivar os anuncioa",
+    "(These announcements are only shown to administrators)" : "(Estes anuncios só se amosan aos administradores)",
     "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "Os anuncios do Nextcloud incorporan as últimas noticias de Nextcloud nas súas notificacións.",
     "Shows the latest news of Nextcloud in your notifications." : "Amosa as últimas noticias do Nextcloud nas súas notificacións.",
     "These groups will be notified about the announcements." : "Estes grupos recibirán notificacións sobre os anuncios."
