@@ -23,8 +23,7 @@ OC.L10N.register(
     "No notifications" : "沒有通知",
     "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Nextcloud GmbH 為私人使用者贊助了一個免費的推送通知閘道。 為了確保良好的服務，閘道限制了每台服務器的推播通知數量。 對於企業使用者，可以使用更具擴展性的閘道。如需更多資訊，請聯絡 Nextcloud GmbH。",
     "Failed to dismiss all notifications" : "關閉所有通知失敗",
-    "Notifications defaults" : "通知預設值",
-    "Configure the default notification settings for new users" : "設定新使用者的預設通知設定",
+    "You need to set up your email address before you can receive notification emails." : "在您開始接收通知電子郵件前，您必須先設定您的電子郵件地址。",
     "Send email reminders about unhandled notifications after:" : "在多久之後傳送關於未處理通知的電子郵件提醒：",
     "Play sound when a new notification arrives" : "收到新通知時播放音效",
     "Play sound when a call started (requires Nextcloud Talk)" : "通話開始時播放音效（需要 Nextcloud Talk）",
@@ -34,7 +33,6 @@ OC.L10N.register(
     "1 day" : "1天",
     "1 week" : "1週",
     "Your settings have been updated." : "您的設定已更新。",
-    "An error occurred while updating your settings." : "更新您的設定時發生錯誤。",
-    "You need to set up your email address before you can receive notification emails." : "在您開始接收通知電子郵件前，您必須先設定您的電子郵件地址。"
+    "An error occurred while updating your settings." : "更新您的設定時發生錯誤。"
 },
 "nplurals=1; plural=0;");
