@@ -85,6 +85,13 @@ class TestPush extends Command {
 	 * @return int
 	 */
 	protected function execute(InputInterface $input, OutputInterface $output): int {
+		if (!$this->notificationManager->isFairUseOfFreePushService()) {
+			$output->writeln('<error>We want to keep offering our push notification service for free, but large</error>');
+			$output->writeln('<error>users overload our infrastructure. For this reason we have to rate-limit the</error>');
+			$output->writeln('<error>use of push notifications. If you need this feature, consider using Nextcloud Enterprise.</error>');
+			return 1;
+		}
+
 		$userId = $input->getArgument('user-id');
 		$subject = 'Testing push notifications';
 
