@@ -28,6 +28,6 @@ OC.L10N.register(
     "History size has to be a non negative number" : "El tamaño del histórico no puede ser un número negativo",
     "Expiration days have to be a non negative number" : "Los días de caducidad no pueden ser un número negativo",
     "Maximum login attempts have to be a non negative number" : "El número máximo de intentos de inicio de sesión no puede ser un número negativo",
-    "Password needs to be at least %s characters long" : "La contraseña debe tener al menos %s caracteres"
+    "Error while saving" : "Error al guardar"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
