@@ -13,4 +13,4 @@ OC.L10N.register(
     "Enforce special characters" : "Forçar caracteres especiais",
     "Unknown error" : "Erro desconhecido"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
