@@ -1,7 +1,7 @@
 OC.L10N.register(
     "password_policy",
     {
-    "Saved" : "Saqlangan",
-    "Unknown error" : "Noma'lum xatolik"
+    "Saved" : "Saved",
+    "Unknown error" : "Unknown error"
 },
 "nplurals=1; plural=0;");
