@@ -3,26 +3,39 @@ OC.L10N.register(
     {
     "Photos" : "Fotografies",
     "Your memories under your control" : "Els vostres records sota control",
-    "Your photos" : "Les vostres fotografies",
-    "Your videos" : "Els vostres vídeos",
+    "Videos" : "Vídeos",
+    "Albums" : "Àlbums",
+    "People" : "Gent",
+    "Folders" : "Carpetes",
     "Favorites" : "Preferits",
     "On this day" : "Aquest mateix dia",
-    "Your folders" : "Les vostres carpetes",
     "Shared with you" : "Compartit amb vós",
-    "Tagged photos" : "Fotografies etiquetades",
+    "Tags" : "Etiquetes",
     "Locations" : "Ubicacions",
+    "Back" : "Torna",
+    "Save" : "Desa",
     "Open the full size \"{name}\" image" : "Obre la imatge «{name}» a mida completa",
     "Open the \"{name}\" sub-directory" : "Obre la subcarpeta «{name}»",
-    "Share this folder" : "Comparteix la carpeta",
     "Back to {folder}" : "Torna a {folder}",
+    "Share this folder" : "Comparteix la carpeta",
     "_{years} year ago_::_{years} years ago_" : ["Fa {years} any","Fa {years} anys"],
-    "View" : "Visualitza",
     "Enable squared photos view" : "Habilita la visualització de fotos quadrades",
-    "This folder does not exist" : "Aquesta carpeta no existeix",
+    "View" : "Visualitza",
     "An error occurred" : "S'ha produït un error",
+    "Favorite" : "Preferit",
+    "Remove from favorites" : "Suprimeix dels preferits",
+    "This folder does not exist" : "Aquesta carpeta no existeix",
     "No photos in here" : "No hi ha cap fotografia",
     "No tags yet" : "Encara no hi ha etiquetes",
     "Photos with tags will show up here" : "Aquí es mostraran les fotografies amb etiquetes",
+    "Add" : "Afegeix",
+    "Download" : "Baixa",
+    "Delete selection" : "Suprimeix la selecció",
+    "Delete" : "Suprimeix",
+    "Tagged photos" : "Fotografies etiquetades",
+    "Your photos" : "Les vostres fotografies",
+    "Your videos" : "Els vostres vídeos",
+    "Your folders" : "Les vostres carpetes",
     "Settings" : "Paràmetres"
 },
 "nplurals=2; plural=(n != 1);");
