@@ -3,26 +3,40 @@ OC.L10N.register(
     {
     "Photos" : "Fotos",
     "Your memories under your control" : "Sus recuerdos bajo su control",
-    "Your photos" : "Tus fotos",
-    "Your videos" : "Tus vídeos",
+    "Videos" : "Vídeos",
+    "Albums" : "Álbumes",
+    "People" : "Personas",
+    "Folders" : "Carpetas",
     "Favorites" : "Favoritos",
     "On this day" : "En este día",
-    "Your folders" : "Tus carpetas",
     "Shared with you" : "Compartido contigo",
-    "Tagged photos" : "Fotos etiquetadas",
+    "Tags" : "Etiquetas",
     "Locations" : "Ubicaciones",
+    "Back" : "Atrás",
+    "Save" : "Guardar",
     "Open the full size \"{name}\" image" : "Abrir la imagen \"{name}\" a tamaño completo",
+    "Upload from computer" : "Cargar desde el ordenador",
     "Open the \"{name}\" sub-directory" : "Abrir el subdirectorio \"{name}\"",
-    "Share this folder" : "Compartir esta carpeta",
     "Back to {folder}" : "Atrás a {folder}",
+    "Share this folder" : "Compartir esta carpeta",
     "_{years} year ago_::_{years} years ago_" : ["Hace {years} año","Hace {years} años","Hace {years} años"],
-    "View" : "Ver",
     "Enable squared photos view" : "Habilitar vista de fotos cuadradas",
-    "This folder does not exist" : "Esta carpeta no existe",
+    "View" : "Ver",
     "An error occurred" : "Ocurrió un error",
+    "Favorite" : "Marcar como favorito",
+    "Remove from favorites" : "Eliminar de favoritos",
+    "This folder does not exist" : "Esta carpeta no existe",
     "No photos in here" : "No hay fotos aquí",
     "No tags yet" : "Todavía no hay etiquetas",
     "Photos with tags will show up here" : "Las fotos con etiquetas aparecerán aquí",
+    "Add" : "Añadir",
+    "Download" : "Descargar",
+    "Delete selection" : "Borrar la selección",
+    "Delete" : "Eliminar",
+    "Tagged photos" : "Fotos etiquetadas",
+    "Your photos" : "Tus fotos",
+    "Your videos" : "Tus vídeos",
+    "Your folders" : "Tus carpetas",
     "Settings" : "Ajustes"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
