@@ -3,19 +3,29 @@ OC.L10N.register(
     {
     "Photos" : "Fotos",
     "Your memories under your control" : "Tus recuerdos bajo tu control",
-    "Your photos" : "Tus Fotos",
+    "Videos" : "Videos",
+    "Folders" : "Carpetas",
     "Favorites" : "Favoritos",
     "Shared with you" : "Compartido con usted",
-    "Tagged photos" : "Fotos con etiquetas",
+    "Tags" : "Etiquetas",
     "Locations" : "Ubicaciones",
+    "Back" : "Atrás",
+    "Save" : "Guardar",
     "Open the full size \"{name}\" image" : "Abrir Imagen \"{name}\" en tamaño completo",
     "Open the \"{name}\" sub-directory" : "Abrir el sub-directorio de \"{name}\"",
     "Back to {folder}" : "Regresar a {folder}",
     "View" : "Ver",
     "An error occurred" : "Ha ocurrido un error",
+    "Favorite" : "Marcar como favorito",
+    "Remove from favorites" : "Eliminar de favoritos",
     "No photos in here" : "No hay fotos aquí",
     "No tags yet" : "Aún no hay etiquetas",
     "Photos with tags will show up here" : "Las fotos con etiquetas se mostrarán aquí",
+    "Add" : "Agregar",
+    "Download" : "Descargar",
+    "Delete" : "Eliminar",
+    "Tagged photos" : "Fotos con etiquetas",
+    "Your photos" : "Tus Fotos",
     "Settings" : "Configuraciones "
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
