@@ -3,19 +3,29 @@ OC.L10N.register(
     {
     "Photos" : "Fotos",
     "Your memories under your control" : "Tus recuerdos bajo tu control",
-    "Your photos" : "Tus fotos",
+    "Videos" : "Videos",
+    "Folders" : "Carpetas",
     "Favorites" : "Favoritos",
     "Shared with you" : "Compartido con usted",
-    "Tagged photos" : "Fotos etiquetadas",
+    "Tags" : "Etiquetas",
     "Locations" : "Ubicaciones",
+    "Back" : "Atrás",
+    "Save" : "Guardar",
     "Open the full size \"{name}\" image" : "Abrir la imagen \"{name}\" en tamaño completo",
     "Open the \"{name}\" sub-directory" : "Abrir el subdirectorio \"{name}\"",
-    "Share this folder" : "Compartir esta carpeta",
     "Back to {folder}" : "Volver a {folder}",
+    "Share this folder" : "Compartir esta carpeta",
     "An error occurred" : "Se presentó un error",
+    "Favorite" : "Hacer favorito",
+    "Remove from favorites" : "Eliminar de favoritos",
     "No photos in here" : "No hay fotos aquí",
     "No tags yet" : "Aún no hay etiquetas",
     "Photos with tags will show up here" : "Fotos con etiquetas serán mostradas aquí",
+    "Add" : "Agregar",
+    "Download" : "Descargar",
+    "Delete" : "Borrar",
+    "Tagged photos" : "Fotos etiquetadas",
+    "Your photos" : "Tus fotos",
     "Settings" : "Configuraciones "
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
