@@ -1,7 +1,6 @@
 OC.L10N.register(
     "photos",
     {
-    "Public link" : "Ligazón pública",
     "Photos" : "Fotos",
     "Your memories under your control" : "O seus recordos baixo o seu control",
     "Videos" : "Vídeos",
@@ -13,22 +12,22 @@ OC.L10N.register(
     "Locations" : "Localizacións",
     "Back" : "Atrás",
     "Save" : "Gardar",
-    "Copy public link" : "Copiar a ligazón pública",
-    "An error occurred" : "Produciuse un erro",
     "Open the full size \"{name}\" image" : "Abrir a imaxe «{name}» a tamaño completo",
     "Open the \"{name}\" sub-directory" : "Abrir o subdirectorio «{name}»",
     "Back to {folder}" : "Volver a {folder}",
     "Share this folder" : "Compartir este cartafol",
     "Enable squared photos view" : "Activar a vista de fotos cadradas",
     "View" : "Ver",
+    "An error occurred" : "Produciuse un erro",
     "Favorite" : "Favorito",
     "Remove from favorites" : "Retirar de favoritos",
     "No photos in here" : "Aquí non hai fotos",
-    "Shared albums" : "Albums compartidos",
     "No tags yet" : "Non hai nada etiquetado",
     "Photos with tags will show up here" : "As fotos etiquetadas aparecerán aquí",
     "Add" : "Engadir",
+    "Download" : "Descargar",
     "Delete selection" : "Eliminar a selección",
+    "Delete" : "Eliminar",
     "Tagged photos" : "Fotos etiquetadas",
     "Your photos" : "As súas fotos",
     "Your videos" : "Os seus vídeos",
