@@ -3,24 +3,36 @@ OC.L10N.register(
     {
     "Photos" : "Fotografije",
     "Your memories under your control" : "Upravljajte svojim sjećanjima",
-    "Your photos" : "Vaše fotografije",
-    "Your videos" : "Vaši videozapisi",
+    "Videos" : "Videozapisi",
+    "People" : "Ljudi",
+    "Folders" : "Mape",
     "Favorites" : "Favoriti",
-    "Your folders" : "Vaše mape",
     "Shared with you" : "Podijeljeno s vama",
-    "Tagged photos" : "Označene fotografije",
+    "Tags" : "Oznake",
     "Locations" : "Lokacije",
+    "Back" : "Natrag",
+    "Save" : "Spremi",
     "Open the full size \"{name}\" image" : "Otvori sliku „{name}” u punoj veličini",
     "Open the \"{name}\" sub-directory" : "Otvori poddirektorij „{name}”",
-    "Share this folder" : "Dijeli ovu mapu",
     "Back to {folder}" : "Natrag na {folder}",
-    "View" : "Pregledaj",
+    "Share this folder" : "Dijeli ovu mapu",
     "Enable squared photos view" : "Omogući kvadratni prikaz fotografija",
-    "This folder does not exist" : "Ova mapa ne postoji",
+    "View" : "Pregledaj",
     "An error occurred" : "Došlo je do pogreške",
+    "Favorite" : "Favorit",
+    "Remove from favorites" : "Ukloni iz favorita",
+    "This folder does not exist" : "Ova mapa ne postoji",
     "No photos in here" : "Ovdje nema fotografija",
     "No tags yet" : "Još nema oznaka",
     "Photos with tags will show up here" : "Ovdje će se prikazivati fotografije s oznakama",
+    "Add" : "Dodaj",
+    "Download" : "Preuzmi",
+    "Delete selection" : "Izbriši odabir",
+    "Delete" : "Izbriši",
+    "Tagged photos" : "Označene fotografije",
+    "Your photos" : "Vaše fotografije",
+    "Your videos" : "Vaši videozapisi",
+    "Your folders" : "Vaše mape",
     "Settings" : "Postavke"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
