@@ -3,27 +3,39 @@ OC.L10N.register(
     {
     "Photos" : "Ljósmyndir",
     "Your memories under your control" : "Haltu minningunum þínum undir þinni stjórn",
-    "Your photos" : "Ljósmyndirnar þínar",
-    "Your videos" : "Myndskeiðin þín",
+    "Videos" : "Myndskeið",
+    "People" : "Fólk",
+    "Folders" : "Möppur",
     "Favorites" : "Eftirlæti",
     "On this day" : "Á þessum degi",
-    "Your folders" : "Möppurnar þínar",
     "Shared with you" : "Deilt með þér",
-    "Tagged photos" : "Merktar ljósmyndir",
+    "Tags" : "Merki",
     "Locations" : "Staðsetningar",
     "Photos settings" : "Stillingar ljósmynda",
+    "Back" : "Til baka",
+    "Save" : "Vista",
     "Open the full size \"{name}\" image" : "Opna myndina \"{name}\" í fullri stærð",
     "Open the \"{name}\" sub-directory" : "Opna \"{name}\" undirmöppuna",
-    "Share this folder" : "Deila þessari möppu",
     "Back to {folder}" : "Til baka í {folder}",
+    "Share this folder" : "Deila þessari möppu",
     "_{years} year ago_::_{years} years ago_" : ["Fyrir {years} ári","Fyrir {years} árum"],
-    "View" : "Skoða",
     "Enable squared photos view" : "Virkja sýn með ferköntuðum myndum",
-    "This folder does not exist" : "Þessi mappa er ekki til",
+    "View" : "Skoða",
     "An error occurred" : "Villa kom upp",
+    "Favorite" : "Eftirlæti",
+    "Remove from favorites" : "Fjarlægja úr eftirlætum",
+    "This folder does not exist" : "Þessi mappa er ekki til",
     "No photos in here" : "Engar myndir hér",
     "No tags yet" : "Engin merki ennþá",
     "Photos with tags will show up here" : "Ljósmyndir með merkjum munu birtast hér",
+    "Add" : "Bæta við",
+    "Download" : "Sækja",
+    "Delete selection" : "Eyða vali",
+    "Delete" : "Eyða",
+    "Tagged photos" : "Merktar ljósmyndir",
+    "Your photos" : "Ljósmyndirnar þínar",
+    "Your videos" : "Myndskeiðin þín",
+    "Your folders" : "Möppurnar þínar",
     "Settings" : "Stillingar"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
