@@ -3,26 +3,40 @@ OC.L10N.register(
     {
     "Photos" : "Foto",
     "Your memories under your control" : "I tuoi ricordi sotto il tuo controllo",
-    "Your photos" : "Le tue foto",
-    "Your videos" : "I tuoi video",
+    "Videos" : "Video",
+    "Albums" : "Album",
+    "People" : "Persone",
+    "Folders" : "Cartelle",
     "Favorites" : "Preferiti",
     "On this day" : "In questo giorno",
-    "Your folders" : "Le tue cartelle",
     "Shared with you" : "Condivise con te",
-    "Tagged photos" : "Foto con tag",
+    "Tags" : "Etichette",
     "Locations" : "Posizioni",
+    "Back" : "Indietro",
+    "Save" : "Salva",
     "Open the full size \"{name}\" image" : "Apri l'immagine \"{name}\" a dimensione piena",
+    "Upload from computer" : "Carica dal computer",
     "Open the \"{name}\" sub-directory" : "Apri la sottocartella \"{name}\"",
-    "Share this folder" : "Condividi questa cartella",
     "Back to {folder}" : "Torna a {folder}",
+    "Share this folder" : "Condividi questa cartella",
     "_{years} year ago_::_{years} years ago_" : ["{years} anno fa","{years} anni fa","{years} anni fa"],
-    "View" : "Visualizza",
     "Enable squared photos view" : "Abilita vista foto quadrate",
-    "This folder does not exist" : "Questa cartella non esiste",
+    "View" : "Visualizza",
     "An error occurred" : "Si è verificato un errore",
+    "Favorite" : "Preferito",
+    "Remove from favorites" : "Rimuovi dai preferiti",
+    "This folder does not exist" : "Questa cartella non esiste",
     "No photos in here" : "Nessuna foto qui",
     "No tags yet" : "Ancora nessun tag",
     "Photos with tags will show up here" : "Le foto con i tag saranno mostrate qui",
+    "Add" : "Aggiungi",
+    "Download" : "Scarica",
+    "Delete selection" : "Elimina selezione",
+    "Delete" : "Elimina",
+    "Tagged photos" : "Foto con tag",
+    "Your photos" : "Le tue foto",
+    "Your videos" : "I tuoi video",
+    "Your folders" : "Le tue cartelle",
     "Settings" : "Impostazioni"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
