@@ -1,13 +1,11 @@
 OC.L10N.register(
     "photos",
     {
-    "Public link" : "Link público",
     "Photos" : "Fotos",
     "Your memories under your control" : "Suas memórias sob seu controle",
     "All media" : "Toda mídia",
     "Videos" : "Vídeos",
     "Albums" : "Álbuns",
-    "Collaborative albums" : "Álbuns colaborativos",
     "People" : "Pessoas",
     "Folders" : "Pastas",
     "Favorites" : "Favoritos",
@@ -16,9 +14,7 @@ OC.L10N.register(
     "Tags" : "Etiquetas",
     "Locations" : "Localizações",
     "Photos settings" : "Configurações de fotos",
-    "Mark selection as favorite" : "Marcar seleção como favorito",
-    "Add selection to favorites" : "Adicionar seleção aos favoritos",
-    "Remove selection from favorites" : "Remover seleção dos favoritos",
+    "_%n item_::_%n photos and videos_" : ["%nitem","%nfotos e vídeos","%nfotos e vídeos"],
     "Name of the album" : "Nome do álbum",
     "Location of the album" : "Localização do álbum",
     "Go back to the previous view." : "Ir para a visualização anterior.",
@@ -31,33 +27,18 @@ OC.L10N.register(
     "Create album" : "Criar álbum",
     "Back to the new album form." : "Voltar ao formulário de novo álbum.",
     "Add to Album" : "Adicionar ao Álbum",
-    "Add selection to album {albumName}" : "Adicionar seleção ao álbum {albumName}",
     "Create a new album." : "Criar um novo álbum.",
     "Create new album" : "Criar novo álbum",
     "New album" : "Novo álbum",
-    "_%n item_::_%n photos and videos_" : ["%nitem","%nfotos e vídeos","%nfotos e vídeos"],
     "_Share with %n user_::_Share with %n users_" : ["Compartilhar com %nusuário","Compartilhar com %nusuários","Compartilhar com %nusuários"],
-    "Add people or groups who can edit your album" : "Adicione pessoas ou grupos que podem editar seu álbum",
-    "Search for collaborators" : "Pesquisar colaboradores",
-    "Search people or groups" : "Pesquisar pessoas ou grupos",
-    "Add {collaboratorLabel} to the collaborators list" : "Adicionar {collaboratorsLabel} à lista de colaboradores",
-    "No collaborators available" : "Nenhum colaborador disponível",
-    "Remove {collaboratorLabel} from the collaborators list" : "Remova {collaboratorLabel} da lista de colaboradores",
-    "Copy the public link" : "Copiar link público",
-    "Public link copied!" : "Link público copiado!",
-    "Copy public link" : "Copiar link público",
-    "Delete the public link" : "Remover link público",
-    "Share via public link" : "Compartilhar via link público",
-    "Failed to fetch collaborators list." : "Falha ao buscar a lista de colaboradores.",
-    "Failed to fetch album." : "Falha ao buscar álbum.",
-    "Failed to update album." : "Falha ao atualizar álbum.",
-    "This collection does not exist" : "Esta coleção não existe",
-    "An error occurred" : "Ocorreu um erro",
+    "Add users who can edit your album" : "Adicionar usuários que podem editar seu álbum",
+    "Share this album via link" : "Compartilhar álbum via link",
+    "Search users, email or Federated Cloud ID" : "Buscar usuários, email ou Cloud ID Federado",
     "_%n photos_::_%n photos_" : ["%nfoto","%nfotos","%nfotos"],
     "Select image {imageName}" : "Selecionar imagem {imageName}",
     "The file is in the favorites" : "Esse arquivo está nos favoritos",
     "Open the full size \"{name}\" image" : "Abrir a imagem \"{name}\" no tamanho normal",
-    "There are no photos or videos yet!" : "Ainda não há fotos ou vídeos!",
+    "Upload from computer" : "Enviar do computador",
     "Add to {destination}" : "Adicionar a {destionation}",
     "Open the \"{name}\" sub-directory" : "Abrir o subdiretório \"{name}\"",
     "Back to {folder}" : "Voltar para {folder}",
@@ -65,31 +46,30 @@ OC.L10N.register(
     "_{years} year ago_::_{years} years ago_" : ["{anos} ano atrás","{anos} anos atrás","{anos} anos atrás"],
     "Enable squared photos view" : "Ativar exibição de fotos quadradas",
     "Default Photos upload and Albums location" : "Localização padrão de upload para fotos e álbuns",
-    "Select the default location for your media" : "Selecione o local padrão para sua mídia",
     "Invalid location selected" : "Invalidar localização selecionada",
     "View" : "Exibição",
     "Photos directory" : "Diretório de fotos",
-    "_%n photo_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
-    "Manage collaborators for this album" : "Gerenciar colaboradores para este álbum",
-    "Open actions menu" : "Abrir menu de ações",
+    "This album does not exist" : "Este álbum não existe",
+    "An error occurred" : "Ocorreu um erro",
+    "Add photos to this album" : "Adicionar fotos a este álbum",
+    "Share this album" : "Compartilhar este álbu",
     "Edit album details" : "Modificar detalhes do álbu",
     "Download all files in album" : "Baixar todos os arquivos do álbum",
-    "Delete album" : "Remover álbum",
+    "Download selection" : "Baixar seleção",
     "Download selected files" : "Baixar arquivos selecionados",
-    "Remove selection from album" : "Remover seleção do álbum",
-    "This album does not have any photos or videos yet!" : "Este álbum ainda não possui fotos ou vídeos!",
-    "Add photos to this album" : "Adicionar fotos a este álbum",
+    "Mark selection as favorite" : "Marcar seleção como favorito",
+    "Favorite" : "Favorito",
+    "Remove selection from favorites" : "Remover seleção dos favoritos",
+    "Remove from favorites" : "Remover dos favoritos",
+    "Delete album" : "Remover álbum",
     "Add photos to the album" : "Adicionar fotos ao álbum",
-    "Manage collaborators" : "Gerenciar colaboradores",
-    "Save collaborators for this album." : "Salve os colaboradores deste álbum.",
-    "Cover photo for album {albumName}" : "Foto da capa do álbum {albumName}",
-    "There is no album yet!" : "Ainda não há álbum!",
+    "Share the album" : "Compartilhar o álbum",
+    "_Remove item from album_::_Remove selection from album_" : ["Remover seleção do álbum","Remover seleção do álbum","Remover seleção do álbum"],
+    "Create a new album" : "Criar um novo álbum",
     "This person could not be found" : "Essa pessoa não pôde ser encontrada",
     "Rename person" : "Renomear pessoa",
     "Merge with different person" : "Unir com outra pessoa",
     "Download selected photos" : "Baixar fotos selecionadas",
-    "Favorite" : "Favorito",
-    "Remove from favorites" : "Remover dos favoritos",
     "Remove person" : "Remover pessoa",
     "Name of this person" : "Nome desta pessoa",
     "Merge person" : "Unir pessoa",
@@ -97,32 +77,27 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "Isso pode levar um tempo a depender do tamanho da sua biblioteca de fotos.",
     "Recognized people will show up here" : "Pessoas reconhecidas aparecerão aqui",
     "This folder does not exist" : "Esta pasta não existe",
-    "Loading folders …" : "Carregando pastas…",
     "No photos in here" : "Não há fotos aqui",
-    "Failed to fetch albums list." : "Falha ao buscar lista de álbuns.",
-    "Shared albums" : "Álbuns compartilhados",
-    "Cover photo for shared album {albumName}." : "Foto da capa do álbum compartilhado {albumName}.",
-    "Back to tags overview" : "Voltar para a visão geral das etiquetas",
-    "No photos with this tag yet" : "Ainda não há fotos com esta etiqueta",
     "No tags yet" : "Ainda não há marcações",
     "Photos with tags will show up here" : "Fotos com marcações serão mostradas aqui",
-    "Popular tags" : "Etiquetas populares",
     "Add" : "Adicionar",
-    "Create a new album" : "Criar um novo álbum",
+    "Upload media" : "Upload de mídia",
     "Add selection to an album" : "Adicionar seleção a um álbu",
     "Add to album" : "Adicionar a álbum",
+    "Download" : "Baixar",
     "Delete selection" : "Excluir seleção",
+    "Delete" : "Excluir",
+    "{startDate} to {endDate}" : "{startDate} até {endDate}",
+    "Failed to fetch albums list." : "Falha ao buscar lista de álbuns.",
     "Failed to fetch faces list." : "Falha ao buscar lista de rostos.",
-    "All your media" : "Todas as suas mídias",
     "Tagged photos" : "Fotos marcadas",
+    "Failed to favorite {fileName}." : "Falha ao favoritar {fileName}",
     "Failed to create {albumName}." : "Falha ao criar {albumName}.",
     "Failed to rename {currentAlbumName} to {newAlbumName}." : "Falha ao renomear {currentAlbumName} para {newAlbumName}.",
+    "Failed to update location of {albumName} to {newLocation}." : "Falha ao atualizar localização do {albumName} para {newLocation}.",
+    "Failed to delete {albumName}." : "Falha ao apagar {albumName}.",
     "Failed to rename {oldName} to {faceName}." : "Falha ao renomear {oldName} para {faceName}.",
     "Failed to delete {faceName}." : "Falha ao remover {faceName}.",
-    "Failed to delete {fileId}." : "Falha ao excluir {fileId}.",
-    "Failed to delete {fileName}." : "Falha ao excluir {fileName}.",
-    "Failed to set favorite state for {fileId}." : "Falha ao definir o estado de favorito para {fileId}.",
-    "Failed to set favorite state for {fileName}." : "Falha ao definir o estado de favorito para {fileName}.",
     "Your photos" : "Suas fotos",
     "Your videos" : "Seus vídeos",
     "Your folders" : "Suas pastas",
