@@ -11,22 +11,22 @@ OC.L10N.register(
     "Locations" : "Các địa điểm",
     "Back" : "Quay lại",
     "Save" : "Lưu",
-    "Copy public link" : "Sao chép liên kết công khai",
-    "An error occurred" : "Có lỗi đã xảy ra",
     "Open the full size \"{name}\" image" : "Mở kích thước đủ của ảnh \"{name}\"",
     "Open the \"{name}\" sub-directory" : "Mở thư mục phụ của \"{name}\" ",
     "Back to {folder}" : "Trở về {folder}",
     "Share this folder" : "Chia sẻ thư mục này",
     "Enable squared photos view" : "Bật chế độ xem theo ô",
     "View" : "Xem",
+    "An error occurred" : "Có lỗi đã xảy ra",
     "Favorite" : "Ưa thích",
     "Remove from favorites" : "Xóa khỏi ưa thích",
     "This folder does not exist" : "Thư mục này không tồn tại",
     "No photos in here" : "Không có ảnh nào trong này",
-    "Shared albums" : "Các tập ảnh đã chia sẽ",
     "No tags yet" : "Chưa gắn nhãn",
     "Photos with tags will show up here" : "Ảnh đã gắn nhãn sẽ được cho thấy trên này",
     "Add" : "Thêm",
+    "Download" : "Tải xuống",
+    "Delete" : "Xóa",
     "Tagged photos" : "Ảnh gắn nhãn",
     "Your photos" : "Ảnh của bạn",
     "Your videos" : "Video của bạn",
