@@ -3,19 +3,11 @@ OC.L10N.register(
     {
     "Privacy" : "개인 정보 취급 방침",
     "-" : "-",
-    "Remove external admin" : "외부 관리자 제거",
     "Add external admin" : "외부 관리자 추가",
-    "Name of external admin" : "외부 관리자 이름",
     "This server is using full-disk-encryption." : "이 서버에서 전체 디스크 암호화를 사용하고 있습니다.",
-    "Additionally, this server is protected with full-disk-encryption." : "추가적으로, 이 서버는 전체 디스크 암호화로 보호됩니다.",
     "This server is protected with full-disk-encryption." : "이 서버는 전체 디스크 암호화로 보호됩니다.",
     "Your files are not protected by encryption." : "파일이 더 이상 암호화로 보호되지 않습니다.",
-    "Your data is located in:" : "귀하의 데이터는 여기에 있습니다:",
-    "The admin has not selected the location of the server yet." : "관리자가 서버 위치를 지정하지 않았습니다.",
-    "Change data location" : "데이터 위치 변경",
-    "Please select a region" : "지역을 선택하십시오",
     "You don't have any shares with individual users." : "개인 사용자와 공유한 항목이 없습니다.",
-    "Somaliland" : "소말릴란드",
     "Andorra" : "안도라",
     "United Arab Emirates" : "아랍에미리트",
     "Afghanistan" : "아프가니스탄",
@@ -43,8 +35,6 @@ OC.L10N.register(
     "Benin" : "베냉",
     "Saint Barthélemy" : "성 바르텔레미",
     "Bermuda" : "버뮤다",
-    "Brunei" : "브루나이",
-    "Bolivia" : "볼리비아",
     "Bonaire, Sint Eustatius and Saba" : "보나이러",
     "Brazil" : "브라질",
     "Bahamas" : "바하마",
@@ -55,11 +45,9 @@ OC.L10N.register(
     "Belize" : "벨리즈",
     "Canada" : "캐나다",
     "Cocos (Keeling) Islands" : "코코스 킬링 제도",
-    "Democratic Republic of the Congo" : "콩고민주공화국",
     "Central African Republic" : "중앙아프리카공화국",
     "Congo" : "콩고",
     "Switzerland" : "스위스",
-    "Cote d'Ivoire" : "코트디부아르",
     "Cook Islands" : "쿡 제도",
     "Chile" : "칠레",
     "Cameroon" : "카메룬",
@@ -80,18 +68,14 @@ OC.L10N.register(
     "Ecuador" : "에콰도르",
     "Estonia" : "에스토니아",
     "Egypt" : "이집트",
-    "West Sahara" : "서사하라",
     "Eritrea" : "에리트레아",
     "Spain" : "스페인",
     "Ethiopia" : "에티오피아",
     "Finland" : "핀란드",
     "Fiji" : "피지",
-    "Falkland Islands" : "포글랜드 제도",
-    "Micronesia" : "미크로네시아",
     "Faroe Islands" : "패로제도",
     "France" : "프랑스",
     "Gabon" : "가봉",
-    "United Kingdom" : "영국",
     "Grenada" : "그레나다",
     "Georgia" : "조지아",
     "French Guiana" : "프랑스령 기아나",
@@ -122,7 +106,6 @@ OC.L10N.register(
     "India" : "인도",
     "British Indian Ocean Territory" : "영국령인도양식민지",
     "Iraq" : "이라크",
-    "Iran" : "이란",
     "Iceland" : "아이슬란드",
     "Italy" : "이탈리아",
     "Jamaica" : "자메이카",
@@ -133,12 +116,9 @@ OC.L10N.register(
     "Cambodia" : "캄보디아",
     "Kiribati" : "키리바시",
     "Saint Kitts and Nevis" : "세인트키츠 네비스",
-    "North Korea" : "북한",
-    "South Korea" : "대한민국",
     "Kuwait" : "쿠웨이트",
     "Cayman Islands" : "케이맨 제도",
     "Kazakhstan" : "카자흐스탄",
-    "Laos" : "라오스",
     "Lebanon" : "레바논",
     "Saint Lucia" : "세인트루시아",
     "Liechtenstein" : "리히텐슈타인",
@@ -151,11 +131,9 @@ OC.L10N.register(
     "Libya" : "리비아",
     "Morocco" : "모로코",
     "Monaco" : "모나코",
-    "Moldova" : "몰도바",
     "Montenegro" : "몬테네그로",
     "Madagascar" : "마다가스카르",
     "Marshall Islands" : "마셜제도",
-    "Macedonia" : "마케도니아",
     "Mali" : "말리",
     "Myanmar" : "미얀마",
     "Mongolia" : "몽골",
@@ -193,7 +171,6 @@ OC.L10N.register(
     "Saint Pierre and Miquelon" : "생피에르 미클롱",
     "Pitcairn" : "핏케언 제도",
     "Puerto Rico" : "푸에르토리코",
-    "Palestine" : "팔레스타인",
     "Portugal" : "포르투갈",
     "Palau" : "팔라우",
     "Paraguay" : "파라과이",
@@ -201,7 +178,6 @@ OC.L10N.register(
     "Réunion" : "레위니옹",
     "Romania" : "루마니아",
     "Serbia" : "세르비아",
-    "Russia" : "러시아",
     "Rwanda" : "르완다",
     "Saudi Arabia" : "사우디아라비아",
     "Solomon Islands" : "솔로몬제도",
@@ -221,7 +197,6 @@ OC.L10N.register(
     "South Sudan" : "남수단",
     "Sao Tome and Principe" : "상투메 프린시페 민주 공화국",
     "El Salvador" : "엘살바도르",
-    "Syria" : "시리아",
     "Swaziland" : "에스와티니",
     "Turks and Caicos Islands" : "터크스카이코스 제도",
     "Chad" : "차드",
@@ -237,19 +212,15 @@ OC.L10N.register(
     "Trinidad and Tobago" : "트리니다드토바고",
     "Tuvalu" : "투발루",
     "Taiwan" : "대만",
-    "Tanzania" : "탄자니아",
     "Ukraine" : "우크라이나",
     "Uganda" : "우간다",
     "United States Minor Outlying Islands" : "미국령 군소 제도",
-    "United States" : "미국",
     "Uruguay" : "우루과이",
     "Uzbekistan" : "우즈베키스탄",
     "Holy See" : "바티칸시국",
     "Saint Vincent and the Grenadines" : "세인트빈센트 그레나딘",
-    "Venezuela" : "베네수엘라",
     "Virgin Islands (British)" : "영국령 버진 아일랜드",
     "Virgin Islands (U.S.)" : "미국령 버진 아일랜드",
-    "Vietnam" : "베트남",
     "Vanuatu" : "바누아투",
     "Wallis and Futuna" : "왈리스에푸투나",
     "Samoa" : "사모아",
@@ -258,8 +229,7 @@ OC.L10N.register(
     "South Africa" : "남아프리카공화국",
     "Zambia" : "잠비아",
     "Zimbabwe" : "짐바브웨",
-    "Your %s account" : "당신의 %s 계정",
-    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "사용자의 데이터를 통해 해당 사용자가 어떤 사람인지 알 수 있으며, 이는 쉽게 오남용될 수 있습니다. 저희 Nextcloud는 모든 사람이 자신의 데이터 활용을 스스로 결정할 수 있는 권리가 있다고 믿습니다. Nextcloud는 사용자 데이터 선언(User Data Manifesto)에서 정의한 대로 사용자의 권리를 보호합니다!",
+    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "내 데이터를 통해서 개인을 식별할 수 있고 쉽게 잘못 사용될 수 있습니다. 저희 Nextcloud는 모든 사람이 자신의 데이터를 사용할 방법을 결정할 수 있는 권리가 있다고 믿습니다. Nextcloud는 사용자 데이터 선언(User Data Manifesto)에서 정의한 대로 사용자의 권리를 보호합니다!",
     "User Data Manifesto 2.0" : "User Data Manifesto 2.0",
     "Defining basic rights for people to control their own data in the internet age" : "인터넷에서 사람들의 데이터를 제어하는 기본 권리 선언",
     "Control" : "제어:",
