@@ -54,6 +54,7 @@ OC.L10N.register(
     "Colombia" : "Kolumbija",
     "Costa Rica" : "Kosta Rika",
     "Cuba" : "Kuba",
+    "Christmas Island" : "Kalėdų sala",
     "Cyprus" : "Kipras",
     "Czech" : "Čekija",
     "Germany" : "Vokietija",
@@ -71,12 +72,14 @@ OC.L10N.register(
     "Finland" : "Suomija",
     "Fiji" : "Fidžis",
     "Falkland Islands" : "Folklando salos",
+    "Faroe Islands" : "Farerų salos",
     "France" : "Prancūzija",
     "Gabon" : "Gabonas",
     "United Kingdom" : "Jungtinė Karalystė",
     "Grenada" : "Grenada",
     "Georgia" : "Gruzija",
     "Ghana" : "Gana",
+    "Gibraltar" : "Gibraltaras",
     "Greenland" : "Grenlandija",
     "Gambia" : "Gambija",
     "Guinea" : "Gvinėja",
@@ -86,6 +89,7 @@ OC.L10N.register(
     "Guinea-Bissau" : "Bisau Gvinėja",
     "Guyana" : "Gajana",
     "Honduras" : "Hondūras",
+    "Hong Kong" : "Honkongas",
     "Croatia" : "Kroatija",
     "Haiti" : "Haitis",
     "Hungary" : "Vengrija",
@@ -124,6 +128,7 @@ OC.L10N.register(
     "Moldova" : "Moldova",
     "Montenegro" : "Juodkalnija",
     "Madagascar" : "Madagaskaras",
+    "Marshall Islands" : "Maršalo salos",
     "Macedonia" : "Makedonija",
     "Mali" : "Malis",
     "Myanmar" : "Mianmaras",
@@ -220,8 +225,6 @@ OC.L10N.register(
     "Privacy policy" : "Privatumo politika",
     "Read the privacy policy." : "Skaitykite privatumo politiką.",
     "Encryption" : "Šifravimas",
-    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Jūsų failai yra šifruoti naudojant {linkopen}serverio šifravimą ↗{linkclose}.",
-    "Your data is located in: " : "Jūsų duomenų vieta yra čia: ",
     "The admin hasn't selected the location of the server yet." : "Administratorius kol kas nepasirinko serverio vietovės."
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
