@@ -11,4 +11,4 @@ OC.L10N.register(
     "No recommendations yet" : "Ancora nessun consiglio",
     "Show recommendations" : "Mostra consigli"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
