@@ -3,7 +3,9 @@ OC.L10N.register(
     {
     "CPU info not available" : "Information CPU non disponible",
     "Load average: {cpu} (last minute)" : "Moyenne de la charge : (CPU) (dernière minute)",
+    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM : Total : {memTotalBytes}/Utilisation actuelle : {memUsageBytes}",
     "RAM info not available" : "Informations sur la RAM non disponibles",
+    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP : Total : {swapTotalBytes}/Utilisation actuelle : {swapUsageBytes}",
     "SWAP info not available" : "L'information SWAP n'est pas disponible",
     "Users" : "Utilisateurs",
     "Groups" : "Groupes",
@@ -28,10 +30,14 @@ OC.L10N.register(
     "CPU:" : "CPU :",
     "Unknown Processor" : "Processeur inconnu",
     "Memory:" : "Mémoire :",
+    "Server time:" : "Heure du serveur :",
+    "Uptime:" : "Durée de fonctionnement :",
     "Temperature" : "Température",
     "Load" : "Charge",
     "Memory" : "Mémoire",
     "Disk" : "Disque",
+    "Mount:" : "Montage :",
+    "Filesystem:" : "Système de fichiers :",
     "Size:" : "Taille :",
     "Available:" : "Disponible :",
     "Used:" : "Utilisé :",
