@@ -21,21 +21,35 @@ OC.L10N.register(
     "Monitoring" : "Seguimento",
     "Monitoring app with useful server information" : "Aplicación de seguimento con información útil do servidor",
     "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fornece información útil do servidor, como a carga da CPU, o uso da memoria RAM, o uso do disco, o número de usuarios, etc.",
+    "Temperature" : "Temperatura",
     "Load" : "Carga",
     "Memory" : "Memoria",
     "Disk" : "Disco",
     "Size:" : "Tamaño:",
+    "Used:" : "Usado:",
     "You will get a notification once one of your disks is nearly full." : "Recibirá unha notificación cando un dos seus discos estea case completo.",
     "Files:" : "Ficheiros:",
     "Storages:" : "Almacenamentos:",
     "Free Space:" : "Espazo libre:",
     "Network" : "Rede",
+    "Hostname:" : "Nome de máquina:",
+    "DNS:" : "DNS:",
+    "Gateway:" : "Pasarela:",
+    "Status:" : "Estado:",
+    "Speed:" : "Velocidade:",
+    "MAC:" : "MAC:",
+    "IPv4:" : "IPv4:",
+    "IPv6:" : "IPv6:",
     "Active users" : "Usuarios activos",
     "Total users:" : "Total de usuarios:",
     "Shares" : "Comparticións",
     "PHP" : "PHP",
     "Version:" : "Versión:",
+    "Memory limit:" : "Límite de memoria:",
+    "Max execution time:" : "Tempo máximo de execución:",
     "Upload max size:" : "Tamaño máximo de envío:",
+    "Extensions:" : "Extensións:",
+    "Unable to list extensions" : "Non foi posíbel listar as extensións",
     "Database" : "Base de datos",
     "Type:" : "Tipo:",
     "External monitoring tool" : "Ferramenta externa de supervisión",
