@@ -3,6 +3,9 @@ OC.L10N.register(
     {
     "Users" : "អ្នកប្រើ",
     "Groups" : "ក្រុ",
+    "Copied!" : "បានចម្លង",
+    "Press ⌘-C to copy." : " ចុច ⌘-C ដើម្បីចម្លង",
+    "Press Ctrl-C to copy." : "ចុច Ctrl-C ដើម្បីចម្លង",
     "Size:" : "ទំហំ៖",
     "Shares" : "ចែក​រំលែក",
     "Type:" : "ប្រភេទ៖",
