@@ -4,25 +4,31 @@ OC.L10N.register(
     "Users" : "Brukarare",
     "Groups" : "Grupper",
     "Links" : "Lenker",
+    "Copy" : "Kopier",
     "Copied!" : "Kopiert!",
     "Not supported!" : "Ikkje støtta!",
     "Press ⌘-C to copy." : "Trykk  ⌘-C for å kopiere.",
     "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere.",
+    "System" : "System",
     "Monitoring" : "Overvåker",
-    "Size" : "Storleik",
-    "Status" : "Status",
+    "Size:" : "Storleik:",
+    "Files:" : "Filar:",
     "Active users" : "Aktive brukarare",
     "Shares" : "Delingar",
+    "Upload max size:" : "Maks opplastning storleik:",
     "Database" : "Database",
+    "Type:" : "Type:",
     "External monitoring tool" : "Eksternt monoitor verktøy",
     "Last minute" : "Siste minutt",
     "Memory info not available" : "Minne informasjon ikkje tilgjengleg",
     "Total" : "Totalt",
     "Current usage" : "Nåverende bruk",
-    "Files:" : "Filar:",
+    "Size" : "Storleik",
+    "Hostname" : "Vertsnamn",
+    "Status" : "Status",
     "Memory Limit:" : "Minne grense:",
-    "Upload max size:" : "Maks opplastning storleik:",
-    "Type:" : "Type:",
-    "Size:" : "Storleik:"
+    "Files" : "Filer",
+    "Version" : "Utgåve",
+    "Type" : "Type"
 },
 "nplurals=2; plural=(n != 1);");
