@@ -11,11 +11,16 @@ OC.L10N.register(
     "Press ⌘-C to copy." : "Apasă ⌘-C pentru copiere.",
     "Press Ctrl-C to copy." : "Apasă Ctrl-C pentru copiere.",
     "System" : "Sistem",
-    "Size" : "Mărime",
-    "Hostname" : "Nume mașină",
-    "Status" : "Stare",
+    "Size:" : "Mărime:",
     "Shares" : "Partajări",
     "Type:" : "Tip:",
-    "Size:" : "Mărime:"
+    "Mails" : "Mailuri",
+    "Size" : "Mărime",
+    "Available" : "Disponibil",
+    "Hostname" : "Nume mașină",
+    "Status" : "Stare",
+    "Files" : "Fișiere",
+    "Version" : "Versiune",
+    "Type" : "Tip"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
