@@ -11,7 +11,6 @@ OC.L10N.register(
     "So-so password" : "Contraseña pasable",
     "Good password" : "Contraseña bona",
     "Strong password" : "Contraseña mui bona",
-    "Select a profile picture" : "Esbillar una imaxe de perfil",
     "Groups" : "Grupos",
     "{actor} changed your password" : "{actor} camudó la to contraseña",
     "You changed your password" : "Camudesti la to contraseña",
@@ -118,12 +117,19 @@ OC.L10N.register(
     "This is the final warning: Do you really want to enable encryption?" : "Esta ye l'alvertencia final: ¿De xuru que quies activar el cifráu?",
     "No encryption module loaded, please enable an encryption module in the app menu." : "Nun se cargó dengún módulu de cifráu, activa un módulu de cifráu nel menú d'aplicaciones.",
     "Select default encryption module:" : "Esbilla'l módulu predetermináu de cifráu:",
+    "Current password" : "Contraseña actual",
+    "New password" : "Contraseña nueva",
+    "Change password" : "Camudar contraseña",
+    "png or jpg, max. 20 MB" : "png o jpg, máximu 20 MB",
+    "Picture provided by original account" : "Semeya fornida pola cuenta orixinal",
+    "Cancel" : "Encaboxar",
     "Your email address" : "Direición de corréu-e",
     "No email address set" : "Nun s'afitó denguna direición de corréu",
     "Language" : "Llingua",
     "Help translate" : "Ayúdanos nes traducciones",
+    "Your phone number" : "El to númberu de teléfonu",
+    "Your website" : "El to sitiu web",
     "Add" : "Amestar",
-    "Cancel" : "Encaboxar",
     "{size} used" : "{size} usaos",
     "Display name" : "Nome",
     "Email" : "Corréu-e",
@@ -148,7 +154,8 @@ OC.L10N.register(
     "Not saved" : "Nun se guardó",
     "Sending…" : "Unviando...",
     "Email sent" : "Corréu-e unviáu",
-    "Address" : "Direición",
+    "Location" : "Llocalización",
+    "Profile picture" : "Semeya de perfil",
     "About" : "Tocante a",
     "Full name" : "Nome completu",
     "Phone number" : "Númberu de teléfonu",
@@ -196,19 +203,9 @@ OC.L10N.register(
     "Follow us on Twitter" : "Síguimos en Twitter.",
     "Check out our blog" : "Comprueba'l nuesu blogue",
     "Subscribe to our newsletter" : "Soscríbite al nuesu boletín",
-    "Profile picture" : "Semeya de perfil",
-    "Upload new" : "Xubir otra",
-    "Remove image" : "Desaniciar imaxe",
-    "png or jpg, max. 20 MB" : "png o jpg, máximu 20 MB",
-    "Picture provided by original account" : "Semeya fornida pola cuenta orixinal",
-    "Your phone number" : "El to númberu de teléfonu",
-    "Your postal address" : "La to direición postal",
-    "Link https://…" : "Enllaz https://…",
-    "Current password" : "Contraseña actual",
-    "New password" : "Contraseña nueva",
-    "Change password" : "Camudar contraseña",
     "Migration in progress. Please wait until the migration is finished" : "Migración en cursu. Espera fasta que la migración fine, por favor.",
     "Migration started …" : "Migración aniciada...",
+    "Select a profile picture" : "Esbillar una imaxe de perfil",
     "Couldn't remove app." : "Nun pudo desaniciase l'aplicación.",
     "Couldn't update app." : "Nun pudo anovase l'aplicación.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "El backend nun sofita'l cambéu de contraseña pero anovóse la clave del cifráu d'usuarios",
@@ -224,6 +221,11 @@ OC.L10N.register(
     "Recommended" : "Recomendáu",
     "The cron.php needs to be executed by the system user \"%s\"." : "cron.php precisa executalu l'usuariu del sistema «%s».",
     "days" : "díes",
-    "No display name set" : "Nun s'afitó'l nome p'amosar"
+    "Upload new" : "Xubir otra",
+    "Remove image" : "Desaniciar imaxe",
+    "No display name set" : "Nun s'afitó'l nome p'amosar",
+    "Address" : "Direición",
+    "Your postal address" : "La to direición postal",
+    "Link https://…" : "Enllaz https://…"
 },
 "nplurals=2; plural=(n != 1);");
