@@ -2,6 +2,7 @@ OC.L10N.register(
     "settings",
     {
     "Private" : "Privat",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Només visible per a les persones que coincideixen mitjançant la integració del número de telèfon a través de Talk al mòbil",
     "Local" : "Local",
     "Only visible to people on this instance and guests" : "Només visible per a les persones d'aquesta instància i convidats",
     "Federated" : "Federat",
@@ -18,7 +19,6 @@ OC.L10N.register(
     "Strong password" : "Contrasenya forta",
     "An error occurred while changing your language. Please reload the page and try again." : "S'ha produït un error mentre es canviava el vostre idioma. Si us plau, recarregueu la pàgina i torneu-ho a provar.",
     "An error occurred while changing your locale. Please reload the page and try again." : "S'ha produït un error mentre es canviava la vostra configuració regional. Si us plau, recarregueu la pàgina i torneu-ho a provar.",
-    "Select a profile picture" : "Seleccioneu una imatge de perfil",
     "Week starts on {fdow}" : "La setmana comença en {fdow}",
     "Groups" : "Grups",
     "Group list is empty" : "La llista de grups està buida",
@@ -119,7 +119,7 @@ OC.L10N.register(
     "Personal" : "Personal",
     "Administration" : "Administració",
     "Additional settings" : "Paràmetres addicionals",
-    "Admin privileges" : "Privilegis d'administrador",
+    "Administration privileges" : "Privilegis d'administració",
     "Groupware" : "Treball en grup",
     "Overview" : "Resum",
     "Basic settings" : "Configuració bàsica",
@@ -145,7 +145,6 @@ OC.L10N.register(
     "Profile information" : "Informació del perfil",
     "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Imatge del perfil, nom complet, correu electrònic, número de telèfon, adreça, lloc web, Twitter, organització, rol, titular, biografia i si el vostre perfil està habilitat",
     "Nextcloud settings" : "Paràmetres del Nextcloud",
-    "Administration privileges" : "Privilegis d'administració",
     "Here you can decide which group can access certain sections of the administration settings." : "Aquí podeu decidir quin grup pot accedir a certes seccions dels paràmetres d'administració.",
     "None" : "Cap",
     "Unable to modify setting" : "No es pot modificar el paràmetre",
@@ -231,16 +230,24 @@ OC.L10N.register(
     "Copy" : "Copia",
     "Could not copy app password. Please copy it manually." : "No s’ha pogut copiar la contrasenya de l’aplicació. Copieu-la manualment.",
     "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Perquè el servidor funcioni correctament, és important configurar els treballs en segon pla correctament. Cron és el paràmetre recomanat. Per a més informació, vegeu la documentació.",
+    "Last job execution ran {time}. Something seems wrong." : "L'última execució de la tasca s'ha executat a les {time}. Sembla que hi ha algun problema.",
     "Background job did not run yet!" : "La tasca en segon pla encara no s'ha executat",
     "AJAX" : "AJAX",
     "Execute one task with each page loaded. Use case: Single user instance." : "Executeu una tasca amb cada pàgina carregada. Cas d'ús: instància d'un sol usuari.",
     "Webcron" : "Webcron",
+    "Cron (Recommended)" : "Cron (recomanat)",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Per executar això es necessita l'extensió POSIX de PHP. Per més detalls, vegeu {linkstart}documentació de PHP{linkend}.",
+    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Utilitzeu el servei cron del sistema per a cridar el fitxer cron.php cada 5 minuts. Recomanat per a totes les instàncies.",
+    "The cron.php needs to be executed by the system user \"{user}\"." : "El cron.php l'ha d'executar l'usuari del sistema \"{user}\".",
+    "Unable to update background job mode" : "No s'ha pogut actualitzar el mode de tasca en segon pla",
     "Profile" : "Perfil",
+    "Enable or disable profile by default for new users." : "Habiliteu o deshabiliteu el perfil per defecte per als usuaris nous.",
     "Enable" : "Activa",
+    "Unable to update profile default setting" : "No s'ha pogut actualitzar la configuració predeterminada del perfil",
     "Server-side encryption" : "Encriptació en el servidor",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "L'encriptació en el servidor permet xifrar els fitxers que s'hi carreguen. Això afecta al rendiment, així que activeu-ho només si és necessari.",
     "Enable server-side encryption" : "Activa l'encriptació en el servidor",
+    "Please read carefully before activating server-side encryption:" : "Llegiu atentament abans d'activar el xifratge del servidor:",
     "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Un cop s’activi l'encriptació, tots els fitxers carregats al servidor des d'aquest punt cap endavant quedaran encriptats al servidor. Només serà possible desactivar l'encriptació posteriorment si el mòdul criptogràfic actiu té aquesta funció, i es compleixen totes les pre-condicions (p. ex. definir una clau de recuperació).",
     "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "L'encriptació per si mateixa no garanteix la seguretat del sistema. Consulteu la documentació per a més informació sobre com funciona l'aplicació d'encriptació i els casos d'ús suportats.",
     "Be aware that encryption always increases the file size." : "Tingueu en compte que l'encriptació sempre augmenta la mida del fitxer.",
@@ -248,14 +255,43 @@ OC.L10N.register(
     "This is the final warning: Do you really want to enable encryption?" : "Avís final: Realment voleu activar l'encriptació?",
     "No encryption module loaded, please enable an encryption module in the app menu." : "No s'ha carregat cap mòdul d'encriptació, si us plau activeu un mòdul d'encriptació al menú d'aplicacions.",
     "Select default encryption module:" : "Seleccioneu el mòdul criptogràfic per defecte:",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Heu de migrar les claus de xifratge del xifratge anterior (ownCloud .= 8.0) al nou. Habiliteu el \"Mòdul de xifratge peredeterminat\" i executeu {command}",
+    "Unable to update server side encryption config" : "No es pot actualitzar la configuració del xifratge de la banda del servidor",
+    "Rename group" : "Canvia el nom del grup",
     "Remove group" : "Suprimeix el grup",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Esteu a punt de suprimir el grup {group}. Els usuaris NO seran suprimits.",
     "Please confirm the group removal " : "Confirmeu la supressió del grup ",
+    "Current password" : "Contrasenya actual",
+    "New password" : "Contrasenya nova",
+    "Change password" : "Canvia la contrasenya",
+    "Your profile picture" : "La vostra imatge de perfil",
+    "Upload profile picture" : "Puja la imatge de perfil",
+    "Choose profile picture from files" : "Trieu una imatge de perfil als fitxers",
+    "Remove profile picture" : "Treu la imatge de perfil",
+    "png or jpg, max. 20 MB" : "png o jpg, màx. 20 MB",
+    "Picture provided by original account" : "Imatge proporcionada pel compte original",
+    "Cancel" : "Cancel·la",
+    "Set as profile picture" : "Estableix com a imatge de perfil",
+    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Tingueu en compte que la imatge de perfil pot tardar fins a 24 hores a actualitzar-se  a tot arreu.",
+    "Choose your profile picture" : "Trieu la vostra imatge de perfil",
+    "Please select a valid png or jpg file" : "Seleccioneu un fitxer png o jpg vàlid",
+    "Error setting profile picture" : "Error en establir la imatge de perfil",
+    "Error cropping profile picture" : "Error en retallar la imatge de perfil",
+    "Error saving profile picture" : "Error en desar la imatge de perfil",
+    "Error removing profile picture" : "Error en treure la imatge de perfil",
+    "Your biography" : "La vostra biografia",
+    "Your full name" : "El vostre nom complet",
+    "Email options" : "Opcions de correu electrònic",
+    "Primary email for password reset and notifications" : "Adreça electrònica principal per a restablir la contrasenya i per a les notificacions",
+    "Remove primary email" : "Treu l'adreça electrònica principal",
+    "Delete email" : "Treu l'adreça electrònica",
     "Your email address" : "El vostre correu electrònic",
     "No email address set" : "No s'ha establert cap adreça de correu electrònic",
     "Language" : "Llengua",
     "Help translate" : "Ajudeu-nos amb la traducció",
     "No language set" : "No s'ha establert cap idioma",
+    "Your phone number" : "El vostre número de telèfon",
+    "Your website" : "El teu lloc web",
     "Add" : "Afegeix",
     "You do not have permissions to see the details of this user" : "No teniu els permisos necessaris per veure els detalls d'aquest usuari",
     "Add new password" : "Afegeix una nova contrasenya",
@@ -270,7 +306,6 @@ OC.L10N.register(
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "En cas de perdre un dispositiu o sortir de l’organització, es pot esborrar de forma remota les dades del Nextcloud de tots els dispositius associats a {userid}. Només funciona si els dispositius estan connectats a Internet.",
     "Remote wipe of devices" : "Neteja remota de dispositius",
     "Wipe {userid}'s devices" : "Neteja els dispositius de {userid}",
-    "Cancel" : "Cancel·la",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "Suprimeix completament el compte de {userid} inclosos tots els seus fitxers personals, dades d'aplicacions, etc.",
     "Account deletion" : "Supressió del compte",
     "Delete {userid}'s account" : "Suprimeix el compte de {userid}",
@@ -332,8 +367,8 @@ OC.L10N.register(
     "Not saved" : "No s'ha desat",
     "Sending…" : "S'està enviant…",
     "Email sent" : "S'ha enviat el correu electrònic",
-    "Address" : "Adreça",
-    "Avatar" : "Avatar",
+    "Location" : "Ubicació",
+    "Profile picture" : "Foto de perfil",
     "About" : "Quant a",
     "Full name" : "Nom complet",
     "Headline" : "Titular",
@@ -346,7 +381,6 @@ OC.L10N.register(
     "Enable untested app" : "Activa aplicacions no provades",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Aquesta aplicació no està marcada com a compatible amb la vostra versió de Nextcloud. Si continueu, encara podreu instal·lar l’aplicació. Tingueu en compte que pot ser que l’aplicació no funcioni correctament.",
     "Never" : "Mai",
-    "An error occured during the request. Unable to proceed." : "S'ha produït un error durant la sol·licitud. No es pot continuar.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'aplicació s'ha activat però ha de ser actualitzada. Sereu redirigits a la pàgina d’actualització d'aquí 5 segons.",
     "Administrator documentation" : "Documentació d'administrador",
     "Documentation" : "Documentació",
@@ -404,29 +438,15 @@ OC.L10N.register(
     "Check out our blog" : "Consulteu el nostre bloc",
     "Subscribe to our newsletter" : "Subscriviu-vos al nostre butlletí",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Aquest llançament de la comunitat de Nextcloud no és compatible i les notificacions instantànies no estan disponibles.",
-    "Profile picture" : "Foto de perfil",
-    "Upload new" : "Carrega'n una de nova",
-    "Select from Files" : "Selecciona dels Fitxers",
-    "Remove image" : "Suprimeix imatge",
-    "png or jpg, max. 20 MB" : "png o jpg, màx. 20 MB",
-    "Picture provided by original account" : "Imatge proporcionada pel compte original",
-    "Choose as profile picture" : "Tria una imatge de perfil",
     "You are a member of the following groups:" : "Sou membre dels grups següents:",
     "You are using <strong>%s</strong>" : "Esteu utilitzant <strong>%s</strong>",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Esteu utilitzant <strong>%1$s</strong> de <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
-    "Your phone number" : "El vostre número de telèfon",
-    "Your postal address" : "La vostra adreça postal",
-    "It can take up to 24 hours before the account is displayed as verified." : "Pot trigar fins a 24 hores abans que el compte es mostri com a verificat.",
-    "Link https://…" : "Enllaç https://…",
-    "Twitter handle @…" : "Compte Twitter @…",
     "Locale" : "Configuració regional",
-    "Current password" : "Contrasenya actual",
-    "New password" : "Contrasenya nova",
-    "Change password" : "Canvia la contrasenya",
     "Use a second factor besides your password to increase security for your account." : "Feu servir un segon factor a més de la vostra contrasenya per augmentar la seguretat del vostre compte.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si utilitzeu aplicacions de tercers per a connectar-vos a Nextcloud, assegureu-vos de crear i configurar una contrasenya d'aplicació per a cadascuna abans d'habilitar l'autenticació de segon factor.",
     "Migration in progress. Please wait until the migration is finished" : "Migració en procés. Si us plau, espereu fins que finalitzi la migració",
     "Migration started …" : "S'ha iniciat la migració …",
+    "Select a profile picture" : "Seleccioneu una imatge de perfil",
     "Couldn't remove app." : "No s'ha pogut suprimit l'aplicació.",
     "Couldn't update app." : "No s'ha pogut actualitzar l'aplicació.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "El mòdul de suport no admet canvis de contrasenya, però la clau de xifrat de l'usuari ha estat actualitzada satisfactòriament.",
@@ -434,6 +454,7 @@ OC.L10N.register(
     "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Revocant aquest token impedirà la neteja del vostre dispositiu si encara no ha començat.",
     "All languages" : "Tots els idiomes",
     "Everyone" : "Tothom",
+    "An error occured during the request. Unable to proceed." : "S'ha produït un error durant la sol·licitud. No es pot continuar.",
     "Test email settings" : "Prova els paràmetres de correu electrònic",
     "Please read carefully before activating server-side encryption: " : "Si us plau, llegiu atentament abans d'activar l'encriptació en el servidor: ",
     "Enable encryption" : "Activa l'encriptació",
@@ -449,6 +470,17 @@ OC.L10N.register(
     "Recommended" : "Recomanat",
     "The cron.php needs to be executed by the system user \"%s\"." : "El cron.php ha de ser executat per l'usuari del sistema \"%s\".",
     "days" : "dies",
-    "No display name set" : "No s'ha establert cap nom para mostrar"
+    "Upload new" : "Carrega'n una de nova",
+    "Select from Files" : "Selecciona dels Fitxers",
+    "Remove image" : "Suprimeix imatge",
+    "Choose as profile picture" : "Tria una imatge de perfil",
+    "No display name set" : "No s'ha establert cap nom para mostrar",
+    "Address" : "Adreça",
+    "Your postal address" : "La vostra adreça postal",
+    "It can take up to 24 hours before the account is displayed as verified." : "Pot trigar fins a 24 hores abans que el compte es mostri com a verificat.",
+    "Link https://…" : "Enllaç https://…",
+    "Twitter handle @…" : "Compte Twitter @…",
+    "Admin privileges" : "Privilegis d'administrador",
+    "Avatar" : "Avatar"
 },
 "nplurals=2; plural=(n != 1);");
