@@ -17,6 +17,9 @@ OC.L10N.register(
     "So-so password" : "Středně odolné heslo",
     "Good password" : "Dobré heslo",
     "Strong password" : "Odolné heslo",
+    "An error occurred while changing your language. Please reload the page and try again." : "Při změně jazyka došlo k chybě. Znovu načtěte stránku a zkuste to ještě jednou.",
+    "An error occurred while changing your locale. Please reload the page and try again." : "Došlo k chybě při změně místních a jazykových nastavení. Načtěte stránku znovu a zopakujte pokus.",
+    "Week starts on {fdow}" : "Týden začíná v {fdow}",
     "Groups" : "Skupiny",
     "Group list is empty" : "Seznam skupin je prázdný.",
     "Unable to retrieve the group list" : "Nedaří se získat seznam skupiny",
@@ -73,8 +76,6 @@ OC.L10N.register(
     "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Je téměř vyčerpán nejvyšší umožněný počet klíčů v OPcache. Aby bylo zajištěno, že se do mezipaměti vejdou veškeré skripty, je doporučeno přidat do nastavení PHP volbu <code>opcache.max_accelerated_files</code> s hodnotou vyšší než <code>%s</code>.",
     "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "Vnitřní vyrovnávací paměť OPcache je téměř zaplněná. Aby bylo zajištěno, že se do mezipaměti vejdou veškeré skripty, je doporučeno přidat do nastavení PHP volbu <code>opcache.memory_consumption</code> s hodnotou vyšší než <code>%s</code>.",
     "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "Vnitřní vyrovnávací paměť OPcache pro řetězce je téměř zaplněná. Aby bylo zajištěno, že ukládání řetězců do mezipaměti bude skutečně prováděno, je doporučeno přidat do nastavení PHP volbu <code>opcache.interned_strings_buffer</code> s hodnotou vyšší než <code>%s</code>.",
-    "Administrator documentation" : "Dokumentace pro správce",
-    "User documentation" : "Dokumentace pro uživatele",
     "Invalid SMTP password." : "Neplatné heslo pro SMTP.",
     "Email setting test" : "Zkouška nastavení e-mailu",
     "Well done, %s!" : "Úspěšně nastaveno, %s!",
@@ -123,8 +124,6 @@ OC.L10N.register(
     "Overview" : "Přehled",
     "Basic settings" : "Základní nastavení",
     "Sharing" : "Sdílení",
-    "Availability" : "Dostupnost",
-    "Calendar" : "Kalendář",
     "Personal info" : "Osobní údaje",
     "Mobile & desktop" : "Mobilní a desktop",
     "Email server" : "E-mailový server",
@@ -172,6 +171,7 @@ OC.L10N.register(
     "View in store" : "Zobrazit v katalogu",
     "Visit website" : "Navštívit webovou stránku",
     "Report a bug" : "Nahlásit chybu",
+    "User documentation" : "Dokumentace pro uživatele",
     "Admin documentation" : "Dokumentace pro správce",
     "Developer documentation" : "Dokumentace pro vývojáře",
     "This app is supported via your current Nextcloud subscription." : "Tato aplikace je podporována prostřednictvím vašeho stávajícího předplatného podpory Nextcloud.",
@@ -282,10 +282,6 @@ OC.L10N.register(
     "Error saving profile picture" : "Chyba při ukládání profilového obrázku",
     "Error removing profile picture" : "Chyba při odebírání profilového obrázku",
     "Your biography" : "Váš životopis",
-    "Details" : "Podrobnosti",
-    "You are a member of the following groups:" : "Jste členy následujících skupin:",
-    "You are using <strong>{usage}</strong>" : "Využíváte <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Využíváte <strong>{usage}</strong> z <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "Your full name" : "Vaše celé jméno",
     "Email options" : "Předvolby e-mailu",
     "Primary email for password reset and notifications" : "Hlavní e-mail pro resetování hesla a oznamování",
@@ -303,16 +299,11 @@ OC.L10N.register(
     "Unable to delete additional email address" : "Nepodařilo se smazat další e-mailovou adresu",
     "No email address set" : "E-mailová adresa není nastavena",
     "Additional emails" : "Další e-maily",
-    "Your handle" : "Váš identifikátor (handle)",
     "Your headline" : "Váš nadpis",
     "Language" : "Jazyk",
     "Help translate" : "Pomoci s překladem",
     "Unable to update language" : "Jazyk se nedaří aktualizovat",
     "No language set" : "Není nastaven jazyk",
-    "Locale" : "Místní a jazyková nastavení",
-    "Week starts on {firstDayOfWeek}" : "Týden začíná {firstDayOfWeek}",
-    "Unable to update locale" : "Nedaří se aktualizovat místní a jazyková nastavení",
-    "No locale set" : "Nenastaveno žádné místní a jazykové nastavení",
     "Your location" : "Kde se nacházíte",
     "Your organisation" : "Vaše organizace",
     "Your phone number" : "Vaše telefonní číslo",
@@ -383,7 +374,13 @@ OC.L10N.register(
     "The following devices are configured for your account:" : "U svého účtu máte nastavená následující zařízení:",
     "Your browser does not support WebAuthn." : "Vámi používaný prohlížeč nepodporuje WebAuthn.",
     "Your apps" : "Vaše aplikace",
+    "Active apps" : "Aktivní aplikace",
+    "Disabled apps" : "Vypnuté aplikace",
+    "Updates" : "Aktualizace",
+    "App bundles" : "Sady aplikací",
+    "Featured apps" : "Doporučené aplikace",
     "{license}-licensed" : "licencováno pod {license}",
+    "Details" : "Podrobnosti",
     "Changelog" : "Souhrn změn",
     "by {author}\n{license}" : "od {author}\n{license}",
     "Enter group name" : "Zadejte název skupiny",
@@ -411,17 +408,10 @@ OC.L10N.register(
     "Phone number" : "Telefonní číslo",
     "Role" : "Role",
     "Twitter" : "Twitter",
-    "Fediverse (e.g. Mastodon)" : "Fediverse (např. Mastodon)",
     "Website" : "Webová stránka",
     "Profile visibility" : "Viditelnost profilu",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Není k dispozici, protože tato vlastnost je vyžadována pro  hlavní funkce, včetně sdílení souborů a pozvánek v kalendáři",
-    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Není k dispozici protože pro váš účet bylo federování vypnuto. V případě dotazů se obraťte na svého správce",
     "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Není k dispozici protože zveřejňování údajů o konkrétních uživatelích není vyhledávacímu serveru povoleno. Pokud máte jakékoli dotazy, obraťte se na správce systémů",
-    "Active apps" : "Aktivní aplikace",
-    "Disabled apps" : "Vypnuté aplikace",
-    "Updates" : "Aktualizace",
-    "App bundles" : "Sady aplikací",
-    "Featured apps" : "Doporučené aplikace",
     "Show to everyone" : "Ukázat všem",
     "Show to logged in users only" : "Ukázat pouze přihlášeným uživatelům",
     "Hide" : "Skrýt",
@@ -433,6 +423,8 @@ OC.L10N.register(
     "An error occurred during the request. Unable to proceed." : "Během požadavku došlo k chybě. Nelze pokračovat.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikace byla zapnuta ale je třeba ji ještě aktualizovat. Za 5 sekund budete přesměrování na stránku pro aktualizaci.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Chyba: tuto aplikaci nelze zapnout, protože způsobuje nestabilitu serveru",
+    "User already exists." : "Uživatel už existuje.",
+    "Administrator documentation" : "Dokumentace pro správce",
     "Documentation" : "Dokumentace",
     "Forum" : "Diskuzní fórum",
     "Login" : "Přihlásit",
@@ -500,33 +492,27 @@ OC.L10N.register(
     "Check out our blog" : "Čtete náš blog",
     "Subscribe to our newsletter" : "Přihlaste se k odběru našeho zpravodaje",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Toto komunitní vydání Nextcloud není podporováno a okamžitá oznámení proto nejsou k dispozici",
+    "You are a member of the following groups:" : "Jste členy následujících skupin:",
+    "You are using <strong>%s</strong>" : "Vaše data zabírají <strong>%s</strong>",
+    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Používáte <strong>%1$s</strong> z <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
+    "Locale" : "Místní a jazyková nastavení",
     "Use a second factor besides your password to increase security for your account." : "Pro zlepšení zabezpečení vašeho účtu použijte vedle hesla také druhý faktor.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Pokud pro připojování se k Nextcloud používáte aplikace třetích stran, nezapomeňte před zapnutím ověřování druhým faktorem vytvořit pro jednotlivé aplikace jejich hesla.",
     "Migration in progress. Please wait until the migration is finished" : "Probíhá migrace. Vyčkejte jejího dokončení",
     "Migration started …" : "Migrace spuštěna…",
-    "An error occurred while changing your language. Please reload the page and try again." : "Při změně jazyka došlo k chybě. Znovu načtěte stránku a zkuste to ještě jednou.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "Došlo k chybě při změně místních a jazykových nastavení. Načtěte stránku znovu a zopakujte pokus.",
     "Select a profile picture" : "Vyberte profilový obrázek",
-    "Week starts on {fdow}" : "Týden začíná v {fdow}",
     "Couldn't remove app." : "Aplikaci se nepodařilo odebrat.",
     "Couldn't update app." : "Aplikaci se nedaří aktualizovat.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "Podpůrná vrstva nepodporuje změnu hesla, ale uživatelův šifrovací klíč byl aktualizován.",
     "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Nelze zjistit, zda je verze TLS cURL zastaralá nebo ne, protože během požadavku HTTPS na https://nextcloud.com došlo k chybě. Další podrobnosti najdete v souboru se záznamy událostí v Nextcloud.",
-    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Je téměř vyčerpán nejvyšší umožněný počet klíčů v OPcache. Aby bylo zajištěno, že se do mezipaměti vejdou veškeré skripty, je doporučeno přidat do nastavení PHP volbu <code>opcache.max_accelerated_files</code> s hodnotou vyšší než <code>%s</code>.",
-    "Admin privileges" : "Oprávnění správce",
+    "You need to set your user email before being able to send test emails." : "Pro možnost odeslání zkušebních e-mailů musíte nejprve nastavit svou e-mailovou adresu.",
     "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Odstranění tohoto tokenu může zabránit vymazání obsahu přístroje, pokud nebyl proces vymazání do teď zahájen.",
-    "Unable to update biography" : "Životopis se nedaří aktulizovat",
-    "Unable to update full name" : "Nedaří se aktualizovat celé jméno",
-    "No full name set" : "Nenastaveno celé jméno",
-    "Unable to update headline" : "Nadpis se nedaří změnit",
-    "Unable to update organisation" : "Nedaří se aktualizovat organizaci",
-    "Unable to update role" : "Nedaří se aktualizovat roli",
-    "Change scope level of {accountProperty}" : "Změnit stupeň rozsahu {accountProperty}",
-    "Unable to update federation scope of the primary {accountProperty}" : "Nedaří se aktualizovat rozsah federování primární {accountProperty}",
-    "Unable to update federation scope of additional {accountProperty}" : "Nedaří se aktualizovat rozsah federování dodatečné {accountProperty}",
-    "Address" : "Adresa",
-    "Avatar" : "Profilový obrázek",
+    "Set as primary mail" : "Nastavit jako hlavní e-mai",
+    "Change privacy level of email" : "Změnit úroveň soukromí e-mailu",
+    "All languages" : "Všechny jazyky",
+    "Everyone" : "Všichni",
     "An error occured during the request. Unable to proceed." : "Během požadavku došlo k chybě. Nelze pokračovat.",
+    "Test email settings" : "Vyzkoušet nastavení e-mailu",
     "Please read carefully before activating server-side encryption: " : "Důkladně si pročtěte a až teprve poté případně zapínejte šifrování dat na straně serveru: ",
     "Enable encryption" : "Šifrovat",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Je třeba přenést své šifrovací klíče ze staré verze šifrování (ownCloud <= 8.0) na novou. Zapněte „Default encryption module“ a spusťte příkaz „occ encryption:migrate“",
@@ -541,6 +527,7 @@ OC.L10N.register(
     "Pick background job setting" : "Vybrat nastavení úlohy na pozadí",
     "Recommended" : "Doporučené",
     "The cron.php needs to be executed by the system user \"%s\"." : "Je třeba, aby cron.php bylo spouštěno s právy systémového uživatele „%s“.",
+    "days" : "dnech",
     "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Povolit automatické dokončování uživatelského jména při zadávání celého jména nebo e-mailové adresy (při ignorování chybějící shody s telefonním seznamem a toho, že je ve stejné skupině)",
     "Change privacy level of profile picture" : "Změnit úroveň soukromí profilového obrázku",
     "Upload new" : "Nahrát nový",
@@ -548,15 +535,28 @@ OC.L10N.register(
     "Remove image" : "Odebrat obrázek",
     "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Mějte na paměti, že může trvat až 24 hodin, než bude avatar aktualizován všude.",
     "Choose as profile picture" : "Vybrat jako profilový obrázek",
-    "You are using <strong>%s</strong>" : "Vaše data zabírají <strong>%s</strong>",
-    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Používáte <strong>%1$s</strong> z <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
+    "Change privacy level of full name" : "Změnit úroveň soukromí pro celé jméno",
+    "No display name set" : "Nenastaveno žádné zobrazované jméno",
     "Change privacy level of phone number" : "Změnit úroveň soukromí telefonního čísla",
+    "Address" : "Adresa",
     "Change privacy level of address" : "Změnit úroveň soukromí adresy",
     "Your postal address" : "Vaše poštovní adresa",
     "Change privacy level of website" : "Změnit úroveň soukromí webové stránky",
     "It can take up to 24 hours before the account is displayed as verified." : "Může trvat až 24 hodin, než se účet zobrazí jako ověřený.",
     "Link https://…" : "Odkaz https://…",
     "Change privacy level of Twitter profile" : "Změnit úroveň soukromí Twitteru",
-    "Twitter handle @…" : "Přezdívka na Twitteru @…"
+    "Twitter handle @…" : "Přezdívka na Twitteru @…",
+    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Je téměř vyčerpán nejvyšší umožněný počet klíčů v OPcache. Aby bylo zajištěno, že se do mezipaměti vejdou veškeré skripty, je doporučeno přidat do nastavení PHP volbu <code>opcache.max_accelerated_files</code> s hodnotou vyšší než <code>%s</code>.",
+    "Admin privileges" : "Oprávnění správce",
+    "Unable to update biography" : "Životopis se nedaří aktulizovat",
+    "Unable to update full name" : "Nedaří se aktualizovat celé jméno",
+    "No full name set" : "Nenastaveno celé jméno",
+    "Unable to update headline" : "Nadpis se nedaří změnit",
+    "Unable to update organisation" : "Nedaří se aktualizovat organizaci",
+    "Unable to update role" : "Nedaří se aktualizovat roli",
+    "Change scope level of {accountProperty}" : "Změnit stupeň rozsahu {accountProperty}",
+    "Unable to update federation scope of the primary {accountProperty}" : "Nedaří se aktualizovat rozsah federování primární {accountProperty}",
+    "Unable to update federation scope of additional {accountProperty}" : "Nedaří se aktualizovat rozsah federování dodatečné {accountProperty}",
+    "Avatar" : "Profilový obrázek"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
