@@ -12,6 +12,9 @@ OC.L10N.register(
     "So-so password" : "Mezbona pasvorto",
     "Good password" : "Bona pasvorto",
     "Strong password" : "Forta pasvorto",
+    "An error occurred while changing your language. Please reload the page and try again." : "Eraro okazis dum ŝanĝo de lingvo. Bv. reŝargi la paĝon kaj provi ree.",
+    "An error occurred while changing your locale. Please reload the page and try again." : "Eraro okazis dum ŝanĝo de lokaĵaro. Bv. reŝargi la paĝon kaj provi ree.",
+    "Week starts on {fdow}" : "Semajno komencas je {fdow}",
     "Groups" : "Grupoj",
     "Group list is empty" : "Gruplisto malpenas",
     "Unable to retrieve the group list" : "Ne eblis ricevi grupliston",
@@ -51,8 +54,6 @@ OC.L10N.register(
     "Wrong admin recovery password. Please check the password and try again." : "Neĝusta reekhava pasvorto de administranto. Bv. kontroli la pasvorton kaj reprovi.",
     "Federated Cloud Sharing" : "Federnuba kunhavado",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL uzas neĝisdatan version %1$s (%2$s). Bv. ĝisdatigi vian operaciumon aŭ programon, aŭ trajtoj kiel %3$s ne plu funkcios fidinde.",
-    "Administrator documentation" : "Dokumentaro por administranto",
-    "User documentation" : "Dokumentaro por uzanto",
     "Invalid SMTP password." : "Nevalida SMTP-pasvorto.",
     "Email setting test" : "Provo de retpoŝtagordo",
     "Well done, %s!" : "Bonege, %s!",
@@ -95,7 +96,6 @@ OC.L10N.register(
     "Overview" : "Superrigardo",
     "Basic settings" : "Bazaj agordoj",
     "Sharing" : "Kunhavigo",
-    "Calendar" : "Kalendaro",
     "Personal info" : "Persona informo",
     "Mobile & desktop" : "Porteblaj kaj labortablaj aplikaĵoj",
     "Email server" : "Retpoŝtoservilo",
@@ -128,6 +128,7 @@ OC.L10N.register(
     "View in store" : "Vidi en butiko",
     "Visit website" : "Viziti retejon",
     "Report a bug" : "Raporti problemon",
+    "User documentation" : "Dokumentaro por uzanto",
     "Admin documentation" : "Dokumentaro por administranto",
     "Developer documentation" : "Dokumentaro por programisto",
     "This app is supported via your current Nextcloud subscription." : "Tiu aplikaĵo estas subtenita per via nuna Nextcloud-abono.",
@@ -198,14 +199,11 @@ OC.L10N.register(
     "png or jpg, max. 20 MB" : "png aŭ jpg, maksimume 20 MB",
     "Picture provided by original account" : "Bildo el la origina konto",
     "Cancel" : "Nuligi",
-    "Details" : "Detaloj",
-    "You are a member of the following groups:" : "Vi estas membro el la jenaj grupoj:",
     "Your email address" : "Via retpoŝta adreso",
     "No email address set" : "Neniu retpoŝta adreso agordita",
     "Language" : "Lingvo",
     "Help translate" : "Helpu traduki",
     "No language set" : "Neniu lingvo agordita",
-    "Locale" : "Lokaĵaro",
     "Your phone number" : "Via telefonnumero",
     "Add" : "Aldoni",
     "You do not have permissions to see the details of this user" : "Vi ne rajtas vidi detalojn pri tiu ĉu uzanto",
@@ -240,7 +238,12 @@ OC.L10N.register(
     "Common languages" : "Ordinaraj lingvoj",
     "Password change is disabled because the master key is disabled" : "Pasvorta ŝanĝo ne eblas, ĉar la ĉefa ŝlosilo estas neebligita",
     "Your apps" : "Viaj aplikaĵoj",
+    "Active apps" : "Aktivaj aplikaĵoj",
+    "Disabled apps" : "Malŝaltitaj aplikaĵoj",
+    "Updates" : "Ĝisdatigoj",
+    "App bundles" : "Aplikaĵaj kuniĝoj",
     "{license}-licensed" : "Permesilo: {license}",
+    "Details" : "Detaloj",
     "Changelog" : "Ŝanĝoprotokolo",
     "Add group" : "Aldoni grupon",
     "Active users" : "Aktivaj uzantoj",
@@ -263,16 +266,13 @@ OC.L10N.register(
     "Phone number" : "Telefonnumero",
     "Twitter" : "Twitter",
     "Website" : "Retejo",
-    "Active apps" : "Aktivaj aplikaĵoj",
-    "Disabled apps" : "Malŝaltitaj aplikaĵoj",
-    "Updates" : "Ĝisdatigoj",
-    "App bundles" : "Aplikaĵaj kuniĝoj",
     "Hide" : "Malmontri",
     "Download and enable" : "Elŝuti kaj ŝalti",
     "Enable untested app" : "Ŝalti netestitan aplikaĵon",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Tiu aplikaĵo ne kongruas kun via Nextcloud-versio. Se vi daŭrigas, vi tamen povos instali ĝin, sed eble tiu aplikaĵo ne funkcios bone.",
     "Never" : "Neniam",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplikaĵo estis ŝaltita, sed ĝi bezonas ĝisdatiĝi. Vi estos direktita al ĝisdatiga paĝon post 5 sekundoj.",
+    "Administrator documentation" : "Dokumentaro por administranto",
     "Documentation" : "Dokumentaro",
     "Forum" : "Forumo",
     "Login" : "Ensaluti",
@@ -324,20 +324,23 @@ OC.L10N.register(
     "Check out our blog" : "Vizitu nian blogon",
     "Subscribe to our newsletter" : "Aboni nian retan bultenon",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Tiu elkomunuma eldono de Nextcloud ne estas subtenata, kaj tuj-sciigoj ne disponeblas.",
+    "You are a member of the following groups:" : "Vi estas membro el la jenaj grupoj:",
+    "You are using <strong>%s</strong>" : "Vi uzas <strong>%s</strong>",
+    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Vi uzas <strong>%1$s</strong> el <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
+    "Locale" : "Lokaĵaro",
     "Use a second factor besides your password to increase security for your account." : "Uzu duan fazon krom via pasvorto por plisekurigi vian konton.",
     "Migration in progress. Please wait until the migration is finished" : "Transmeto faranta. Bv. atendi ĝis la fino de la transmeto.",
     "Migration started …" : "Ektransmetado...",
-    "An error occurred while changing your language. Please reload the page and try again." : "Eraro okazis dum ŝanĝo de lingvo. Bv. reŝargi la paĝon kaj provi ree.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "Eraro okazis dum ŝanĝo de lokaĵaro. Bv. reŝargi la paĝon kaj provi ree.",
     "Select a profile picture" : "Elekti profilan bildon",
-    "Week starts on {fdow}" : "Semajno komencas je {fdow}",
     "Couldn't remove app." : "Ne eblis forigi la aplikaĵon.",
     "Couldn't update app." : "Ne eblis ĝisdatigi la aplikaĵon.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "Servilo ne subtenas pasvorto-ŝanĝon, tamen ĉifroŝlosilo de la uzanto estis ĝisdatigita.",
+    "You need to set your user email before being able to send test emails." : "Vi bezonas agordi vian retpoŝtadreso, antaŭ ol povi sendi provan retmesaĝon.",
     "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Senvalido de tiu ĉi ĵetono eble malhelpos forviŝadon de via aparato, se ĝi ankoraŭ ne komencis forviŝadon.",
-    "Address" : "Adreso",
-    "Avatar" : "Avataro",
+    "All languages" : "Ĉiuj lingvoj",
+    "Everyone" : "Ĉiuj",
     "An error occured during the request. Unable to proceed." : "Eraro okazis dum peto. Ne eblas plui.",
+    "Test email settings" : "Provi retpoŝtagordon",
     "Please read carefully before activating server-side encryption: " : "Atente legu antaŭ ol ŝalti ĉeservilan ĉifradon:",
     "Enable encryption" : "Ŝalti ĉifradon",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Vi bezonas transigi vian ĉifroŝlosilon el malnova instalaĵo (ownCloud ⩽ 8.0) al la nova. Bv. ebligi la „defaŭltan ĉifrado-modulon“ kaj ruli komandlinie „occ encryption:migrate“",
@@ -349,15 +352,17 @@ OC.L10N.register(
     "Pick background job setting" : "Elekti agordon pri fona tasko",
     "Recommended" : "Rekomendata",
     "The cron.php needs to be executed by the system user \"%s\"." : "cron.php bezonas esti rulita de la sistema uzanto „%s“.",
+    "days" : "tagoj",
     "Upload new" : "Alŝuti novan",
     "Select from Files" : "Elekti el dosieroj",
     "Remove image" : "Forigi bildon",
     "Choose as profile picture" : "Elekti kiel profilan bildon",
-    "You are using <strong>%s</strong>" : "Vi uzas <strong>%s</strong>",
-    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Vi uzas <strong>%1$s</strong> el <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
+    "No display name set" : "Neniui vidiga nomo agordita",
+    "Address" : "Adreso",
     "Your postal address" : "Via poŝta adreso",
     "It can take up to 24 hours before the account is displayed as verified." : "Ĝis 24 horoj estas kelkfoje bezonataj, antaŭ ol la konto estas markita kiel kontrolita.",
     "Link https://…" : "Ligilo https://…",
-    "Twitter handle @…" : "Twitter-kontonomo @…"
+    "Twitter handle @…" : "Twitter-kontonomo @…",
+    "Avatar" : "Avataro"
 },
 "nplurals=2; plural=(n != 1);");
