@@ -30,8 +30,6 @@ OC.L10N.register(
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Favor de proporcionar una contraseña de recuperación de administrador; de lo contrario toda la información del usuario se perderá. ",
     "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación de administrador incorrecta. Favor de verificarla e inténtelo de nuevo.",
     "Federated Cloud Sharing" : "Compartir en la Nube Federada",
-    "Administrator documentation" : "Documentación de adminsitrador",
-    "User documentation" : "Documentación del usuario",
     "Invalid SMTP password." : "Constraseña SMTP inválida. ",
     "Email setting test" : "Prueba de ajustes de correo",
     "Well done, %s!" : "¡Bien hecho, %s!",
@@ -69,7 +67,6 @@ OC.L10N.register(
     "Additional settings" : "Configuraciones adicionales",
     "Basic settings" : "Configuraciones  básicas",
     "Sharing" : "Compartiendo",
-    "Calendar" : "Calendario",
     "Personal info" : "Información Personal",
     "Email server" : "Servidor de correo electrónico",
     "Security & setup warnings" : "Advertencias de seguridad y configuración",
@@ -93,6 +90,7 @@ OC.L10N.register(
     "View in store" : "Ver en la tienda",
     "Visit website" : "Visite el sitio web",
     "Report a bug" : "Reporte un tema",
+    "User documentation" : "Documentación del usuario",
     "Admin documentation" : "Documentación del administrador",
     "Developer documentation" : "Documentación del desarrollador",
     "Featured" : "Destacado",
@@ -141,7 +139,6 @@ OC.L10N.register(
     "png or jpg, max. 20 MB" : "png o jpg max. 20 MB",
     "Picture provided by original account" : "Imagen proporcionadoa por la cuenta original ",
     "Cancel" : "Cancelar",
-    "Details" : "Detalles",
     "Your email address" : "Su dirección de correo electrónico",
     "No email address set" : "No se ha establecido la dirección de correo electrónico",
     "Language" : "Idioma",
@@ -160,6 +157,10 @@ OC.L10N.register(
     "Default quota" : "Cuota predeterminada",
     "Unnamed device" : "Dispositivo sin nombre",
     "Your apps" : "Sus aplicaciones",
+    "Disabled apps" : "Aplicaciones deshabilitadas",
+    "Updates" : "Actualizaciones",
+    "App bundles" : "Paquetes de aplicacion",
+    "Details" : "Detalles",
     "Changelog" : "Bitácora de cambios",
     "Add group" : "Agregar grupo",
     "Active users" : "Usuarios activos",
@@ -177,12 +178,10 @@ OC.L10N.register(
     "Phone number" : "Número de teléfono",
     "Twitter" : "Twitter",
     "Website" : "Sitio web",
-    "Disabled apps" : "Aplicaciones deshabilitadas",
-    "Updates" : "Actualizaciones",
-    "App bundles" : "Paquetes de aplicacion",
     "Hide" : "Ocultar",
     "Never" : "Nunca",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplicación está habilitada pero necesita ser actualizada. Usted será redireccionado a la página de actualización en 5 segundos. ",
+    "Administrator documentation" : "Documentación de adminsitrador",
     "Documentation" : "Documentación",
     "Forum" : "Foro",
     "Login" : "Inicio de sesión",
@@ -230,8 +229,10 @@ OC.L10N.register(
     "Couldn't remove app." : "No fue posible eliminar la aplicación. ",
     "Couldn't update app." : "No fue posible actualizar la aplicación.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "El backend no soporta el cambio de contraseñas, pero la llave de encripción del usuario fue actualizada.",
-    "Address" : "Dirección",
-    "Avatar" : "Avatar",
+    "You need to set your user email before being able to send test emails." : "Requiere establecer su correo electrónico andes de poder enviar correos electrónicos de prueba. ",
+    "All languages" : "Todos los idiomas",
+    "Everyone" : "Todos",
+    "Test email settings" : "Probar las configuraciones de correo electrónico",
     "Please read carefully before activating server-side encryption: " : "Favor de leer detenidamente antes de activar la encripción del lado de servidor:",
     "Enable encryption" : "Habilitar encripción",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Usted necesita migrar sus llaves de encripción de la encripción anterior (ownCloud <= 8.0) a la actual. Favor de habilitar el \"Módulo de encripción predeterminado\" y ejecute el comando 'occ encryption:migrate'",
@@ -241,13 +242,17 @@ OC.L10N.register(
     "Last job ran %s." : "El último trabajo corrió %s.",
     "Background job didn’t run yet!" : "¡El trabajo de segundo plano aún no ha corrido!",
     "The cron.php needs to be executed by the system user \"%s\"." : "El cron.php necesita ser ejecutado por el usuario del sistema \"%s\".",
+    "days" : "días",
     "Upload new" : "Cargar nuevo",
     "Select from Files" : "Seleccionar desde Archivos",
     "Remove image" : "Eliminar imagen",
     "Choose as profile picture" : "Seleccionar como foto del perfil",
+    "No display name set" : "No se ha establecido el nombre a desplegar",
+    "Address" : "Dirección",
     "Your postal address" : "Su dirección postal",
     "It can take up to 24 hours before the account is displayed as verified." : "Puede tomar hasta 24 horas antes de que la cuenta se muestre como verificada. ",
     "Link https://…" : "Link https:// ...",
-    "Twitter handle @…" : "Cuenta de twitter @..."
+    "Twitter handle @…" : "Cuenta de twitter @...",
+    "Avatar" : "Avatar"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
