@@ -1,14 +1,9 @@
 OC.L10N.register(
     "settings",
     {
-    "Migration in progress. Please wait until the migration is finished" : "La migración está en curso. Por favor espera hasta que termine la migración",
-    "Migration started …" : "La migración ha comenzado ...",
-    "Saved" : "Guardado",
-    "Not saved" : "No guardado",
-    "Sending…" : "Enviando...",
-    "Email sent" : "Correo electrónico enviado",
     "Private" : "Privado",
     "Local" : "Local",
+    "Federated" : "Federado",
     "Verify" : "Verificar",
     "Verifying …" : "Verificando ...",
     "Unable to change password" : "No fue posible cambiar la contraseña",
@@ -17,7 +12,6 @@ OC.L10N.register(
     "So-so password" : "Contraseña aceptable",
     "Good password" : "Buena contraseña",
     "Strong password" : "Contraseña fuerte",
-    "Select a profile picture" : "Selecciona una imagen de perfil",
     "Groups" : "Grupos",
     "{actor} changed your password" : "{actor} ha cambiado tu contraseña",
     "You changed your password" : "Cambiaste tu contraseña",
@@ -29,14 +23,12 @@ OC.L10N.register(
     "You successfully logged in using two-factor authentication (%1$s)" : "Has iniciado sesión exitosamente usando autenticación de dos-factores (%1$s)",
     "A login attempt using two-factor authentication failed (%1$s)" : "Un intento de autenticación usando autenticación de dos-factores ha fallado (%1$s)",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Tu <strong>contraseña</strong> o <strong>correo electrónico</strong> ha sido modificado",
-    "Couldn't remove app." : "No fue posible eliminar la aplicación. ",
-    "Couldn't update app." : "No fue posible actualizar la aplicación.",
     "Wrong password" : "Contraseña incorrecta",
+    "Saved" : "Guardado",
     "No user supplied" : "No se proporcionó usuario alguno",
     "Authentication error" : "Error de autenticación",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor proporciona una contraseña de recuperación de administrador; de lo contrario toda la información del usuario se perderá. ",
     "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación de administrador incorrecta. Por favor verificala e inténtalo de nuevo.",
-    "Backend doesn't support password change, but the user's encryption key was updated." : "El backend no soporta el cambio de contraseñas, pero la llave de encripción del usuario fue actualizada.",
     "Federated Cloud Sharing" : "Compartir en la Nube Federada",
     "Invalid SMTP password." : "Constraseña SMTP inválida. ",
     "Email setting test" : "Prueba de ajustes de correo",
@@ -44,7 +36,7 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Si has recibido este correo electrónico, la configuración del correo electrónico parece estar correcta. ",
     "Email could not be sent. Check your mail server log" : "No fue posible enviar el correo electrónico. Por favor verfica la bitácora de tu servidor de correo",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Se presentó un problema al enviar el correo electrónico. Por favor revisa tus configuraciones (Error: %s)",
-    "You need to set your user email before being able to send test emails." : "Requieres establecer tu correo electrónico antes de poder enviar correos electrónicos de prueba. ",
+    "Invalid user" : "Usuario inválido",
     "Invalid mail address" : "Dirección de correo inválida",
     "Settings saved" : "Se han guardado las configuraciones ",
     "Unable to change full name" : "No fue posible cambiar el nombre completo",
@@ -131,12 +123,32 @@ OC.L10N.register(
     "Done" : "Terminado",
     "Copied!" : "¡Copiado!",
     "Copy" : "Copiar",
+    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Para correr esto necesitas la extensión POSIX de PHP. Por favor ve la {linkstart}documentación de PHP{linkend} para más detalles. ",
+    "Enable" : "Habilitar",
+    "Server-side encryption" : "Encripción del lado del servidor",
+    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "La encripción del lado del servidor hace posible encriptar archivos que serán cargados a este servidor. Esto trae consigo algunas limitaciónes como penalizaciones en el desemeño, asi que habilítalo sólo si es necesario. ",
+    "Enable server-side encryption" : "Habilitar encripción del lado del servidor",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Una vez que la encripción se encuentre habilitada, todos lo archivos cargados al servidor desde ese momento en tiempo, se encriptarán en el servidor. Sólo será posible deshabilitar la encripción en una fecha posterior si el modulo de encripción activo soporta esa funcionalidad y si todas las preciondiciones están satisfechas (ejem. establecer una llave de recuperación).",
+    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "La encripción por sí sola no garantiza la seguridad del sistema. Por favor consulta la documentación para mayores informes de cómo funciona la aplicación de encripción y de los casos de uso soportados. ",
+    "Be aware that encryption always increases the file size." : "Por favor considera que la encripción siempre aumenta el tamaño de los archivos. ",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Siempre es una buena idea generar respaldos de tus datos, en caso de tener encripción asegúrate de respaldar las llaves de encripción junto con tus datos. ",
+    "This is the final warning: Do you really want to enable encryption?" : "Esta es la advertencia final: ¿Realmente deseas habilitar la encripción?",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "No se ha cargado un módulo de encripción, por favor habilita un módulo de encripción en el menú de la aplicación. ",
+    "Select default encryption module:" : "Selecciona el modulo de encripción predeterminado:",
+    "Current password" : "Contraseña actual",
+    "New password" : "Nueva contraseña",
+    "Change password" : "Cambiar contraseña",
+    "png or jpg, max. 20 MB" : "png o jpg max. 20 MB",
+    "Picture provided by original account" : "Imagen proporcionada por la cuenta original ",
+    "Cancel" : "Cancelar",
     "Your email address" : "Tu dirección de correo electrónico",
     "No email address set" : "No se ha establecido la dirección de correo electrónico",
     "Language" : "Idioma",
     "Help translate" : "Ayuda a traducir",
+    "Your phone number" : "Su número telefónico",
+    "Your Twitter handle" : "Tu cuenta de Twitter",
+    "Your website" : "Tu sitio web",
     "Add" : "Agregar",
-    "Cancel" : "Cancelar",
     "{size} used" : "{size} usado",
     "Display name" : "Nombre a desplegar",
     "Email" : "Correo electrónico",
@@ -154,19 +166,24 @@ OC.L10N.register(
     "Details" : "Detalles",
     "Changelog" : "Bitácora de cambios",
     "Add group" : "Agregar grupo",
+    "Active users" : "Usuarios activos",
     "Admins" : "Administradores",
     "Show last login" : "Mostrar último inicio de sesión",
     "Show user backend" : "Mostrar backend del usuario",
     "Send email to new user" : "Enviar un correo electrónico al usuario nuevo",
-    "Address" : "Dirección",
+    "Not saved" : "No guardado",
+    "Sending…" : "Enviando...",
+    "Email sent" : "Correo electrónico enviado",
+    "Location" : "Ubicación",
+    "Profile picture" : "Foto de perfil",
+    "About" : "Acerca",
     "Full name" : "Nombre completo",
     "Phone number" : "Número de teléfono",
     "Twitter" : "Twitter",
     "Website" : "Sitio web",
-    "Enable" : "Habilitar",
+    "Hide" : "Ocultar",
     "Never" : "Nunca",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplicación está habilitada pero necesita ser actualizada. Serás redireccionado a la página de actualización en 5 segundos. ",
-    "App update" : "Actualización de la aplicación",
     "Administrator documentation" : "Documentación del adminsitrador",
     "Documentation" : "Documentación",
     "Forum" : "Foro",
@@ -188,37 +205,16 @@ OC.L10N.register(
     "SMTP Username" : "Usuario SMTP",
     "SMTP Password" : "Contraseña SMTP",
     "Save" : "Guardar",
-    "Test email settings" : "Probar las configuraciones de correo electrónico",
     "Send email" : "Enviar correo electrónico",
     "All checks passed." : "Pasaron todas las verificaciones. ",
     "Version" : "Versión",
-    "Server-side encryption" : "Encripción del lado del servidor",
-    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "La encripción del lado del servidor hace posible encriptar archivos que serán cargados a este servidor. Esto trae consigo algunas limitaciónes como penalizaciones en el desemeño, asi que habilítalo sólo si es necesario. ",
-    "Enable server-side encryption" : "Habilitar encripción del lado del servidor",
-    "Please read carefully before activating server-side encryption: " : "Por favor lee detenidamente antes de activar la encripción del lado de servidor:",
-    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Una vez que la encripción se encuentre habilitada, todos lo archivos cargados al servidor desde ese momento en tiempo, se encriptarán en el servidor. Sólo será posible deshabilitar la encripción en una fecha posterior si el modulo de encripción activo soporta esa funcionalidad y si todas las preciondiciones están satisfechas (ejem. establecer una llave de recuperación).",
-    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "La encripción por sí sola no garantiza la seguridad del sistema. Por favor consulta la documentación para mayores informes de cómo funciona la aplicación de encripción y de los casos de uso soportados. ",
-    "Be aware that encryption always increases the file size." : "Por favor considera que la encripción siempre aumenta el tamaño de los archivos. ",
-    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Siempre es una buena idea generar respaldos de tus datos, en caso de tener encripción asegúrate de respaldar las llaves de encripción junto con tus datos. ",
-    "This is the final warning: Do you really want to enable encryption?" : "Esta es la advertencia final: ¿Realmente deseas habilitar la encripción?",
-    "Enable encryption" : "Habilitar encripción",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "No se ha cargado un módulo de encripción, por favor habilita un módulo de encripción en el menú de la aplicación. ",
-    "Select default encryption module:" : "Selecciona el modulo de encripción predeterminado:",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Necesitas migrar tus llaves de encripción de la encripción anterior (ownCloud <= 8.0) a la actual. Por favor habilita el \"Módulo de encripción predeterminado\" y ejecuta el comando 'occ encryption:migrate'",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Necesitas migar tus llaves de encripción de la encripción anterior (ownCloud <=8.0) a la actual. ",
-    "Start migration" : "Iniciar migración",
-    "Last job execution ran %s. Something seems wrong." : "La última ejecución del trabajo corrió %s. Algo parece estar mal. ",
-    "Last job ran %s." : "El último trabajo corrió %s.",
-    "Background job didn’t run yet!" : "¡El trabajo de segundo plano aún no ha corrido!",
-    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Para un desempeño ideal, es importante configurar los trabajos de fondo correctamente. Para instancias más grandes 'Cron' es la configuración recomendada. Por favor consulta la documentación para más información. ",
-    "The cron.php needs to be executed by the system user \"%s\"." : "El cron.php necesita ser ejecutado por el usuario de sistema \"%s\".",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Para correr esto necesitas la extensión POSIX de PHP. Por favor ve la {linkstart}documentación de PHP{linkend} para más detalles. ",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador, puedes hacer ajustes finos al comportamiento de compartir. Por favor consulta la documentación para más información. ",
     "Allow apps to use the Share API" : "Permitir que las aplicaciones usen el API para Compartir",
     "Enforce expiration date" : "Forzar fecha de expiración",
     "Allow public uploads" : "Permitir cargas públicas",
     "Always ask for a password" : "Siempre pedir una contraseña",
     "Enforce password protection" : "Forzar protección de contraseñas",
+    "Set default expiration date" : "Establecer la fecha de expiración predeterminada",
     "Allow resharing" : "Permitir volver a compartir",
     "Allow sharing with groups" : "Permitir compartir con grupos",
     "Restrict users to only share with users in their groups" : "Limitar a los usuarios a sólo compartir con otros usuarios en sus grupos",
@@ -230,33 +226,36 @@ OC.L10N.register(
     "Follow us on Twitter" : "Síguenos en Twitter",
     "Check out our blog" : "Visita nuestro blog",
     "Subscribe to our newsletter" : "Suscribete a nuestro boletín",
-    "Profile picture" : "Foto de perfil",
+    "Migration in progress. Please wait until the migration is finished" : "La migración está en curso. Por favor espera hasta que termine la migración",
+    "Migration started …" : "La migración ha comenzado ...",
+    "Select a profile picture" : "Selecciona una imagen de perfil",
+    "Couldn't remove app." : "No fue posible eliminar la aplicación. ",
+    "Couldn't update app." : "No fue posible actualizar la aplicación.",
+    "Backend doesn't support password change, but the user's encryption key was updated." : "El backend no soporta el cambio de contraseñas, pero la llave de encripción del usuario fue actualizada.",
+    "You need to set your user email before being able to send test emails." : "Requieres establecer tu correo electrónico antes de poder enviar correos electrónicos de prueba. ",
+    "All languages" : "Todos los idiomas",
+    "Everyone" : "Todos",
+    "Test email settings" : "Probar las configuraciones de correo electrónico",
+    "Please read carefully before activating server-side encryption: " : "Por favor lee detenidamente antes de activar la encripción del lado de servidor:",
+    "Enable encryption" : "Habilitar encripción",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Necesitas migrar tus llaves de encripción de la encripción anterior (ownCloud <= 8.0) a la actual. Por favor habilita el \"Módulo de encripción predeterminado\" y ejecuta el comando 'occ encryption:migrate'",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Necesitas migar tus llaves de encripción de la encripción anterior (ownCloud <=8.0) a la actual. ",
+    "Start migration" : "Iniciar migración",
+    "Last job execution ran %s. Something seems wrong." : "La última ejecución del trabajo corrió %s. Algo parece estar mal. ",
+    "Last job ran %s." : "El último trabajo corrió %s.",
+    "Background job didn’t run yet!" : "¡El trabajo de segundo plano aún no ha corrido!",
+    "The cron.php needs to be executed by the system user \"%s\"." : "El cron.php necesita ser ejecutado por el usuario de sistema \"%s\".",
+    "days" : "días",
     "Upload new" : "Cargar nuevo",
     "Select from Files" : "Seleccionar desde Archivos",
     "Remove image" : "Eliminar imagen",
-    "png or jpg, max. 20 MB" : "png o jpg max. 20 MB",
-    "Picture provided by original account" : "Imagen proporcionada por la cuenta original ",
     "Choose as profile picture" : "Seleccionar como foto del perfil",
-    "Your phone number" : "Su número telefónico",
+    "No display name set" : "No se ha establecido el nombre a desplegar",
+    "Address" : "Dirección",
     "Your postal address" : "Tu dirección postal",
     "It can take up to 24 hours before the account is displayed as verified." : "Puede tomar hasta 24 horas antes de que la cuenta se muestre como verificada. ",
     "Link https://…" : "Liga https:// ...",
     "Twitter handle @…" : "Cuenta de twitter @...",
-    "Current password" : "Contraseña actual",
-    "New password" : "Nueva contraseña",
-    "Change password" : "Cambiar contraseña",
-    "Public" : "Público",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "Instalando y actualizando aplicaciones por la tienda de aplicaciones o Compartido la Nube Federada",
-    "Close" : "Cerrar",
-    "All languages" : "Todos los idiomas",
-    "Everyone" : "Todos",
-    "The app will be downloaded from the app store" : "La aplicación será descargada de la tienda de aplicaciones <app store>",
-    "Error: This app can not be enabled because it makes the server unstable" : "Error: Esta aplicación no puede ser habilitada porque genera inestabilidad en el servidor",
-    "mail" : "correo",
-    "Expire after " : "Expirar después de",
-    "days" : "días",
-    "Allow users to share via link" : "Permitir a los usuarios compartir mediante ligas",
-    "No display name set" : "No se ha establecido el nombre a desplegar",
-    "For password reset and notifications" : "Para restablecer contraseña y notificaciones"
+    "Avatar" : "Avatar"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
