@@ -15,6 +15,9 @@ OC.L10N.register(
     "So-so password" : "Kohtalainen salasana",
     "Good password" : "Hyvä salasana",
     "Strong password" : "Vahva salasana",
+    "An error occurred while changing your language. Please reload the page and try again." : "Kieltä vaihtaessa tapahtui virhe. Päivitä sivu ja yritä uudelleen.",
+    "An error occurred while changing your locale. Please reload the page and try again." : "Maa-asetustoa vaihtaessa tapahtui virhe. Päivitä sivu ja yritä uudelleen.",
+    "Week starts on {fdow}" : "Viikon ensimmäinen päivä on {fdow}",
     "Groups" : "Ryhmät",
     "Group list is empty" : "Ryhmälista on tyhjä",
     "Unable to retrieve the group list" : "Ryhmälistaa ei voitu noutaa",
@@ -60,8 +63,6 @@ OC.L10N.register(
     "Wrong admin recovery password. Please check the password and try again." : "Väärä ylläpitäjän salasana. Tarkista salasana ja yritä uudelleen.",
     "Federated Cloud Sharing" : "Federoitu pilvijakaminen",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL käyttää vanhentunutta %1$s versiota (%2$s). Päivitä käyttöjärjestelmäsi tai toiminnot, kuten %3$s, eivät toimi luotettavasti.",
-    "Administrator documentation" : "Ylläpidon dokumentaatio",
-    "User documentation" : "Käyttäjädokumentaatio",
     "Invalid SMTP password." : "Virheellinen SMTP-salasana.",
     "Email setting test" : "Sähköpostiasetusten testaus",
     "Well done, %s!" : "Hyvin tehty, %s!",
@@ -107,8 +108,6 @@ OC.L10N.register(
     "Overview" : "Yleiskuvaus",
     "Basic settings" : "Perusasetukset",
     "Sharing" : "Jakaminen",
-    "Availability" : "Saatavuus",
-    "Calendar" : "Kalenteri",
     "Personal info" : "Henkilökohtaiset tiedot",
     "Mobile & desktop" : "Mobiili ja työpöytä",
     "Email server" : "Sähköpostipalvelin",
@@ -149,6 +148,7 @@ OC.L10N.register(
     "View in store" : "Näytä kaupassa",
     "Visit website" : "Käy verkkosivustolla",
     "Report a bug" : "Ilmoita viasta",
+    "User documentation" : "Käyttäjädokumentaatio",
     "Admin documentation" : "Ylläpitäjän ohjeistus",
     "Developer documentation" : "Kehittäjädokumentaatio",
     "This app is supported via your current Nextcloud subscription." : "Tämä sovellus on tuettu nykyisen Nextcloud-tilauksesi kautta.",
@@ -228,26 +228,10 @@ OC.L10N.register(
     "Current password" : "Nykyinen salasana",
     "New password" : "Uusi salasana",
     "Change password" : "Vaihda salasana",
-    "Your profile picture" : "Profiilikuvasi",
-    "Upload profile picture" : "Lähetä profiilikuva",
-    "Choose profile picture from files" : "Valitse profiilikuva tiedostoista",
-    "Remove profile picture" : "Poista profiilikuva",
     "png or jpg, max. 20 MB" : "png tai jpg, korkeintaan 20 Mt",
     "Picture provided by original account" : "Kuvan tarjoaa alkuperäinen tili",
     "Cancel" : "Peru",
-    "Set as profile picture" : "Aseta profiilikuvaksi",
-    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Ota huomioon, että profiilikuvasi päivittyminen kaikkialle saattaa kestää jopa 24 tuntia.",
-    "Choose your profile picture" : "Valitse profiilikuva",
-    "Please select a valid png or jpg file" : "Valitse kelvollinen png- tai jpg-tiedosto",
-    "Error setting profile picture" : "Virhe profiilikuvaa asettaessa",
-    "Error cropping profile picture" : "Virhe profiilikuvaa rajatessa",
-    "Error saving profile picture" : "Virhe profiilikuvaa tallentaessa",
-    "Error removing profile picture" : "Virhe profiilikuvaa poistaessa",
     "Your biography" : "Sinun elämäkertasi",
-    "Details" : "Yksityiskohdat",
-    "You are a member of the following groups:" : "Olet seuraavien ryhmien jäsen:",
-    "You are using <strong>{usage}</strong>" : "Käytössäsi on <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Käytössäsi on <strong>{usage}</strong>/<strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "Your full name" : "Koko nimesi",
     "Email options" : "Sähköpostiasetukset",
     "Primary email for password reset and notifications" : "Ensisijainen sähköposti salasanan nollaamista ja ilmoituksia varten",
@@ -267,11 +251,6 @@ OC.L10N.register(
     "Help translate" : "Auta kääntämisessä",
     "Unable to update language" : "Kieltä ei voi päivittää",
     "No language set" : "Kieltä ei ole asetettu",
-    "Locale" : "Aluekohtainen asetus",
-    "Week starts on {firstDayOfWeek}" : "Viikon ensimmäinen päivä on {firstDayOfWeek}",
-    "Unable to update locale" : "Maa-asetuston päivittäminen ei onnistu",
-    "No locale set" : "Maa-asetustoa ei ole asetettu",
-    "Your location" : "Sijaintisi",
     "Your organisation" : "Organisaatiosi",
     "Your phone number" : "Puhelinnumerosi",
     "Edit your Profile visibility" : "Muokkaa profiilisi näkyvyyttä",
@@ -329,7 +308,13 @@ OC.L10N.register(
     "The following devices are configured for your account:" : "Seuraavat laitteet on määritetty tilillesi:",
     "Your browser does not support WebAuthn." : "Selaimesi ei tue WebAuthn-standardia.",
     "Your apps" : "Sovelluksesi",
+    "Active apps" : "Aktiiviset sovellukset",
+    "Disabled apps" : "Käytöstä poistetut sovellukset",
+    "Updates" : "Päivitykset",
+    "App bundles" : "Sovelluskokoelmat",
+    "Featured apps" : "Esitellyt sovellukset",
     "{license}-licensed" : "{license}-lisensoitu",
+    "Details" : "Yksityiskohdat",
     "Changelog" : "Muutosloki",
     "by {author}\n{license}" : "tekijä {author}\n{license}",
     "Enter group name" : "Kirjoita ryhmän nimi",
@@ -358,11 +343,6 @@ OC.L10N.register(
     "Twitter" : "Twitter",
     "Website" : "Verkkosivusto",
     "Profile visibility" : "Profiilin näkyvyys",
-    "Active apps" : "Aktiiviset sovellukset",
-    "Disabled apps" : "Käytöstä poistetut sovellukset",
-    "Updates" : "Päivitykset",
-    "App bundles" : "Sovelluskokoelmat",
-    "Featured apps" : "Esitellyt sovellukset",
     "Show to everyone" : "Näytä kaikille",
     "Show to logged in users only" : "Näytä vain sisäänkirjautuneille käyttäjille",
     "Hide" : "Piilota",
@@ -371,9 +351,10 @@ OC.L10N.register(
     "The app will be downloaded from the App Store" : "Sovellus ladataan sovelluskaupasta",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Sovellusta ei ole merkattu yhteensopivaksi Nextcloud-versiosi kanssa. Voit kuitenkin jatkaa ja asentaa sovelluksen. Huomioi, että sovellus ei välttämättä toimi odotetusti.",
     "Never" : "Ei koskaan",
-    "An error occurred during the request. Unable to proceed." : "Pyynnön aikana tapahtui virhe. Jatkaminen ei onnistu.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Sovellus on käytössä, mutta se tulee päivittää. Sinut ohjataan sovelluksen päivityssivulle viiden sekunnin kuluttua.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Virhe: Sovellusta ei voida ottaa käyttöön, koska se aiheuttaa palvelimen epävakauden",
+    "User already exists." : "Käyttäjä on jo olemassa.",
+    "Administrator documentation" : "Ylläpidon dokumentaatio",
     "Documentation" : "Dokumentaatio",
     "Forum" : "Keskustelupalsta",
     "Login" : "Kirjaudu",
@@ -416,7 +397,6 @@ OC.L10N.register(
     "Allow public uploads" : "Salli julkiset lähetykset",
     "Always ask for a password" : "Kysy aina salasanaa",
     "Enforce password protection" : "Pakota salasanasuojaus",
-    "Exclude groups from password requirements:" : "Sulje ryhmiä salasanavaatimusten ulkopuolelle:",
     "Set default expiration date" : "Aseta lopettamispäivän oletus",
     "Allow resharing" : "Salli uudelleenjakaminen",
     "Allow sharing with groups" : "Salli jakaminen ryhmien kanssa",
@@ -435,25 +415,25 @@ OC.L10N.register(
     "Check out our blog" : "Lue blogia",
     "Subscribe to our newsletter" : "Tilaa uutiskirje",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Tätä yhteisöjulkaisua Nextcloudista ei tueta, ja pikailmoitukset eivät ole saatavilla.",
+    "You are a member of the following groups:" : "Olet seuraavien ryhmien jäsen:",
+    "You are using <strong>%s</strong>" : "Käytössäsi on <strong>%s</strong>",
+    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Käytössäsi on <strong>%1$s</strong> / <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
+    "Locale" : "Aluekohtainen asetus",
     "Use a second factor besides your password to increase security for your account." : "Käytä toista vaihetta salasanasi lisäksi parantaaksesi tilisi tietoturvaa.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Jos yhdistät kolmannen osapuolen ohjelmia Nextcloudiin, määritä niille sovellussalasanat ennen kaksiosaisen todentamismenetelmän käyttöönottoa.",
     "Migration in progress. Please wait until the migration is finished" : "Migraatio on kesken. Odota kunnes migraatio valmistuu",
     "Migration started …" : "Migraatio käynnistyi…",
-    "An error occurred while changing your language. Please reload the page and try again." : "Kieltä vaihtaessa tapahtui virhe. Päivitä sivu ja yritä uudelleen.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "Maa-asetustoa vaihtaessa tapahtui virhe. Päivitä sivu ja yritä uudelleen.",
     "Select a profile picture" : "Valitse profiilikuva",
-    "Week starts on {fdow}" : "Viikon ensimmäinen päivä on {fdow}",
     "Couldn't remove app." : "Sovelluksen poistaminen epäonnistui.",
     "Couldn't update app." : "Sovelluksen päivitys epäonnistui.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "Taustaosa ei tue salasanan vaihtamista, mutta käyttäjän salausavain päivitettiin.",
-    "Admin privileges" : "Ylläpitäjän oikeudet",
-    "Unable to update full name" : "Koko nimeä ei voi päivittää",
-    "No full name set" : "Koko nimeä ei ole asetettu",
-    "Unable to update organisation" : "Organisaatiota ei voi päivittää",
-    "Unable to update role" : "Roolin päivittäminen ei onnistu",
-    "Address" : "Osoite",
-    "Avatar" : "Profiilikuva",
+    "You need to set your user email before being able to send test emails." : "Aseta sähköpostiosoite, jotta voit testata sähköpostin toimivuutta.",
+    "Set as primary mail" : "Aseta ensisijaiseksi sähköpostiosoitteeksi",
+    "Change privacy level of email" : "Muuta sähköpostin yksityisyystasoa",
+    "All languages" : "Kaikki kielet",
+    "Everyone" : "Kaikki",
     "An error occured during the request. Unable to proceed." : "Pyynnön aikana tapahtui virhe. Jatkaminen ei onnistu.",
+    "Test email settings" : "Testaa sähköpostiasetukset",
     "Please read carefully before activating server-side encryption: " : "Lue tarkasti, ennen kuin otat palvelinpään salauksen käyttöön:",
     "Enable encryption" : "Käytä salausta",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Sinun täytyy siirtää salausavaimet vanhasta salaustekniikasta (ownCloud <= 8.0) uuteen. Ota \"Default encryption module\" käyttöön ja suorita komento 'occ encryption:migrate'",
@@ -467,20 +447,28 @@ OC.L10N.register(
     "Pick background job setting" : "Valitse taustatyöasetus",
     "Recommended" : "Suositeltu",
     "The cron.php needs to be executed by the system user \"%s\"." : "Tiedosto cron.php tulee suorittaa järjestelmän käyttäjänä \"%s\".",
+    "days" : "päivän jälkeen",
     "Change privacy level of profile picture" : "Muuta profiilikuvan yksityisyystasoa",
     "Upload new" : "Lähetä uusi",
     "Select from Files" : "Valitse tiedostosovelluksesta",
     "Remove image" : "Poista kuva",
     "Choose as profile picture" : "Valitse profiilikuvaksi",
-    "You are using <strong>%s</strong>" : "Käytössäsi on <strong>%s</strong>",
-    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Käytössäsi on <strong>%1$s</strong> / <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
+    "Change privacy level of full name" : "Muuta koko nimen yksityisyystasoa",
+    "No display name set" : "Näyttönimeä ei ole asetettu",
     "Change privacy level of phone number" : "Muuta puhelinnumeron yksityisyystasoa",
+    "Address" : "Osoite",
     "Change privacy level of address" : "Muuta osoitteen yksityisyystasoa",
     "Your postal address" : "Postiosoitteesi",
     "Change privacy level of website" : "Muuta verkkosivuston yksityisyystasoa",
     "It can take up to 24 hours before the account is displayed as verified." : "Saattaa kestää jopa 24 tuntia, ennen kuin tili näytetään vahvistettuna.",
     "Link https://…" : "Linkki https://…",
     "Change privacy level of Twitter profile" : "Muuta Twitter-tunnuksen yksityisyystasoa",
-    "Twitter handle @…" : "Twitter-tunnus @…"
+    "Twitter handle @…" : "Twitter-tunnus @…",
+    "Admin privileges" : "Ylläpitäjän oikeudet",
+    "Unable to update full name" : "Koko nimeä ei voi päivittää",
+    "No full name set" : "Koko nimeä ei ole asetettu",
+    "Unable to update organisation" : "Organisaatiota ei voi päivittää",
+    "Unable to update role" : "Roolin päivittäminen ei onnistu",
+    "Avatar" : "Profiilikuva"
 },
 "nplurals=2; plural=(n != 1);");
