@@ -16,7 +16,6 @@ OC.L10N.register(
     "Strong password" : "סיסמא חזקה",
     "An error occurred while changing your language. Please reload the page and try again." : "אירעה שגיאה בעת החלפת השפה שלך. נא לטעון את העמוד מחדש ולנסות שוב.",
     "An error occurred while changing your locale. Please reload the page and try again." : "אירעה שגיאה בעת החלפת ההגדרות האזוריות שלך. נא לטעון את העמוד מחדש ולנסות שוב.",
-    "Select a profile picture" : "יש לבחור תמונת פרופיל",
     "Week starts on {fdow}" : "השבוע מתחיל ב{fdow}",
     "Groups" : "קבוצות",
     "Group list is empty" : "רשימת הקבוצות ריקה",
@@ -209,11 +208,18 @@ OC.L10N.register(
     "Remove group" : "הסרת קבוצה",
     "You are about to remove the group {group}. The users will NOT be deleted." : "פעולה זו תסיר את הקבוצה {group}. המשתמשים ﬥﬡ יימחקו.",
     "Please confirm the group removal " : "נא לאשר את הסרת הקבוצה",
+    "Current password" : "סיסמא נוכחית",
+    "New password" : "סיסמא חדשה",
+    "Change password" : "שינוי סיסמא",
+    "png or jpg, max. 20 MB" : "png או jpg, מקסימום 20 מגה-בייט",
+    "Picture provided by original account" : "תמונה סופקה על ידי חשבון מקור",
+    "Cancel" : "ביטול",
     "Your email address" : "כתובת הדואר האלקטרוני שלך",
     "No email address set" : "לא נקבעה כתובת דואר אלקטרוני",
     "Language" : "שפה",
     "Help translate" : "עזרה בתרגום",
     "No language set" : "לא הוגדרה שפה",
+    "Your phone number" : "מספר הטלפון שלך",
     "Add" : "הוספה",
     "You do not have permissions to see the details of this user" : "אין לך הרשאות לצפות בפירוט על המשתמש",
     "Add new password" : "הוספת ססמה חדשה",
@@ -228,7 +234,6 @@ OC.L10N.register(
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "במקרה של אובדן מכשיר או עזיבה של הארגון, מנגנון זה יכול להשמיד את נתוני ה־Nextcloud מכל המכשירים שמשויכים אל {userid}. יעבוד רק אם כל המכשירים מחוברים לאינטרנט.",
     "Remote wipe of devices" : "השמדת נתונים מרוחקת במכשירים",
     "Wipe {userid}'s devices" : "השמדת נתוני המכשירים של {userid}",
-    "Cancel" : "ביטול",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "למחוק לחלוטין את החשבון של {userid} לרבות כל הקבצים האישיים, נתוני היישומונים וכו׳.",
     "Account deletion" : "מחיקת חשבון",
     "Delete {userid}'s account" : "מחיקת החשבון של {userid}",
@@ -289,8 +294,8 @@ OC.L10N.register(
     "Not saved" : "לא נשמר",
     "Sending…" : "בשליחה…",
     "Email sent" : "הודעת הדואר האלקטרוני נשלחה",
-    "Address" : "כתובת",
-    "Avatar" : "תמונה מייצגת",
+    "Location" : "מיקום",
+    "Profile picture" : "תמונת פרופיל",
     "About" : "על אודות",
     "Full name" : "שם מלא",
     "Phone number" : "מספר טלפון",
@@ -301,7 +306,6 @@ OC.L10N.register(
     "Enable untested app" : "לאפשר יישומון שלא נבדק",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "היישומון הזה לא מסומן כנתמך בגרסת ה־Nextcloud. עדיין יתאפשר לך להמשיך ולהתקין את היישומון. נא לשים לב שיכול להיות שהיישומון לא יעבוד כצפוי.",
     "Never" : "מעולם לא",
-    "An error occured during the request. Unable to proceed." : "אירעה שגיאה במהלך הבקשה. לא ניתן להמשיך.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "היישומון הופעל אך יש לעדכן אותו. ההפניה לעמוד העדכון תחל בעוד 5 שניות.",
     "Administrator documentation" : "תיעוד מנהל",
     "Documentation" : "תיעוד",
@@ -360,29 +364,15 @@ OC.L10N.register(
     "Follow us on Mastodon" : "למעקב אחרינו ב־Mastodon",
     "Check out our blog" : "לעיין בבלוג שלנו",
     "Subscribe to our newsletter" : "הרשמה לרשימת הדיוור שלנו",
-    "Profile picture" : "תמונת פרופיל",
-    "Upload new" : "העלאת חדש",
-    "Select from Files" : "בחירה מתוך קבצים",
-    "Remove image" : "הסרת תמונה",
-    "png or jpg, max. 20 MB" : "png או jpg, מקסימום 20 מגה-בייט",
-    "Picture provided by original account" : "תמונה סופקה על ידי חשבון מקור",
-    "Choose as profile picture" : "יש לבחור כתמונת פרופיל",
     "You are a member of the following groups:" : "הקבוצות הבאות כוללות אותך:",
     "You are using <strong>%s</strong>" : "הניצולת שלך היא <strong>%s</strong>",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "מנוצלים <strong>%1$s</strong> מתוך <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
-    "Your phone number" : "מספר הטלפון שלך",
-    "Your postal address" : "כתובת הדואר שלך",
-    "It can take up to 24 hours before the account is displayed as verified." : "יתכן שיעברו עד 24 שעות בטרם הצגת החשבון כמאומת.",
-    "Link https://…" : "קישור https://…‎",
-    "Twitter handle @…" : "כינוי בטוויטר @…",
     "Locale" : "הגדרות אזוריות",
-    "Current password" : "סיסמא נוכחית",
-    "New password" : "סיסמא חדשה",
-    "Change password" : "שינוי סיסמא",
     "Use a second factor besides your password to increase security for your account." : "ניתן להשתמש בגורם נוסף מלבד הססמה שלך כדי להגביר את אבטחת החשבון שלך.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "אם משמשים אותך יישומי צד־שלישי להתחברות אל Nextcloud, נא לוודא יצירת והגדרת ססמה ליישומון לכל אחד מהם בטרם הפעלת אימות דו־שלבי.",
     "Migration in progress. Please wait until the migration is finished" : "המרה בביצוע. יש להמתין עד סיום ההמרה",
     "Migration started …" : "המרה החלה...",
+    "Select a profile picture" : "יש לבחור תמונת פרופיל",
     "Couldn't remove app." : "לא ניתן להסיר את היישום.",
     "Couldn't update app." : "לא ניתן לעדכן את היישום.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "המנגנון אינו תומך בשינוי ססמה אך מפתח ההצפנה של המשתמש עודכן.",
@@ -391,6 +381,7 @@ OC.L10N.register(
     "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "שלילת האסימון הזו עשויה למנוע את השמדת נתוני המכשיר שלך אם ההשמדה טרם החלה.",
     "All languages" : "כל השפות",
     "Everyone" : "כולם",
+    "An error occured during the request. Unable to proceed." : "אירעה שגיאה במהלך הבקשה. לא ניתן להמשיך.",
     "Test email settings" : "בדיקת הגדרות דואר אלקטרוני",
     "Please read carefully before activating server-side encryption: " : "יש לקרוא בתשומת לב רבה לפני שמפעילים הצפנת צד שרת:",
     "Enable encryption" : "אפשר הצפנה",
@@ -406,6 +397,16 @@ OC.L10N.register(
     "Recommended" : "מומלץ",
     "The cron.php needs to be executed by the system user \"%s\"." : "יש להפעיל את cron.php בתור משתמש המערכת „%s”.",
     "days" : "ימים",
-    "No display name set" : "לא נקבע שם תצוגה"
+    "Upload new" : "העלאת חדש",
+    "Select from Files" : "בחירה מתוך קבצים",
+    "Remove image" : "הסרת תמונה",
+    "Choose as profile picture" : "יש לבחור כתמונת פרופיל",
+    "No display name set" : "לא נקבע שם תצוגה",
+    "Address" : "כתובת",
+    "Your postal address" : "כתובת הדואר שלך",
+    "It can take up to 24 hours before the account is displayed as verified." : "יתכן שיעברו עד 24 שעות בטרם הצגת החשבון כמאומת.",
+    "Link https://…" : "קישור https://…‎",
+    "Twitter handle @…" : "כינוי בטוויטר @…",
+    "Avatar" : "תמונה מייצגת"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
