@@ -4,7 +4,6 @@ OC.L10N.register(
     "Private" : "Einka",
     "Local" : "Staðvært",
     "Federated" : "Deilt milli þjóna (skýjasambandssameign)",
-    "Published" : "Útgefið",
     "Verify" : "Sannreyna",
     "Verifying …" : "Sannreyni …",
     "Unable to change password" : "Ekki tókst að breyta lykilorði",
@@ -13,6 +12,9 @@ OC.L10N.register(
     "So-so password" : "Svo-svo lykilorð",
     "Good password" : "Gott lykilorð",
     "Strong password" : "Sterkt lykilorð",
+    "An error occurred while changing your language. Please reload the page and try again." : "Villa kom upp við að skipta um tungumálið þitt. Endurlestu síðuna og prófaðu aftur.",
+    "An error occurred while changing your locale. Please reload the page and try again." : "Villa kom upp við að skipta um staðfærsluna þína. Endurlestu síðuna og prófaðu aftur.",
+    "Week starts on {fdow}" : "Vika byrjar á {fdow}",
     "Groups" : "Hópar",
     "Group list is empty" : "Listi yfir hópa er tómur",
     "Unable to retrieve the group list" : "Tókst ekki að ná í lista yfir hópinn",
@@ -52,8 +54,6 @@ OC.L10N.register(
     "Wrong admin recovery password. Please check the password and try again." : "Rangt endurheimtulykilorð kerfisstjóra, athugaðu lykilorðið og reyndu aftur.",
     "Federated Cloud Sharing" : "Deiling með skýjasambandi",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL er að nota úrelda útgáfu af %1$s (%2$s). Uppfærðu stýrikerfið þitt, annars er hætt við að eiginleikar á borð við %3$s virki ekki sem skyldi.",
-    "Administrator documentation" : "Hjálparskjöl stjórnanda",
-    "User documentation" : "Hjálparskjöl notenda",
     "Invalid SMTP password." : "Ógilt SMTP-lykilorð",
     "Email setting test" : "Prófa tölvupóststillingar",
     "Well done, %s!" : "Vel gert, %s!",
@@ -96,7 +96,6 @@ OC.L10N.register(
     "Overview" : "Yfirlit",
     "Basic settings" : "Grunnstillingar",
     "Sharing" : "Deiling",
-    "Calendar" : "Dagatal",
     "Personal info" : "Persónulegar upplýsingar",
     "Mobile & desktop" : "Farsímar og borðtölvur",
     "Email server" : "Póstþjónn",
@@ -129,6 +128,7 @@ OC.L10N.register(
     "View in store" : "Skoða í hugbúnaðarsafni",
     "Visit website" : "Heimsækja vefsvæðið",
     "Report a bug" : "Tilkynna um villu",
+    "User documentation" : "Hjálparskjöl notenda",
     "Admin documentation" : "Hjálparskjöl kerfisstjóra",
     "Developer documentation" : "Skjölun fyrir þróunaraðila",
     "Supported" : "Stutt",
@@ -197,15 +197,11 @@ OC.L10N.register(
     "png or jpg, max. 20 MB" : "png eða jpg, hám. 20 MB",
     "Picture provided by original account" : "Mynd frá upprunalegum aðgangi",
     "Cancel" : "Hætta við",
-    "Details" : "Nánar",
-    "You are a member of the following groups:" : "Þú ert meðlimur eftirfarandi hópa:",
-    "Delete email" : "Eyða tölvupósti",
     "Your email address" : "Netfangið þitt",
     "No email address set" : "Ekkert tölvupóstfang sett",
     "Language" : "Tungumál",
     "Help translate" : "Hjálpa við þýðingu",
     "No language set" : "Ekkert tungumál skilgreint",
-    "Locale" : "Staðfærsla",
     "Your phone number" : "Símanúmerið þitt",
     "Your Twitter handle" : "Twitter notandanafnið þitt",
     "Your website" : "Vefsvæðið þitt",
@@ -250,7 +246,12 @@ OC.L10N.register(
     "No devices configured." : "Engin tæki skilgreind.",
     "Your browser does not support WebAuthn." : "Vafrinn þinn styður ekki WebAuthn.",
     "Your apps" : "Forritin þín",
+    "Active apps" : "Virk forrit",
+    "Disabled apps" : "Óvirk forrit",
+    "Updates" : "Uppfærslur",
+    "App bundles" : "Forritavöndlar",
     "{license}-licensed" : "{license}-notkunarleyfi",
+    "Details" : "Nánar",
     "Changelog" : "Breytingaskrá",
     "Add group" : "Bæta við hópi",
     "Active users" : "Virkir notendur",
@@ -275,16 +276,13 @@ OC.L10N.register(
     "Role" : "Role",
     "Twitter" : "Twitter",
     "Website" : "Vefsvæði",
-    "Active apps" : "Virk forrit",
-    "Disabled apps" : "Óvirk forrit",
-    "Updates" : "Uppfærslur",
-    "App bundles" : "Forritavöndlar",
     "Hide" : "Fela",
     "Download and enable" : "Sækja og virkja",
     "Enable untested app" : "Virkja óprófað forrit",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Þetta forrit er merkt sem ekki samhæft við þína útgáfu af Nextcloud. Ef þú heldur áfram er mögulegt að þú getir samt sett forritið upp. En athugaðu þá að ekki er víst að forritið virki eins og skyldi.",
     "Never" : "Aldrei",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Forritið hefur verið virkjað, en það þarf að uppfæra það. Þú verður áframsendur á uppfærslusíðuna eftir 5 sekúndur.",
+    "Administrator documentation" : "Hjálparskjöl stjórnanda",
     "Documentation" : "Hjálparskjöl",
     "Forum" : "Vefspjall",
     "Login" : "Innskráning",
@@ -337,19 +335,22 @@ OC.L10N.register(
     "Check out our blog" : "Kíktu á bloggið okkar",
     "Subscribe to our newsletter" : "Gerstu áskrifandi að fréttabréfinu okkar",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Þessi samfélagsútgáfa Nextcloud kemur ekki með neinni opinberri aðstoð og rauntímatilkynningar eru ekki til taks.",
+    "You are a member of the following groups:" : "Þú ert meðlimur eftirfarandi hópa:",
+    "You are using <strong>%s</strong>" : "Þú ert að nota <strong>%s</strong>",
+    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Þú ert að nota <strong>%1$s</strong> af <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
+    "Locale" : "Staðfærsla",
     "Use a second factor besides your password to increase security for your account." : "Notaðu annað þrep til viðbótar lykilorðinu þínu til að auka öryggi notandaaðgangsins þíns.",
     "Migration in progress. Please wait until the migration is finished" : "Yfirfærsla er í gangi. Dokaðu við þar til henni er lokið",
     "Migration started …" : "Yfirfærsla hafin...",
-    "An error occurred while changing your language. Please reload the page and try again." : "Villa kom upp við að skipta um tungumálið þitt. Endurlestu síðuna og prófaðu aftur.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "Villa kom upp við að skipta um staðfærsluna þína. Endurlestu síðuna og prófaðu aftur.",
     "Select a profile picture" : "Veldu einkennismynd",
-    "Week starts on {fdow}" : "Vika byrjar á {fdow}",
     "Couldn't remove app." : "Gat ekki fjarlægt forrit.",
     "Couldn't update app." : "Gat ekki uppfært forrit.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "Bakendi styður ekki breytingu á lykilorði, en það tókst að uppfæra dulritunarlykil notandans.",
-    "Address" : "Heimilisfang",
-    "Avatar" : "Auðkennismynd",
+    "You need to set your user email before being able to send test emails." : "Þú verður að gefa upp netfangið þitt svo að þú getir sent prófunarpósta.",
+    "All languages" : "Öll tungumál",
+    "Everyone" : "Allir",
     "An error occured during the request. Unable to proceed." : "Villa kom upp við beiðnina. Get ekki haldið áfram.",
+    "Test email settings" : "Prófa tölvupóststillingar",
     "Please read carefully before activating server-side encryption: " : "Lestu eftirfarandi gaumgæfilega áður en þú virkjar dulritun á þjóni: ",
     "Enable encryption" : "Virkja dulritun",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Þú verður að yfirfæra dulritunarlyklana þína úr gömlu dulrituninni (ownCloud <= 8.0) yfir í þá nýju. Virkjaðu \"Sjálfgefna dulritunareiningu\" og keyrðu 'occ encryption:migrate'",
@@ -361,15 +362,17 @@ OC.L10N.register(
     "Pick background job setting" : "Veldu stillingu á bakgrunnsverki",
     "Recommended" : "Mælt með",
     "The cron.php needs to be executed by the system user \"%s\"." : "cron.php verður að vera keyrt af kerfisnotandanum \"%s\".",
+    "days" : "daga",
     "Upload new" : "Senda inn nýtt",
     "Select from Files" : "Veldu skrár",
     "Remove image" : "Fjarlægja mynd",
     "Choose as profile picture" : "Veldu sem einkennismynd",
-    "You are using <strong>%s</strong>" : "Þú ert að nota <strong>%s</strong>",
-    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Þú ert að nota <strong>%1$s</strong> af <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
+    "No display name set" : "Ekkert birtingarnafn sett",
+    "Address" : "Heimilisfang",
     "Your postal address" : "Heimilisfangið þitt",
     "It can take up to 24 hours before the account is displayed as verified." : "Það getur tekið allt að 24 klukkustundum áður en notandaaðgangurinn er birtur sem sannvottaður.",
     "Link https://…" : "Tengill https://…",
-    "Twitter handle @…" : "Twitter notandanafn @…"
+    "Twitter handle @…" : "Twitter notandanafn @…",
+    "Avatar" : "Auðkennismynd"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
