@@ -30,8 +30,6 @@ OC.L10N.register(
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "გთხოვთ მოგვაწოდოთ ადმინისტრატორის აღდგენის პაროლი; სხვა შემთხვევაში ყველა მონაცემი დაიკარგება.",
     "Wrong admin recovery password. Please check the password and try again." : "ადმინისტრატორის აღდგენის არასწორი პაროლი. გთხოვთ გადაამოწმოთ პაროლი და სცადოთ ახლიდან.",
     "Federated Cloud Sharing" : "ფედერალური ქლაუდ გაზიარება",
-    "Administrator documentation" : "ადმინისტრატორის დოკუმენტაცია",
-    "User documentation" : "მომხმარებლის დოკუმენტაცია",
     "Invalid SMTP password." : "არასწორი SMTP პაროლი.",
     "Email setting test" : "ელ-ფოსტის დაყენების შემოწმება",
     "Well done, %s!" : "ყველაფერი კარგადაა, %s!",
@@ -73,7 +71,6 @@ OC.L10N.register(
     "Overview" : "ზოგადი მიმოხილვა",
     "Basic settings" : "ძირითადი პარამეტრები",
     "Sharing" : "გაზიარება",
-    "Calendar" : "კალენდარი",
     "Personal info" : "პირადი ინფორმაცია",
     "Mobile & desktop" : "მობილური და დესკტოპი",
     "Email server" : "საფოსტო სერვერი",
@@ -98,6 +95,7 @@ OC.L10N.register(
     "View in store" : "იხილეთ store-ში",
     "Visit website" : "საიტზე სტუმრობა",
     "Report a bug" : "განაცხადეთ შეცდომის შესახებ",
+    "User documentation" : "მომხმარებლის დოკუმენტაცია",
     "Admin documentation" : "ადმინისტრატორის დოკუმენტაცია",
     "Developer documentation" : "დეველოპერის დოკუმენტაცია",
     "Supported" : "მხარდაჭერილია",
@@ -147,7 +145,6 @@ OC.L10N.register(
     "png or jpg, max. 20 MB" : "png ან jpg, მაქს. 20 მბ",
     "Picture provided by original account" : "სურათი ორიგინალი ანგარიშიდან",
     "Cancel" : "უარყოფა",
-    "Details" : "დეტალები",
     "Your email address" : "თქვენი ელ-ფოსტის მისამართი",
     "No email address set" : "ელ-ფოსტის მისამართი არაა დაყენებული",
     "Language" : "ენა",
@@ -167,6 +164,10 @@ OC.L10N.register(
     "Default quota" : "საწყისი კვოტა",
     "Unnamed device" : "უსახელო მოწყობილობა",
     "Your apps" : "თქვენი აპლიკაციები",
+    "Disabled apps" : "არამოქმედი აპლიკაციები",
+    "Updates" : "განახლებები",
+    "App bundles" : "აპლიკაციის შეკვრები",
+    "Details" : "დეტალები",
     "Changelog" : "ცვლილებების ლოგი",
     "Add group" : "ჯგუფის დამატება",
     "Active users" : "აქტიური მომხმარებლები",
@@ -184,12 +185,10 @@ OC.L10N.register(
     "Phone number" : "ტელეფონის ნომერი",
     "Twitter" : "Twitter-ი",
     "Website" : "ვებ-საიტი",
-    "Disabled apps" : "არამოქმედი აპლიკაციები",
-    "Updates" : "განახლებები",
-    "App bundles" : "აპლიკაციის შეკვრები",
     "Hide" : "დამალვა",
     "Never" : "არასდროს",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "აპლიკაცია ამოქმედდა, თუმცა საჭიროებს განახლებას. 5 წამში გადამისამართდებით განახლების გვერდზე.",
+    "Administrator documentation" : "ადმინისტრატორის დოკუმენტაცია",
     "Documentation" : "დოკუმენტაცია",
     "Forum" : "ფორუმი",
     "Login" : "ლოგინი",
@@ -238,8 +237,10 @@ OC.L10N.register(
     "Couldn't remove app." : "აპლიკაციის წაშლა ვერ მოხერხდა.",
     "Couldn't update app." : "აპლიკაციის განახლება ვერ მოხერხდა.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "ბექენდს არ აქვს პაროლის ცვლილების მხარდაჭერა, თუმცა მომხმარებლის შიფრაციის გასაღები განახლდა.",
-    "Address" : "მისამართი",
-    "Avatar" : "ავატარი",
+    "You need to set your user email before being able to send test emails." : "შემოწმების წერილების გაგზავნამდე, უნდა დააყენოთ თქვენი მომხმარებლის ელ-ფოსტა.",
+    "All languages" : "ყველა ენა",
+    "Everyone" : "ყველა",
+    "Test email settings" : "ელ-ფოსტის პარამეტრების შემომება",
     "Please read carefully before activating server-side encryption: " : "სანამ გააქტიურებთ სერვერული-მხარის შიფრაციას გთხოვთ ყურადღებით გაეცნოთ:",
     "Enable encryption" : "შიფრაციის ამოქმედება",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "საჭიროა შიფრაციის გასაღებების მიგრაცია (ownCloud <= 8.0) ახალებზე. გთხოვთ აამოქმედოთ \"საწყისი მიგრაციის მოდული\" და გაუშვათ 'occ encryption:migrate'",
@@ -249,13 +250,17 @@ OC.L10N.register(
     "Last job ran %s." : "ბოლო საქმის გაშვება - %s.",
     "Background job didn’t run yet!" : "ფონური საქმე ჯერ არ გაშვებულა!",
     "The cron.php needs to be executed by the system user \"%s\"." : "cron.php უნდა გაუშვას სისტემურმა მოხმარებელმა \"%s\".",
+    "days" : "დღე",
     "Upload new" : "ახალი ატვირთვა",
     "Select from Files" : "აირჩიეთ ფაილებიდან",
     "Remove image" : "სურათის წაშლა",
     "Choose as profile picture" : "აირჩიეთ პროფილის სურათად",
+    "No display name set" : "დისპლეი სახელი არაა დაყენებული",
+    "Address" : "მისამართი",
     "Your postal address" : "თქვენი საფოსტო მისამართი",
     "It can take up to 24 hours before the account is displayed as verified." : "თქვენი ანგარიშის ვერიფიცირებულად გამოჩენამ შეიძლება გასტანოს 24 საათი.",
     "Link https://…" : "ბმული https://…",
-    "Twitter handle @…" : "Twitter @…"
+    "Twitter handle @…" : "Twitter @…",
+    "Avatar" : "ავატარი"
 },
 "nplurals=2; plural=(n!=1);");
