@@ -2,12 +2,9 @@ OC.L10N.register(
     "settings",
     {
     "Private" : "Privatus",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Matoma tik žmonėms, su kuriais pokalbių programėlėje mobiliajame įrenginyje buvo rasta atitiktis per telefono numerio integraciją",
     "Local" : "Vietinis",
-    "Only visible to people on this instance and guests" : "Matoma tik žmonėms šiame egzemplioriuje ir svečiams",
     "Federated" : "Federacinis",
     "Only synchronize to trusted servers" : "Sinchronizuoti tik į patikimus serverius",
-    "Published" : "Paskelbtas",
     "Synchronize to trusted servers and the global and public address book" : "Sinchronizuoti į patikimus serverius ir į visuotinę bei viešą adresų knygą",
     "Verify" : "Patikrinti",
     "Verifying …" : "Tikrinama...",
@@ -17,6 +14,9 @@ OC.L10N.register(
     "So-so password" : "Neblogas slaptažodis",
     "Good password" : "Geras slaptažodis",
     "Strong password" : "Stiprus slaptažodis",
+    "An error occurred while changing your language. Please reload the page and try again." : "Keičiant jūsų kalbą, įvyko klaida. Įkelkite puslapį iš naujo ir bandykite dar kartą.",
+    "An error occurred while changing your locale. Please reload the page and try again." : "Keičiant jūsų lokalę, įvyko klaida. Įkelkite puslapį iš naujo ir bandykite dar kartą.",
+    "Week starts on {fdow}" : "Savaitės pradžia yra {fdow}",
     "Groups" : "Grupės",
     "Group list is empty" : "Grupės sąrašas yra tuščias",
     "Unable to retrieve the group list" : "Nepavyko nuskaityti grupių sąrašo",
@@ -39,7 +39,6 @@ OC.L10N.register(
     "You changed your email address" : "Jūs pakeitėte savo el. pašto adresą",
     "Your email address was changed by an administrator" : "Administratorius pakeitė jūsų el. pašto adresą",
     "You created app password \"{token}\"" : "Jūs sukūrėte programėlės slaptažodį \"{token}\"",
-    "An administrator created app password \"{token}\"" : "Administratorius sukūrė programėlės slaptažodį „{token}“",
     "You deleted app password \"{token}\"" : "Jūs ištrynėte programėlės slaptažodį \"{token}\"",
     "You renamed app password \"{token}\" to \"{newToken}\"" : "Jūs pervadinote programėlės slaptažodį \"{token}\" į \"{newToken}\"",
     "You granted filesystem access to app password \"{token}\"" : "Jūs suteikėte failų sistemai prieigą prie programos slaptažodžio  „{token}“.",
@@ -50,31 +49,20 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Nuotolinių duomenų ištrynimas buvo pradėtas ties %1$s",
     "Remote wipe has finished on %1$s" : "Nuotolinių duomenų ištrynimas užbaigtas ties %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Jūsų <strong>slaptažodis</strong> ar <strong>el. paštas</strong> buvo pakeisti",
-    "Could not remove app." : "Nepavyko pašalinti programėlės.",
-    "Could not update app." : "Nepavyko atnaujinti programėlės.",
     "Wrong password" : "Neteisingas slaptažodis",
-    "Unable to change personal password" : "Nepavyko pakeisti asmeninio slaptažodžio",
     "Saved" : "Įrašyta",
     "No user supplied" : "Nepateiktas naudotojas",
-    "Unable to change password. Password too long." : "Nepavyko pakeisti slaptažodžio. Slaptažodis per ilgas.",
     "Authentication error" : "Tapatybės nustatymo klaida",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Pateikite administratoriaus atkūrimo slaptažodį; kitu atveju visi naudotojo duomenis bus prarasti.",
     "Wrong admin recovery password. Please check the password and try again." : "Netinkamas administratoriaus atkūrimo slaptažodis. Prašome pasitikrinti ir bandyti vėl.",
     "Federated Cloud Sharing" : "Bendrinimas federacinėje debesijoje",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL naudoja pasenusią %1$s versiją (%2$s). Atnaujinkite savo operacinę sistemą arba tokios ypatybės kaip %3$s neveiks patikimai.",
-    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "Nepavyko nustatyti ar TLS versija, priklausanti cURL, yra pasenusi ar ne, nes į https://nextcloud.com siunčiamos HTTPS užklausos metu įvyko klaida. Išsamesnei informacijai patikrinkite Nextcloud žurnalo failą.",
-    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP OPcache modulis nėra įkeltas. Geresniam našumui rekomenduojame įkelti šį modulį į savo PHP diegimą.",
-    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache yra išjungtas. Geresniam našumui rekomenduojame taikyti savo PHP konfigūracijoje <code>opcache.enable=1</code>.",
-    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache yra sukonfigūruotas taip, kad šalintų kodo komentarus. Turint įjungtą OPcache, privalo būti nustatyta <code>opcache.save_comments=1</code>, kad Nextcloud galėtų funkcionuoti.",
-    "Administrator documentation" : "Administratoriaus dokumentacija",
-    "User documentation" : "Naudotojo dokumentacija",
     "Invalid SMTP password." : "Neteisingas SMTP slaptažodis.",
     "Email setting test" : "El. pašto nustatymo testas",
     "Well done, %s!" : "Gerai padirbėjote, %s!",
     "If you received this email, the email configuration seems to be correct." : "Jeigu gavote šį laišką, tuomet atrodo, jog el. pašto konfigūracija yra teisinga.",
     "Email could not be sent. Check your mail server log" : "El. laiškas nebuvo išsiųstas. Peržiūrėkite savo pašto serverio žurnalą.",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Siunčiant el. laišką atsirado problemų. Peržiūrėkite savo nustatymus. (Klaida: %s)",
-    "You need to set your user email before being able to send test emails. Go to %s for that." : "Prieš tai, kai galėsite siųsti bandomuosius el. laiškus, turite nusistatyti naudotojo el. paštą. Norėdami tai atlikti, pereikite į %s.",
     "Invalid user" : "Neteisingas naudotojas",
     "Invalid mail address" : "Neteisingas pašto adresas",
     "Settings saved" : "Nustatymai įrašyti",
@@ -109,13 +97,10 @@ OC.L10N.register(
     "Personal" : "Asmeniniai",
     "Administration" : "Administravimas",
     "Additional settings" : "Papildomi nustatymai",
-    "Administration privileges" : "Administravimo teisės",
     "Groupware" : "Grupinio darbo įranga",
     "Overview" : "Apžvalga",
     "Basic settings" : "Pagrindiniai nustatymai",
     "Sharing" : "Bendrinimas",
-    "Availability" : "Pasiekiamumas",
-    "Calendar" : "Kalendorius",
     "Personal info" : "Asmeninė informacija",
     "Mobile & desktop" : "Mobilieji ir darbalaukiai",
     "Email server" : "El. pašto serveris",
@@ -127,12 +112,7 @@ OC.L10N.register(
     "Reshare" : "Pakartotinai bendrinti",
     "Unlimited" : "Neribotai",
     "Verifying" : "Tikrinimas",
-    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "Yra naudojama MariaDB versija „%s“. Nextcloud 21 ir naujesnės laidos nepalaiko šios MariaDB versijos ir reikalauja 10.2 ar naujesnės versijos.",
-    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "Yra naudojama MySQL versija „%s“. Nextcloud 21 ir naujesnės laidos nepalaiko šios MySQL versijos ir reikalauja MySQL 8.0 arba MariaDB 10.2, ar naujesnės versijos.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "Yra naudojama PostgreSQL versija „%s“. Nextcloud 21 ir naujesnės laidos nepalaiko šios PostgreSQL versijos ir reikalauja PostgreSQL 9.6 ar naujesnės versijos.",
-    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profilio paveikslėlis, vardas, pavardė, el. paštas, telefono numeris, adresas, svetainė, „Twitter“, organizacija, vaidmuo, santrauka apie jus, biografija bei tai, ar jūsų profilis yra įjungtas, ar ne",
     "Nextcloud settings" : "Nextcloud nustatymai",
-    "Here you can decide which group can access certain sections of the administration settings." : "Čia galite nuspręsti, kuri grupė galės gauti prieigą prie tam tikrų administravimo nustatymų sekcijų.",
     "None" : "Nėra",
     "Two-Factor Authentication" : "Dviejų faktorių tapatybės nustatymas",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Dviejų faktorių tapatybės nustatymas gali būti priverstinis visiems naudotojams ir tam tikroms grupėms. Jeigu naudotojai ar grupės neturės sukonfigūruoto dviejų faktorių teikėjo, tuomet jie negalės prisijungti prie sistemos.",
@@ -157,12 +137,11 @@ OC.L10N.register(
     "View in store" : "Rodyti parduotuvėje",
     "Visit website" : "Aplankyti svetainę",
     "Report a bug" : "Pranešti apie klaidą",
+    "User documentation" : "Naudotojo dokumentacija",
     "Admin documentation" : "Administratoriaus dokumentacija",
     "Developer documentation" : "Plėtotojo dokumentacija",
     "This app is supported via your current Nextcloud subscription." : "Ši programėlė yra palaikoma per jūsų esamą Nextcloud prenumeratą.",
     "Supported" : "Palaikoma",
-    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Siūlomos programėlės yra kuriamos bendruomenės viduje ir jas kuria bendruomenė. Šios programėlės siūlo svarbiausią funkcionalumą ir yra paruoštos kasdieniam naudojimui.",
-    "Featured" : "Siūlomos",
     "Update to {update}" : "Atnaujinti į {update}",
     "All apps are up-to-date." : "Visos programėlės yra naujausios laidos.",
     "Results from other categories" : "Rezultatai iš kitų kategorijų",
@@ -185,8 +164,6 @@ OC.L10N.register(
     "Google Chrome for Android" : "Google Chrome, skirta Android",
     "iPhone" : "iPhone",
     "iPad" : "iPad",
-    "{productName} iOS app" : "{productName} „iOS“ programėlė",
-    "{productName} Android app" : "{productName} „Android“ programėlė",
     "Sync client - {os}" : "Sinchronizavimo klientas - {os}",
     "This session" : "Šis seansas",
     "Device" : "Įrenginys",
@@ -211,19 +188,7 @@ OC.L10N.register(
     "Copied!" : "Nukopijuota!",
     "Copy" : "Kopijuoti",
     "Could not copy app password. Please copy it manually." : "Nepavyko nukopijuoti programos slaptažodžio. Nukopijuokite jį ranka.",
-    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Tam, kad serveris tinkamai veiktų, yra svarbu teisingai sukonfigūruoti fonines užduotis. „Cron“ yra rekomenduojamas nustatymas. Išsamesnei informacijai žiūrėkite dokumentaciją.",
-    "Last job execution ran {time}. Something seems wrong." : "Paskutinis užduoties vykdymas buvo atliktas {time}. Atrodo, kad kažkas nutiko.",
-    "Last job ran {relativeTime}." : "Paskutinis užduoties vykdymas buvo atliktas {relativeTime}.",
-    "Background job did not run yet!" : "Foninės užduotys kol kas nebuvo vykdomos!",
-    "AJAX" : "„AJAX“",
-    "Execute one task with each page loaded. Use case: Single user instance." : "Su kiekvienu įkeltu puslapiu vykdyti po vieną užduotį. Naudojimo atvejis: Egzempliorius su vienu naudotoju.",
-    "Webcron" : "„Webcron“",
-    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "„cron.php“ yra registruojamas „webcron“ tarnyboje, kad kas 5 minutes per HTTP būtų iškviečiamas failas „cron.php“. Naudojimo atvejis: Labai mažas egzempliorius (priklausomai nuo našumo, 1–5 naudotojai).",
-    "Cron (Recommended)" : "„Cron“ (Rekomenduojama)",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Norint tai paleisti, jums reikia PHP POSIX plėtinio. Išsamesnei informacijai, žiūrėkite {linkstart}PHP dokumentaciją{linkend}.",
-    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Naudoti sistemos „cron“ tarnybą, kad kas 5 minutes būtų iškviečiamas failas „cron.php“. Rekomenduojama visiems egzemplioriams.",
-    "The cron.php needs to be executed by the system user \"{user}\"." : "Failą „cron.php“ turi vykdyti sistemos naudotojas „{user}“.",
-    "Unable to update background job mode" : "Nepavyko atnaujinti foninių užduočių veiksenos",
     "Profile" : "Profilis",
     "Enable" : "Įjungti",
     "Server-side encryption" : "Šifravimas serverio pusėje",
@@ -236,63 +201,33 @@ OC.L10N.register(
     "This is the final warning: Do you really want to enable encryption?" : "Tai yra paskutinis įspėjimas: Ar tikrai norite įjungti šifravimą?",
     "No encryption module loaded, please enable an encryption module in the app menu." : "Neįkeltas joks šifravimo modulis, įjunkite šifravimo modulį programėlės meniu.",
     "Select default encryption module:" : "Pasirinkite numatytąjį šifravimo modulį:",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Jūs turite perkelti savo šifravimo raktus iš senojo šifravimo (ownCloud <= 8.0) į naująjį. Įjunkite „Numatytąjį šifravimo modulį“ ir paleiskite komandą {command}",
-    "Rename group" : "Pervadinti grupę",
     "Remove group" : "Šalinti grupę",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Jūs ketinate pašalinti grupę {group}. Naudotojai NEBUS ištrinti.",
     "Please confirm the group removal " : "Patvirtinkite grupės pašalinimą",
     "Current password" : "Dabartinis slaptažodis",
     "New password" : "Naujas slaptažodis",
     "Change password" : "Pakeisti slaptažodį",
-    "Your profile picture" : "Jūsų profilio paveikslėlis",
-    "Remove profile picture" : "Šalinti profilio paveikslėlį",
     "png or jpg, max. 20 MB" : "png arba jpg, daugiausiai 20 MB",
     "Picture provided by original account" : "Paveikslėlis gautas iš pagrindinės paskyros",
     "Cancel" : "Atšaukti",
-    "Set as profile picture" : "Nustatyti kaip profilio paveikslėlį",
-    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Turėkite omenyje, kad gali praeiti iki 24 valandų, kol jūsų profilis bus visur atnaujintas.",
-    "Error setting profile picture" : "Klaida nustatant profilio paveikslėlį",
-    "Error cropping profile picture" : "Klaida apkerpant profilio paveikslėlį",
-    "Error saving profile picture" : "Klaida įrašant profilio paveikslėlį",
-    "Error removing profile picture" : "Klaida šalinant profilio paveikslėlį",
     "Your biography" : "Jūsų biografija",
-    "Details" : "Išsamiau",
-    "You are a member of the following groups:" : "Jūs esate šių grupių narys:",
-    "You are using <strong>{usage}</strong>" : "Jūs naudojate <strong>{usage}</strong>",
     "Your full name" : "Jūsų visas vardas",
-    "Email options" : "El. pašto parinktys",
-    "Primary email for password reset and notifications" : "Pirminis el. paštas, skirtas slaptažodžio atstatymui bei pranešimams",
     "Remove primary email" : "Šalinti pirminį el. paštą",
     "Delete email" : "Ištrinti el. paštą",
     "This address is not confirmed" : "Šis adresas nėra patvirtintas",
     "Set as primary email" : "Nustatyti kaip pirminį el. paštą",
     "Your email address" : "Jūsų el. pašto adresas",
-    "Additional email address {index}" : "Papildomas el. pašto adresas {index}",
-    "Unable to delete primary email address" : "Nepavyko ištrinti pirminio el. pašto adreso",
-    "Unable to update primary email address" : "Nepavyko atnaujinti pirminio el. pašto adreso",
-    "Unable to add additional email address" : "Nepavyko pridėti papildomo el. pašto adreso",
-    "Unable to update additional email address" : "Nepavyko atnaujinti papildomo el. pašto adreso",
-    "Unable to delete additional email address" : "Nepavyko ištrinti papildomo el. pašto adreso",
     "No email address set" : "Nenustatytas joks el. pašto adresas",
-    "Additional emails" : "Papildomi el. paštai",
-    "Your headline" : "Santrauka apie jus",
     "Language" : "Kalba",
     "Help translate" : "Padėkite išversti",
-    "Unable to update language" : "Nepavyko atnaujinti kalbos",
     "No language set" : "Nenustatyta jokia kalba",
-    "Locale" : "Lokalė",
-    "Your organisation" : "Jūsų organizacija",
     "Your phone number" : "Jūsų telefono numeris",
     "Edit your Profile visibility" : "Taisyti savo profilio matomumą",
     "Enable Profile" : "Įjungti profilį",
     "Unable to update profile enabled state" : "Nepavyko atnaujinti profilio įjungimo būsenos",
     "{displayId}" : "{displayId}",
     "Unable to update visibility of {displayId}" : "Nepavyko atnaujinti {displayId} matomumo",
-    "Your role" : "Jūsų vaidmuo",
-    "Your Twitter handle" : "Jūsų „Twitter“ rankenėlė",
     "Your website" : "Jūsų svetainė",
-    "Unable to update {property}" : "Nepavyko atnaujinti {property}",
-    "Add additional email" : "Pridėti papildomą el. paštą",
     "Add" : "Pridėti",
     "You do not have permissions to see the details of this user" : "Jūs neturite leidimų matyti išsamesnę informaciją apie šį naudotoją",
     "Add new password" : "Pridėti naują slaptažodį",
@@ -345,7 +280,12 @@ OC.L10N.register(
     "The following devices are configured for your account:" : "Jūsų paskyrai sukonfiguruoti šie įrenginiai:",
     "Your browser does not support WebAuthn." : "Jūsų naršyklė nepalaiko WebAuthn.",
     "Your apps" : "Jūsų programėlės",
+    "Active apps" : "Aktyvios programėlės",
+    "Disabled apps" : "Išjungtos programėlės",
+    "Updates" : "Atnaujinimai",
+    "App bundles" : "Programėlių rinkiniai",
     "{license}-licensed" : "Licencijuota pagal {license}",
+    "Details" : "Išsamiau",
     "Changelog" : "Keitinių žurnalas",
     "by {author}\n{license}" : "pagal {author}\n{license}",
     "Enter group name" : "Įveskite grupės pavadinimą",
@@ -367,31 +307,20 @@ OC.L10N.register(
     "Profile picture" : "Profilio paveikslėlis",
     "About" : "Apie",
     "Full name" : "Vardas, pavardė",
-    "Additional email" : "Papildomas el. paštas",
-    "Headline" : "Santrauka",
     "Organisation" : "Organizacija",
     "Phone number" : "Telefono numeris",
-    "Role" : "Vaidmuo",
     "Twitter" : "Twitter",
     "Website" : "Svetainė",
     "Profile visibility" : "Profilio matomumas",
-    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Neprieinama, nes su naudotoju susijusios informacijos paskelbimas į paieškos serverį yra neleidžiamas. Jei turite klausimų, susisiekite su savo sistemos administratoriumi",
-    "Active apps" : "Aktyvios programėlės",
-    "Disabled apps" : "Išjungtos programėlės",
-    "Updates" : "Atnaujinimai",
-    "App bundles" : "Programėlių rinkiniai",
-    "Featured apps" : "Siūlomos programėlės",
     "Show to everyone" : "Rodyti visiems",
     "Show to logged in users only" : "Rodyti tik prisijungusiems naudotojams",
     "Hide" : "Slėpti",
     "Download and enable" : "Atsisiųsti ir įjungti",
     "Enable untested app" : "Įjungti netestuotą programą",
-    "The app will be downloaded from the App Store" : "Programėlė bus atsisiųsta iš programėlių parduotuvės",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ši programėlė nėra pažymėta kaip suderinama su jūsų Nextcloud versija. Jei tęsite, vis tiek galėsite įdiegti programėlę. Turėkite omenyje, kad programėlė gali neveikti taip kaip tikimasi.",
     "Never" : "Niekada",
-    "An error occurred during the request. Unable to proceed." : "Užklausos metu įvyko klaida. Nepavyksta tęsti.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Programėlė įjungta, tačiau turi būti atnaujinta. Po 5 sekundžių būsite peradresuoti į atnaujinimo puslapį.",
-    "Error: This app cannot be enabled because it makes the server unstable" : "Klaida: Ši programėlė negali būti įjungta, nes ji neigiamai veikia serverio stabilumą",
+    "Administrator documentation" : "Administratoriaus dokumentacija",
     "Documentation" : "Dokumentacija",
     "Forum" : "Forumas",
     "Login" : "Prisijungti",
@@ -413,7 +342,6 @@ OC.L10N.register(
     "SMTP Username" : "SMTP naudotojo vardas",
     "SMTP Password" : "SMTP slaptažodis",
     "Save" : "Įrašyti",
-    "Test and verify email settings" : "Išbandyti ir patikrinti el. pašto nustatymus",
     "Send email" : "Siųsti el. paštą",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Siekiant jūsų egzemplioriaus saugumo ir našumo, yra svarbu, kad viskas būtų teisingai sukonfigūruota. Norėdami jums padėti, atliekame tam tikrus automatinius patikrinimus. Išsamesnei informacijai, žiūrėkite susietą dokumentaciją.",
     "All checks passed." : "Visi patikros rezultatai teigiami.",
@@ -446,25 +374,23 @@ OC.L10N.register(
     "Follow us on Mastodon" : "Sekite mus Mastodon",
     "Check out our blog" : "Peržvelkite mūsų tinklaraštį",
     "Subscribe to our newsletter" : "Prenumeruokite mūsų naujienlaiškį",
+    "You are a member of the following groups:" : "Jūs esate šių grupių narys:",
+    "You are using <strong>%s</strong>" : "Jūs naudojate <strong>%s</strong>",
+    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Jūs naudojate <strong>%1$s</strong> iš <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
+    "Locale" : "Lokalė",
     "Use a second factor besides your password to increase security for your account." : "Be savo slaptažodžio naudokite ir antrąjį faktorių, kad padidintumėte savo paskyros saugumą.",
     "Migration in progress. Please wait until the migration is finished" : "Vyksta perkėlimas. Palaukite, kol perkėlimas bus užbaigtas",
     "Migration started …" : "Perkėlimas pradėtas …",
-    "An error occurred while changing your language. Please reload the page and try again." : "Keičiant jūsų kalbą, įvyko klaida. Įkelkite puslapį iš naujo ir bandykite dar kartą.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "Keičiant jūsų lokalę, įvyko klaida. Įkelkite puslapį iš naujo ir bandykite dar kartą.",
     "Select a profile picture" : "Pasirinkite profilio paveikslėlį",
-    "Week starts on {fdow}" : "Savaitės pradžia yra {fdow}",
     "Couldn't remove app." : "Nepavyko pašalinti programėlės.",
     "Couldn't update app." : "Nepavyko atnaujinti programėlės.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "Vidinė pusė nepalaiko slaptažodžio keitimo, tačiau naudotojo šifravimo raktas buvo atnaujintas.",
-    "Admin privileges" : "Administravimo teisės",
+    "You need to set your user email before being able to send test emails." : "Prieš galėdami siųsti bandomuosius el. laiškus, turite nusistatyti savo naudotojo el. paštą.",
     "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Panaikinus šį prieigos raktą, jums gali būti neleista ištrinti šio įrenginio duomenų, jeigu jis dar nepradėjo duomenų ištrynimo.",
-    "Unable to update biography" : "Nepavyko atnaujinti biografijos",
-    "Unable to update full name" : "Nepavyko atnaujinti viso vardo",
-    "No full name set" : "Nenustatyta jokio viso vardo",
-    "Unable to update headline" : "Nepavyko atnaujinti santraukos apie jus",
-    "Address" : "Adresas",
-    "Avatar" : "Avataras",
+    "All languages" : "Visos kalbos",
+    "Everyone" : "Visi",
     "An error occured during the request. Unable to proceed." : "Užklausos metu, įvyko klaida. Nepavyksta tęsti.",
+    "Test email settings" : "Išbandyti el. pašto nustatymus",
     "Please read carefully before activating server-side encryption: " : "Prieš aktyvuodami šifravimą serverio pusėje, įdėmiai perskaitykite:",
     "Enable encryption" : "Įjungti šifravimą",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Jūs turite perkelti savo šifravimo raktus iš senojo šifravimo (ownCloud <= 8.0) į naująjį. Prašome įjungti „Numatytąjį šifravimo modulį“ ir įvykdyti „occ encryption:migrate“",
@@ -478,15 +404,20 @@ OC.L10N.register(
     "Pick background job setting" : "Parinkite foninių darbų nustatymus",
     "Recommended" : "Rekomenduojama",
     "The cron.php needs to be executed by the system user \"%s\"." : "Cron.php turi įvykdyti sistemos naudotojas „%s“.",
+    "days" : "dienos",
     "Upload new" : "Įkelti naują",
     "Select from Files" : "Pasirinkti iš failų",
     "Remove image" : "Šalinti paveikslą",
     "Choose as profile picture" : "Pasirinkti kaip profilio paveikslėlį",
-    "You are using <strong>%s</strong>" : "Jūs naudojate <strong>%s</strong>",
-    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Jūs naudojate <strong>%1$s</strong> iš <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
+    "No display name set" : "Rodomas vardas nenurodytas",
+    "Address" : "Adresas",
     "Your postal address" : "Jūsų adresas",
     "It can take up to 24 hours before the account is displayed as verified." : "Gali užtrukti iki 24 valandų, kol paskyra bus rodoma kaip patikrinta. ",
     "Link https://…" : "Nuoroda https://…",
-    "Twitter handle @…" : "Twitter rankenėlė @…"
+    "Twitter handle @…" : "Twitter rankenėlė @…",
+    "Unable to update biography" : "Nepavyko atnaujinti biografijos",
+    "Unable to update full name" : "Nepavyko atnaujinti viso vardo",
+    "No full name set" : "Nenustatyta jokio viso vardo",
+    "Avatar" : "Avataras"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
