@@ -22,8 +22,6 @@ OC.L10N.register(
     "Authentication error" : "Autentifikācijas kļūda",
     "Wrong admin recovery password. Please check the password and try again." : "Nepareiza administratora atjaunošanas parole. Lūdzu pārbaudiet paroli un mēģiniet vēlreiz.",
     "Federated Cloud Sharing" : "Federatīva mākoņkoplietošana",
-    "Administrator documentation" : "Administratora dokumentācija",
-    "User documentation" : "Lietotāja dokumentācija",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Radās kļūda, nosūtot e-pastu. Lūdzu, pārskatiet savus iestatījumus. (Kļūda: %s)",
     "Invalid user" : "Nepareizs lietotājs",
     "Invalid mail address" : "Nepareiza e-pasta adrese",
@@ -34,12 +32,8 @@ OC.L10N.register(
     "Apps" : "Lietotnes",
     "Settings" : "Iestatījumi",
     "Personal" : "Personīgs",
-    "Administration" : "Administrēšana",
     "Additional settings" : "Papildu iestatījumi",
-    "Administration privileges" : "Administrēšanas privilēģijas",
     "Sharing" : "Koplietošana",
-    "Availability" : "Pieejamība",
-    "Calendar" : "Kalendārs",
     "Personal info" : "Personiskā informācija",
     "Email server" : "E-pasta serveris",
     "Security & setup warnings" : "Drošības un iestatījumu brīdinājumi",
@@ -47,7 +41,6 @@ OC.L10N.register(
     "Change" : "Mainīt",
     "Delete" : "Dzēst",
     "Unlimited" : "Neierobežota",
-    "Nextcloud settings" : "Nextcloud iestatījumi",
     "None" : "Nav",
     "Limit to groups" : "Grupu ierobežojums",
     "Save changes" : "Saglabāt izmaiņas",
@@ -58,10 +51,10 @@ OC.L10N.register(
     "Disable" : "Deaktivēt",
     "Visit website" : "Apmeklējiet vietni",
     "Report a bug" : "Ziņot par kļūdu",
+    "User documentation" : "Lietotāja dokumentācija",
     "Admin documentation" : "Administratora dokumentācija",
     "Developer documentation" : "Izstrādātāja dokumentācija",
     "No apps found for your version" : "Neatrada lietotnes jūsu versijai",
-    "Device settings" : "Ierīces iestatījumi",
     "Rename" : "Pārsaukt",
     "Revoke" : "Atsaukt",
     "Internet Explorer" : "Internet Explorer",
@@ -99,7 +92,6 @@ OC.L10N.register(
     "Change password" : "Mainīt paroli",
     "png or jpg, max. 20 MB" : "png vai jpg, max. 20 MB",
     "Cancel" : "Atcelt",
-    "Details" : "Detaļas",
     "Your email address" : "Jūsu e-pasta adrese",
     "No email address set" : "Nav norādīts e-pasts",
     "Language" : "Valoda",
@@ -114,11 +106,11 @@ OC.L10N.register(
     "Storage location" : "Krātuves atrašanās vieta",
     "Last login" : "Pēdējā pieteikšanās",
     "Default quota" : "Apjoms pēc noklusējuma",
-    "Changelog" : "Izmaiņu žurnāls",
+    "Updates" : "Atjauninājumi",
+    "Details" : "Detaļas",
     "Add group" : "Pievienot grupu",
     "Active users" : "Aktīvie lietotāji",
     "Admins" : "Admins",
-    "Show last login" : "Rādīt pēdējo autorizāciju",
     "Send email to new user" : "Sūtīt e-pastu jaunajam lietotājam",
     "Not saved" : "Nav saglabāts",
     "Sending…" : "Sūta …",
@@ -130,9 +122,9 @@ OC.L10N.register(
     "Phone number" : "Tālruņa numurs",
     "Twitter" : "Twitter",
     "Website" : "Mājaslapa",
-    "Updates" : "Atjauninājumi",
     "Hide" : "Slēpt",
     "Never" : "Nekad",
+    "Administrator documentation" : "Administratora dokumentācija",
     "Documentation" : "Dokumentācija",
     "Forum" : "Forums",
     "Login" : "Autorizēties",
@@ -170,16 +162,22 @@ OC.L10N.register(
     "Select a profile picture" : "Izvēlieties profila attēlu",
     "Couldn't remove app." : "Nebija iespējams noņemt lietotni.",
     "Couldn't update app." : "Nevarēja atjaunināt lietotni.",
-    "Address" : "Adrese",
-    "Avatar" : "Profila attēls",
+    "You need to set your user email before being able to send test emails." : "Nepieciešams norādīt sava lietotāja e-pasta adresi, lai nosūtīta testa e-pastus.",
+    "All languages" : "Visas valodas",
+    "Everyone" : "Visi",
+    "Test email settings" : "Izmēģināt e-pasta iestatījumus",
     "Please read carefully before activating server-side encryption: " : "Lūdzu, izlasiet uzmanīgi pirms aktivējiet servera šifrēšanu:",
     "Enable encryption" : "Ieslēgt šifrēšanu",
     "Start migration" : "Sākt migrāciju",
     "Recommended" : "Rekomendēts",
+    "days" : "dienas",
     "Upload new" : "Ielādēt jaunu",
     "Select from Files" : "Izvēlēties no Datnes",
     "Remove image" : "Novākt attēlu",
     "Choose as profile picture" : "Izvēlēties kā profila attēlu",
-    "Your postal address" : "Jūsu pasta adrese"
+    "No display name set" : "Nav norādīts ekrāna vārds",
+    "Address" : "Adrese",
+    "Your postal address" : "Jūsu pasta adrese",
+    "Avatar" : "Profila attēls"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
