@@ -16,7 +16,6 @@ OC.L10N.register(
     "Strong password" : "Sterkt passord",
     "An error occurred while changing your language. Please reload the page and try again." : "En feil oppstod under endring av språk. Last inn siden på nytt og prøv igjen.",
     "An error occurred while changing your locale. Please reload the page and try again." : "En feil oppstod under endring av nasjonal innstilling. Last inn siden på nytt og prøv igjen.",
-    "Select a profile picture" : "Velg et profilbilde",
     "Week starts on {fdow}" : "Uken starter på {fdow}",
     "Groups" : "Grupper",
     "Group list is empty" : "Gruppeliste er tom",
@@ -199,11 +198,20 @@ OC.L10N.register(
     "Remove group" : "Fjern gruppe",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Du skal til å fjerne gruppen {group}. Brukerne vil IKKE bli slettet.",
     "Please confirm the group removal " : "Vennligst bekreft fjerning av gruppe",
+    "Current password" : "Nåværende passord",
+    "New password" : "Nytt passord",
+    "Change password" : "Endre passord",
+    "png or jpg, max. 20 MB" : "png eller jpg, maks. 20 MB",
+    "Picture provided by original account" : "Bilde kommer fra opprinnelig konto",
+    "Cancel" : "Avbryt",
     "Your email address" : "Din e-postadresse",
     "No email address set" : "E-postadresse ikke satt",
     "Language" : "Språk",
     "Help translate" : "Bidra til oversettelsen",
     "No language set" : "Språk ikke satt",
+    "Your phone number" : "Ditt telefonnummer",
+    "Your Twitter handle" : "Din Twitter-konto",
+    "Your website" : "Din nettside",
     "Add" : "Legg til",
     "You do not have permissions to see the details of this user" : "Du har ikke tilgang til å se detaljer om denne brukeren",
     "Set user as admin for" : "Sett bruker som administrator for",
@@ -215,7 +223,6 @@ OC.L10N.register(
     "Resend welcome email" : "Send velkomst-epost igjen",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "I tilfelle man har mistet enheter eller skal ut av organisasjonen, så kan dette fjernslette Nextcloud data fra alle enheter tilknyttet bruker med {userid}. Dette fungerer kun dersom enhetene er tilkoblet internett.",
     "Remote wipe of devices" : "Fjernsletting av enheter",
-    "Cancel" : "Avbryt",
     "Welcome mail sent!" : "Velkomst-epost sendt!",
     "{size} used" : "{size} brukt",
     "New user" : "Ny bruker",
@@ -259,18 +266,20 @@ OC.L10N.register(
     "Not saved" : "Ikke lagret",
     "Sending…" : "Sender…",
     "Email sent" : "E-post sendt",
-    "Address" : "Adresse",
-    "Avatar" : "Avatar",
+    "Location" : "Sted",
+    "Profile picture" : "Profilbilde",
     "About" : "Om",
     "Full name" : "Fullt navn",
+    "Headline" : "Overskrift",
+    "Organisation" : "Organisasion",
     "Phone number" : "Telefonnummer",
+    "Role" : "Rolle",
     "Twitter" : "Twitter",
     "Website" : "Nettsted",
     "Hide" : "Skjul",
     "Download and enable" : "Last ned og aktiver",
     "Enable untested app" : "Aktiver utestet app",
     "Never" : "Aldri",
-    "An error occured during the request. Unable to proceed." : "En feil oppstod under forespørselen. Kan ikke fortsette.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Appen er aktivert men må oppdateres. Du vil bli videresendt til oppdateringssiden om 5 sekunder.",
     "Administrator documentation" : "Administratordokumentasjon",
     "Documentation" : "Dokumentasjon",
@@ -324,34 +333,21 @@ OC.L10N.register(
     "Check out our blog" : "Sjekk ut bloggen vår",
     "Subscribe to our newsletter" : "Abonner på vårt nyhetsbrev",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Denne community-utgaven av NextCloud er ikke understøttet og umiddelbare varsler er derfor ikke tilgjengelig. ",
-    "Profile picture" : "Profilbilde",
-    "Upload new" : "Last opp nytt",
-    "Select from Files" : "Velg fra filer",
-    "Remove image" : "Fjern bilde",
-    "png or jpg, max. 20 MB" : "png eller jpg, maks. 20 MB",
-    "Picture provided by original account" : "Bilde kommer fra opprinnelig konto",
-    "Choose as profile picture" : "Velg som profilbilde",
     "You are a member of the following groups:" : "Du er medlem av følgende grupper:",
     "You are using <strong>%s</strong>" : "Du bruker <strong>%s</strong>",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Du bruker <strong>%1$s</strong> av <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
-    "Your phone number" : "Ditt telefonnummer",
-    "Your postal address" : "Din postadresse",
-    "It can take up to 24 hours before the account is displayed as verified." : "Det kan ta opptil ett døgn før kontoen vises som bekreftet.",
-    "Link https://…" : "Lenke https://…",
-    "Twitter handle @…" : "Twitter-konto @ …",
     "Locale" : "Nasjonal innstilling",
-    "Current password" : "Nåværende passord",
-    "New password" : "Nytt passord",
-    "Change password" : "Endre passord",
     "Use a second factor besides your password to increase security for your account." : "Bruk en annen faktor i tillegg til passordet ditt for å øke sikkerheten for kontoen din.",
     "Migration in progress. Please wait until the migration is finished" : "Migrering utføres. Vent til den er ferdig.",
     "Migration started …" : "Migrering startet…",
+    "Select a profile picture" : "Velg et profilbilde",
     "Couldn't remove app." : "Klarte ikke å fjerne app.",
     "Couldn't update app." : "Kunne ikke oppdatere appen.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "Serveren støtter ikke endring av passord, men brukerens krypteringsnøkkel ble oppdatert.",
     "You need to set your user email before being able to send test emails." : "Du må sette e-postadressen for brukeren din før du kan teste sending av e-post.",
     "All languages" : "Alle språk",
     "Everyone" : "Alle",
+    "An error occured during the request. Unable to proceed." : "En feil oppstod under forespørselen. Kan ikke fortsette.",
     "Test email settings" : "Test innstillinger for e-post",
     "Please read carefully before activating server-side encryption: " : "Les dette nøye før du aktiverer kryptering på serverdelen:",
     "Enable encryption" : "Aktiver kryptering",
@@ -365,6 +361,16 @@ OC.L10N.register(
     "Recommended" : "Anbefalt",
     "The cron.php needs to be executed by the system user \"%s\"." : "Filen cron.php må kjøres systemet som følgende bruker \"%s\".",
     "days" : "dager",
-    "No display name set" : "Visningsnavn ikke satt"
+    "Upload new" : "Last opp nytt",
+    "Select from Files" : "Velg fra filer",
+    "Remove image" : "Fjern bilde",
+    "Choose as profile picture" : "Velg som profilbilde",
+    "No display name set" : "Visningsnavn ikke satt",
+    "Address" : "Adresse",
+    "Your postal address" : "Din postadresse",
+    "It can take up to 24 hours before the account is displayed as verified." : "Det kan ta opptil ett døgn før kontoen vises som bekreftet.",
+    "Link https://…" : "Lenke https://…",
+    "Twitter handle @…" : "Twitter-konto @ …",
+    "Avatar" : "Avatar"
 },
 "nplurals=2; plural=(n != 1);");
