@@ -20,8 +20,6 @@ OC.L10N.register(
     "No user supplied" : "Ingen brukar gjeve",
     "Authentication error" : "Autentiseringsfeil",
     "Wrong admin recovery password. Please check the password and try again." : "Feil admingjenopprettingspassord. Ver venleg og sjekk passordet og prøv igjen.",
-    "Administrator documentation" : "Administratordokumentasjon",
-    "User documentation" : "Brukardokumentasjon",
     "Invalid mail address" : "Ugyldig e--postadresse",
     "Welcome aboard" : "Velkomen ombord",
     "Welcome aboard %s" : "Velkomen ombord %s",
@@ -36,7 +34,6 @@ OC.L10N.register(
     "Additional settings" : "Tilleggsinnstillingar",
     "Overview" : "Oversyn",
     "Sharing" : "Deling",
-    "Calendar" : "Kalendar",
     "Personal info" : "Personleg informasjon",
     "Email server" : "E-postserver",
     "Create" : "Lag",
@@ -48,6 +45,7 @@ OC.L10N.register(
     "Disable" : "Slå av",
     "Visit website" : "Besøk nettstaden",
     "Report a bug" : "Rapporter feil",
+    "User documentation" : "Brukardokumentasjon",
     "Admin documentation" : "Admin-dokumentasjon",
     "Rename" : "Gje nytt namn",
     "Internet Explorer" : "Internet Explorer",
@@ -74,7 +72,6 @@ OC.L10N.register(
     "Change password" : "Endra passord",
     "png or jpg, max. 20 MB" : "png eller jpg, maks. 20 MB",
     "Cancel" : "Avbryt",
-    "Details" : "Detaljar",
     "Your email address" : "Di e-postadresse",
     "Language" : "Språk",
     "Help translate" : "Hjelp oss å omsetja",
@@ -82,6 +79,7 @@ OC.L10N.register(
     "Email" : "E-post",
     "Quota" : "Kvote",
     "Last login" : "Siste innlogging",
+    "Details" : "Detaljar",
     "Add group" : "Legg til gruppe",
     "Active users" : "Aktive brukarare",
     "Email sent" : "E-post sendt",
@@ -91,6 +89,7 @@ OC.L10N.register(
     "Full name" : "Fult namn",
     "Hide" : "Gøym",
     "Never" : "Aldri",
+    "Administrator documentation" : "Administratordokumentasjon",
     "Documentation" : "Dokumentasjon",
     "Forum" : "Forum",
     "Login" : "Logg inn",
@@ -116,13 +115,17 @@ OC.L10N.register(
     "Select a profile picture" : "Vel eit profilbilete",
     "Couldn't remove app." : "Klarte ikkje å fjerne appen.",
     "Couldn't update app." : "Klarte ikkje oppdatera programmet.",
-    "Address" : "Adresse",
-    "Avatar" : "Avatar",
+    "Everyone" : "Alle",
+    "Test email settings" : "Test e-postinnstillingar",
     "Enable encryption" : "Aktiver kryptering",
     "Start migration" : "Start migrasjon",
+    "days" : "dagar",
     "Upload new" : "Last opp ny",
     "Select from Files" : "Vel frå filer",
     "Remove image" : "Fjern bilete",
-    "Choose as profile picture" : "Vel eit profilbilete"
+    "Choose as profile picture" : "Vel eit profilbilete",
+    "No display name set" : "Visingsnamn ikkje valt",
+    "Address" : "Adresse",
+    "Avatar" : "Avatar"
 },
 "nplurals=2; plural=(n != 1);");
