@@ -19,7 +19,6 @@ OC.L10N.register(
     "Strong password" : "Mocne hasło",
     "An error occurred while changing your language. Please reload the page and try again." : "Wystąpił błąd podczas zmiany języka. Przeładuj stronę i spróbuj ponownie.",
     "An error occurred while changing your locale. Please reload the page and try again." : "Wystąpił błąd podczas zmiany ustawień lokalnych. Przeładuj stronę i spróbuj ponownie.",
-    "Select a profile picture" : "Wybierz zdjęcie profilowe",
     "Week starts on {fdow}" : "Tydzień zaczyna się w {fdow}",
     "Groups" : "Grupy",
     "Group list is empty" : "Lista grup jest pusta",
@@ -120,7 +119,7 @@ OC.L10N.register(
     "Personal" : "Osobiste",
     "Administration" : "Administracja",
     "Additional settings" : "Ustawienia dodatkowe",
-    "Admin privileges" : "Uprawnienia administratora",
+    "Administration privileges" : "Uprawnienia administracyjne",
     "Groupware" : "Praca grupowa",
     "Overview" : "Przegląd",
     "Basic settings" : "Ustawienia podstawowe",
@@ -146,7 +145,6 @@ OC.L10N.register(
     "Profile information" : "Informacje o profilu",
     "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Zdjęcie profilowe, imię i nazwisko, adres e-mail, numer telefonu, adres, witryna internetowa, Twitter, organizacja, rola, nagłówek, biografia i czy Twój profil jest włączony",
     "Nextcloud settings" : "Ustawienia Nextcloud",
-    "Administration privileges" : "Uprawnienia administracyjne",
     "Here you can decide which group can access certain sections of the administration settings." : "Możesz zdecydować, która grupa ma dostęp do określonych sekcji ustawień administracyjnych.",
     "None" : "Brak",
     "Unable to modify setting" : "Nie można zmienić ustawienia",
@@ -265,11 +263,26 @@ OC.L10N.register(
     "Remove group" : "Usuń grupę",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Zamierzasz usunąć grupę {group}. Użytkownicy NIE zostaną usunięci.",
     "Please confirm the group removal " : "Potwierdź usunięcie grupy",
+    "Current password" : "Bieżące hasło",
+    "New password" : "Nowe hasło",
+    "Change password" : "Zmień hasło",
+    "Your profile picture" : "Twoje zdjęcie profilowe",
+    "Upload profile picture" : "Wyślij zdjęcie profilowe",
+    "Choose profile picture from files" : "Wybierz zdjęcie profilowe z Plików",
+    "Remove profile picture" : "Usuń zdjęcie profilowe",
+    "png or jpg, max. 20 MB" : "png lub jpg, maks. 20 MB",
+    "Picture provided by original account" : "Zdjęcie dostarczone przez oryginalne konto",
+    "Cancel" : "Anuluj",
+    "Set as profile picture" : "Ustaw jako zdjęcie profilowe",
+    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Pamiętaj, że aktualizacja Twojego zdjęcia profilowego może potrwać do 24 godzin.",
+    "Choose your profile picture" : "Wybierz swoje zdjęcie profilowe",
+    "Please select a valid png or jpg file" : "Wybierz prawidłowy plik png lub jpg",
+    "Error setting profile picture" : "Błąd podczas ustawiania zdjęcia profilowego",
+    "Error cropping profile picture" : "Błąd przycinania zdjęcia profilowego",
+    "Error saving profile picture" : "Błąd podczas zapisywania zdjęcia profilowego",
+    "Error removing profile picture" : "Błąd podczas usuwania zdjęcia profilowego",
     "Your biography" : "Twoja biografia",
-    "Unable to update biography" : "Nie można zaktualizować biografii",
     "Your full name" : "Twoja pełna nazwa",
-    "Unable to update full name" : "Nie można zaktualizować pełnej nazwy",
-    "No full name set" : "Nie ustawiono pełnej nazwy",
     "Email options" : "Opcje e-mail",
     "Primary email for password reset and notifications" : "Główny adres e-mail do resetowania hasła i powiadomień",
     "Remove primary email" : "Usuń podstawowy adres e-mail",
@@ -287,13 +300,13 @@ OC.L10N.register(
     "No email address set" : "Brak adresu e-mail",
     "Additional emails" : "Dodatkowe e-maile",
     "Your headline" : "Twój nagłówek",
-    "Unable to update headline" : "Nie można zaktualizować nagłówka",
     "Language" : "Język",
     "Help translate" : "Pomóż w tłumaczeniu",
     "Unable to update language" : "Nie można zaktualizować języka",
     "No language set" : "Nie ustawiono języka",
+    "Your location" : "Twoja lokalizacja",
     "Your organisation" : "Twoja organizacja",
-    "Unable to update organisation" : "Nie udało się zaktualizować organizacji",
+    "Your phone number" : "Twój numer telefonu",
     "Edit your Profile visibility" : "Edycja widoczności swojego profilu",
     "Enable Profile" : "Włącz profil",
     "Unable to update profile enabled state" : "Nie można zaktualizować stanu włączenia profilu",
@@ -301,10 +314,13 @@ OC.L10N.register(
     "{displayId}" : "{displayId}",
     "Unable to update visibility of {displayId}" : "Nie można zaktualizować widoczności {displayId}",
     "Your role" : "Twoja rola społeczna",
-    "Unable to update role" : "Nie można zaktualizować roli społecznej",
-    "Change scope level of {accountProperty}, current scope is {scope}" : "Zmień poziom zakresu {accountProperty}, obecny zakres to {scope}",
-    "Unable to update federation scope of the primary {accountProperty}" : "Nie można zaktualizować zakresu federacji podstawowego {accountProperty}",
-    "Unable to update federation scope of additional {accountProperty}" : "Nie można zaktualizować zakresu federacji dodatkowego {accountProperty}",
+    "Your Twitter handle" : "Twój Twitter:",
+    "Your website" : "Twoja strona WWW",
+    "No {property} set" : "Nie ustawiono {property}",
+    "Unable to update {property}" : "Nie można zaktualizować {property}",
+    "Change scope level of {property}, current scope is {scope}" : "Zmień poziom zakresu {property}, obecny zakres to {scope}",
+    "Unable to update federation scope of the primary {property}" : "Nie można zaktualizować zakresu federacji podstawowej {property}",
+    "Unable to update federation scope of additional {property}" : "Nie można zaktualizować zakresu federacji dodatkowego {property}",
     "Add additional email" : "Dodaj dodatkowy e-mail",
     "Add" : "Dodaj",
     "You do not have permissions to see the details of this user" : "Nie masz uprawnień aby zobaczyć informacje o tym użytkowniku",
@@ -321,7 +337,6 @@ OC.L10N.register(
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "W przypadku zagubienia urządzenia lub opuszczenia organizacji można zdalnie wyczyścić dane Nextcloud ze wszystkich urządzeń powiązanych z {userid}. Działa tylko wtedy, gdy urządzenia są podłączone do Internetu.",
     "Remote wipe of devices" : "Zdalne czyszczenie urządzeń",
     "Wipe {userid}'s devices" : "Wyczyść urządzenia {userid}",
-    "Cancel" : "Anuluj",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "Całkowicie usuń konto {userid}, w tym wszystkie pliki osobiste, dane aplikacji itp.",
     "Account deletion" : "Usunięcie konta",
     "Delete {userid}'s account" : "Usuń konto {userid}",
@@ -383,8 +398,8 @@ OC.L10N.register(
     "Not saved" : "Nie zapisano",
     "Sending…" : "Wysyłam…",
     "Email sent" : "E-mail został wysłany",
-    "Address" : "Adres",
-    "Avatar" : "Awatar",
+    "Location" : "Lokalizacja",
+    "Profile picture" : "Zdjęcie profilowe",
     "About" : "Informacje",
     "Full name" : "Pełna nazwa",
     "Additional email" : "Dodatkowy e-mail",
@@ -405,10 +420,9 @@ OC.L10N.register(
     "The app will be downloaded from the App Store" : "Aplikacja zostanie pobrana ze sklepu z aplikacjami",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ta aplikacja jest niezgodna z wersją Nextcloud. Przy dalszej kontynuacji, możesz pozwolić na zainstalowanie tej aplikacji. Pamiętaj, że aplikacja może nie działać zgodnie z oczekiwaniami.",
     "Never" : "Nigdy",
-    "An error occured during the request. Unable to proceed." : "Wystąpił błąd zapytania. Nie można kontynuować.",
+    "An error occurred during the request. Unable to proceed." : "Wystąpił błąd podczas żądania. Nie można kontynuować.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikacja została włączona, ponieważ wymaga aktualizacji. Za 5 sekund nastąpi przekierowanie do strony aktualizacji.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Błąd: Ta aplikacja nie zostanie włączona ze względu na możliwość niestabilnej pracy serwera",
-    "An error occurred during the request. Unable to proceed." : "Wystąpił błąd podczas żądania. Nie można kontynuować.",
     "User already exists." : "Użytkownik już istnieje.",
     "Administrator documentation" : "Dokumentacja administratora",
     "Documentation" : "Dokumentacja",
@@ -478,35 +492,15 @@ OC.L10N.register(
     "Check out our blog" : "Sprawdź nasz blog",
     "Subscribe to our newsletter" : "Subskrybuj nasz newsletter",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "To wydanie społecznościowe Nextcloud nie jest obsługiwane i powiadomienia natychmiastowe są niedostępne.",
-    "Profile picture" : "Zdjęcie profilowe",
-    "Change privacy level of profile picture" : "Zmień poziom prywatności zdjęcia profilowego",
-    "Upload new" : "Wczytaj nowe",
-    "Select from Files" : "Wybierz z Plików",
-    "Remove image" : "Usuń zdjęcie",
-    "png or jpg, max. 20 MB" : "png lub jpg, maks. 20 MB",
-    "Picture provided by original account" : "Zdjęcie dostarczone przez oryginalne konto",
-    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Pamiętaj, że aktualizacja awatara może potrwać do 24 godzin.",
-    "Choose as profile picture" : "Wybierz zdjęcie profilowe",
     "You are a member of the following groups:" : "Należysz do następujących grup:",
     "You are using <strong>%s</strong>" : "Używasz: <strong>%s</strong>",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Używasz: <strong>%1$s</strong> z <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
-    "Change privacy level of phone number" : "Zmień poziom prywatności numeru telefonu",
-    "Your phone number" : "Twój numer telefonu",
-    "Change privacy level of address" : "Zmień poziom prywatności adresu",
-    "Your postal address" : "Twój adres pocztowy",
-    "Change privacy level of website" : "Zmień poziom prywatności strony internetowej",
-    "It can take up to 24 hours before the account is displayed as verified." : "Do 24 godzin konto będzie widoczne jako zweryfikowane.",
-    "Link https://…" : "Link https://…",
-    "Change privacy level of Twitter profile" : "Zmień poziom prywatności profilu Twitter",
-    "Twitter handle @…" : "Twitter @…",
     "Locale" : "Region",
-    "Current password" : "Bieżące hasło",
-    "New password" : "Nowe hasło",
-    "Change password" : "Zmień hasło",
     "Use a second factor besides your password to increase security for your account." : "Użyj drugiego zabezpieczenia oprócz hasła, aby zwiększyć bezpieczeństwo konta.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Jeśli używasz aplikacji innych firm do łączenia się z Nextcloud, upewnij się, że utworzyłeś i skonfigurowałeś hasło aplikacji dla każdej przed włączeniem uwierzytelniania dwuskładnikowego.",
     "Migration in progress. Please wait until the migration is finished" : "Migracja w toku. Poczekaj na zakończenie migracji.",
     "Migration started …" : "Migracja rozpoczęta…",
+    "Select a profile picture" : "Wybierz zdjęcie profilowe",
     "Couldn't remove app." : "Nie można usunąć aplikacji.",
     "Couldn't update app." : "Nie można zaktualizować aplikacji.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "System zaplecza nie obsługuje zmiany hasła, ale klucz szyfrowania użytkownika został zaktualizowany.",
@@ -517,6 +511,7 @@ OC.L10N.register(
     "Change privacy level of email" : "Zmień poziom prywatności adresu e-mail",
     "All languages" : "Wszystkie języki",
     "Everyone" : "Wszyscy",
+    "An error occured during the request. Unable to proceed." : "Wystąpił błąd zapytania. Nie można kontynuować.",
     "Test email settings" : "Przetestuj ustawienia poczty e-mail",
     "Please read carefully before activating server-side encryption: " : "Przeczytaj uważnie przed aktywacją szyfrowania po stronie serwera:",
     "Enable encryption" : "Włącz szyfrowanie",
@@ -534,9 +529,34 @@ OC.L10N.register(
     "The cron.php needs to be executed by the system user \"%s\"." : "Cron.php musi zostać wykonywany przez użytkownika systemu \"%s\".",
     "days" : "dniach",
     "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Zezwalaj na automatyczne uzupełnianie nazwy użytkownika podczas wpisywania imienia i nazwiska lub adresu e-mail (ignorowanie brakującego dopasowania w książce telefonicznej i przynależności do tej samej grupy)",
+    "Change privacy level of profile picture" : "Zmień poziom prywatności zdjęcia profilowego",
+    "Upload new" : "Wczytaj nowe",
+    "Select from Files" : "Wybierz z Plików",
+    "Remove image" : "Usuń zdjęcie",
+    "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Pamiętaj, że aktualizacja awatara może potrwać do 24 godzin.",
+    "Choose as profile picture" : "Wybierz zdjęcie profilowe",
     "Change privacy level of full name" : "Zmień poziom prywatności pełnej nazwy",
     "No display name set" : "Brak wyświetlanej nazwy",
+    "Change privacy level of phone number" : "Zmień poziom prywatności numeru telefonu",
+    "Address" : "Adres",
+    "Change privacy level of address" : "Zmień poziom prywatności adresu",
+    "Your postal address" : "Twój adres pocztowy",
+    "Change privacy level of website" : "Zmień poziom prywatności strony internetowej",
+    "It can take up to 24 hours before the account is displayed as verified." : "Do 24 godzin konto będzie widoczne jako zweryfikowane.",
+    "Link https://…" : "Link https://…",
+    "Change privacy level of Twitter profile" : "Zmień poziom prywatności profilu Twitter",
+    "Twitter handle @…" : "Twitter @…",
     "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Maksymalna liczba kluczy OPcache jest prawie przekroczona. Aby upewnić się, że wszystkie skrypty mogą być przechowywane w pamięci podręcznej, zaleca się zastosowanie <code>opcache.max_accelerated_files</code> w konfiguracji PHP z wartością wyższą niż <code>%s</code>.",
-    "Change scope level of {accountProperty}" : "Zmień poziom zakresu {accountProperty}"
+    "Admin privileges" : "Uprawnienia administratora",
+    "Unable to update biography" : "Nie można zaktualizować biografii",
+    "Unable to update full name" : "Nie można zaktualizować pełnej nazwy",
+    "No full name set" : "Nie ustawiono pełnej nazwy",
+    "Unable to update headline" : "Nie można zaktualizować nagłówka",
+    "Unable to update organisation" : "Nie udało się zaktualizować organizacji",
+    "Unable to update role" : "Nie można zaktualizować roli społecznej",
+    "Change scope level of {accountProperty}" : "Zmień poziom zakresu {accountProperty}",
+    "Unable to update federation scope of the primary {accountProperty}" : "Nie można zaktualizować zakresu federacji podstawowego {accountProperty}",
+    "Unable to update federation scope of additional {accountProperty}" : "Nie można zaktualizować zakresu federacji dodatkowego {accountProperty}",
+    "Avatar" : "Awatar"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
