@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "Private" : "Private",
     "Local" : "Lokale",
+    "Federated" : "Federated",
     "Verify" : "Verifiko",
     "Verifying …" : "Duke verifikuar ...",
     "Unable to change password" : "S’arrin të ndryshojë fjalëkalimin",
@@ -11,7 +12,6 @@ OC.L10N.register(
     "So-so password" : "Fjalëkalim çka",
     "Good password" : "Fjalëkalim i mirë",
     "Strong password" : "Fjalëkalim i fortë",
-    "Select a profile picture" : "Përzgjidhni një foto profili",
     "Groups" : "Grupe",
     "{actor} changed your password" : "{actor} ndryshoi fjalëkalimin tuaj ",
     "You changed your password" : "Ju ndëruat fjalëkalimin",
@@ -23,15 +23,12 @@ OC.L10N.register(
     "You successfully logged in using two-factor authentication (%1$s)" : "Ju keni hyrë me sukses duke përdorur autentifikimin me dy faktorë ( %1$s )",
     "A login attempt using two-factor authentication failed (%1$s)" : "Një përpjekje e identifikimit me anë të autentifikimit me dy faktorë dështoi ( %1$s )",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>fjalëkalimi</strong> ose <strong>emaili</strong> juaj është modifikuar",
-    "Couldn't remove app." : "S’hoqi dot aplikacionin.",
-    "Couldn't update app." : "S’përditësoi dot aplikacionin.",
     "Wrong password" : "Fjalëkalim i gabuar",
     "Saved" : "U ruajt",
     "No user supplied" : "S’u dha përdorues",
     "Authentication error" : "Gabim mirëfilltësimi",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Ju lutemi siguro një fjalëkalim të rikuperueshëm admini; përndryshe, të gjithë të dhënat e përdoruesit do të humbasin ",
     "Wrong admin recovery password. Please check the password and try again." : "Fjalëkalim i gabuar rikthimesh për përgjegjësin. Ju lutemi, kontrolloni fjalëkalimin dhe provoni përsëri.",
-    "Backend doesn't support password change, but the user's encryption key was updated." : "Programi klient s’mbulon ndryshime fjalëkalimi, por kyçi i përdoruesi për fshehtëzime u përditësua me sukses.",
     "Federated Cloud Sharing" : "Ndarje Në Re të Federuar ",
     "Invalid SMTP password." : "Fjalëkalim SMTP i pavlefshëm",
     "Email setting test" : "Test i konfigurimeve të Email-it",
@@ -39,6 +36,7 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Nëse keni marrë këtë email, konfigurimi i email-it duket të jetë i saktë.",
     "Email could not be sent. Check your mail server log" : "Email nuk mund të dërgohej. Kontrolloni logun e serverit tuaj të postës",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ndodhi një gabim gjatë dërgimit të email-it. Ju lutemi, rishikoni rregullimet tuaja. (Error: %s)",
+    "Invalid user" : "Përdorues i pavlefshëm",
     "Invalid mail address" : "Adresë email e pavlefshme",
     "Settings saved" : "Konfigurimet u ruajtën",
     "Unable to change full name" : "S’arrin të ndryshojë emrin e plotë",
@@ -124,14 +122,33 @@ OC.L10N.register(
     "Done" : "U bë",
     "Copied!" : "U kopjua!",
     "Copy" : "Kopjo",
+    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Për të bërë këtë ekzekutim ju duhet shtesa PHP POSIX. Shikoni {linkstart} dokumentacionin e PHP {linkend} pë më shumë detaje.",
     "Enable" : "Aktivizoje",
+    "Server-side encryption" : "Fshehtëzim më anë shërbyesi",
+    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Enkriptimi nga ana e serverit bën të mundur enkriptimin e skedarëve të ngarkuar në këtë server. Kjo vjen me kufizime si një ndëshkim për performancën, prandaj e lejoni këtë vetëm nëse është e nevojshme.",
+    "Enable server-side encryption" : "Aktivizo fshehtëzim më anë të shërbyesit",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Pasi të jetë aktivizuar fshehtëzimi, krejt kartelat e ngarkuara te shërbyesi nga kjo pikë e tutje do të fshehtëzohen pasi të jenë depozituar në shërbyes. Çaktivizimi i fshehtëzimit në një datë të mëvonshme do të jetë i mundur vetëm nëse moduli aktiv i fshehtëzimeve e mbulon këtë funksion, dhe nëse plotësohen krejt parakushtet (p.sh. caktimi i një kyçi rimarrjesh).",
+    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Vetëm shifrimi nuk garaton sigurinë e sistemit. Ju lutem shikoni dokumentimin për më shumë informacion mbi mënyrën si applikacioni punon, dhe përdorimin e rasteve të suportuara.",
+    "Be aware that encryption always increases the file size." : "Kini parasysh që fshehtëzimi e rrit gjithnjë madhësinë e kartelës.",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Është gjithmonë ide e mirë të krijohen kopjeruajtje të rregullta të të dhënave tuaja, në rast fshehtëzimi sigurohuni që bëni kopjeruajtje të kyçeve të fshehtëzimit, tok me të dhënat tuaja.",
+    "This is the final warning: Do you really want to enable encryption?" : "Ky është sinjalizimi përfundimtar: Doni vërtet të aktivizohet fshehtëzimi?",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "S’ka të ngarkuar modul fshehtëzimi, ju lutemi, aktivizoni një modul fshehtëzimi që nga menuja e aplikacionit.",
+    "Select default encryption module:" : "Përzgjidhni modul parazgjedhje fshehtëzimi:",
     "Remove group" : "Hiq grupin",
+    "Current password" : "Fjalëkalimi i tanishëm",
+    "New password" : "Fjalëkalimi i ri",
+    "Change password" : "Ndrysho fjalëkalimin",
+    "png or jpg, max. 20 MB" : "png ose jpg, maks. 20 MB",
+    "Picture provided by original account" : "Foto e prurë nga llogaria origjinale",
+    "Cancel" : "Anuloje",
     "Your email address" : "Adresa juaj email",
     "No email address set" : "S’është caktuar adresë email",
     "Language" : "Gjuhë",
     "Help translate" : "Ndihmoni në përkthim",
+    "Your phone number" : "Numri juaj i telefonit",
+    "Your Twitter handle" : "Emri i përdoruesit tuaj në Twitter",
+    "Your website" : "Website-i juaj",
     "Add" : "Shto",
-    "Cancel" : "Anuloje",
     "{size} used" : "{madhësia} e përdorur",
     "New user" : "Përdorues i ri",
     "Display name" : "Shfaq emrin",
@@ -153,21 +170,23 @@ OC.L10N.register(
     "Details" : "Detaje",
     "Changelog" : "Katalogu i ndryshimeve",
     "Add group" : "Shto grup",
+    "Active users" : "Përdoruesit aktivë",
     "Admins" : "Administratorë",
     "Disabled users" : "Përdoruesit të çaktivizuar",
     "Show last login" : "Shfaq hyrjen e fundit",
     "Show user backend" : "Shfaq programin klient të përdoruesit",
     "Send email to new user" : "Dërgo email përdoruesi të ri",
-    "Migration in progress. Please wait until the migration is finished" : "Migrimi në rrugë e sipër. Ju lutemi, pritni, teksa migrimi përfundon",
-    "Migration started …" : "Migrimi filloi …",
     "Not saved" : "Nuk u ruajt",
     "Sending…" : "dërgim",
     "Email sent" : "Email-i u dërgua",
-    "Address" : "Adresa",
+    "Location" : "Vendndodhje",
+    "Profile picture" : "Foto profili",
+    "About" : "Rreth ",
     "Full name" : "Emër i plotë",
     "Phone number" : "Numri i telefonit",
     "Twitter" : "Twitter",
     "Website" : "Faqe web-i",
+    "Hide" : "Fshihe",
     "Never" : "Kurrë",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikacioni është aktivizuar, por lyp të përditësohet. Do të ridrejtoheni te faqja e përditësimeve brenda 5 sekondash.",
     "Administrator documentation" : "Dokumentim për përgjegjës",
@@ -194,33 +213,13 @@ OC.L10N.register(
     "Send email" : "Dërgo email",
     "All checks passed." : "I kaloi krejt kontrollet.",
     "Version" : "Version",
-    "Server-side encryption" : "Fshehtëzim më anë shërbyesi",
-    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Enkriptimi nga ana e serverit bën të mundur enkriptimin e skedarëve të ngarkuar në këtë server. Kjo vjen me kufizime si një ndëshkim për performancën, prandaj e lejoni këtë vetëm nëse është e nevojshme.",
-    "Enable server-side encryption" : "Aktivizo fshehtëzim më anë të shërbyesit",
-    "Please read carefully before activating server-side encryption: " : "Ju lutemi, lexoni me kujdes përpara aktivizimit të fshehtëzimeve më anë shërbyesi: ",
-    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Pasi të jetë aktivizuar fshehtëzimi, krejt kartelat e ngarkuara te shërbyesi nga kjo pikë e tutje do të fshehtëzohen pasi të jenë depozituar në shërbyes. Çaktivizimi i fshehtëzimit në një datë të mëvonshme do të jetë i mundur vetëm nëse moduli aktiv i fshehtëzimeve e mbulon këtë funksion, dhe nëse plotësohen krejt parakushtet (p.sh. caktimi i një kyçi rimarrjesh).",
-    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Vetëm shifrimi nuk garaton sigurinë e sistemit. Ju lutem shikoni dokumentimin për më shumë informacion mbi mënyrën si applikacioni punon, dhe përdorimin e rasteve të suportuara.",
-    "Be aware that encryption always increases the file size." : "Kini parasysh që fshehtëzimi e rrit gjithnjë madhësinë e kartelës.",
-    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Është gjithmonë ide e mirë të krijohen kopjeruajtje të rregullta të të dhënave tuaja, në rast fshehtëzimi sigurohuni që bëni kopjeruajtje të kyçeve të fshehtëzimit, tok me të dhënat tuaja.",
-    "This is the final warning: Do you really want to enable encryption?" : "Ky është sinjalizimi përfundimtar: Doni vërtet të aktivizohet fshehtëzimi?",
-    "Enable encryption" : "Aktivizoni fshehtëzim",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "S’ka të ngarkuar modul fshehtëzimi, ju lutemi, aktivizoni një modul fshehtëzimi që nga menuja e aplikacionit.",
-    "Select default encryption module:" : "Përzgjidhni modul parazgjedhje fshehtëzimi:",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Lypset të migroni kyçet tuaj të fshehtëzimit nga fshehtëzimi i vjetër (ownCloud <= 8.0) te i riu. Ju lutemi, aktivizoni \"Modul parazgjedhje fshehtëzimesh\" dhe ekzekutoni 'occ encryption:migrate'",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Lypset të migroni kyçet tuaj të fshehtëzimit nga fshehtëzimi i vjetër (ownCloud <= 8.0) te i riu.",
-    "Start migration" : "Fillo migrimin",
-    "Last job execution ran %s. Something seems wrong." : "Ekzekutimi i punës së fundit vazhdoi %s. Diçka shkoi keq.",
-    "Last job ran %s." : "Puna e fundit vazhdoi %s.",
-    "Background job didn’t run yet!" : "Puna ne background nuk ka filluar akoma!",
-    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Për performancë optimale është e rëndësishme të konfigurosh punë të sfondit në mënyrë korrekte. Për raste më të mëdha 'Cron' është konfigurimi i rekomanduar. Ju lutem shih dokumentacionin për më shumë informacion.",
-    "The cron.php needs to be executed by the system user \"%s\"." : "con.php duhet të ekzekutohet bga përdoruesi i sistemit \"%s\".",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Për të bërë këtë ekzekutim ju duhet shtesa PHP POSIX. Shikoni {linkstart} dokumentacionin e PHP {linkend} pë më shumë detaje.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Si admin ju mund të rregulloni mirë sjelljen e ndarjes. Ju lutem shih dokumentacionin për më shumë informacion.",
     "Allow apps to use the Share API" : "Lejoni aplikacionet të përdorin API Share",
     "Enforce expiration date" : "Detyro datë skadimi",
     "Allow public uploads" : "Lejo ngarkime publike",
     "Always ask for a password" : "Gjithmonë pyet për një fjalëkalim",
     "Enforce password protection" : "Detyro mbrojtje me fjalëkalim",
+    "Set default expiration date" : "Caktoni datë parazgjedhje skadimi",
     "Allow resharing" : "Lejo rindarje",
     "Allow sharing with groups" : "Lejoni ndarje me grupe",
     "Restrict users to only share with users in their groups" : "Përdoruesve kufizoju të ndajnë gjëra vetëm me përdorues në grupin e tyre",
@@ -232,36 +231,38 @@ OC.L10N.register(
     "Follow us on Twitter" : "Na ndiqni në Twitter",
     "Check out our blog" : "Shikoni blogun tonë",
     "Subscribe to our newsletter" : "Abonohu në gazeten tonë",
-    "Profile picture" : "Foto profili",
+    "You are using <strong>%s</strong>" : "Ju po përdorni <strong>%s</strong>",
+    "Migration in progress. Please wait until the migration is finished" : "Migrimi në rrugë e sipër. Ju lutemi, pritni, teksa migrimi përfundon",
+    "Migration started …" : "Migrimi filloi …",
+    "Select a profile picture" : "Përzgjidhni një foto profili",
+    "Couldn't remove app." : "S’hoqi dot aplikacionin.",
+    "Couldn't update app." : "S’përditësoi dot aplikacionin.",
+    "Backend doesn't support password change, but the user's encryption key was updated." : "Programi klient s’mbulon ndryshime fjalëkalimi, por kyçi i përdoruesi për fshehtëzime u përditësua me sukses.",
+    "You need to set your user email before being able to send test emails." : "Lypset të caktoni email-in tuaj si përdorues, përpara se të jeni në gjendje të dërgoni email-e provë.",
+    "All languages" : "Të gjitha gjuhët",
+    "Everyone" : "Kushdo",
+    "Test email settings" : "Testoni rregullimet e email-it",
+    "Please read carefully before activating server-side encryption: " : "Ju lutemi, lexoni me kujdes përpara aktivizimit të fshehtëzimeve më anë shërbyesi: ",
+    "Enable encryption" : "Aktivizoni fshehtëzim",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Lypset të migroni kyçet tuaj të fshehtëzimit nga fshehtëzimi i vjetër (ownCloud <= 8.0) te i riu. Ju lutemi, aktivizoni \"Modul parazgjedhje fshehtëzimesh\" dhe ekzekutoni 'occ encryption:migrate'",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Lypset të migroni kyçet tuaj të fshehtëzimit nga fshehtëzimi i vjetër (ownCloud <= 8.0) te i riu.",
+    "Start migration" : "Fillo migrimin",
+    "Last job execution ran %s. Something seems wrong." : "Ekzekutimi i punës së fundit vazhdoi %s. Diçka shkoi keq.",
+    "Last job ran %s." : "Puna e fundit vazhdoi %s.",
+    "Background job didn’t run yet!" : "Puna ne background nuk ka filluar akoma!",
+    "Recommended" : "E rekomanduar",
+    "The cron.php needs to be executed by the system user \"%s\"." : "con.php duhet të ekzekutohet bga përdoruesi i sistemit \"%s\".",
+    "days" : "ditësh",
     "Upload new" : "Ngarko të re",
     "Select from Files" : "Përzgjidhni prej Kartelash",
     "Remove image" : "Hiqe figurën",
-    "png or jpg, max. 20 MB" : "png ose jpg, maks. 20 MB",
-    "Picture provided by original account" : "Foto e prurë nga llogaria origjinale",
     "Choose as profile picture" : "Zgjidhni një foto profili",
-    "You are using <strong>%s</strong>" : "Ju po përdorni <strong>%s</strong>",
-    "Your phone number" : "Numri juaj i telefonit",
+    "No display name set" : "S’është caktuar emër për në ekran",
+    "Address" : "Adresa",
     "Your postal address" : "Adresa juaj postale",
     "It can take up to 24 hours before the account is displayed as verified." : "Kjo mund të marrë mbi 24 orë, përpara se llogaria të shfaqet si e verifikuar.",
     "Link https://…" : "Linku https://…",
     "Twitter handle @…" : "Përdoruesi i Twitter @ ...",
-    "Current password" : "Fjalëkalimi i tanishëm",
-    "New password" : "Fjalëkalimi i ri",
-    "Change password" : "Ndrysho fjalëkalimin",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "instalim dhe përditësim aplikacionesh përmes shitores së aplikacioneve ose Federated Cloud Sharing",
-    "You need to set your user email before being able to send test emails." : "Lypset të caktoni email-in tuaj si përdorues, përpara se të jeni në gjendje të dërgoni email-e provë.",
-    "Close" : "Mbylleni",
-    "All languages" : "Të gjitha gjuhët",
-    "Everyone" : "Kushdo",
-    "The app will be downloaded from the app store" : "Aplikacioni do të shkarkohet nga shitorja e aplikacioneve",
-    "App update" : "Përditësim aplikacioni",
-    "Error: This app can not be enabled because it makes the server unstable" : "Gabim: Ky aplikacion s’u aktivizua dot, ngaqë e bën shërbyesin të paqëndrueshëm.",
-    "mail" : "email",
-    "Test email settings" : "Testoni rregullimet e email-it",
-    "Expire after " : "Skadon pas ",
-    "days" : "ditësh",
-    "Allow users to share via link" : "Lejoji përdoruesit të ndajnë me të tjerët përmes lidhjesh",
-    "No display name set" : "S’është caktuar emër për në ekran",
-    "For password reset and notifications" : "Për të rivendosur fjalëkalimin dhe njoftimet"
+    "Avatar" : "Avatari"
 },
 "nplurals=2; plural=(n != 1);");
