@@ -19,7 +19,6 @@ OC.L10N.register(
     "Strong password" : "强密码",
     "An error occurred while changing your language. Please reload the page and try again." : "修改您的语言时遇到错误。请重新载入页面后再试。",
     "An error occurred while changing your locale. Please reload the page and try again." : "修改您的地区时遇到错误。请重新载入页面后再试。",
-    "Select a profile picture" : "选择个人头像",
     "Week starts on {fdow}" : "周开始于 {fdow}",
     "Groups" : "分组",
     "Group list is empty" : "群组列表为空",
@@ -105,7 +104,7 @@ OC.L10N.register(
     "Personal" : "个人",
     "Administration" : "管理",
     "Additional settings" : "其他设置",
-    "Admin privileges" : "管理员特权",
+    "Administration privileges" : "管理权限",
     "Groupware" : "组件",
     "Overview" : "概览",
     "Basic settings" : "基本设置",
@@ -126,7 +125,6 @@ OC.L10N.register(
     "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "LDAP 用户或组的 UUID 无效。请审查你在 LDAP 配置的专家部分的 \"覆盖 UUID 检测 \"设置，并使用 \"occ ldap:update-uuid\" 来更新它们。",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "旧的服务器端加密格式已启用。我们建议禁用此功能。",
     "Nextcloud settings" : "Nextcloud 设置",
-    "Administration privileges" : "管理权限",
     "Here you can decide which group can access certain sections of the administration settings." : "您可以在此决定哪个组可以访问管理设置的特定部分。",
     "None" : "无",
     "Unable to modify setting" : "无法更改设置",
@@ -232,11 +230,14 @@ OC.L10N.register(
     "Remove group" : "删除分组",
     "You are about to remove the group {group}. The users will NOT be deleted." : "您将要移除群组 {group}。组中的用户不会被删除。",
     "Please confirm the group removal " : "请确认移除群组",
+    "Current password" : "当前密码",
+    "New password" : "新密码",
+    "Change password" : "修改密码",
+    "png or jpg, max. 20 MB" : "png 或 jpg 格式，最大 20MB",
+    "Picture provided by original account" : "初始账号提供的图片",
+    "Cancel" : "取消",
     "Your biography" : "个人小传",
-    "Unable to update biography" : "无法更新小传",
     "Your full name" : "你的全名",
-    "Unable to update full name" : "无法更新全名",
-    "No full name set" : "未设置全名",
     "Email options" : "电子邮件选项",
     "Primary email for password reset and notifications" : "用于重设密码和通知的主邮件",
     "Remove primary email" : "删除主邮件地址",
@@ -254,13 +255,12 @@ OC.L10N.register(
     "No email address set" : "尚未设置 Email 地址",
     "Additional emails" : "附加邮箱地址",
     "Your headline" : "你的标题",
-    "Unable to update headline" : "无法更新标题",
     "Language" : "语言",
     "Help translate" : "帮助翻译",
     "Unable to update language" : "无法更新语言",
     "No language set" : "没有设置语言",
     "Your organisation" : "你的组织",
-    "Unable to update organisation" : "无法更新组织",
+    "Your phone number" : "您的电话号码",
     "Edit your Profile visibility" : "编辑个人资料可见性",
     "Enable Profile" : "编辑个人资料",
     "Unable to update profile enabled state" : "无法更新个人资料启用状态",
@@ -268,9 +268,8 @@ OC.L10N.register(
     "{displayId}" : "{displayId}",
     "Unable to update visibility of {displayId}" : "无法更新 {displayId} 的可见性",
     "Your role" : "你的角色",
-    "Unable to update role" : "无法更新角色",
-    "Unable to update federation scope of the primary {accountProperty}" : "无法更新主 {accountProperty} 的联盟范围",
-    "Unable to update federation scope of additional {accountProperty}" : "无法更新附加 {accountProperty} 的联盟范围",
+    "Your Twitter handle" : "您的 Twitter 账号",
+    "Your website" : "您的网站",
     "Add" : "添加",
     "You do not have permissions to see the details of this user" : "您没有权限查看该用户的详细信息",
     "Add new password" : "添加新的密码",
@@ -286,7 +285,6 @@ OC.L10N.register(
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "如果设备丢失或退出组织，这可以从与 {userid} 关联的所有设备中远程擦除 Nextcloud 数据。 仅当设备连接到互联网时才有效。",
     "Remote wipe of devices" : "远程擦除设备",
     "Wipe {userid}'s devices" : "擦除 {userid} 的设备",
-    "Cancel" : "取消",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "完全删除 {userid} 的账号，包括其所有个人文件，应用程序数据等。",
     "Account deletion" : "帐号删除",
     "Delete {userid}'s account" : "删除 {userid} 的账号",
@@ -348,8 +346,8 @@ OC.L10N.register(
     "Not saved" : "未保存",
     "Sending…" : "正在发送…",
     "Email sent" : "邮件已发送",
-    "Address" : "地址",
-    "Avatar" : "头像",
+    "Location" : "位置",
+    "Profile picture" : "个人头像",
     "About" : "关于",
     "Full name" : "全名",
     "Additional email" : "附加邮箱",
@@ -370,7 +368,6 @@ OC.L10N.register(
     "The app will be downloaded from the App Store" : "将从应用商店下载应用",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "此应用被标记为与您的 Nextcloud 版本不兼容。如果您要继续，您仍可安装此应用。请注意此应用可能不会正常工作。",
     "Never" : "从不",
-    "An error occured during the request. Unable to proceed." : "请求期间发生错误。 无法继续。",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "该应用已启用，但是需要更新。5秒后将跳转到更新页面。",
     "Error: This app cannot be enabled because it makes the server unstable" : "错误:这个应用程序不能被启用，因为它使服务器不稳定 ",
     "Administrator documentation" : "管理员文档",
@@ -439,34 +436,15 @@ OC.L10N.register(
     "Check out our blog" : "浏览我们的博客！",
     "Subscribe to our newsletter" : "订阅我们的最新消息！",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Nextcloud 的这个社区版本不受支持，即时通知不可用。",
-    "Profile picture" : "个人头像",
-    "Change privacy level of profile picture" : "更改个人头像的隐私级别",
-    "Upload new" : "上传",
-    "Select from Files" : "选择文件",
-    "Remove image" : "删除图片",
-    "png or jpg, max. 20 MB" : "png 或 jpg 格式，最大 20MB",
-    "Picture provided by original account" : "初始账号提供的图片",
-    "Choose as profile picture" : "选择个人头像",
     "You are a member of the following groups:" : "您是以下群组的成员：",
     "You are using <strong>%s</strong>" : "您已经使用了 <strong>%s</strong> 存储空间",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "您正在使用 <strong>%1$s</strong> ，来自 <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
-    "Change privacy level of phone number" : "更改电话号码的隐私级别",
-    "Your phone number" : "您的电话号码",
-    "Change privacy level of address" : "更改地址的隐私级别",
-    "Your postal address" : "您的邮寄地址",
-    "Change privacy level of website" : "更改网站的隐私级别",
-    "It can take up to 24 hours before the account is displayed as verified." : "在账号显示为已验证之前最多可能需要 24 小时。",
-    "Link https://…" : "链接 https://…",
-    "Change privacy level of Twitter profile" : "更改推特资料的隐私权限",
-    "Twitter handle @…" : "Twitter 用户名 @…",
     "Locale" : "本地",
-    "Current password" : "当前密码",
-    "New password" : "新密码",
-    "Change password" : "修改密码",
     "Use a second factor besides your password to increase security for your account." : "使用除您密码之外的第二种方法来增强您账号的安全性。",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "如果您使用第三方应用程序连接到 Nextcloud，请确保在启用第二因素身份验证之前为每个应用程序创建和配置应用程序密码。",
     "Migration in progress. Please wait until the migration is finished" : "正在进行迁移。请稍等，直到迁移完成",
     "Migration started …" : "迁移开始...",
+    "Select a profile picture" : "选择个人头像",
     "Couldn't remove app." : "无法删除应用。",
     "Couldn't update app." : "无法更新应用。",
     "Backend doesn't support password change, but the user's encryption key was updated." : "后端不支持密码更改，但用户的加密密钥已更新。",
@@ -477,6 +455,7 @@ OC.L10N.register(
     "Change privacy level of email" : "更改电子邮件的隐私级别",
     "All languages" : "所有语言",
     "Everyone" : "所有人",
+    "An error occured during the request. Unable to proceed." : "请求期间发生错误。 无法继续。",
     "Test email settings" : "测试电子邮件设置",
     "Please read carefully before activating server-side encryption: " : "在激活服务器端加密之前，请仔细阅读：",
     "Enable encryption" : "启用加密",
@@ -494,8 +473,32 @@ OC.L10N.register(
     "The cron.php needs to be executed by the system user \"%s\"." : "cron.php 需要被系统用户 \"%s\" 执行。",
     "days" : "天",
     "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "在输入全名或电子邮件地址时允许用户名自动完成 (忽略丢失的电话簿匹配和同属一个小组的匹配)",
+    "Change privacy level of profile picture" : "更改个人头像的隐私级别",
+    "Upload new" : "上传",
+    "Select from Files" : "选择文件",
+    "Remove image" : "删除图片",
+    "Choose as profile picture" : "选择个人头像",
     "Change privacy level of full name" : "更改全名的隐私级别",
     "No display name set" : "不显示名称设置",
-    "Change scope level of {accountProperty}" : "更改 {accountProperty} 的范围"
+    "Change privacy level of phone number" : "更改电话号码的隐私级别",
+    "Address" : "地址",
+    "Change privacy level of address" : "更改地址的隐私级别",
+    "Your postal address" : "您的邮寄地址",
+    "Change privacy level of website" : "更改网站的隐私级别",
+    "It can take up to 24 hours before the account is displayed as verified." : "在账号显示为已验证之前最多可能需要 24 小时。",
+    "Link https://…" : "链接 https://…",
+    "Change privacy level of Twitter profile" : "更改推特资料的隐私权限",
+    "Twitter handle @…" : "Twitter 用户名 @…",
+    "Admin privileges" : "管理员特权",
+    "Unable to update biography" : "无法更新小传",
+    "Unable to update full name" : "无法更新全名",
+    "No full name set" : "未设置全名",
+    "Unable to update headline" : "无法更新标题",
+    "Unable to update organisation" : "无法更新组织",
+    "Unable to update role" : "无法更新角色",
+    "Change scope level of {accountProperty}" : "更改 {accountProperty} 的范围",
+    "Unable to update federation scope of the primary {accountProperty}" : "无法更新主 {accountProperty} 的联盟范围",
+    "Unable to update federation scope of additional {accountProperty}" : "无法更新附加 {accountProperty} 的联盟范围",
+    "Avatar" : "头像"
 },
 "nplurals=1; plural=0;");
