@@ -17,13 +17,14 @@ OC.L10N.register(
     "Send usage" : "Odeslat přehled",
     "Never" : "Nikdy",
     "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Odesílá anonymizovaná data vývojářům Nextcloud a pomáhá tak k jeho zlepšování.",
-    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Odesílá anonymizovaná data vývojářům Nextcloud aby ho na jejich základě mohli dále vylepšovat.\n       vždy máte plnou kontrolu nad odesílaným obsahem a kdykoli tuto funkci můžete opět vypnout.",
+    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n\t\talways have full control over the content sent to Nextcloud and can disable\n\t\tit again at any time." : "Odesílá anonymizovaná data vývojářům Nextcloud aby ho na jejich základě mohli dále vylepšovat.\n\t\tVždy máte plnou kontrolu nad odesílaným obsahem a kdykoli tuto funkci můžete opět vypnout.",
     "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Můžete pomoci zlepšit Nextcloud tím, že nám pošlete nějaké údaje o vašem aktuálním nastavení a použití.",
     "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Vaše soukromí bereme vážně. Odesílání dat je ve výchozím nastavení vypnuté a pokud se ho rozhodnete zapnout, budou data nejprve anonymizována a budete mít možnost vybrat, které věci sdílet. Nejnovější přijatý přehled na naší straně přepíše ten předchozí. Pokud chcete odstranit veškerá doposud od vás obdržená data, stačí zrušit zaškrtnutí všech kolonek a odeslat (tím prázdný) přehled.",
     "Send new report now" : "Odeslat nový přehled teď",
     "Send usage survey monthly" : "Odesílat přehled o používání každý měsíc",
     "Data to send" : "Data k odeslání",
     "Last report sent on: %s" : "Poslední přehled odeslán: %s",
-    "Last report" : "Poslední přehled"
+    "Last report" : "Poslední přehled",
+    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Odesílá anonymizovaná data vývojářům Nextcloud aby ho na jejich základě mohli dále vylepšovat.\n       vždy máte plnou kontrolu nad odesílaným obsahem a kdykoli tuto funkci můžete opět vypnout."
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
