@@ -17,13 +17,13 @@ OC.L10N.register(
     "Send usage" : "Enviar o uso",
     "Never" : "Nunca",
     "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Envíe datos anonimizados a Nextcloud para axudarnos a mellorar o NextCloud.",
-    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Envíe datos anonimizados a Nextcloud para axudarnos a mellorar o NextCloud.\n        Vostede terá sempre o control total do contido enviado a Nextcloud e poderá\n        desactivalo en calquera momento.",
     "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Pode axudar a mellorar o Nextcloud enviándonos algúns datos sobre os seus axustes e e uso.",
     "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Tomámonos moi en serio a súa privacidade. O envío de datos, por omisión, está desactivado, e se o activa, o primeiro será anonimizalos e se le lle dará a opción de escoller que é o que quere compartir. Ao recibir un informe, eliminarase o anterior. Envíe un informe en branco para eliminar todos os datos almacenados actualmente no servidor.",
     "Send new report now" : "Enviar agora un novo informe",
     "Send usage survey monthly" : "Enviar a enquisa de uso mensualmente",
     "Data to send" : "Data do envío",
     "Last report sent on: %s" : "O último informe foi enviado o: %s",
-    "Last report" : "Último informe"
+    "Last report" : "Último informe",
+    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Envíe datos anonimizados a Nextcloud para axudarnos a mellorar o NextCloud.\n        Vostede terá sempre o control total do contido enviado a Nextcloud e poderá\n        desactivalo en calquera momento."
 },
 "nplurals=2; plural=(n != 1);");
