@@ -31,7 +31,6 @@ OC.L10N.register(
     "Insert an attachment" : "Lisää liite",
     "guest" : "vieras",
     "Show author colors" : "Näytä tekijän värit",
-    "Author colors are only shown until everyone has closed the document." : "Tekijöiden värit näytetään siihen asti, kunnes kaikki ovat sulkeneet asiakirjan.",
     "Active people" : "Aktiiviset ihmiset",
     "Document save status" : "Asiakirjan tallennuksen tila",
     "Last saved" : "Viimeksi tallennettu",
@@ -68,17 +67,14 @@ OC.L10N.register(
     "Quoted text" : "Lainattu teksti",
     "Code block" : "Koodilohko",
     "Some code" : "Koodia",
-    "No user found" : "Käyttäjää ei löytynyt",
     "Upload from computer" : "Lähetä tietokoneelta",
     "Insert from Files" : "Syötä Tiedostot-sovelluksesta",
-    "Remove link" : "Poista linkki",
-    "Link to file or folder" : "Linkki tiedostoon tai kansioon",
-    "Link to website" : "Linkki verkkosivulle",
-    "Update link" : "Päivitä linkki",
-    "Select file or folder to link to" : "Valitse tiedosto tai kansio, johon linkitetään",
-    "_%n word_::_%n words_" : ["%n sana","%n sanaa"],
-    "_%n char_::_%n chars_" : ["%n merkki","%n merkkiä"],
     "Formatting menu bar" : "Muotoiluvalikko",
+    "Update Link" : "Päivitä linkki",
+    "Add Link" : "Lisää linkki",
+    "Link file" : "Linkitä tiedosto",
+    "Remove Link" : "Poista linkki",
+    "Select file to link to" : "Valitse tiedosto johon linkitetään",
     "Link to this section" : "Linkki tähän osioon",
     "Delete this attachment" : "Poista tämä liite",
     "Delete this image" : "Poista tämä kuva",
@@ -110,18 +106,14 @@ OC.L10N.register(
     "Command" : "Komento",
     "Control" : "Hallinta",
     "Edit" : "Muokkaa",
+    "New text document" : "Uusi tekstiasiakirja",
     "Enter your name so other users can see who is editing" : "Kirjoita nimesi, jotta muut näkevät kuka muokkaa asiakirjaa",
     "Insert image" : "Lisää kuva",
     "Insert an image" : "Lisää kuva",
-    "Update Link" : "Päivitä linkki",
-    "Add Link" : "Lisää linkki",
-    "Link file" : "Linkitä tiedosto",
-    "Select file to link to" : "Valitse tiedosto johon linkitetään",
     "Currently active users:" : "Aktiiviset käyttäjät nyt:",
     "_and %n other editor_::_and %n other editors_" : ["ja %n muu muokkaaja","ja %n muuta muokkaajaa"],
     "ToDo list" : "Tehtävälista",
     "Emoji picker" : "Emoji-valitsin",
-    "Image file format not supported" : "Kuvan tiedostomuoto ei ole tuettu",
-    "Remove Link" : "Poista linkki"
+    "Image file format not supported" : "Kuvan tiedostomuoto ei ole tuettu"
 },
 "nplurals=2; plural=(n != 1);");
