@@ -4,11 +4,13 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Le file incargate excede le directiva MAX_FILE_SIZE que esseva specificate in le formulario HTML",
     "No file was uploaded" : "Nulle file esseva incargate",
     "Missing a temporary folder" : "Il manca un dossier temporari",
+    "Guest" : "Invitato",
+    "guest" : "hospite",
     "Saved" : "Salveguardate",
     "Keyboard shortcuts" : "Combinationes de claves",
-    "Edit" : "Modificar",
     "Undo" : "Disfacer",
     "Info" : "Info",
-    "Warning" : "Aviso"
+    "Warning" : "Aviso",
+    "Edit" : "Modificar"
 },
 "nplurals=2; plural=(n != 1);");
