@@ -3,9 +3,10 @@ OC.L10N.register(
     {
     "No file was uploaded" : "ವರ್ಗಾವಣೆಗೆ ﻿ಯಾವುದೇ ಕಡತಗಳು ಕಂಡುಬಂದಿಲ್ಲ",
     "Missing a temporary folder" : "ತಾತ್ಕಾಲಿಕ ಕಡತಕೋಶ ದೊರೆಕುತ್ತಿಲ್ಲ",
+    "guest" : "ಅತಿಥಿ",
     "Saved" : "﻿ಉಳಿಸಿದ",
-    "Edit" : "ಸಂಪಾದಿಸು",
     "Info" : "Info",
-    "Warning" : "﻿ಎಚ್ಚರಿಕೆ"
+    "Warning" : "﻿ಎಚ್ಚರಿಕೆ",
+    "Edit" : "ಸಂಪಾದಿಸು"
 },
 "nplurals=2; plural=(n > 1);");
