@@ -13,6 +13,7 @@ OC.L10N.register(
     "No file uploaded or file size exceeds maximum of %s" : "沒有上傳檔案或檔案大小超過 %s 的最大值",
     "Nextcloud Text" : "Nextcloud 文字編輯器",
     "text document" : "文字文件",
+    "{user} has mentioned you in the text document {node}" : "{user} 在  {node} 的文字文件中提到了您",
     "Readme" : "說明",
     "Text" : "文字編輯器",
     "📝 Collaborative document editing" : "📝 協作文件編輯",
@@ -24,12 +25,13 @@ OC.L10N.register(
     "The document has been changed outside of the editor. The changes cannot be applied." : "文件已在編輯器外變更。變更無法套用。",
     "File could not be loaded. Please check your internet connection." : "無法載入檔案。請檢查您的網路連線。",
     "This file is opened read-only as it is currently locked by {user}." : "此檔案以唯讀模式打開，因為它當前被 {user} 鎖上。",
+    "Outline" : "大綱",
+    "Close outline view" : "關閉大綱檢視",
     "Enter your name so other people can see who is editing" : "輸入您的姓名，以便其他人可以看到誰在編輯",
     "Edit guest name" : "編輯訪客名稱",
     "Guest" : "訪客",
     "Save guest name" : "儲存訪客名稱",
-    "Image file format not supported" : "不支持圖像格式",
-    "Insert an image" : "插入圖像",
+    "Insert an attachment" : "插入附件",
     "guest" : "訪客",
     "Show author colors" : "顯示作者顏色",
     "Author colors are only shown until everyone has closed the document." : "僅在所有人都關閉文件前才顯示文件顏色。",
@@ -76,12 +78,15 @@ OC.L10N.register(
     "Insert from Files" : "從檔案插入",
     "Formatting menu bar" : "格式化選項單欄",
     "Editor actions" : "編輯器操作",
-    "Remaining Actions" : "剩餘操作",
+    "Remaining actions" : "剩餘操作",
     "Update Link" : "更新連結",
     "Add Link" : "添加連結",
     "Link file" : "連結檔案",
     "Remove Link" : "移除連結",
     "Select file to link to" : "選擇要連結的檔案",
+    "Link to this section" : "連結到本節",
+    "Delete this attachment" : "刪除此附件",
+    "Delete this image" : "刪除此圖像",
     "Failed to load" : "加載失敗",
     "Unsupported image type" : "不支援的圖片類型",
     "Add row before" : "在前面添加行",
@@ -100,6 +105,8 @@ OC.L10N.register(
     "Heading 3" : "標題 3",
     "Heading 4" : "標題 4",
     "Heading 5" : "標題 5",
+    "Hide outline" : "隱藏大綱",
+    "Show outline" : "顯示大綱",
     "To-Do list" : "待辦事項清單",
     "Callouts" : "標記",
     "Info" : "資訊",
@@ -108,7 +115,7 @@ OC.L10N.register(
     "Danger" : "危險",
     "Table" : "表",
     "Insert emoji" : "插入 emoji",
-    "Insert image" : "插入圖像",
+    "Insert attachment" : "插入附件",
     "Command" : "指令",
     "Control" : "掌控",
     "Option" : "選項",
@@ -116,10 +123,13 @@ OC.L10N.register(
     "Front matter" : "前言",
     "New text document" : "新文字文件",
     "Enter your name so other users can see who is editing" : "輸入您的名稱，這樣其他用戶才能查看是誰在編輯",
+    "Insert image" : "插入圖像",
+    "Insert an image" : "插入圖像",
     "Currently active users:" : "目前活躍用戶：",
     "_and %n other editor_::_and %n other editors_" : ["及其他 %n 個編輯"],
     "ToDo list" : "待辦清單",
     "Emoji picker" : "Emoji 選擇器",
+    "Image file format not supported" : "不支持圖像格式",
     "Todo item" : "待辦事項",
     "Alt" : "Alt"
 },
