@@ -5,19 +5,20 @@ OC.L10N.register(
     "Admin" : "Správa",
     "Saved" : "Uloženo",
     "a safe home for all your data" : "bezpečný domov pro všechna vaše data",
+    "Error uploading the file" : "Chyba při nahrávání souboru",
     "Name cannot be empty" : "Je třeba zadat název",
     "The given name is too long" : "Zadaný název je příliš dlouhý",
     "The given web address is too long" : "Zadaná webová adresa je příliš dlouhá",
     "The given web address is not a valid URL" : "Zadaná webová adresa není platné URL",
     "The given legal notice address is too long" : "Daná adresa právního upozornění je příliš dlouhá",
-    "The given legal notice address is not a valid URL" : "Daná adresa právního upozornění není platnou URL adresou",
+    "The given legal notice address is not a valid URL" : "Daná adresa právního upozornění není platné URL",
     "The given privacy policy address is too long" : "Daná adresa zásad ochrany osobních údajů je příliš dlouhá",
-    "The given privacy policy address is not a valid URL" : "Daná adresa prohlášení o ochraně soukromí není platná URL adresa",
-    "The given slogan is too long" : "Zadaný slogan je příliš dlouhý",
-    "The given color is invalid" : "Zadaná barva není platná",
+    "The given privacy policy address is not a valid URL" : "Daná adresa prohlášení o ochraně soukromí není platné URL",
+    "The given slogan is too long" : "Daný slogan je příliš dlouhý",
+    "The given color is invalid" : "Daná barva není platná",
     "The file was uploaded" : "Soubor byl nahrán",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Velikost nahrávaného souboru překračuje limit nastavení direktivou upload_max_filesize v php.ini",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Nahraný soubor překračuje nastavení MAX_FILE_SIZE, která byla zadána ve HTML formuláři",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Velikost nahrávaného souboru překračuje nastavení MAX_FILE_SIZE, která byla zadána v HTML formuláři",
     "The file was only partially uploaded" : "Soubor byl nahrán pouze z části",
     "No file was uploaded" : "Nebyl nahrán žádný soubor",
     "Missing a temporary folder" : "Chybí složka pro dočasné soubory",
@@ -28,7 +29,7 @@ OC.L10N.register(
     "Theming" : "Motiv vzhledu",
     "Appearance and accessibility" : "Vzhled a zpřístupnění",
     "Dark theme with high contrast mode" : "Tmavý motiv vzhledu s režimem vysokého kontrastu",
-    "Enable dark high contrast mode" : "Zapnout tmavý režim s vysokým kontrastem",
+    "Enable dark high contrast mode" : "Používat tmavý režim s vysokým kontrastem",
     "Similar to the high contrast mode, but with dark colours." : "Podobné režimu s vysokým kontrastem, ale s tmavými barvami.",
     "Dark theme" : "Tmavý motiv vzhledu",
     "Enable dark theme" : "Používat tmavý motiv vzhledu",
@@ -62,13 +63,13 @@ OC.L10N.register(
     "Logo" : "Logo",
     "Upload new logo" : "Nahrát nové logo",
     "Login image" : "Přihlašovací obrázek",
-    "Upload new login background" : "Nahrát nové přihlašovací pozadí",
+    "Upload new login background" : "Nahrát nové pozadí pro přihlašovací obrazovku",
     "Remove background image" : "Odebrat obrázek z pozadí",
     "Advanced options" : "Pokročilé předvolby",
     "Legal notice link" : "Odkaz na právní upozornění",
     "Privacy policy link" : "Odkaz na zásady ochrany osobních údajů",
-    "Header logo" : "Logo v záhlaví",
-    "Upload new header logo" : "Nahrát nové logo do záhlaví",
+    "Header logo" : "Logo pro záhlaví",
+    "Upload new header logo" : "Nahrát nové logo pro záhlaví",
     "Favicon" : "ikona webu",
     "Upload new favicon" : "Nahrát novou ikonu webu",
     "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Nainstalujte rozšíření Imagemagick PHP s podporou obrázků SVG, které automaticky vytváří favicon na základě nahraného loga a barvy."
