@@ -5,6 +5,7 @@ OC.L10N.register(
     "Admin" : "Rendszergazda",
     "Saved" : "Mentve",
     "a safe home for all your data" : "biztonságos hely az adatai számára",
+    "Error uploading the file" : "Hiba a fájl feltöltése során",
     "Name cannot be empty" : "A név nem lehet üres",
     "The given name is too long" : "A megadott név túl hosszú",
     "The given web address is too long" : "A megadott webcím túl hosszú",
@@ -49,7 +50,7 @@ OC.L10N.register(
     "Privacy policy" : "Adatvédelmi irányelvek",
     "Adjust the Nextcloud theme" : "A Nextcloud téma módosítása",
     "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Az akadálymentesítés fontos számunka. A webes szabványokat követjük, és ellenőrizzük, hogy minden használható egér nélkül, illetve akadálymentesítési technológiákkal, például képernyőolvasókkal. Arra törekszünk, hogy a {guidelines}Webes tartalomra vonatkozó akadálymentesítési irányelvek{linkend} 2.1-es változatának AA szinten, a magas kontrasztú témával pedig AAA szinten megfeleljünk.",
-    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Ha problémákat tapasztal, jelentse a {issuetracker}hibakövetőnkben{linkend}. És ha segíteni szeretne, csatlakozzon a {designteam}dizájn csapatunkhoz{linkend}!",
+    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Ha problémákat tapasztal, jelentse a {issuetracker}hibakövetőnkben{linkend}. És ha segíteni szeretne, csatlakozzon a {designteam}dizájn csapatunkhoz{linkend}!",
     "Theme selection is enforced" : "A témaválasztás kényszerített",
     "Open documentation" : "Dokumentáció megnyitása",
     "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "A témák lehetővé teszik, hogy könnyedén személyre szabja a példány és a támogatott kliensek megjelenését. Ez minden felhasználó számára látható lesz.",
