@@ -1,6 +1,11 @@
 OC.L10N.register(
     "theming",
     {
+    "Loading preview…" : "Carregando pré-visualização...",
+    "Admin" : "Administrador",
+    "Saved" : "Salva",
+    "a safe home for all your data" : "um lugar seguro para seus dados",
+    "Name cannot be empty" : "O nome não pode ficar em branco",
     "The given name is too long" : "O nome é muito longo",
     "The given web address is too long" : "O endereço web fornecido é muito longo",
     "The given web address is not a valid URL" : "O endereço web não é uma URL válida",
@@ -10,8 +15,6 @@ OC.L10N.register(
     "The given privacy policy address is not a valid URL" : "O endereço da política de privacidade não é uma URL válida",
     "The given slogan is too long" : "O slogan dado é muito longo",
     "The given color is invalid" : "A cor fornecida é inválida",
-    "Disable-user-theming should be true or false" : "Desabilitar-tema-usuário deve ser verdadeiro ou falso",
-    "Saved" : "Salva",
     "The file was uploaded" : "O arquivo foi enviado",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O arquivo enviado excede a diretiva upload_max_filesize do php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O arquivo enviado excede a diretiva MAX_FILE_SIZE especificada no formulário HTML",
@@ -21,8 +24,6 @@ OC.L10N.register(
     "Could not write file to disk" : "Não foi possível escrever no disco",
     "A PHP extension stopped the file upload" : "Uma extensão PHP parou o envio do arquivo",
     "No file uploaded" : "Nenhum arquivo enviado",
-    "Cleanup old theming cache" : "Limpar cache de temas antigos",
-    "Failed to delete folder: \"%1$s\", error: %2$s" : "Falha ao excluir a pasta:\"%1$s\", erro: %2$s",
     "You are already using a custom theme. Theming app settings might be overwritten by that." : "Você já está usando um tema personalizado. As configurações do aplicativo Theming podem ser sobrescritas por isso.",
     "Theming" : "Personalização",
     "Appearance and accessibility" : "Aparência e acessibilidade",
@@ -47,60 +48,29 @@ OC.L10N.register(
     "Legal notice" : "Aviso legal",
     "Privacy policy" : "Política de privacidade",
     "Adjust the Nextcloud theme" : "Ajustar o tema do Nextcloud",
+    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "O acesso universal é muito importante para nós. Seguimos os padrões da web e nos certificamos de tornar tudo utilizável também sem mouse e software auxiliar, como leitores de tela. Nosso objetivo é estar em conformidade com as {guidelines}Diretrizes de Acessibilidade para Conteúdo da Web{linkend} 2.1 no nível AA, com o tema de alto contraste, mesmo no nível AAA.",
+    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Se você encontrar algum problema, não hesite em denunciá-lo em {issuetracker}nosso rastreador de problemas{linkend}. E se você quiser se envolver, junte-se a {designteam}nossa equipe de design{linkend}!",
+    "Theme selection is enforced" : "A seleção do tema é aplicada",
+    "Open documentation" : "Abrir documentação",
     "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Criar e alterar temas torna possível personalizar facilmente o Nextcloud e clientes suportados. Isso será visível para todos os usuários.",
-    "Advanced options" : "Opções avançadas",
-    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instale a extensão PHP ImageMagick para ter suporte a geração automática em SVG para favicons baseados no logotipo e cores enviados.",
     "Name" : "Nome",
+    "Reset to default" : "Redefinir para o padrão",
     "Web link" : "Link web",
-    "a safe home for all your data" : "um lugar seguro para seus dados",
+    "https://…" : "https://...",
     "Slogan" : "Slogan",
     "Color" : "Cor",
     "Logo" : "Logotipo",
     "Upload new logo" : "Enviar novo logotipo",
-    "Background and login image" : "Plano de fundo e imagem de login",
-    "Upload new background and login image" : "Envie um novo papel de parede e imagem de login",
+    "Login image" : "Imagem de login",
+    "Upload new login background" : "Enviar nova imagem de fundo para o login",
+    "Remove background image" : "Excluir a imagem de fundo",
+    "Advanced options" : "Opções avançadas",
     "Legal notice link" : "Link do aviso legal",
     "Privacy policy link" : "Link da política de privacidade",
     "Header logo" : "Logotipo de cabeçalho",
     "Upload new header logo" : "Enviar novo logotipo de cabeçalho",
     "Favicon" : "Ícone de favoritos",
     "Upload new favicon" : "Enviar novo ícone de favorito",
-    "User settings" : "Configurações de usuário",
-    "Disable user theming" : "Desabilitar temas do usuário",
-    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Embora você possa selecionar e personalizar sua instância, os usuários podem alterar o plano de fundo e as cores. Se você quiser impor sua personalização, marque esta caixa.",
-    "Keyboard shortcuts" : "Atalhos do teclado",
-    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Em alguns casos, os atalhos de teclado podem interferir nas ferramentas de acessibilidade. Para permitir o foco em sua ferramenta corretamente, você pode desativar todos os atalhos de teclado aqui. Isso também desativará todos os atalhos disponíveis nos aplicativos.",
-    "Disable all keyboard shortcuts" : "Desabilitar todos os atalhos de teclado",
-    "Background" : "Fundo",
-    "Customization has been disabled by your administrator" : "A personalização foi desativada pelo seu administrador",
-    "Set a custom background" : "Defina um plano de fundo personalizado",
-    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "O acesso universal é muito importante para nós. Seguimos os padrões da web e nos certificamos de tornar tudo utilizável também sem mouse e software auxiliar, como leitores de tela. Nosso objetivo é estar em conformidade com as {guidelines}Diretrizes de Acessibilidade para Conteúdo da Web{linkend} 2.1 no nível AA, com o tema de alto contraste, mesmo no nível AAA.",
-    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Se você encontrar algum problema, não hesite em denunciá-lo em {issuetracker}nosso rastreador de problemas{linkend}. E se você quiser se envolver, junte-se a {designteam}nossa equipe de design{linkend}!",
-    "Custom background" : "Papel de parede personalizado",
-    "Default background" : "Papel de parede padrão",
-    "Change color" : "Trocar a cor",
-    "Remove background" : "Remover papel de parede",
-    "Select a background from your files" : "Selecione o papel de parede de seus arquivos",
-    "Theme selection is enforced" : "A seleção do tema é aplicada",
-    "Select a custom color" : "Selecione uma cor personalizada",
-    "Reset to default" : "Redefinir para o padrão",
-    "Upload" : "Enviar",
-    "Remove background image" : "Excluir a imagem de fundo",
-    "Loading preview…" : "Carregando pré-visualização...",
-    "Admin" : "Administrador",
-    "Error uploading the file" : "Erro ao carregar o arquivo",
-    "Name cannot be empty" : "O nome não pode ficar em branco",
-    "Open documentation" : "Abrir documentação",
-    "https://…" : "https://...",
-    "Login image" : "Imagem de login",
-    "Upload new login background" : "Enviar nova imagem de fundo para o login",
-    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instale a extensão PHP Imagemagick com suporte a imagens SVG para gerar favicons automaticamente, com base no logotipo e na cor enviados.",
-    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Em alguns casos, os atalhos de teclado podem interferir nas ferramentas de acessibilidade. Para permitir o foco em sua ferramenta corretamente, você pode desativar todos os atalhos de teclado aqui. Isso também desativará todos os atalhos disponíveis nos aplicativos.",
-    "Pick from Files" : "Escolher de Arquivos",
-    "Default image" : "Imagem padrão",
-    "Custom color" : "Cor personalizada",
-    "Plain background" : "Fundo simples",
-    "Insert from {productName}" : "Inserir de {productName}",
-    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "Embora você possa selecionar e personalizar sua instância, os usuários podem alterar o plano de fundo e as cores. Se você quiser impor sua personalização, marque esta caixa."
+    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instale a extensão PHP Imagemagick com suporte a imagens SVG para gerar favicons automaticamente, com base no logotipo e na cor enviados."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
