@@ -2,8 +2,8 @@ OC.L10N.register(
     "theming",
     {
     "Loading preview…" : "Учитавам преглед…",
-    "Saved" : "Сачувано",
     "Admin" : "Администрација",
+    "Saved" : "Сачувано",
     "a safe home for all your data" : "сигурно место за све ваше податке",
     "Name cannot be empty" : "Назив не може бити празан",
     "The given name is too long" : "Назив је предугачак",
@@ -26,9 +26,18 @@ OC.L10N.register(
     "No file uploaded" : "Није отпремљен фајл",
     "You are already using a custom theme. Theming app settings might be overwritten by that." : "Већ користите прилагођену тему. Поставке ове апликације ће прегажене са њом.",
     "Theming" : "Изглед",
+    "Dark theme" : "Тамна тема",
+    "Enable dark theme" : "укључи тамну тему",
+    "Dyslexia font" : "Фонт Дислексија",
+    "Enable dyslexia font" : "укључи фонт Дислексија",
+    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "„OpenDyslexic“ је бесплатни фонт дизајниран да умањи честе грешке у читању изазване дислексијом.",
+    "High contrast mode" : "Режим високог контраста",
+    "Enable high contrast mode" : "укључи режим високог контраста",
+    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Режим високог контраста за лакшу навигацију. Визуелни доживљај биће лошији али ће јасноћа бити боља.",
     "Legal notice" : "Правно обавештење",
     "Privacy policy" : "Смернице приватности",
     "Adjust the Nextcloud theme" : "Прилагоди Некстклауд тему",
+    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Универзални приступ нам је веома важан. Пратимо веб стандарде и проверавамо да све буде употребљиво и без миша а и са помоћним софтвером попут читача екрана. Циљ нам је да будемо усклађени са документом {guidelines}Смернице приступачности веб садржаја{linkend}  2.1 на АА нивоу а са темом високог контраста и на ААА нивоу.",
     "Open documentation" : "Отвори документацију",
     "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Омогућава да лако измените изглед и угођај вашег Некстклауда. Ово ће бити видљиво свим корисницима.",
     "Name" : "Назив",
