@@ -5,6 +5,7 @@ OC.L10N.register(
     "Admin" : "Адмін",
     "Saved" : "Збережено",
     "a safe home for all your data" : "безпечна домівка для ваших даних",
+    "Error uploading the file" : "Помилка завантаження файлу",
     "Name cannot be empty" : "Ім'я не може бути порожнім",
     "The given name is too long" : "Ім'я задовге",
     "The given web address is too long" : "Вебадреса занадто довга",
@@ -38,7 +39,6 @@ OC.L10N.register(
     "Privacy policy" : "Політика конфіденційності",
     "Adjust the Nextcloud theme" : "Налаштуйте тему Nextcloud",
     "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Для нас дуже важливо забезпечити доступ для всіх. Ми дотримуємось веб-стандартів і перевіряємо, щоб забезпечити зручність користування без комп'ютерної миші, а також за допомогую допоміжного програмного забезпечення, наприклад, програми зчитування з екрана. Ми прагнемо відповідати {guidelines} Правила доступу до веб-вмісту {linkend} 2.1 на рівні AA, а з темою високої контрастності навіть на рівні AAA.",
-    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Якщо ви знайшли будь-які проблеми, будь-ласка повідомте про них на {issuetracker} до нашого трекера задач{linkend}. Якщо ж ви бажаєте стати учасником - будь-ласка приєднуйтесь до {designteam} нашої команди{linkend}! ",
     "Open documentation" : "Відкрити документацію",
     "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Оформлення дозволяє легко налаштувати зовнішній вигляд вашого сервера та підтримуваних клієнтів. Це будуть бачити всі користувачі.",
     "Name" : "Ім’я",
