@@ -12,12 +12,10 @@ OC.L10N.register(
     "Update for {app} to version %s is available." : "Pre {app} je dostupná aktualizácia na verziu %s.",
     "Update notification" : "Aktualizovať hlásenie",
     "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Zobrazí upozornenie na aktualizáciu pre Nextcloud a poskytuje zjednotené prihlasovanie pre aktualizátor.",
-    "Update" : "Aktualizovať",
     "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Verzia, ktorú používate už nie je podporovaná. Čím skôr aktualizujte na podporovanú verziu prosím.",
     "Apps missing compatible version" : "Aplikácie s chýbajúcou kompatibilnou verziou",
     "View in store" : "Zobraziť v obchode",
     "Apps with compatible version" : "Aplikácie s kompatibilnou verziou",
-    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Upozorňujeme, že webový aktualizátor sa neodporúča pre viac ako 100 používateľov! Namiesto toho použite nástroj na aktualizáciu príkazového riadku!",
     "Open updater" : "Otvoriť aktualizátor",
     "Download now" : "Stiahnuť teraz",
     "Please use the command line updater to update." : "Použite prosím aktualizáciu cez príkazový riadok.",
@@ -25,7 +23,6 @@ OC.L10N.register(
     "The update check is not yet finished. Please refresh the page." : "Kontrola aktualizácií ešte neskončila. Obnovte prosím stránku.",
     "Your version is up to date." : "Vaša verzia je atuálna.",
     "A non-default update server is in use to be checked for updates:" : "Pre kontrolu aktualizácií sa používa iný než predvolený server:",
-    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Nižšie môžete zmeniť aktualizačný kanál, ktorý ovplyvní aj stránku správy aplikácií. napr. po prepnutí na beta kanál sa vám na stránke správy aplikácií ponúknu aktualizácie beta aplikácií.",
     "Update channel:" : "Aktualizačný kanál:",
     "You can always update to a newer version. But you can never downgrade to a more stable version." : "Vždy môžete aktualizovať na novšiu verziu, ale nikdy nemôžete prejsť na nižšiu, stabilnejšiu verziu.",
     "Notify members of the following groups about available updates:" : "Upozorňovať členov nasledujúcich skupín o dostupných aktualizáciach:",
