@@ -813,7 +813,7 @@ class Wizard extends LDAPUtility {
 			return false;
 		}
 		$er = $this->ldap->firstEntry($cr, $rr);
-		while (is_resource($er)) {
+		while ($this->ldap->isResource($er)) {
 			$this->ldap->getDN($cr, $er);
 			$attrs = $this->ldap->getAttributes($cr, $er);
 			$result = [];
@@ -1059,7 +1059,7 @@ class Wizard extends LDAPUtility {
 			['app' => 'user_ldap']
 		);
 		$cr = $this->ldap->connect($host, $port);
-		if (!is_resource($cr)) {
+		if (!$this->ldap->isResource($cr)) {
 			throw new \Exception(self::$l->t('Invalid Host'));
 		}
 
@@ -1269,7 +1269,7 @@ class Wizard extends LDAPUtility {
 
 	/**
 	 * appends a list of values fr
-	 * @param resource $result the return value from ldap_get_attributes
+	 * @param array $result the return value from ldap_get_attributes
 	 * @param string $attribute the attribute values to look for
 	 * @param array &$known new values will be appended here
 	 * @return int, state on of the class constants LRESULT_PROCESSED_OK,
