@@ -5,10 +5,20 @@ OC.L10N.register(
     "Simple file viewer with slideshow for media" : "Ur seller restroù simpl gant un diaporama evit ar mediaoù",
     "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Diskwellit fotoioù ha videoioù ho vakansoù divezhañ evel en ur film, roit un taol-lagad war ho danevel divezhañ diozhtu e Nextcloud, choazit ar GIF gwellañ en ho dastum a drugarez d'ar ragwell war ho restroù karetañ ha muioc'h c'hoaz !",
     "Error loading {name}" : "Ur fazi zo bet en ur kargañ {name}",
+    "Unsaved changes" : "Kemmoù n'int ket bet enrollet",
     "Your browser does not support videos." : "Ne doug ket ho furcher ar videoioù.",
+    "Edit" : "Cheñch",
     "Open sidebar" : "Digori ar varenn gostez",
     "Download" : "Pellgargañ",
     "Delete" : "Lemel",
-    "View" : "Gwell"
+    "View" : "Gwell",
+    "Name" : "Anv",
+    "Save" : "Enrollañ",
+    "Back" : "Distro",
+    "Loading …" : "O Kargañ ...",
+    "Cancel" : "Arrest",
+    "Continue" : "Kendec'hel",
+    "Original" : "Orin",
+    "Size" : "Ment"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
