@@ -3,9 +3,9 @@ OC.L10N.register(
     {
     "Viewer" : "מציג",
     "Simple file viewer with slideshow for media" : "מציג קבצים פשוט עם תמיכה במצגות למדיה",
+    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "הצגת התמונות והסרטונים מהחופשה האחרונה שלך כמו בקולנוע, הפצת הצצה מתוך הרומן האחרון שלך ישירות מ־nextcloud, בחירת ה־GIF הטוב ביותר מתוך האוסף שלך בזכות תצוגה מקדימה של הקבצים המועדפים שלך ועוד מגוון יכולות!",
     "Your browser does not support audio." : "הדפדפן שלך אינו תומך בשמע.",
     "Error loading {name}" : "שגיאה בטעינת {name}",
-    "Image saved" : "תמונה נשמרה",
     "Unsaved changes" : "שינויים שלא נשמרו",
     "Your browser does not support videos." : "הדפדפן שלך לא תומך בסרטונים.",
     "Edit" : "עריכה",
@@ -32,7 +32,6 @@ OC.L10N.register(
     "Position" : "מיקום",
     "Extension" : "הרחבה",
     "Name is required." : "נדרש שם.",
-    "Quality" : "איכות",
-    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "הצגת התמונות והסרטונים מהחופשה האחרונה שלך כמו בקולנוע, הפצת הצצה מתוך הרומן האחרון שלך ישירות מ־nextcloud, בחירת ה־GIF הטוב ביותר מתוך האוסף שלך בזכות תצוגה מקדימה של הקבצים המועדפים שלך ועוד מגוון יכולות!"
+    "Quality" : "איכות"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
