@@ -5,9 +5,26 @@ OC.L10N.register(
     "Simple file viewer with slideshow for media" : "Простий переглядач файлів зі слайдшоу для медіа",
     "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Покажіть фото і відео ваших канікул як кіно, покажіть найяскравіші моменти вашого роману прямо у Nextcloud, оберіть найкращі гіфки з вашої колекції завдяки прямому перегляду ваших файлів, а також багато інших можливостей!",
     "Error loading {name}" : "Помилка при завантаженні {name}",
+    "Unsaved changes" : "Незбережені зміни",
+    "Edit" : "Редагувати",
     "Open sidebar" : "Відкрити бічну панель",
     "Download" : "Завантажити",
     "Delete" : "Вилучити",
-    "View" : "Перегляд"
+    "View" : "Перегляд",
+    "Name" : "Ім'я",
+    "Save" : "Зберегти",
+    "Back" : "Назад",
+    "Loading …" : "Завантаження …",
+    "Reset" : "Скидання",
+    "Cancel" : "Скасувати",
+    "Continue" : "Продовжити",
+    "Undo" : "Скасувати",
+    "Redo" : "Повторити",
+    "Value" : "Значення",
+    "Line" : "лінія",
+    "Text" : "Текст",
+    "Size" : "Розмір",
+    "Position" : "Позиція",
+    "Name is required." : "Ім'я є обов'язковим."
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
