@@ -11,6 +11,28 @@ OC.L10N.register(
     "Detect location" : "Откриване на местоположение",
     "Set custom address" : "Задаване на персонализиран адрес",
     "Favorites" : "Любими",
+    "{temperature} {unit} clear sky later today" : "{temperature} {unit} по късно днес небето ще е ясно",
+    "{temperature} {unit} clear sky" : "{temperature} {unit} ясно",
+    "{temperature} {unit} cloudy later today" : "{temperature} {unit} по късно днес ще е облачно",
+    "{temperature} {unit} cloudy" : "{temperature} {unit} облачно",
+    "{temperature} {unit} fair weather later today" : "{temperature} {unit} по-късно днес времето ще е хубаво",
+    "{temperature} {unit} fair weather" : "{temperature} {unit} хубаво време",
+    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} по късно днес ще има частична облачност",
+    "{temperature} {unit} partly cloudy" : "{temperature} {unit} частична облачност",
+    "{temperature} {unit} foggy later today" : "{temperature} {unit} по късно днес ще е мъгливо",
+    "{temperature} {unit} foggy" : "{temperature} {unit} мъгливо",
+    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} по късно днес ще има слаби валежи",
+    "{temperature} {unit} light rainfall" : "{temperature} {unit} слаби валежи",
+    "{temperature} {unit} rainfall later today" : "{temperature} {unit} по късно днес ще има валежи",
+    "{temperature} {unit} rainfall" : "{temperature} {unit} дъжд",
+    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} по късно днес ще има силни валежи",
+    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} силни валежи",
+    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} по късно днес ще има превалявания от дъжд",
+    "{temperature} {unit} rainfall showers" : "{temperature} {unit} превалявания от дъжд",
+    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} по късно днес ще има леки превалявания от дъжд",
+    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} леки превалявания от дъжд",
+    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} по късно днес ще има обилни превалявания от дъжд",
+    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} обилни превалявания от дъжд",
     "More weather for {adr}" : "Още за времето за {adr}",
     "Loading weather" : "Зареждане на времето",
     "Remove from favorites" : "Премахни от любимите",
@@ -26,8 +48,8 @@ OC.L10N.register(
     "Set location for weather" : "Задаване на местоположение за метеорологично време",
     "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Ясно небе в {time}",
     "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Облачно в {time}",
-    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Задоволителен ден в {time}",
-    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Задоволителна нощ в {time}",
+    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Хубаво време през деня в {time}",
+    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Хубаво време през нощта в {time}",
     "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Частична облачност в {time}",
     "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Мъгливо в {time}",
     "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Слаб дъжд в {time}",
