@@ -11,6 +11,28 @@ OC.L10N.register(
     "Detect location" : "地域を検出",
     "Set custom address" : "地域を入力",
     "Favorites" : "お気に入り",
+    "{temperature} {unit} clear sky later today" : "{temperature} {unit} 今日遅く快晴",
+    "{temperature} {unit} clear sky" : "{temperature} {unit} 快晴",
+    "{temperature} {unit} cloudy later today" : "{temperature} {unit} 今日遅く曇り",
+    "{temperature} {unit} cloudy" : "{temperature} {unit} 曇り",
+    "{temperature} {unit} fair weather later today" : "{temperature} {unit} 今日遅く晴れ",
+    "{temperature} {unit} fair weather" : "{temperature} {unit} 晴れ",
+    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} 今日遅く所々曇り",
+    "{temperature} {unit} partly cloudy" : "{temperature} {unit} 所々曇り",
+    "{temperature} {unit} foggy later today" : "{temperature} {unit} 今日遅く霧",
+    "{temperature} {unit} foggy" : "{temperature} {unit} 霧",
+    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} 今日遅く小雨",
+    "{temperature} {unit} light rainfall" : "{temperature} {unit} 小雨",
+    "{temperature} {unit} rainfall later today" : "{temperature} {unit} 今日遅く雨",
+    "{temperature} {unit} rainfall" : "{temperature} {unit} 雨",
+    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} 今日遅く大雨",
+    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} 大雨",
+    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} 今日遅くにわか雨",
+    "{temperature} {unit} rainfall showers" : "{temperature} {unit} にわか雨",
+    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} 今日遅く小雨",
+    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} 小雨",
+    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} 今日遅く大雨",
+    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} 大雨",
     "More weather for {adr}" : "{adr} の詳しい天気",
     "Loading weather" : "天気を読み込み中",
     "Remove from favorites" : "お気に入りから削除",
