@@ -21,21 +21,21 @@ OC.L10N.register(
     "{temperature} {unit} partly cloudy" : "{temperature} {unit} parçalı bulutlu",
     "{temperature} {unit} foggy later today" : "{temperature} {unit} bugün sisli",
     "{temperature} {unit} foggy" : "{temperature} {unit} sisli",
-    "{temperature} {unit} light rain later today" : "{temperature} {unit} bugün hafif yağmurlu",
-    "{temperature} {unit} light rain" : "{temperature} {unit} hafif yağmurlu",
-    "{temperature} {unit} rain later today" : "{temperature} {unit} bugün yağmurlu",
-    "{temperature} {unit} rain" : "{temperature} {unit} yağmurlu",
-    "{temperature} {unit} heavy rain later today" : "{temperature} {unit} bugün yoğun yağmurlu",
-    "{temperature} {unit} heavy rain" : "{temperature} {unit} yoğun yağmurlu",
-    "{temperature} {unit} rain showers later today" : "{temperature} {unit} bugün sağanak yağışlı",
-    "{temperature} {unit} rain showers" : "{temperature} {unit} sağanak yağışlı",
-    "{temperature} {unit} light rain showers later today" : "{temperature} {unit} bugün hafif sağanak yağışlı",
-    "{temperature} {unit} light rain showers" : "{temperature} {unit} hafif sağanak yağışlı",
-    "{temperature} {unit} heavy rain showers later today" : "{temperature} {unit} bugün ağır sağanak yağışlı",
-    "{temperature} {unit} heavy rain showers" : "{temperature} {unit} ağır sağanak yağışlı",
+    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} bugün hafif yağmurlu",
+    "{temperature} {unit} light rainfall" : "{temperature} {unit} hafif yağmurlu",
+    "{temperature} {unit} rainfall later today" : "{temperature} {unit} bugün hafif yağmurlu",
+    "{temperature} {unit} rainfall" : "{temperature} {unit} yağmurlu",
+    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} bugün şiddetli yağmurlu",
+    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} şiddetli yağmurlu",
+    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} bugün sağanak yağışlı",
+    "{temperature} {unit} rainfall showers" : "{temperature} {unit} sağanak yağışlı",
+    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} bugün hafif sağanak yağışlı",
+    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} hafif sağanak yağışlı",
+    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} bugün şiddetli sağanak yağışlı",
+    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} şiddetli sağanak yağışlı",
     "More weather for {adr}" : "{adr} için geniş hava durumu",
     "Loading weather" : "Hava durumu yükleniyor",
-    "Remove from favorites" : "Sık kullanılanlardan çıkar",
+    "Remove from favorites" : "Sık kullanılanlardan kaldır",
     "Add as favorite" : "Sık kullanılanlara ekle",
     "You are not logged in." : "Oturum açmamışsınız.",
     "There was an error getting the weather status information." : "Hava durumu bilgileri alınırken bir sorun çıktı.",
@@ -54,9 +54,9 @@ OC.L10N.register(
     "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Sisli {time}",
     "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Hafif yağışlı {time}",
     "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Yağışlı {time}",
-    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Ağır yağışlı {time}",
+    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} şiddetli yağmur {time}",
     "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Sağanak yağış {time}",
     "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Hafif sağnak {time}",
-    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Ağır sağnak {time}"
+    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} şiddetli sağanak yağış {time}"
 },
 "nplurals=2; plural=(n > 1);");
