@@ -76,11 +76,16 @@ class GuestAvatarController extends Controller {
 	public function getAvatar($guestName, $size) {
 		$size = (int) $size;
 
-		// min/max size
-		if ($size > 2048) {
-			$size = 2048;
-		} elseif ($size <= 0) {
+		if ($size <= 64) {
+			if ($size !== 64) {
+				$this->logger->debug('Avatar requested in deprecated size ' . $size);
+			}
 			$size = 64;
+		} else {
+			if ($size !== 512) {
+				$this->logger->debug('Avatar requested in deprecated size ' . $size);
+			}
+			$size = 512;
 		}
 
 		try {
