@@ -86,6 +86,14 @@ window.firstDay = 0;
 // setup dummy webroots
 /* jshint camelcase: false */
 window.oc_debug = true;
+
+// Mock @nextcloud/capabilities
+window._oc_capabilities = {
+	files_sharing: {
+		api_enabled: true
+	}
+}
+
 // FIXME: OC.webroot is supposed to be only the path!!!
 OC.webroot = location.href + '/';
 OC.appswebroots = {
