@@ -40,8 +40,7 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Някои от вашите споделяния на връзки са премахнати",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Поради грешка в сигурността трябваше да премахнем някои от вашите споделяния на връзки. Моля, вижте връзката за повече информация.",
     "The user limit of this instance is reached." : " Достигнат е потребителският лимит на този екземпляр.",
-    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Въведете абонаментния си ключ в приложението за поддръжка, за да увеличите лимита на потребителите. Това ви дава и всички допълнителни предимства, които Nextcloud Enterprise предлага, и е силно препоръчително за работа в компании.",
-    "Learn more ↗" : "Научете повече ↗",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Въведете абонаментния си ключ, за да увеличите потребителския си лимит. За повече информация относно Nextcloud Enterprise вижте нашия уеб сайт.",
     "Preparing update" : "Подготовка за актуализиране",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Стъпка на поправка:",
@@ -84,6 +83,7 @@ OC.L10N.register(
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Не е конфигурирана кеш паметта. За да подобрите производителността, моля, конфигурирайте memcache, ако е наличен. Допълнителна информация можете да намерите в {linkstart}документацията ↗{linkend}.",
     "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Не е открит подходящ източник за случайност от PHP, което е силно обезкуражително от съображения за сигурност. Допълнителна информация можете да намерите в {linkstart}документацията ↗{linkend}.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "В момента използвате PHP {версия}. Надстройте своята версия на PHP, за да се възползвате от {linkstart}актуализациите за производителност и сигурност, предоставени от PHP Group ↗{linkend}, веднага щом вашата дистрибуция я поддържа.",
+    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 е последното издание, поддържащо PHP 7.3. Nextcloud 24 изисква поне PHP 7.4.",
     "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Конфигурацията на заглавката на обратния прокси сървър е неправилна или осъществявате достъп до Nextcloud от доверен прокси сървър. Ако не, това е проблем със сигурността и може да позволи на хакер да прикрие IP адреса си в Nextcloud. Допълнителна информация можете да намерите в {linkstart}документацията ↗{linkend}.",
     "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Кеширането на паметта е настроено като разпределена кеш, но е инсталиран грешен PHP модул \"memcache\". \\OC\\Memcache\\Memcached поддържа само \"memcached\", но не и \"memcache\". Вижте {linkstart}memcached wiki за двата модула ↗{linkend}.",
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Някои файлове не са преминали проверката за цялост. Допълнителна информация за това как да разрешите този проблем можете да намерите в {linkstart1}документация ↗{linkend}. ({linkstart2}Списък с невалидни файлове…{linkend} / {linkstart3}Повторно сканиране…{linkend})",
@@ -99,7 +99,7 @@ OC.L10N.register(
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "В този екземпляр липсват някои препоръчани PHP модули. За подобрена производителност и по-добра съвместимост е силно препоръчително да ги инсталирате.",
     "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "PHP модулът \"imagick\" не е активиран, въпреки че приложението за теми е активирано. За да работи правилно генерирането на аватари тип favicon, трябва да инсталирате и активирате този модул.",
     "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "PHP модулите \"gmp\" и/или \"bcmath\" не са активирани. Ако използвате удостоверяване без парола WebAuthn, тези модули са нужни.",
-    "It seems like you are running a 32-bit PHP version. Nextcloud 26 and higher require 64-bit. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "Изглежда, че използвате 32-битова PHP версия. Приложението Nextcloud 26 и по-новите версии изискват 64-битова версия. Моля, обновете операционната си система и PHP на 64-битова версия! За повече подробности прочетете {linkstart}страницата с документация за това {linkend}.",
+    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Изглежда, че използвате 32-битова PHP версия. Приложението Nextcloud се нуждае от 64 бита, за да работи добре. Моля, надстройте вашата операционна система и PHP до 64 бита! За повече подробности прочетете {linkstart}страницата с документация за това ↗{linkend}.",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Модулът php-imagick в този случай няма поддръжка на SVG. За по-добра съвместимост се препоръчва да го инсталирате.",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "В някои колони в базата данни липсва преобразуване в big int. Поради факта, че промяната на типовете колони в големи таблици може да отнеме известно време, те не се променят автоматично. Чрез стартиране на \"occ db:convert-filecache-bigint\", тези предстоящи промени могат да бъдат приложени ръчно. Тази операция трябва да се извърши, докато екземплярът е офлайн. За повече подробности прочетете {linkstart}страницата с документация за това ↗{linkend}.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Понастоящем SQLite се използва като вътрешна база данни. За по-големи инсталации ви препоръчваме да превключите към друг сървър на базата данни.",
@@ -116,7 +116,7 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Вероятно вашите данни и файлове са достъпни от интернет. .htaccess файлът не функционира. Силно се препоръчва да настроите уеб сървъра по такъв начин, че директорията за данни да не бъде достъпна или я преместете извън началната директория на уеб сървъра.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавката „{header}“ не е зададена на „{expected}“. Това е потенциален риск за сигурността или поверителността, като се препоръчва да настроите по подходящ начин тази настройка.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP заглавката „{header}“ не е зададена на „{expected}“. Някои функции може да не работят правилно, тъй като се препоръчва да настроите по подходящ начин тази настройка.",
-    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавката „{header}“ не съдържа „{expected}“. Това е потенциален риск за сигурността или поверителността, като се препоръчва да коригирате по подходящ начин тази настройка.",
+    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавката „{header}“ не съдържа „{expected}“. Това е потенциален риск за сигурността или поверителността, като се препоръчва да настроитепо подходящ начин тази настройка.",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTP заглавката \"{header}\" не е зададена на \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" или \"{val5}\". Това може да доведе до изтичане на референтна информация. Вижте {linkstart}препоръката на W3C ↗{linkend}.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "HTTP заглавката \"Strict-Transport-Security\" не е настроена на поне \"{seconds}\" секунди. За подобрена сигурност се препоръчва да активирате HSTS, както е описано в {linkstart}съветите за сигурност ↗{linkend}.",
     "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Достъпът до сайта е несигурен чрез HTTP. Силно ви препоръчваме да настроите сървъра си да изисква HTTPS вместо това, както е описано в {linkstart}съветите за сигурност ↗{linkend}. ",
@@ -147,7 +147,6 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "Опитайте отново или се свържете с администраотра.",
     "Account name or email" : "Име на профил или имейл",
     "Password" : "Парола",
-    "Log in to {productName}" : "Вписване в {productName}",
     "Wrong username or password." : "Грешен потребител или парола",
     "User disabled" : "Потребителят е деактивиран",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Открихме множество невалидни опити за влизане от вашия IP. Следователно следващото ви влизане се ограничава за 30 секунди.",
@@ -180,7 +179,8 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Бъдете с колегите и приятелите си на едно място, без да изтича тяхната лична информация.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Опростено приложение за електронна поща, добре интегрирано с файлове, контакти и календар.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Чат, видео разговори, споделяне на екрана, онлайн срещи и уеб конферентни връзки - във вашия браузър и с мобилни приложения.",
-    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Документи, електронни таблици и презентации за съвместна работа, създадени в Collabora Online.",
+    "Collaboratively edit office documents." : "Съвместно редактиране на офис документи.",
+    "Local document editing back-end used by the Collabora Online app." : "Местно фоново редактиране на документи, чрез използване на приложението Collabora Online.",
     "Forgot password?" : "Забравена парола?",
     "Log in with a device" : "Вписване с устройство",
     "Back" : "Назад",
@@ -202,11 +202,6 @@ OC.L10N.register(
     "Search" : "Търсене",
     "An error occurred while searching for {type}" : "Възникна грешка при търсенето на {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Моля, въведете {minSearchLength} знака или повече, за да търсите","Моля, въведете {minSearchLength} знака или повече, за да търсите"],
-    "This browser is not supported" : "Този браузър не се поддържа",
-    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Вашият браузър не се поддържа. Моля, преминете към по-нова версия или към версия, която се поддържа.",
-    "Continue with this unsupported browser" : "Продължете с този неподдържан браузър",
-    "Supported versions" : "Поддържани версии",
-    "{name} version {version} and above" : "{name} версия {version} и по-нови",
     "Search {types} …" : "Търсене на  {types}  ...",
     "Settings" : "Настройки",
     "Could not load your contacts" : "Контактите не могат да бъдат заредени",
@@ -279,8 +274,8 @@ OC.L10N.register(
     "No action available" : "Няма налични действия",
     "Error fetching contact actions" : "Грешка при извличането на действия за контакт",
     "Non-existing tag #{tag}" : "Несъществуващ етикет #{tag}",
-    "Restricted" : "Ограничен",
-    "Invisible" : "Невидим",
+    "restricted" : "ограничен",
+    "invisible" : "невидим",
     "Delete" : "Изтрий",
     "Rename" : "Преименувай",
     "Collaborative tags" : "Съвместни етикети",
@@ -294,8 +289,8 @@ OC.L10N.register(
     "Profile not found" : "Профилът не е намерен",
     "The profile does not exist." : "Профилът не съществува.",
     "Back to %s" : "Обратно към %s",
-    "Page not found" : "Страницата не е намерена",
-    "The page could not be found on the server." : "Страницата не е намерена на сървъра.",
+    "File not found" : "Файлът не е открит",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Документът не можа да бъде намерен на сървъра. Може би споделянето е изтрито или е изтекло?",
     "Too many requests" : "Твърде много заявки",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Имаше твърде много заявки от вашата мрежа. Опитайте отново по-късно или се свържете с вашия администратор, ако това е грешка.",
     "Error" : "Грешка",
@@ -346,11 +341,11 @@ OC.L10N.register(
     "Skip to main content" : "Преминаване към основното съдържание",
     "Skip to navigation of app" : "Преминаване към навигация на приложението",
     "Get your own free account" : "Вземете свой собствен безплатен профил",
+    "%s's homepage" : "%s's начална страница",
     "Contacts" : "Контакти",
     "Contacts menu" : "Контакти",
     "Open settings menu" : "Отваряне на меню за настройки",
     "Confirm your password" : "Потвърдете паролата си",
-    "%s's homepage" : "%s's начална страница",
     "Connect to your account" : "Свързване към вашия профил",
     "Please log in before granting %1$s access to your %2$s account." : "Необходимо е да се впишете, преди да дадете достъп на %1$s до вашия %2$s профил.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ако не се опитвате да настроите ново устройство или приложение, някой се опитва да ви подмами, за да му предоставите достъп до вашите данни. В този случай не продължавайте и вместо това се свържете със системния си администратор.",
@@ -402,27 +397,22 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "В момента се извършва профилактика на %s, може да продължи дълго.",
     "This page will refresh itself when the instance is available again." : "Страницата ще се зареди автоматично, когато е отново на линия.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Свържете се със системния администратор ако това съобщение се задържи твърде дълго или се е появило неочаквано.",
-    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Тази общностна версия на Nextcloud не се поддържа и незабавните известия не са налични.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Въведете абонаментния си ключ, за да увеличите потребителския си лимит. За повече информация относно Nextcloud Enterprise вижте нашия уеб сайт.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Проверяване на таблица %s",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Това е неподдържаната общностна версия на Nextcloud. Като се има предвид размера на този екземпляр, производителността, надеждността и мащабируемостта не могат да бъдат гарантирани. Push известията са деактивирани, за да се избегне претоварването на нашата безплатна услуга. Научете повече за предимствата на Nextcloud Enterprise на nextcloud.com/enterprise.",
-    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 е последното издание, поддържащо PHP 7.3. Nextcloud 24 изисква поне PHP 7.4.",
+    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Сървърът няма работеща интернет връзка: Множество крайни точки не могат да бъдат достигнати. Това означава, че някои от функциите като монтиране на външно хранилище, известия за актуализации или инсталиране на приложения на трети страни няма да работят. Достъпът до файлове от разстояние и изпращането на имейли с известия също може да не работят. Установете връзка от този сървър с Интернет, за да се насладите на всички функции.",
+    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 е последното издание, поддържащо PHP 7.2. Nextcloud 21 изисква поне PHP 7.3.",
+    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "Модулът PHca OPcache не е зареден. {linkstart}За по-добра производителност се препоръчва ↗{linkend} да го заредите във вашата PHP инсталация.",
+    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "Модулът PHca OPcache не е зареден. {linkstart}За по-добра производителност се препоръчва ↗{linkend} да използвате следните настройки в <code>PHP инсталация</code>:",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "В някои колони от базата данни липсва преобразуване в big int. Поради факта, че промяната на типовете колони в големи таблици може да отнеме известно време, те не се променят автоматично. Чрез стартиране на 'occ db:convert-filecache-bigint' тези чакащи промени могат да бъдат приложени ръчно. Тази операция трябва да се извърши, докато екземплярът е офлайн. За повече подробности прочетете {linkstart}страницата с документация за това ↗{linkend}. ",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "За да мигрирате към друга база данни, използвайте инструмента за команден ред: 'occ db: convert-type' или вижте  {linkstart}документацията ↗{linkend}.",
-    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавката „{header}“ не съдържа „{expected}“. Това е потенциален риск за сигурността или поверителността, като се препоръчва да настроитепо подходящ начин тази настройка.",
-    "Collaboratively edit office documents." : "Съвместно редактиране на офис документи.",
-    "Local document editing back-end used by the Collabora Online app." : "Местно фоново редактиране на документи, чрез използване на приложението Collabora Online.",
-    "You haven't added any info yet" : "Все още не сте добавили никаква информация",
-    "{user} hasn't added any info yet" : "{user} все още не е добавил никаква информация",
-    "restricted" : "ограничен",
-    "invisible" : "невидим",
-    "File not found" : "Файлът не е открит",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Документът не можа да бъде намерен на сървъра. Може би споделянето е изтрито или е изтекло?",
+    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Най-вероятно вашите данни и файлове са достъпни от интернет. .htaccess файлът не функционира. Силно се препоръчва да настроите уеб сървъра по такъв начин, че директорията за данни да не бъде достъпна или я преместете извън началната директория на уеб сървъра.",
     "More" : "Още",
     "More apps menu" : "Още от меню за приложения",
     "Settings menu" : "Настройки",
     "The password is wrong. Try again." : "Паролата е грешна. Опитайте отново.",
     "Setup two-factor authentication" : "Свържи двустепенно удостоверяване",
-    "It seems like you are running a 32-bit PHP version. Nextcloud 26 and higher require 64-bit. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Изглежда, че използвате 32-битова PHP версия. Приложението Nextcloud 26 и по-новите версии изискват 64-битова версия. Моля, обновете операционната си система и PHP на 64-битова версия! За повече подробности прочетете {linkstart}страницата с документация за това {linkend}."
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Тази общностна версия на Nextcloud не се поддържа и незабавните известия не са налични.",
+    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Това е неподдържаната общностна версия на Nextcloud. Като се има предвид размера на този екземпляр, производителността, надеждността и мащабируемостта не могат да бъдат гарантирани. Push известията са деактивирани, за да се избегне претоварването на нашата безплатна услуга. Научете повече за предимствата на Nextcloud Enterprise на nextcloud.com/enterprise.",
+    "You haven't added any info yet" : "Все още не сте добавили никаква информация",
+    "{user} hasn't added any info yet" : "{user} все още не е добавил никаква информация"
 },
 "nplurals=2; plural=(n != 1);");
