@@ -26,7 +26,6 @@ OC.L10N.register(
     "Invalid app password" : "Contraseña de la app no válida",
     "Could not complete login" : "No se ha podido completar el inicio de sesión",
     "Your login token is invalid or has expired" : "Tu token de login no es válido o ha caducado",
-    "This community release of Nextcloud is unsupported and push notifications are limited." : "Esta versión comunitaria de Nextcloud ya no está soportada y las notificaciones push son limitadas.",
     "Login" : "Iniciar sesión",
     "Password reset is disabled" : "El restablecimiento de la contraseña está deshabilitado",
     "Could not reset password because the token is expired" : "No se puede restablecer la contraseña porque el token de autenticación ha caducado.",
@@ -40,8 +39,7 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Algunos de tus enlaces compartidos han sido eliminados.",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Debido a un bug de seguridad hemos tenido que eliminar algunos de tus enlaces compartidos. Por favor, accede al link para más información.",
     "The user limit of this instance is reached." : "Se alcanzó el límite de usuarios de esta instancia.",
-    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Ingrese su clave de suscripción en la aplicación de soporte de manera de incrementar el límite de usuarios. Adicionalmente, esto le otorga todos los beneficios adicionales que ofrece Nextcloud Enterprise y es altamente recomendado para la operación dentro de empresas.",
-    "Learn more ↗" : "Saber más ↗",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Introduzca su clave de suscripción para aumentar el límite de usuarios. Para obtener más información sobre Nextcloud Enterprise, visite nuestro sitio web.",
     "Preparing update" : "Preparando la actualización",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Paso de reparación:",
@@ -79,11 +77,11 @@ OC.L10N.register(
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "La instalación no tiene establecida una región telefónica predeterminada. Esto es necesario para validar los números de teléfono en la configuración del perfil sin un código de país. Para permitir números sin código de país, por favor agregue \"default_phone_region\" con el respectivo {linkstart}código ISO 3166-1 ↗{linkend} de la región a su archivo de configuración.",
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "No se ha podido ejecutar el trabajo cron vía CLI. Han aparecido los siguientes errores técnicos:",
     "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "La última ejecución de los trabajos en segundo plano fue hace {relativeTime}. Parece que algo va mal. {linkstart}Compruebe la configuración de los trabajos en segundo plano ↗{linkend}.",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Esta es la versión comunitaria de Nextcloud. Dado el tamaño de esta instancia, no se puede garantizar el redimiento, fiabilidad o escalabilidad. Las notificaciones push están limitadas para evitar la sobrecarga de nuestro servicio gratuito. Obtenga más información sobre las ventajas de Nexcloud Enterprise en {linkstart}https://nextcloud.com/enterprise{linkend} ",
     "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Este servidor no tiene una conexión a Internet que funcione: No se pudieron alcanzar varios puntos finales. Esto significa que algunas de las funciones, como montar almacenamiento externo, notificaciones sobre actualizaciones o instalación de aplicaciones de terceros no funcionarán. Es posible que el acceso a archivos de forma remota y el envío de emails de notificación tampoco funcionen. Establezca una conexión desde este servidor a Internet para disfrutar de todas las funciones.",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "La memoria caché no ha sido configurada. Para mejorar el rendimiento, por favor, configure memcache si está disponible. Puede encontrar más información en la {linkstart}documentación ↗{linkend}.",
     "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "No se ha encontrado una fuente de aleatoriedad en PHP, lo que se desaconseja por razones de seguridad. Puede encontrar más información en la {linkstart}documentación ↗{linkend}.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Actualmente está ejecutando PHP {version}. Actualize la versión de PHP para beneficiarse de las  {linkstart}actualizaciones de rendimiento y seguridad que aporta PHP Group ↗{linkend} en cuanto su distribución lo soporte.",
+    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 es la última versión compatible con PHP 7.3. Nextcloud 24 requiere al menos PHP 7.4.",
     "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "La configuración de la cabecera del proxy reverso no es correcta o está accediendo a Nextcloud desde un proxy de confianza. Si no, esto es un problema de seguridad y podría permitir a un ataccante a disfrazar su dirección IP como visible para Nextcloud. Se puede encontrar más información en la {linkstart}documentación ↗{linkend}.",
     "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached está configurado como una caché distribuida, pero se ha instalado el módulo equivocado de PHP \"memcache\". \\OC\\Memcache\\Memcached solo soporta \"memcached\" y no \"memcache\". Comprueba la {linkstart}wiki de memcached wiki acerca de ambos módulos ↗{linkend}.",
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Algunos archivos no han pasado la comprobación de integridad. Puede encontrar más información sobre cómo resolver este problema en la {linkstart1}documentacióarchivosn ↗{linkend}. ({linkstart2}Lista de archivos no válidos…{linkend} / {linkstart3}Rescanear…{linkend})",
@@ -99,7 +97,6 @@ OC.L10N.register(
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "A esta instancia le faltan algunos módulos PHP recomendados. Para mejorar el rendimiento y aumentar la compatibilidad, se recomienda encarecidamente instalarlos.",
     "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "El módulo PHP \"imagick\" no está habilitado, y la aplicación Temas sí lo está. Para que la generación de favicon funcione correctamente, es necesario instalar y habilitar este módulo.",
     "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "Los módulos PHP \"gmp\" y/o \"bcmath\" no están habilitados. Si usas la autenticación sin contraseña WebAuthn, estos módulos son necesarios.",
-    "It seems like you are running a 32-bit PHP version. Nextcloud 26 and higher require 64-bit. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "Parece que está ejecutando una versión de PHP de 32 bits. Nextcloud 26 y superiores requieren 64 bits.  ¡Por favor, actualice su sistema operativo y PHP a 64 bits! Puede leer más detalles en {linkstart}la página de documentación correspondiente ↗{linkend}.",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "El módulo php-imagick de esta instancia no tiene soporte para SVG. Para una mejor compatibilidad es recomendable instalarlo.",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "A algunas columnas de la base de datos les falta convertirse a \"big int\". Debido a que cambiar los tipos de columna en tablas grandes podría tardar mucho tiempo no fueron cambiadas automáticamente. Ejecutando 'occ db:convert-filecache-bigint'  se pueden aplicar estos cambios pendientes de manera manual. Esta operación debe realizarse cuando el servidor esté sin conexión. Para más detalles, consulte {linkstart}la página de documentación ↗{linkend}.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Actualmente se está usando SQLite como base de datos. Para instalaciones más largas recomendamos cambiar a un motor de bases de datos diferente.",
@@ -116,7 +113,7 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Tu directorio de datos y tus archivos probablemente sean accesibles desde internet. El archivo .htaccess no funciona. Es muy recomendable que configures tu servidor web de tal manera que el directorio de datos no sea accesible, o que lo muevas fuera de la raíz de documentos del servidor web.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "La cabecera HTTP \"{header}\" no está configurada como \"{expected}\". Esto es un riesgo potencial de seguridad o privacidad, y se recomienda ajustar esta configuración de forma adecuada.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "La cabecera HTTP \"{header}\" no está configurada como \"{expected}\". Algunas características podrían no funcionar correctamente, por lo que se recomienda ajustar esta configuración.",
-    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "La cabecera HTTP \"{header}\" no contiene \"{expected}\". \nEste es un riesgo potencial de seguridad o privacidad, por lo que se recomienda ajustar esta configuración.",
+    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "La cabecera HTTP \"{header}\" no contiene \"{expected}\". \nEste es un riesgo potencial de seguridad o privacidad, por lo que se recomienda ajustar esta configuración.",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "La cabecera HTTP \"{header}\" no está configurada a \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" o \"{val5}\". Esto puede filtrar información de la página de procedencia. Compruebe las {linkstart}Recomendaciones de W3C ↗{linkend}.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "La cabecera HTTP \"Strict-Transport-Security\" no está configurada al menos a \"{seconds}\" segundos. Para mejorar la seguridad  se recomienda habilitar HSTS como se describe en los {linkstart}consejos de seguridad ↗{linkend}.",
     "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Se está accediendo al sitio de manera insegura mediante HTTP. Se recomienda encarecidamente que configure su servidor para que requiera HTTPS, como se describe en los {linkstart}consejos de seguridad ↗{linkend}.",
@@ -137,17 +134,13 @@ OC.L10N.register(
     "Continue to {productName}" : "Continuar a {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["La actualización ha terminado con éxito. Redirigiendo a su {productName} en %n segundo. ","La actualización ha terminado con éxito. Redirigiendo a su {productName} en %n segundos. ","La actualización ha terminado con éxito. Redirigiendo a su {productName} en %n segundos. "],
     "More apps" : "Más aplicaciones",
-    "Currently open" : "Actualmente abierto",
-    "_{count} notification_::_{count} notifications_" : ["{count} notificación","{count} notificaciones","{count} notificaciones"],
     "Log in" : "Iniciar sesión",
     "Logging in …" : "Iniciando sesión ...",
     "Server side authentication failed!" : "La autenticación ha fallado en el servidor.",
     "Please contact your administrator." : "Por favor, contacte con el administrador.",
     "An internal error occurred." : "Ha habido un error interno.",
     "Please try again or contact your administrator." : "Por favor reintente nuevamente o contáctese con su administrador.",
-    "Account name or email" : "Nombre de cuenta o correo electrónico",
     "Password" : "Contraseña",
-    "Log in to {productName}" : "Ingrese a {productName}",
     "Wrong username or password." : "Usuario o contraseña erróneos.",
     "User disabled" : "Usuario deshabilitado",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Hemos detectado múltiples intentos inválidos desde tu IP. Por tanto, tu próximo intento se retrasará 30 segundos.",
@@ -180,7 +173,8 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Mantenga a sus colegas y amigos en un sólo sitio sin dejar escapar su información privada.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Simple email app se integra bien con Archivos, Contactos y Calendario.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Mensajes, videollamadas, compartir pantalla, reuniones online y conferencias web – en tu navegador y con apps móviles.",
-    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documentos colaborativos, hojas de cálculo y presentaciones, basadas en Collabora Online.",
+    "Collaboratively edit office documents." : "Edición colaborativa de documentos Office",
+    "Local document editing back-end used by the Collabora Online app." : "Motor (back-end) del editor de documentos usado por la app Collabora Online.",
     "Forgot password?" : "¿Contraseña olvidada?",
     "Log in with a device" : "Iniciar sesión con dispositivo",
     "Back" : "Atrás",
@@ -190,7 +184,6 @@ OC.L10N.register(
     "You have not added any info yet" : "Aún no has añadido nada de información",
     "{user} has not added any info yet" : "{user} no ha añadido aún nada de información",
     "Error opening the user status modal, try hard refreshing the page" : "Error al abrir la ventana de estado del usuario, intente actualizar la página",
-    "Search starts once you start typing" : "La búsqueda comenzará cuando comience a escribir",
     "Reset search" : "Resetear búsqueda",
     "Start search" : "Iniciar búsqueda",
     "Search for {name} only" : "Buscar solo por {name}",
@@ -202,11 +195,6 @@ OC.L10N.register(
     "Search" : "Buscar",
     "An error occurred while searching for {type}" : "Ha ocurrido un error al buscar {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Por favor, introduce {minSearchLength} carácter o más para buscar","Por favor, introduce {minSearchLength} caracteres o más para buscar","Por favor, introduce {minSearchLength} caracteres o más para buscar"],
-    "This browser is not supported" : "Este navegador no está soportado",
-    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Su navegador no está soportado. Por favor actualice a una versión nueva o a uno soportado.",
-    "Continue with this unsupported browser" : "Continuar con este navegador no soportado",
-    "Supported versions" : "Versiones soportadas",
-    "{name} version {version} and above" : "{name} versión {version} y superior",
     "Search {types} …" : "Buscar {types}…",
     "Settings" : "Configuraciones",
     "Could not load your contacts" : "No se han podido cargar los contactos",
@@ -279,8 +267,8 @@ OC.L10N.register(
     "No action available" : "No hay acciones disponibles",
     "Error fetching contact actions" : "Error recuperando las acciones de los contactos",
     "Non-existing tag #{tag}" : "Categoría #{tag} no existente",
-    "Restricted" : "Restringido",
-    "Invisible" : "Invisible",
+    "restricted" : "Restringido",
+    "invisible" : "invisible",
     "Delete" : "Eliminar",
     "Rename" : "Renombrar",
     "Collaborative tags" : "Etiquetas colaborativas",
@@ -294,8 +282,8 @@ OC.L10N.register(
     "Profile not found" : "Perfil no encontrado",
     "The profile does not exist." : "El perfil no existe.",
     "Back to %s" : "Volver a %s",
-    "Page not found" : "Página no encontrada",
-    "The page could not be found on the server." : "La página no se ha encontrado en el servidor.",
+    "File not found" : "Archivo no encontrado",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "El documento no se pudo encontrar en el servidor. Es posible que el enlace fuera eliminado o haya caducado.",
     "Too many requests" : "Demasiadas peticiones",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Hubo demasiadas peticiones desde su red. Vuelva a intentarlo más tarde o póngase en contacto con su administrador si se trata de un error.",
     "Error" : "Error",
@@ -346,11 +334,10 @@ OC.L10N.register(
     "Skip to main content" : "Saltar al contenido principal",
     "Skip to navigation of app" : "Saltar a la navegación de la app",
     "Get your own free account" : "Consigue tu propia cuenta gratuita",
+    "%s's homepage" : "%s página de inicio",
     "Contacts" : "Contactos",
     "Contacts menu" : "Menú de contactos",
-    "Open settings menu" : "Abrir menú de ajustes",
     "Confirm your password" : "Confirme su contraseña",
-    "%s's homepage" : "%s página de inicio",
     "Connect to your account" : "Conectar a cuenta",
     "Please log in before granting %1$s access to your %2$s account." : "Por favor, inicia sesión antes de conceder a %1$s acceso a tu cuenta %2$s.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si no estás intentando añadir un nuevo dispositivo o una nueva app, alguien está intentando engañarte para que proporciones acceso a tus datos. En este caso, no prosigas y en su lugar avisa a tu administrador de sistemas.",
@@ -402,27 +389,22 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Está instancia %s está en modo mantenimiento, y puede tardar un rato.",
     "This page will refresh itself when the instance is available again." : "Esta página se actualizará sola cuando la instancia esté disponible de nuevo.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte con su administrador de sistemas si este mensaje persiste o aparece de forma inesperada.",
-    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "El lanzamiento de esta versión para la comunidad de Nextcloud no cuenta con soporte y las notificaciones instantáneas no están disponibles.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Introduzca su clave de suscripción para aumentar el límite de usuarios. Para obtener más información sobre Nextcloud Enterprise, visite nuestro sitio web.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Zona de comprobación %s",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Esta es la versión para la comunidad, sin soportede Nextcloud. Dado el tamaño de esta instancia, no se puede garantizar el rendimiento, la fiabilidad y la escalabilidad. Las notificaciones Push han sido desactivadas para evitar sobrecargas en nuestro servicio gratuito. Más información sobre las ventajas de Nextcloud Enterprise en nextcloud.com/enterprise.",
-    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 es la última versión compatible con PHP 7.3. Nextcloud 24 requiere al menos PHP 7.4.",
+    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "El servidor no tiene conexión a internet: no se ha podido alcanzar múltiples puntos finales. Esto significa que algunas de las características, como montar almacenamientos externos, notificaciones sobre actualizaciones o instalación de apps de terceras partes no funcionarán. Acceder remotamente a los archivos y enviar correos de notificación tampoco funcionará. Debes establecer una conexión del servidor a internet para disfrutar todas las características.",
+    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 es la última versión que soporta PHP 7.2. Nextcloud 21 requiere al menos PHP 7.3.",
+    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "El módulo OPcache de PHP no está cargado. {linkstart}Para mejorar el rendimiento se recomienda ↗{linkend} cargarlo en su instalación de PHP.",
+    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "El módulo OPcache de PHP no está bien configurado. {linkstart}Para mejorar el rendimiento se recomienda ↗{linkend} usar las siguientes configuraciones en el </code>php.ini</code>:",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "A algunas columnas de la base de datos les falta convertirse a \"big int\". Debido a que cambiar los tipos de columna en tablas grandes podría tardar mucho tiempo no fueron cambiadas automáticamente. Ejecutando 'occ db:convert-filecache-bigint'  se pueden aplicar estos cambios pendientes de manera manual. Esta operación debe realizarse cuando el servidor esté sin conexión. Para más detalles, consulte {linkstart}la página de documentación ↗{linkend}.",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "Para migrar a otra base de datos use la herramienta de línea de comandos (CLI): 'occ db:convert-type', o revise la {linkstart}documentación ↗{linkend}.",
-    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "La cabecera HTTP \"{header}\" no contiene \"{expected}\". \nEste es un riesgo potencial de seguridad o privacidad, por lo que se recomienda ajustar esta configuración.",
-    "Collaboratively edit office documents." : "Edición colaborativa de documentos Office",
-    "Local document editing back-end used by the Collabora Online app." : "Motor (back-end) del editor de documentos usado por la app Collabora Online.",
-    "You haven't added any info yet" : "Aún no has añadido ninguna información",
-    "{user} hasn't added any info yet" : "{user} no ha añadido aún ninguna información",
-    "restricted" : "Restringido",
-    "invisible" : "invisible",
-    "File not found" : "Archivo no encontrado",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "El documento no se pudo encontrar en el servidor. Es posible que el enlace fuera eliminado o haya caducado.",
+    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Tu directorio de datos y tus archivos son probablemente accesibles desde internet. El archivo .htaccess no funciona. Se recomienda encarecidamente que configures tu servidor web de tal manera que el directorio de datos no sea accesible, o que lo muevas fuera de la raíz de documentos del servidor web.",
     "More" : "Más",
     "More apps menu" : "Menú de otras apps",
     "Settings menu" : "Menú de configuraciones",
     "The password is wrong. Try again." : "La contraseña es incorrecta. Vuelve a intentarlo.",
     "Setup two-factor authentication" : "Configurar autenticación de dos factores",
-    "It seems like you are running a 32-bit PHP version. Nextcloud 26 and higher require 64-bit. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Parece que está ejecutando una versión de PHP de 32 bits. Nextcloud 26 y superiores necesitan 64 bits.  ¡Por favor, actualice su sistema operativo y PHP a 64 bits! Puede leer más detalles en {linkstart}la página de documentación correspondiente ↗{linkend}."
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "El lanzamiento de esta versión para la comunidad de Nextcloud no cuenta con soporte y las notificaciones instantáneas no están disponibles.",
+    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Esta es la versión para la comunidad, sin soportede Nextcloud. Dado el tamaño de esta instancia, no se puede garantizar el rendimiento, la fiabilidad y la escalabilidad. Las notificaciones Push han sido desactivadas para evitar sobrecargas en nuestro servicio gratuito. Más información sobre las ventajas de Nextcloud Enterprise en nextcloud.com/enterprise.",
+    "You haven't added any info yet" : "Aún no has añadido ninguna información",
+    "{user} hasn't added any info yet" : "{user} no ha añadido aún ninguna información"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
