@@ -26,7 +26,6 @@ OC.L10N.register(
     "Invalid app password" : "Aplikazio pasahitza baliogabea",
     "Could not complete login" : "Ezin izan da saioa hasi",
     "Your login token is invalid or has expired" : "Zure saio-hasierako tokena baliogabea da edo iraungi da",
-    "This community release of Nextcloud is unsupported and push notifications are limited." : "Nextcloud komunitate bertsio honek ez du laguntza-zerbitzurik eta push jakinarazpenak mugatuta daude.",
     "Login" : "Hasi saioa",
     "Password reset is disabled" : "Pasahitza berrezartzea desgaituta dago",
     "Could not reset password because the token is expired" : "Ezin izan da pasahitza berrezarri tokena iraungi delako",
@@ -40,8 +39,7 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Zure esteka partekatzeetako batzuk kendu dira",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Segurtasun errore baten ondorioz zure esteka partekatze batzuk kendu ditugu. Ikusi esteka informazio gehiagorako.",
     "The user limit of this instance is reached." : "Instantzia honen erabiltzaile mugara iritsi da.",
-    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Sartu zure harpidetza-gakoa laguntza-aplikazioan erabiltzaileen muga handitzeko. Horrek Nextcloud Enterprise-k eskaintzen dituen abantaila gehigarri guztiak ere ematen dizkizu eta oso gomendagarria da enpresetan funtzionatzeko.",
-    "Learn more ↗" : "Ikasi gehiago ↗",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Sartu zure harpidetza-gakoa erabiltzaile muga goratzeko. Nextcloud Enterprise-ri buruzko informazio gehiagorako ikusi gure webgunea.",
     "Preparing update" : "Eguneratzea prestatzen",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Konponketa pausoa:",
@@ -79,11 +77,11 @@ OC.L10N.register(
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Zure instalazioak ez du telefono eskualde lehenetsirik ezarrita. Hori beharrezkoa da baliozkotzeko profilaren ezarpenetan herrialde koderik gabeko telefono zenbakiak.  Herrialde koderik gabeko zenbakiak onartzeko, gehitu \"default_phone_region\" dagokion eskualdeko {linkstart} ISO 3166-1 kodea ↗ {linkend} zure konfigurazio fitxategian.",
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Ezin izan da cron lana komando lerro bidez exekutatu. Ondorengo errore teknikoak gertatu dira:",
     "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Azken atzeko planaren exekuzioa {relativeTime} exekutatu da. Badirudi zerbait gaizki dagoela. {linkstart} Egiaztatu atzeko planoko ezarpenak ↗ {linkend}.",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Hau laguntzarik gabeko Nextcloud komunitate bertsioa da. Instantzia honen tamaina kontuan hartuz, ezin da errendimendua, fidagarritasuna eta eskalabilitatea ziurtatu. Push jakinarazpenak mugatu egin dira gure doako zerbitzua ez gainkargatzeko. Ikusi Nextcloud Enterprise buruzko abantailak {linkstart}https://nextcloud.com/enterprise{linkend} orrian.",
     "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Zerbitzari honek ez dauka Interneteko konexiorik: hainbat amaiera-puntu ezin izan dira atzitu. Horren ondorioz, hainbat ezaugarrik ez dute funtzionatuko, hala nola, kanpoko biltegiratzeak muntatzeak, eguneraketei buruzko jakinarazpenak edo hirugarrengoen aplikazioak. Urruneko fitxategiak atzitzeak eta posta elektroniko bidezko jakinarazpenek ere ez dute funtzionatuko. Ezarri Interneterako konexioa zerbitzari honetan ezaugarri horiek izateko.",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Ez da memoria cachea konfiguratu. Errendimendua hobetzeko, konfiguratu memcache bat, erabilgarri badago. Informazio gehiago aurki dezakezu {linkstart} dokumentazioan ↗ {linkend}.",
     "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "PHP-k ez du aurkitu iturri egokirik ausazkotasunerako, segurtasun arrazoiengatik oso gomendagarria dena. Informazio gehiago aurki dezakezu {linkstart} dokumentazioan ↗ {linkend}.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Une honetan PHP {version} exekutatzen ari zara. Bertsio-berritu zure PHP bertsioa PHP Group-ek link {linkend} eskaintzen dituen {linkstart} errendimendu eta segurtasun eguneratzeak aprobetxatzeko zure banaketak onartu bezain laster.",
+    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 da PHP 7.3 onartzen duen azken bertsioa. Nextcloud 24 PHP 7.4 behar du gutxienez.",
     "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Alderantzizko proxy goiburuko konfigurazioa okerra da, edo Nextcloud-era proxy fidagarri batetik sartzen ari zara. Hala ez bada, segurtasun arazo bat bada eta erasotzaile batek Nextcloud-en ikusgai dagoen IP helbidea faltsutzea baimendu dezake. Informazio gehiago aurkitu daiteke {linkstart} dokumentazioan ↗ {linkend}.",
     "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached banatutako cache gisa konfiguratuta dago, baina \"memcache\" PHP modulu okerra dago instalatuta. \\ OC \\ Memcache \\ Memcached-ek \"memcached\" soilik onartzen du eta ez \"memcache\". Ikusi bi moduluei buruzko {linkstart} memcached wikia ↗{linkend}.",
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Zenbait fitxategik ez dute integritate egiaztapena gainditu. Arazo hau konpontzeko moduari buruzko informazio gehiago aurki daiteke {linkstart1} dokumentazioan ↗ {linkend}. ({linkstart2} Baliogabeko fitxategien zerrenda...{linkend} / {linkstart3} Eskaneatu berriro...{linkend})",
@@ -99,7 +97,6 @@ OC.L10N.register(
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Instantzia honek gomendatutako PHP modulu batzuk falta ditu. Biziki gomendatzen da horiek instalatzea, errendimendua eta bateragarritasuna hobetzeko.",
     "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "\"Imagick\" PHP modulua  ez dago gaituta, gaikako aplikazioa badago ere. Faviconen sorrerak behar bezala funtziona dezan, modulu hau instalatu eta gaitu behar duzu.",
     "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "\"gmp\" eta/edo \"bcmath\" PHP moduluak ez daude gaituta. WebAuthn pasahitz gabeko autentifikazioa erabiltzen baduzu, modulu hauek beharrezkoak dira.",
-    "It seems like you are running a 32-bit PHP version. Nextcloud 26 and higher require 64-bit. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "32 biteko PHP bertsioa exekutatzen ari zarela dirudi. Nextcloud 26k eta berriagoek 64 bitekoa behar dute. Mesedez, eguneratu zure OS eta PHPa 64 bitekora! Xehetasun gehiago lortzeko, irakurri honi buruzko {linkstart}dokumentazio orria {linkend}.",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Module php-imagick-ek ez du SVG onartzen instantzia honetan. Bateragarritasuna hobetzeko instalatzea gomendatzen da.",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Datu baseko zutabe batzuek big int bihurtzea falta dute. Taula handietan zutabe motak aldatzeak denbora dezente har dezakeenez ez dira automatikoki aldatu. 'Occ db: convert-filecache-bigint' exekutatuz zain dauden aldaketak eskuz aplika litezke. Eragiketa hau instantzia lineaz kanpo dagoen bitartean egin behar da. Xehetasun gehiagorako, irakurri {linkstart} honi buruzko dokumentazio orria ↗{linkend}.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite datu-basea erabiltzen ari zara. Instalazio handiagoetarako beste datu-base sistema bat erabiltzea gomendatzen da.",
@@ -116,7 +113,7 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Zure datuen direktorioa eta fitxategiak Internetetik atzitu daitezke. .htaccess fitxategiak ez du funtzionatzen. Biziki gomendatzen da  web zerbitzariaren konfigurazioa aldatzea datuen direktorioa atzigarri egon ez dadin edo datuen direktorioa web zerbitzariaren dokumentu errotik kanpora ateratzea.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP goiburua ez dago \"{expected}\" baliora ezarria. Hau segurtasun edo pribatutasun arrisku bat izan daiteke. Ezarpenean dagokion balioa jartzea gomendatzen da.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP goiburua ez dago \"{expected}\" baliora ezarria. Baliteke ezaugarri batzuk espero bezala ez funtzionatzea. Ezarpenean dagokion balioa jartzea gomendatzen da.",
-    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{expected}\" ez dago \"{header}\" HTTP goiburuaren barnean. Hau segurtasun edo pribatutasun arrisku bat izan daiteke. Ezarpenean dagokion balioa jartzea gomendatzen da.",
+    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{expected}\" ez dago \"{header}\" HTTP goiburuaren barnean. Hau segurtasun edo pribatutasun arrisku bat izan daiteke. Ezarpenean dagokion balioa jartzea gomendatzen da.",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "\"{Header}\" HTTP goiburua ez dago \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" edo \"{val5}\" gisa ezarrita. Horrek aipamenen informazioa isuri dezake. Ikusi {linkstart} W3C gomendioa ↗ {linkend}.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "\"Strict-Transport-Security\" HTTP goiburua ez dago gutxienez \"{segundo}\" segundotan ezarrita. Segurtasuna hobetzeko, HSTS gaitzea gomendatzen da {linkstart} segurtasun aholkuak ↗ {linkend} atalean azaltzen den moduan.",
     "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Gunera HTTP bidez modu ez-seguruan sartzen ari zara. Zure zerbitzaria derrigorrez HTTPS erabiltzeko konfiguratzea gomendatzen da biziki, {linkstart} segurtasun aholkuak ↗ {linkend} atalean azaltzen den moduan.",
@@ -137,17 +134,13 @@ OC.L10N.register(
     "Continue to {productName}" : "Jarraitu hona: {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Eguneraketa behar bezala egin da. {ProductName} ra birbideratuko zaitugu %nsegundotan.","Eguneraketa behar bezala egin da. {ProductName} ra birbideratuko zaitugu %n segundotan."],
     "More apps" : "Aplikazio gehiago",
-    "Currently open" : "Unean irekita",
-    "_{count} notification_::_{count} notifications_" : ["Jakinarazpen {count}","{count} jakinarazpen"],
     "Log in" : "Hasi saioa",
     "Logging in …" : "Saioa hasten...",
     "Server side authentication failed!" : "Zerbitzari aldeko autentifikazioak huts egin du!",
     "Please contact your administrator." : "Mesedez jarri harremanetan zure administratzailearekin.",
     "An internal error occurred." : "Barne-errore bat gertatu da.",
     "Please try again or contact your administrator." : "Saiatu berriro edo jarri harremanetan administratzailearekin.",
-    "Account name or email" : "Kontu izena edo emaila",
     "Password" : "Pasahitza",
-    "Log in to {productName}" : "Hasi saioa {productName} -n",
     "Wrong username or password." : "Erabiltzaile-izen edo pasahitz okerra.",
     "User disabled" : "Erabiltzailea desgaituta",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Saioa hasteko hainbat saiakera baliogabe jaso ditugu zure IPtik. Ondorioz, zure hurrengo saio hasiera 30 segundo atzeratuko da.",
@@ -180,7 +173,8 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Eduki zure lankide eta lagun guztiak leku bakarrean, beren informazioa pribatu mantenduz.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Fitxategiak, Kontaktuak eta Egutegiarekin integratutako posta elektronikoko aplikazio soila.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Txata, bideo-deiak, pantaila partekatzea, lineako bilerak eta web konferentziak - zure nabigatzailean eta mugikorrerako aplikazioekin.",
-    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Dokumentu, kalkulu-orri eta aurkezpen kolaboratiboak, Collabora Online-en sortuak.",
+    "Collaboratively edit office documents." : "Editatu bulegoko dokumentuak elkarlanean.",
+    "Local document editing back-end used by the Collabora Online app." : "Colabora Online aplikazioak dokumentu lokalak editatzeko erabiltzen duen atzealdekoa. ",
     "Forgot password?" : "Pasahitza ahaztu duzu?",
     "Log in with a device" : "Hasi saioa gailu batekin",
     "Back" : "Atzera",
@@ -190,7 +184,6 @@ OC.L10N.register(
     "You have not added any info yet" : "Oraindik ez duzu informaziorik gehitu",
     "{user} has not added any info yet" : "{user} -ek ez du oraindik informaziorik gehitu",
     "Error opening the user status modal, try hard refreshing the page" : "Errorea erabiltzailen egoera leihoa irekitzen, saiatu orria guztiz freskatzen",
-    "Search starts once you start typing" : "Idaztean hasten da bilaketarekin",
     "Reset search" : "Berrezarri bilaketa",
     "Start search" : "Hasi bilaketa",
     "Search for {name} only" : "Biatu {name} bakarrik",
@@ -202,11 +195,6 @@ OC.L10N.register(
     "Search" : "Bilatu",
     "An error occurred while searching for {type}" : "Errorea gertatu da {type} bilatzean",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Sartu karaktere {minSearchLength} edo gehiago bilatzeko","Sartu {minSearchLength} karaktere edo gehiago bilatzeko"],
-    "This browser is not supported" : "Nabigatzaile hau ez da onartzen",
-    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Zure nabigatzailea ez da onartzen. Mesedez, eguneratu bertsio berriago batera edo onartzen den batera.",
-    "Continue with this unsupported browser" : "Jarraitu onartzen ez duen arakatzaile honekin",
-    "Supported versions" : "Onartutako bertsioak",
-    "{name} version {version} and above" : "{name} {bertsioa} bertsioa eta gorago",
     "Search {types} …" : "Bilatu  {types} …",
     "Settings" : "Ezarpenak",
     "Could not load your contacts" : "Ezin izan dira zure kontaktuak kargatu",
@@ -279,8 +267,8 @@ OC.L10N.register(
     "No action available" : "Ez dago ekintzarik eskuragarri",
     "Error fetching contact actions" : "Errorea kontaktu-ekintzak eskuratzean",
     "Non-existing tag #{tag}" : "#{tag} ez da existitzen",
-    "Restricted" : "Mugatua",
-    "Invisible" : "Ikusezina",
+    "restricted" : "mugatua",
+    "invisible" : "ikusezina",
     "Delete" : "Ezabatu",
     "Rename" : "Berrizendatu",
     "Collaborative tags" : "Elkarlaneko etiketak",
@@ -294,8 +282,8 @@ OC.L10N.register(
     "Profile not found" : "Profila ez da aurkitu",
     "The profile does not exist." : "Profila ez da existitzen",
     "Back to %s" : "Itzuli %s(e)ra",
-    "Page not found" : "Orria ez da aurkitu",
-    "The page could not be found on the server." : "Orria ez da zerbitzarian aurkitu.",
+    "File not found" : "Ez da fitxategia aurkitu",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Dokumentua ezin izan da aurkitu zerbitzarian. Agian partekatutakoa ezabatua izan da ala iraungitu egin da?",
     "Too many requests" : "Eskaera gehiegi",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Eskaera gehiegi zeuden zure saretik. Saiatu beranduago edo kontaktatu zure administrailearekin errorerik balego",
     "Error" : "Errorea",
@@ -346,11 +334,11 @@ OC.L10N.register(
     "Skip to main content" : "Salto eduki nagusira",
     "Skip to navigation of app" : "Salto aplikazioaren nabigaziora",
     "Get your own free account" : "Eskuratu zure kontu propioa doan",
+    "%s's homepage" : "%s-(r)en hasiera orria",
     "Contacts" : "Kontaktuak",
     "Contacts menu" : "Kontaktuen menua",
     "Open settings menu" : "Ireki ezarpenen menua",
     "Confirm your password" : "Berretsi pasahitza",
-    "%s's homepage" : "%s-(r)en hasiera orria",
     "Connect to your account" : "Konektatu zure kontura",
     "Please log in before granting %1$s access to your %2$s account." : "Hasi saioa %1$s erabiltzaileari zure %2$s kontura sarbidea eman aurretik.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Gailu edo aplikazio berri bat konfiguratzen saiatzen ari ez bazara, norbaitek zure datuetarako sarbidea eman diezaiozun, zu engainatzen saiatzen ari da. Kasu horretan, jarraitu ordez jarri harremanetan sistemaren administratzailearekin.",
@@ -402,27 +390,22 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "%s instantzia hau mantenu-moduan dago une honetan, honek denbora tarte bat iraun dezake.",
     "This page will refresh itself when the instance is available again." : "Instantzia berriz ere erabilgarri dagoenean orri hau freskatuko da.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Jarri harremanetan zure sistema administratzailearekin mezu honek irauten badu edo ezustean agertu bada.",
-    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Nextcloud komunitate bertsio honek ez du laguntza-zerbitzurik eta berehalako jakinarazpenak ez daude eskuragarri.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Sartu zure harpidetza-gakoa erabiltzaile muga goratzeko. Nextcloud Enterprise-ri buruzko informazio gehiagorako ikusi gure webgunea.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Taula egiaztatzen %s",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Hau laguntzarik gabeko Nextcloud komunitate bertsioa da. Instantzia honen tamaina kontuan hartuz, ezin da errendimendua, fidagarritasuna eta eskalabilitatea ziurtatu. Push jakinarazpenak desgaitu egin dira gure doako zerbitzua ez gainkargatzeko. Ikusi Nextcloud Enterprise buruzko abantailak nextcloud.com/enterprise orrian.",
-    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 da PHP 7.3 onartzen duen azken bertsioa. Nextcloud 24 PHP 7.4 behar du gutxienez.",
+    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Zerbitzari honek ez dauka Interneteko konexiorik: hainbat amaiera-puntu ezin izan dira atzitu. Horren ondorioz, hainbat ezaugarrik ez dute funtzionatuko, hala nola, kanpoko biltegiratzeak muntatzeak, eguneraketei buruzko jakinarazpenak edo hirugarrengoen aplikazioak. Urruneko fitxategiak atzitzeak eta posta elektroniko bidezko jakinarazpenek ere ez dute funtzionatuko. Ezarri Interneterako konexioa zerbitzari honetan ezaugarri horiek izateko.",
+    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 da PHP 7.2rekin erabili daitekeen azken bertsioa. Nextcloud 21 erabiltzeko gutxienez PHP 7.3 behar da.",
+    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "PHP OPcache modulua ez dago kargatuta. {linkstart} Errendimendu hobea lortzeko, zure PHP instalazioan kargatzea gomendatzen da ↗{linked}.",
+    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "PHP OPcache modulua ez dago behar bezala konfiguratuta. {linkstart} Errendimendu hobea lortzeko, ezarpen hauek erabiltzea gomendatzen da ↗ {linkend} ezarpen hauek <code>php.ini</code>-n erabiltzeko:",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Datu baseko zutabe batzuek big int bihurtzea falta dute. Taula handietan zutabe motak aldatzeak denbora dezente har dezakeenez ez dira automatikoki aldatu. 'Occ db: convert-filecache-bigint' exekutatuz zain dauden aldaketak eskuz aplika litezke. Eragiketa hau instantzia lineaz kanpo dagoen bitartean egin behar da. Xehetasun gehiagorako, irakurri {linkstart} honi buruzko dokumentazio orria ↗{linkend}.",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "Beste datu-base batera migratzeko, erabili komando-lerroko tresna hau: 'occ db: convert-type', edo ikusi {linkstart} dokumentazioa ↗ {linkend}.",
-    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{expected}\" ez dago \"{header}\" HTTP goiburuaren barnean. Hau segurtasun edo pribatutasun arrisku bat izan daiteke. Ezarpenean dagokion balioa jartzea gomendatzen da.",
-    "Collaboratively edit office documents." : "Editatu bulegoko dokumentuak elkarlanean.",
-    "Local document editing back-end used by the Collabora Online app." : "Colabora Online aplikazioak dokumentu lokalak editatzeko erabiltzen duen atzealdekoa. ",
-    "You haven't added any info yet" : "Ez duzu informaziorik gehitu oraindik",
-    "{user} hasn't added any info yet" : "{user} ez du informaziorik gehitu oraindik",
-    "restricted" : "mugatua",
-    "invisible" : "ikusezina",
-    "File not found" : "Ez da fitxategia aurkitu",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Dokumentua ezin izan da aurkitu zerbitzarian. Agian partekatutakoa ezabatua izan da ala iraungitu egin da?",
+    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Zure datuen direktorioa eta fitxategiak Internetetik atzitu daitezke. .htaccess fitxategiak ez du funtzionatzen. Biziki gomendatzen da  web zerbitzariaren konfigurazioa aldatzea datuen direktorioa atzigarri egon ez dadin edo datuen direktorioa web zerbitzariaren dokumentu errotik kanpora ateratzea.",
     "More" : "Gehiago",
     "More apps menu" : "Aplikazio gehiago menua",
     "Settings menu" : "Ezarpenak menua",
     "The password is wrong. Try again." : "Pasahitza ez da zuzena. Saiatu berriro.",
     "Setup two-factor authentication" : "Konfiguratu bi faktoreko autentifikazioa",
-    "It seems like you are running a 32-bit PHP version. Nextcloud 26 and higher require 64-bit. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "32 biteko PHP bertsioa exekutatzen ari zarela dirudi. Nextcloud 26k eta berriagoek 64 biteko behar dute. Mesedez, eguneratu zure OS eta PHPa 64 bitekora! Xehetasun gehiago lortzeko, irakurri {linkstart} honi buruzko dokumentazio orria ↗{linkend}."
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Nextcloud komunitate bertsio honek ez du laguntza-zerbitzurik eta berehalako jakinarazpenak ez daude eskuragarri.",
+    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Hau laguntzarik gabeko Nextcloud komunitate bertsioa da. Instantzia honen tamaina kontuan hartuz, ezin da errendimendua, fidagarritasuna eta eskalabilitatea ziurtatu. Push jakinarazpenak desgaitu egin dira gure doako zerbitzua ez gainkargatzeko. Ikusi Nextcloud Enterprise buruzko abantailak nextcloud.com/enterprise orrian.",
+    "You haven't added any info yet" : "Ez duzu informaziorik gehitu oraindik",
+    "{user} hasn't added any info yet" : "{user} ez du informaziorik gehitu oraindik"
 },
 "nplurals=2; plural=(n != 1);");
