@@ -37,7 +37,7 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Uklonjene su neke od vaših dijeljenih poveznica",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Zbog sigurnosne pogreške morali smo ukloniti neke od vaših dijeljenih poveznica. Za više informacija pogledajte poveznicu.",
     "The user limit of this instance is reached." : "Dostignuto je ograničenje broja korisnika za ovu instancu.",
-    "Learn more ↗" : "Saznajte više ↗",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Unesite svoju šifru pretplate kako biste povećali ograničenje broja korisnika. Više informacija o pretplati Nextcloud Enterprise možete pronaći na našem web-mjestu.",
     "Preparing update" : "Priprema ažuriranja",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Korak ispravljanja pogreške:",
@@ -100,6 +100,7 @@ OC.L10N.register(
     "For more details see the {linkstart}documentation ↗{linkend}." : "Više informacija potražite u {linkstart}dokumentaciji ↗{linkend}.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP zaglavlje „{header}” nije postavljeno na „{expected}”. To je potencijalni rizik za sigurnost ili privatnost podataka pa preporučujemo da prilagodite ovu postavku.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP zaglavlje „{header}” nije postavljeno na „{expected}”. Neke značajke možda neće ispravno raditi pa preporučujemo da prilagodite ovu postavku.",
+    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP zaglavlje „{header}” ne sadrži „{expected}”. To je potencijalni rizik za sigurnost ili privatnost podataka pa preporučujemo da prilagodite ovu postavku.",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTP zaglavlje „{header}” nije postavljeno na „{val1}”, „{val2}”, „{val3}”, „{val4}” ili „{val5}”. Može doći do curenja informacija o uputitelju. Pogledajte {linkstart}Preporuke W3C-a ↗{linkend}.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "HTTP zaglavlje „Strict-Transport-Security” nije postavljeno na najmanje „{seconds}” sekundi. Kako biste poboljšali sigurnost sustava, preporučujemo da omogućite HSTS kao što je opisano u {linkstart}sigurnosnim savjetima ↗{linkend}.",
     "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Nesiguran pristup web-mjestu putem HTTP-a. Preporučujemo da postavite poslužitelj tako da zahtijeva korištenje HTTPS-a kao što je opisano u {linkstart}sigurnosnim savjetima ↗{linkend}.",
@@ -159,6 +160,8 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Čuvajte podatke o kolegama i prijateljima na jednom mjestu bez ugrožavanja njihovih osobnih informacija.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Jednostavna aplikacija za upravljanje e-poštom, integrirana s aplikacijama Files, Contacts i Calendar.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Razmjenjivanje poruka, video pozivi, dijeljenje zaslona, sastanci na mreži i web-konferencije – putem preglednika i mobilnih aplikacija.",
+    "Collaboratively edit office documents." : "Surađujte na uređivanju dokumenata paketa Office.",
+    "Local document editing back-end used by the Collabora Online app." : "Pozadinski sustav za uređivanje lokalnih dokumenata u aplikaciji Collabora Online.",
     "Forgot password?" : "Zaboravili ste zaporku?",
     "Log in with a device" : "Prijavite se s pomoću uređaja",
     "Back" : "Natrag",
@@ -242,8 +245,8 @@ OC.L10N.register(
     "No action available" : "Nikakve radnje trenutno nisu dostupne",
     "Error fetching contact actions" : "Pogreška pri dohvaćanju radnji kontakata",
     "Non-existing tag #{tag}" : "Nepostojeća oznaka #{tag}",
-    "Restricted" : "Ograničeno",
-    "Invisible" : "Nevidljiva",
+    "restricted" : "ograničeno",
+    "invisible" : "nevidljivo",
     "Delete" : "Izbriši",
     "Rename" : "Preimenuj",
     "Collaborative tags" : "Oznake za suradnju",
@@ -255,7 +258,8 @@ OC.L10N.register(
     "Help" : "Pomoć",
     "Access forbidden" : "Pristup zabranjen",
     "Back to %s" : "Natrag na %s",
-    "Page not found" : "Stranica nije pronađena",
+    "File not found" : "Datoteka nije pronađena",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Dokument nije moguće pronaći na poslužitelju. Možda je dijeljenje izbrisano ili je isteklo?",
     "Too many requests" : "Previše zahtjeva",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Zaprimljeno je previše zahtjeva iz vaše mreže. Pokušajte kasnije ili se obratite administratoru ako se radi o pogrešci.",
     "Error" : "Pogreška",
@@ -354,22 +358,19 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Ova %s instanca trenutno je u načinu za održavanje; ovo može potrajati.",
     "This page will refresh itself when the instance is available again." : "Ova će se stranica osvježiti kada je instanca ponovno dostupna.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Obratite se administratoru sustava ako se ova poruka ponavlja ili se pojavila neočekivano.",
-    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Ovo izdanje Nextclouda nije podržano i nisu dostupne trenutne obavijesti.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Unesite svoju šifru pretplate kako biste povećali ograničenje broja korisnika. Više informacija o pretplati Nextcloud Enterprise možete pronaći na našem web-mjestu.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Provjeravanje tablice %s",
+    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Ovaj poslužitelj nema aktivnu internetsku vezu: nije moguće pristupiti višestrukim krajnjim točkama. To znači da neće raditi neke značajke kao što su postavljanje vanjske pohrane, obavijesti o ažuriranjima ili instalacija aplikacija treće strane. Daljinski pristup datotekama i slanje e-pošte s obavijestima također možda neće raditi. Uspostavite internetsku vezu za ovaj poslužitelj kako biste se mogli koristiti svim značajkama.",
+    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 posljednje je izdanje s podrškom za PHP 7.2. Nextcloud 21 zahtjeva najmanje PHP 7.3.",
+    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "PHP OPcache modul nije učitan. {linkstart}Preporučuje se da ga učitate ↗{linkend} u svoju instalaciju PHP-a kako biste poboljšali performanse.",
+    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "PHP OPcache modul nije pravilno konfiguriran. {linkstart}Preporučuje se da ↗{linkend} koristite sljedeće postavke u datoteci <code>php.ini</code> kako biste poboljšali performanse:",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "U određenim stupcima baze podataka nedostaje pretvorba u big int. Budući da promjena vrste stupca u velikim tablicama može potrajati neko duže vrijeme, stupci nisu automatski promijenjeni. Izvršenjem 'occ db:convert-filecache-bigint' te se promjene mogu ručno primijeniti. Ovu radnju morate izvršiti dok je instanca izvan mreže. Za više pojedinosti pročitajte {linkstart}odgovarajuće poglavlje dokumentacije ↗{linkend}.",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "Za prelazak na drugu bazu podataka koristite se naredbenim retkom: 'occ db:convert-type' ili pogledajte {linkstart}dokumentaciju ↗{linkend}.",
-    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP zaglavlje „{header}” ne sadrži „{expected}”. To je potencijalni rizik za sigurnost ili privatnost podataka pa preporučujemo da prilagodite ovu postavku.",
-    "Collaboratively edit office documents." : "Surađujte na uređivanju dokumenata paketa Office.",
-    "Local document editing back-end used by the Collabora Online app." : "Pozadinski sustav za uređivanje lokalnih dokumenata u aplikaciji Collabora Online.",
-    "restricted" : "ograničeno",
-    "invisible" : "nevidljivo",
-    "File not found" : "Datoteka nije pronađena",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Dokument nije moguće pronaći na poslužitelju. Možda je dijeljenje izbrisano ili je isteklo?",
+    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Vaši direktoriji i datoteke vjerojatno su dostupni putem Interneta. Datoteka .htaccess nije u funkciji. Preporučujemo da konfigurirate web-poslužitelj tako da direktorij s podacima više nije dostupan ili premjestite direktorij s podacima izvan korijena web poslužitelja.",
     "More" : "Više",
     "More apps menu" : "Izbornik s više aplikacija",
     "Settings menu" : "Izbornik postavki",
     "The password is wrong. Try again." : "Pogrešna zaporka. Pokušajte ponovno.",
-    "Setup two-factor authentication" : "Postavite dvofaktorsku autentifikaciju"
+    "Setup two-factor authentication" : "Postavite dvofaktorsku autentifikaciju",
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Ovo izdanje Nextclouda nije podržano i nisu dostupne trenutne obavijesti."
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
