@@ -40,8 +40,7 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Néhány megosztási hivatkozása eltávolításra került",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Egy biztonsági hiba miatt el kellett távolítsunk néhány megosztási hivatkozását. További információkért lásd a lenti hivatkozást.",
     "The user limit of this instance is reached." : "Elérte ennek a példánynak a felhasználói korlátját.",
-    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Adja meg az előfizetési kulcsát a támogatási alkalmazásban, hogy megnövelje a felhasználókorlátot. Ez a Nextcloud vállalati ajánlatainak további előnyeit is biztosítja, és határozottan ajánlott a céges üzemeltetés esetén.",
-    "Learn more ↗" : "Tudjon meg többet ↗",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Adja meg előfizetésének kulcsát a felhasználói korlát növeléséhez. További információ a Nextcloud Enterprise-ról a weboldalunkon található.",
     "Preparing update" : "Felkészülés a frissítésre",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Javítási lépés:",
@@ -84,6 +83,7 @@ OC.L10N.register(
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Nincs beállítva memória gyorsítótár. A teljesítmény növelése érdekében állítson be egy memcache-t, ha van ilyen. További információk a {linkstart}dokumentációban találhatók ↗{linkend}.",
     "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "A PHP nem talált megfelelő véletlenszerűségi forrást, amely biztonsági okokból erősen ellenjavallt. További információk a {linkstart}dokumentációban találhatók ↗{linkend}.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Ön jelenleg a következő verziójú PHP-t futtatja: {version}. Amint a disztribúciója támogatja, frissítse a PHP verzióját, hogy kihasználhassa a {linkstart}PHP Group által nyújtott teljesítménybeli és biztonsági frissítéseket ↗{linkend}.",
+    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "A Nextcloud 23 az utolsó olyan kiadás, amely támogatja a PHP 7.3-as verzióját. A Nextcloud 21 legalább PHP 7.4-et igényel.",
     "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "A fordított proxy fejléc konfigurációja helytelen, vagy egy megbízható proxyból érhető el a Nextcloud. Ha nem, akkor ez biztonsági probléma, és lehetővé teheti a támadók számára, hogy a Nextcloud számára látható  IP-címüket meghamisítsák. További információk a {linkstart}dokumentációban találhatók ↗{linkend}.",
     "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "A Memcached elosztott gyorsítótárként van konfigurálva, de rossz „memcache” PHP modul van telepítve. Az OC\\Memcache\\Memcached csak a „memcached” modult támogatja, a „memcache”-t nem. Lásd a {linkstart}memcached wiki-t mindkét modulról ↗{linkend}.",
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Néhány fájl elbukott az integritásellenőrzésen. További információk a probléma megoldásáról a {linkstart1}dokumentációban találhatók ↗{linkend}. ({linkstart2}Érvénytelen fájlok listája…{linkend} / {linkstart3}Újrakeresés…{linkend})",
@@ -99,7 +99,7 @@ OC.L10N.register(
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Ennél a példánynál hiányzik néhány javasolt PHP modul. A jobb teljesítmény és nagyobb kompatibilitás miatt ezek telepítése erősen javallott.",
     "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Az „imagick” PHP-modul nem engedélyezett, de a témázó alkalmazás igen. A webhelyikonok előállításához telepítenie és engedélyeznie kell ezt a modult.",
     "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "A „gmp” vagy a „bcmath” PHP modulok nem engedélyezettek. Ha WebAuthn jelszó nélküli hitelesítést használ, akkor szükség van ezekre a modulokra.",
-    "It seems like you are running a 32-bit PHP version. Nextcloud 26 and higher require 64-bit. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "Úgy tűnik, hogy a PHP 32 bites változatát futtatja. a Nextcloud 26-os és újabb verziójához 64 bites szükséges. Frissítse az operációs rendszerét és a PHP-ját 64 bitesre. További információkért olvassa el az erről szóló {linkstart}dokumentációs oldalt ↗{linkend}.",
+    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Úgy tűnik, hogy 32 bites PHP verziót használ. A Nextcloud megfelelő futtatásához 64 bites szükséges. Frissítse 64 bitesre az operációs rendszerét és a PHP-ját. További részletekért olvassa el az {linkstart}erről szóló dokumentációs oldalt ↗{linkend}.",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "A php-imagick modul ebben az esetben nem rendelkezik SVG támogatással. A jobb kompatibilitás érdekében ajánlott telepíteni.",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Az adatbázis egyes oszlopaiból hiányzik a big int átalakítás. MIvel a nagy táblák oszloptípusainak megváltoztatása eltarthat egy ideig, azok nem lettek automatikusan megváltoztatva. Az „occ db: convert-filecache-bigint” futtatásával ezek a függőben lévő módosítások kézileg is alkalmazhatók. Ezt a műveletet offline állapotban kell végrehajtani. További részletekért olvassa el a {linkstart}erről szóló dokumentációs oldalt ↗{linkend}.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Jelenleg SQLite van háttéradatbázisként használva. Nagyobb telepítésekhez javasoljuk, hogy váltson más háttéradatbázisra. ",
@@ -116,7 +116,7 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Az adatkönyvtárai és a fájljai valószínűleg elérhetőek az internetről. A .htaccess fájl nem működik. Erősen javasolt, hogy a webkiszolgálót úgy állítsa be, hogy az adatkönyvtár tartalma ne legyen közvetlenül elérhető, vagy helyezze át a könyvtárat a kiszolgálási területen kívülre.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "A(z) „{header}” HTTP-fejléc nem erre van állítva: „{expected}”. Ez egy lehetséges biztonsági és adatvédelmi kockázat, ezért javasolt, hogy módosítsa megfelelően a beállítást.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "A(z) „{header}” HTTP-fejléc nem erre van állítva: „{expected}”. Egyes szolgáltatások esetleg nem fognak megfelelően működni, ezért javasolt, hogy módosítsa megfelelően a beállítást.",
-    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "A(z) „{header}” HTTP-fejléc nem tartalmazza ezt: „{expected}”. Ez egy lehetséges biztonsági és adatvédelmi kockázat, ezért javasolt, hogy módosítsa megfelelően a beállítást.",
+    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "A(z) „{header}” HTTP-fejléc nem tartalmazza ezt: „{expected}”. Ez egy lehetséges biztonsági és adatvédelmi kockázat, ezért javasolt, hogy módosítsa megfelelően a beállítást.",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "A „{header}” HTTP-fejléc értéke nem a következők egyiket: „{val1}”, „{val2}”, „{val3}”, „{val4}” vagy „{val5}”. Ez kiszivárogtathatja a hivatkozói információkat. Lásd a {linkstart}W3C ajánlást ↗{linkend}.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "A „Strict-Transport-Security” HTTP-fejléc nincs beállítva legalább „{seconds}” másodpercre. A fokozott biztonság érdekében ajánlott engedélyezni a HSTS-t a {linkstart}biztonsági tippek ↗{linkend} leírása szerint.",
     "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "A webhely elérése nem biztonságos HTTP-n keresztül. Javasoljuk, hogy úgy állítsa be a kiszolgálót, hogy követelje meg a HTTPS-t, amint azt a {linkstart}biztonsági tippek ↗{linkend} leírják.",
@@ -135,7 +135,7 @@ OC.L10N.register(
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "A frissítés sikertelen. Bővebb információért <a href=\"{url}\">keresse fel a problémáról szóló fórumbejegyzésünket</a>.",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A frissítés sikertelen. Jelezze a problémát a <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud közösségnek</a>.",
     "Continue to {productName}" : "Tovább erre: {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A frissítés sikeres volt. %n másodperc múlva át lesz irányítva a következőhöz: {productName}.","A frissítés sikeres volt. %n másodperc múlva át lesz irányítva a következőhöz: {productName}."],
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A frissítés sikeres volt. %n másodperc múlva átirányítjuk a(z) {productName} címre.","A frissítés sikeres volt. %n másodperc múlva átirányítás a(z) {productName} címre."],
     "More apps" : "További alkalmazások",
     "Currently open" : "Jelenleg nyitva",
     "_{count} notification_::_{count} notifications_" : ["{count} értesítés","{count} értesítés"],
@@ -145,9 +145,7 @@ OC.L10N.register(
     "Please contact your administrator." : "Lépjen kapcsolatba a rendszergazdával.",
     "An internal error occurred." : "Belső hiba történt.",
     "Please try again or contact your administrator." : "Próbálja meg újra, vagy vegye fel a kapcsolatot a rendszergazdával.",
-    "Account name or email" : "Fióknév vagy e-mail-cím",
     "Password" : "Jelszó",
-    "Log in to {productName}" : "Bejelentkezés ebbe: {productName}",
     "Wrong username or password." : "Hibás felhasználónév vagy jelszó.",
     "User disabled" : "Felhasználó letiltva",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Többszöri sikertelen bejelentkezési kísérletet észleltünk az IP-címéről. A legközelebbi kísérlete így 30 másodperccel késleltetve lesz.",
@@ -180,7 +178,8 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Tartsa egy helyen kollégáit és barátait, anélkül hogy kiszivárogtatná a személyes adataikat.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Egyszerű e-mail alkalmazás, amely szépen integrálódik a Fájlok, Névjegyek és Naptár alkalmazásba.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Csevegés, videóhívások, képernyőmegosztás, online megbeszélések és webes konferencia – a böngészőjében és mobilalkalmazásokkal.",
-    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Közösen szerkeszthető dokumentumok, táblázatok és bemutatók, a Collabora Online-ra építve.",
+    "Collaboratively edit office documents." : "Szerkesszen közösen irodai dokumentumokat.",
+    "Local document editing back-end used by the Collabora Online app." : "Helyi dokumentumszerkesztési háttérprogram, amit a Collabora Online alkalmazás használ.",
     "Forgot password?" : "Elfelejtett jelszó?",
     "Log in with a device" : "Bejelentkezés eszközzel",
     "Back" : "Vissza",
@@ -202,11 +201,6 @@ OC.L10N.register(
     "Search" : "Keresés",
     "An error occurred while searching for {type}" : "Hiba történt a(z) {type} keresése sorá",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["A kereséshez írjon be a legalább {minSearchLength} karaktert","A kereséshez írjon be a legalább {minSearchLength} karaktert"],
-    "This browser is not supported" : "Ez a böngésző nem támogatott.",
-    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "A böngészője nem támogatott. Frissítsen újabb verzióra, vagy váltson egy támogatott böngészőre.",
-    "Continue with this unsupported browser" : "Folytatás ezzel a nem támogatott böngészővel",
-    "Supported versions" : "Támogatott verziók",
-    "{name} version {version} and above" : "{name} {version} verziója, és újabb",
     "Search {types} …" : "{types} keresése…",
     "Settings" : "Beállítások",
     "Could not load your contacts" : "Nem lehet betölteni a névjegyeit",
@@ -279,8 +273,8 @@ OC.L10N.register(
     "No action available" : "Nincs elérhető művelet",
     "Error fetching contact actions" : "Hiba a kapcsolati műveletek lekérésekor",
     "Non-existing tag #{tag}" : "Nem létező címke #{tag}",
-    "Restricted" : "Korlátozott",
-    "Invisible" : "Láthatatlan",
+    "restricted" : "korlátozott",
+    "invisible" : "láthatatlan",
     "Delete" : "Törlés",
     "Rename" : "Átnevezés",
     "Collaborative tags" : "Együttműködési címkék",
@@ -294,8 +288,8 @@ OC.L10N.register(
     "Profile not found" : "Nem található profil",
     "The profile does not exist." : "A profil nem létezik.",
     "Back to %s" : "Vissza ide %s",
-    "Page not found" : "Az oldal nem található",
-    "The page could not be found on the server." : "Az oldal nem található a kiszolgálón.",
+    "File not found" : "Fájl nem található",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "A dokumentum nem található a szerveren. Valószínűleg a megosztás törölve lett vagy lejárt.",
     "Too many requests" : "Túl sok kérés",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Túl sok kérés érkezett a hálózatától. Próbálja újra később, vagy ha ez egy hiba, akkor forduljon a rendszergazdához.",
     "Error" : "Hiba",
@@ -346,11 +340,11 @@ OC.L10N.register(
     "Skip to main content" : "Ugrás a fő tartalomhoz",
     "Skip to navigation of app" : "Ugrás az alkalmazás navigációjához",
     "Get your own free account" : "Szerezzen saját ingyenes fiókot",
+    "%s's homepage" : "%s honlapja",
     "Contacts" : "Névjegyek",
     "Contacts menu" : "Névjegyek menü",
     "Open settings menu" : "Beállítások megnyitása",
     "Confirm your password" : "Erősítse meg a jelszavát:",
-    "%s's homepage" : "%s honlapja",
     "Connect to your account" : "Kapcsolódás a fiókjához",
     "Please log in before granting %1$s access to your %2$s account." : "Lépjen be mielőtthozzáférést biztosít a(z) %1$s kliensnek a(z) %2$s fiókjához.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ha nem új eszközt vagy alkalmazást próbál beállítani, akkor valaki megpróbálja becsapni, hogy hozzáférést biztosítson számára az adatokhoz. Ebben az esetben ne folytassa, hanem lépjen kapcsolatba a rendszergazdával.",
@@ -402,27 +396,22 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Ez a %s példány éppen karbantartási üzemmódban van, amely eltarthat egy darabig.",
     "This page will refresh itself when the instance is available again." : "Ez az oldal frissíteni fogja magát, amint a példány ismét elérhető lesz.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Ha ez az üzenet mindig vagy váratlanul megjelenik, akkor keresse fel a rendszergazdáját!",
-    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "A Nextcloud e közösségi kiadása nem támogatott, és az azonnal értesítések nem érhetők el.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Adja meg előfizetésének kulcsát a felhasználói korlát növeléséhez. További információ a Nextcloud Enterprise-ról a weboldalunkon található.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Tábla ellenőrzése: %s",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Ez a Nextcloud nem támogatott közösségi kiadása. A példány mérete miatt a teljesítménye, megbízhatósága és skálázhatósága nem garantálható. A leküldéses értesítések letiltásra kerültek, hogy ne terheljék túl az ingyenes szolgáltatásunkat. Tudjon meg többet a Nextcloud Enterprise előnyeiről a nextcloud.com/enterprise oldalon.",
-    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "A Nextcloud 23 az utolsó olyan kiadás, amely támogatja a PHP 7.3-as verzióját. A Nextcloud 21 legalább PHP 7.4-et igényel.",
+    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Ennek a kiszolgálónak nincs működő internetkapcsolata: több végpont nem érhető el. Ez azt jelenti, hogy néhány funkció, mint például a külső tárolók csatolása, a frissítési értesítések, vagy a harmadik féltől származó alkalmazások telepítése nem fog működni. Lehet, hogy a fájlok távoli elérése és az e-mail értesítések sem működnek. Létesítsen internetkapcsolatot a kiszolgálón, ha minden funkciót használni szeretne.",
+    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "A Nextcloud 20 az utolsó olyan kiadás, amely támogatja a PHP 7.2-es verziót. A Nextcloud 21 legalább PHP 7.3-at igényel.",
+    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "A PHP OPcache modul nincs betöltve. {linkstart}A jobb teljesítmény érdekében javasoljuk, hogy ↗{link} töltse be a PHP telepítésébe.",
+    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "A PHP OPcache modul nincs megfelelően konfigurálva. {linkstart}A jobb teljesítmény érdekében ↗{linkend} ajánlott a következő beállításokat használni a <code>php.ini</code> fájlban:",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Az adatbázis egyes oszlopaiból hiányzik a big int átalakítás. MIvel a nagy táblák oszloptípusainak megváltoztatása eltarthat egy ideig, azok nem lettek automatikusan megváltoztatva. Az „occ db: convert-filecache-bigint” futtatásával ezek a függőben lévő módosítások kézileg is alkalmazhatók. Ezt a műveletet offline állapotban kell végrehajtani. További részletekért olvassa el a {linkstart}erről szóló dokumentációs oldalt ↗{linkend}.",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "Más adatbázisba történő áttéréshez használja a parancssori eszközt: „occ db: convert-type”, vagy tekintse meg a {linkstart}dokumentációt ↗{linkend}.",
-    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "A(z) „{header}” HTTP-fejléc nem tartalmazza ezt: „{expected}”. Ez egy lehetséges biztonsági és adatvédelmi kockázat, ezért javasolt, hogy módosítsa megfelelően a beállítást.",
-    "Collaboratively edit office documents." : "Szerkesszen közösen irodai dokumentumokat.",
-    "Local document editing back-end used by the Collabora Online app." : "Helyi dokumentumszerkesztési háttérprogram, amit a Collabora Online alkalmazás használ.",
-    "You haven't added any info yet" : "Még nem adott hozzá információkat",
-    "{user} hasn't added any info yet" : "{user} még nem adott hozzá információkat",
-    "restricted" : "korlátozott",
-    "invisible" : "láthatatlan",
-    "File not found" : "Fájl nem található",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "A dokumentum nem található a szerveren. Valószínűleg a megosztás törölve lett vagy lejárt.",
+    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Az adatkönyvtárai és a fájljai valószínűleg elérhetőek az internetről. A .htaccess fájl nem működik. Erősen javasolt, hogy a webkiszolgálót úgy állítsa be, hogy az adatkönyvtár tartalma ne legyen közvetlenül elérhető, vagy helyezze át a könyvtárat a kiszolgálási területen kívülre.",
     "More" : "Továbbiak",
     "More apps menu" : "További alkalmazások menü",
     "Settings menu" : "Beállítások menü",
     "The password is wrong. Try again." : "A megadott jelszó hibás. Próbálja újra.",
     "Setup two-factor authentication" : "Kétfaktoros hitelesítés beállítása",
-    "It seems like you are running a 32-bit PHP version. Nextcloud 26 and higher require 64-bit. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Úgy tűnik, hogy a PHP 32 bites változatát futtatja. a Nextcloud 26-os és újabb verziójához 64 bites szükséges. Frissítse az operációs rendszerét és a PHP-ját 64 bitesre. További információkért olvassa el az erről szóló {linkstart}dokumentációs oldalt ↗{linkend}."
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "A Nextcloud e közösségi kiadása nem támogatott, és az azonnal értesítések nem érhetők el.",
+    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Ez a Nextcloud nem támogatott közösségi kiadása. A példány mérete miatt a teljesítménye, megbízhatósága és skálázhatósága nem garantálható. A leküldéses értesítések letiltásra kerültek, hogy ne terheljék túl az ingyenes szolgáltatásunkat. Tudjon meg többet a Nextcloud Enterprise előnyeiről a nextcloud.com/enterprise oldalon.",
+    "You haven't added any info yet" : "Még nem adott hozzá információkat",
+    "{user} hasn't added any info yet" : "{user} még nem adott hozzá információkat"
 },
 "nplurals=2; plural=(n != 1);");
