@@ -16,8 +16,8 @@ OC.L10N.register(
     "Invalid file provided" : "Pateiktas neteisingas failas",
     "No image or file provided" : "Nenurodytas paveikslas ar failas",
     "Unknown filetype" : "Nežinomas failo tipas",
-    "Invalid image" : "Netinkamas paveikslas",
     "An error occurred. Please contact your admin." : "Įvyko klaida. Susisiekite su savo administratoriumi.",
+    "Invalid image" : "Netinkamas paveikslas",
     "No temporary profile picture available, try again" : "Nėra laikinojo profilio paveikslėlio, bandykite dar kartą",
     "No crop data provided" : "Nenurodyti apkirpimo duomenys",
     "No valid crop data provided" : "Pateikti neteisingi apkirpimo duomenys",
@@ -40,7 +40,6 @@ OC.L10N.register(
     "Repair warning:" : "Taisymo įspėjimas:",
     "Repair error:" : "Taisymo klaida:",
     "Please use the command line updater because automatic updating is disabled in the config.php." : "Automatinis atnaujinimas išjungtas config.php faile. Naudokite komandinės eilutės atnaujinimo įrankį.",
-    "[%d / %d]: Checking table %s" : "[%d / %d]: Tikrinama lentelė %s",
     "Turned on maintenance mode" : "Įjungta techninės priežiūros veiksena",
     "Turned off maintenance mode" : "Išjungta techninės priežiūros veiksena",
     "Maintenance mode is kept active" : "Techninės priežiūros veiksena yra aktyvi",
@@ -78,20 +77,23 @@ OC.L10N.register(
     "Please reload the page." : "Prašome įkelti puslapį iš naujo.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Atnaujinimas buvo nesėkmingas. Išsamesnei informacijai apie šią problemą, <a href=\"{url}\">žiūrėkite įrašą mūsų forume</a>.",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Atnaujinimas buvo nesėkmingas. Prašome pranešti apie šią problemą <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud bendruomenei</a>.",
+    "More apps" : "Daugiau programėlių",
+    "_{count} notification_::_{count} notifications_" : ["{count} pranešimas","{count} pranešimai","{count} pranešimų","{count} pranešimas"],
     "Log in" : "Prisijungti",
     "Logging in …" : "Prisijungiama …",
     "Server side authentication failed!" : "Autentikacija serveryje nepavyko!",
     "Please contact your administrator." : "Susisiekite su savo administratoriumi.",
     "An internal error occurred." : "Įvyko vidinė klaida.",
     "Please try again or contact your administrator." : "Pabandykite dar kartą arba susisiekite su savo administratoriumi.",
-    "Username or email" : "Naudotojas arba el. paštas",
     "Password" : "Slaptažodis",
-    "Show password" : "Rodyti slaptažodį",
     "Wrong username or password." : "Neteisingas naudotojo vardas ar slaptažodis.",
     "User disabled" : "Naudotojas išjungtas",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Dėl daugkartinių nesėkmingų bandymų prisijungti iš jūsų IP adreso, prisijungimai bus uždelsti iki 30 sekundžių.",
+    "Username or email" : "Naudotojas arba el. paštas",
     "Your account is not setup for passwordless login." : "Jūsų paskyra nėra nustatyta prisijungimui be slaptažodžio.",
+    "Browser not supported" : "Naršyklė nepalaikoma",
     "Passwordless authentication is not supported in your browser." : "Tapatybės nustatymas be slaptažodžio nėra palaikomas jūsų naršyklėje.",
+    "Your connection is not secure" : "Jūsų ryšys nėra saugus",
     "Passwordless authentication is only available over a secure connection." : "Tapatybės nustatymas be slaptažodžio yra prieinamas tik per saugų ryšį.",
     "Reset password" : "Atstatyti slaptažodį",
     "Couldn't send reset email. Please contact your administrator." : "Nepavyko išsiųsti atstatymo el. laiško. Susisiekite su savo administratoriumi.",
@@ -110,6 +112,7 @@ OC.L10N.register(
     "Forgot password?" : "Pamiršote slaptažodį?",
     "Log in with a device" : "Prisijungti naudojant įrenginį",
     "Back" : "Atgal",
+    "Edit Profile" : "Taisyti profilį",
     "Reset search" : "Atstatyti paiešką",
     "Search for {name} only" : "Ieškoti tik {name}",
     "No results for {query}" : "{query} negrąžino jokių rezultatų",
@@ -159,6 +162,8 @@ OC.L10N.register(
     "(all selected)" : "(visi pažymėti)",
     "({count} selected)" : "({count} pažymėtų)",
     "Error loading file exists template" : "Klaida įkeliant saugykloje esančių rinkmenų ruošinį",
+    "Show list view" : "Rodyti sąrašo rodinį",
+    "Show grid view" : "Rodyti tinklelio rodinį",
     "Pending" : "Vykdoma",
     "Copy to {folder}" : "Kopijuoti į {folder}",
     "Move to {folder}" : "Perkelti į {folder}",
@@ -201,6 +206,8 @@ OC.L10N.register(
     "Admin" : "Administravimas",
     "Help" : "Pagalba",
     "Access forbidden" : "Prieiga uždrausta",
+    "Profile not found" : "Profilis nerastas",
+    "The profile does not exist." : "Profilio nėra.",
     "Back to %s" : "Atgal į %s",
     "File not found" : "Failas nerastas",
     "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Nepavyko serveryje rasti dokumento. Galbūt, viešinys buvo ištrintas arba pasibaigė jo galiojimo laikas?",
@@ -226,6 +233,8 @@ OC.L10N.register(
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Išsamesnei informacijai apie tai kaip tinkamai sukonfigūruoti savo serverį, žiūrėkite <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaciją</a>.",
     "Create an <strong>admin account</strong>" : "Sukurkite <strong>administratoriaus paskyrą</strong>",
     "Username" : "Naudotojo vardas",
+    "Show password" : "Rodyti slaptažodį",
+    "Toggle password visibility" : "Perjungti slaptažodžio matomumą",
     "Storage & database" : "Saugykla ir duomenų bazė",
     "Data folder" : "Duomenų aplankas",
     "Configure the database" : "Konfigūruokite duomenų bazę",
@@ -242,6 +251,7 @@ OC.L10N.register(
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite turėtų būti naudojama tik minimaliems ir plėtojimo egzemplioriams. Darbiniam egzemplioriui rekomenduojame naudoti kitą duomenų bazės vidinę pusę.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jei sinchronizavimui naudojate kliento programas, tuomet SQLite naudojimas yra primygtinai nerekomenduojamas.",
     "Install" : "Įdiegti",
+    "Installing …" : "Įdiegiama…",
     "Need help?" : "Reikia pagalbos?",
     "See the documentation" : "Žiūrėkite dokumentaciją",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nepavyko iš konfigūracijos aplanko pašalinti failo CAN_INSTALL. Pašalinkite šį failą rankiniu būdu.",
@@ -249,11 +259,9 @@ OC.L10N.register(
     "Skip to main content" : "Pereiti į pagrindinį turinį",
     "Skip to navigation of app" : "Pereiti į programėlės naršymą",
     "Get your own free account" : "Gaukite nemokamą asmeninę paskyrą",
-    "More apps" : "Daugiau programėlių",
-    "More" : "Daugiau",
-    "More apps menu" : "Daugiau programėlių meniu",
     "Contacts" : "Adresatai",
     "Contacts menu" : "Adresatų meniu",
+    "Open settings menu" : "Atverti nustatymų meniu",
     "Confirm your password" : "Patvirtinkite savo slaptažodį",
     "Connect to your account" : "Prisijunkite prie paskyros",
     "Please log in before granting %1$s access to your %2$s account." : "Prieš suteikdami %1$s prieigą prie savo %2$s paskyros, prisijunkite.",
@@ -262,6 +270,7 @@ OC.L10N.register(
     "Grant access" : "Suteikti prieigą",
     "Alternative log in using app token" : "Alternatyvus prisijungimas naudojant programėlės atpažinimo raktą",
     "Account access" : "Paskyros prieiga",
+    "Currently logged in as %1$s (%2$s)." : "Šiuo metu prisijungta kaip %1$s (%2$s).",
     "You are about to grant %1$s access to your %2$s account." : "Ketinate suteikti %1$s prieigą prie savo %2$s paskyros.",
     "Account connected" : "Paskyra prijungta",
     "Your client should now be connected!" : "Dabar, jūsų kliento programa turėtų būti prijungta!",
@@ -298,7 +307,12 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Šis %s egzempliorius šiuo metu yra techninės priežiūros veiksenoje, kas savo ruožtu gali šiek tiek užtrukti.",
     "This page will refresh itself when the instance is available again." : "Šis puslapis bus įkeltas iš naujo, kai egzempliorius bus ir vėl prieinamas.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Susisiekite su savo sistemos administratoriumi, jei šis pranešimas nedingsta arba, jei jis pasirodė netikėtai.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Tikrinama lentelė %s",
+    "More" : "Daugiau",
+    "More apps menu" : "Daugiau programėlių meniu",
     "Settings menu" : "Nustatymų meniu",
-    "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą."
+    "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
+    "You haven't added any info yet" : "Jūs kol kas nesate pridėję jokios informacijos",
+    "{user} hasn't added any info yet" : "Naudotojas {user} kol kas nėra pridėjęs jokios informacijos"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
