@@ -39,6 +39,7 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "D’unes de vòstres ligams de partiment foguèron tirats",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "A causa d’una avaria de seguretat nos calguèt tirar certans de vòstres ligams de partiment. Vejatz lo ligam per mai d’informacions.",
     "The user limit of this instance is reached." : "La limita d’utilizaires d’aquesta instància es atenguda.",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Picatz vòstra clau d’abonament per aumentar la limita d’utilizaires. Per mai d’informacions a prepaus de Nextcloud Enterprise vejatz nòstre site web.",
     "Preparing update" : "Preparacion de la mesa a jorn",
     "[%d / %d]: %s" : "[%d / %d] : %s",
     "Repair step:" : "Etapa de reparacion :",
@@ -81,6 +82,7 @@ OC.L10N.register(
     "Error occurred while checking server setup" : "Error producha pendent la verificacion de l’installacion del servidor",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "L’entèsta HTTP « {header} » es pas definida a « {expected} ». Aquò es un risc de seguretat o de vida privada, es recomandat d’ajustar aqueste paramètre en consequéncia.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "L’entèsta HTTP « {header} » es pas definida a « {expected} ». D’unas foncionalitats poirián foncionar pas corrèctament, es recomandat d’ajustar aqueste paramètre en consequéncia.",
+    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "L’entèsta HTTP « {header} » conten pas « {expected} ». Aquò es un risc potencial de seguretat o de confidencialitat, es recomandat d’ajustar aqueste paramètres en consequéncia.",
     "unknown text" : "tèxt desconegut",
     "Hello world!" : "Adieu monde !",
     "sunny" : "ensolelhat",
@@ -129,6 +131,7 @@ OC.L10N.register(
     "Schedule work & meetings, synced with all your devices." : "Planificatz prètzfaches e reünions, sincronizats amb totes vòstres periferics.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Gardatz vòstres companhs e amics a un sòl lòc sens divulgar lor vida privada.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicacion simpla e simpatica de corrièl integrada a Fichièrs, Contactes e Calendièr.",
+    "Collaboratively edit office documents." : "Modificatz collaborativament de documents burotics.",
     "Forgot password?" : "Senhal oblidat ?",
     "Log in with a device" : "Connexion amb un periferic",
     "Back" : "Retorn",
@@ -210,8 +213,8 @@ OC.L10N.register(
     "No action available" : "Cap d’accion pas disponibla",
     "Error fetching contact actions" : "Error en recuperacion las accions contacte",
     "Non-existing tag #{tag}" : "Etiqueta inexistenta #{tag}",
-    "Restricted" : "Restrencha",
-    "Invisible" : "Invisible",
+    "restricted" : "limitada",
+    "invisible" : "invisibla",
     "Delete" : "Suprimir",
     "Rename" : "Renomenar",
     "Collaborative tags" : "Etiquetas collaborativas",
@@ -225,6 +228,8 @@ OC.L10N.register(
     "Profile not found" : "Perfil pas trobat",
     "The profile does not exist." : "Lo perfil existís pas.",
     "Back to %s" : "Tornar a %s",
+    "File not found" : "Fichièr pas trobat",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Lo document es pas trobable sul servidor. Benlèu que lo partiment foguèt suprimit o a expirat ?",
     "Too many requests" : "Tròp de requèstas",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "I a agut tròp de requèstas a partir de vòstre ret. Tornatz ensajar mai tard o contactatz vòstre administrator s’aquò es una error.",
     "Error" : "Error",
@@ -319,14 +324,9 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "L’instància %s es actualament en mòde manteniment, pòt trigar.",
     "This page will refresh itself when the instance is available again." : "Aquesta pagina s’actualizarà soleta quand l’instància serà disponibla de nòu.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contactatz l’administrator sistèma s’aqueste messatge ten d’aparéisser o apareis sens rason.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Picatz vòstra clau d’abonament per aumentar la limita d’utilizaires. Per mai d’informacions a prepaus de Nextcloud Enterprise vejatz nòstre site web.",
     "[%d / %d]: Checking table %s" : "[%d / %d] : Verificacion taula %s",
-    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "L’entèsta HTTP « {header} » conten pas « {expected} ». Aquò es un risc potencial de seguretat o de confidencialitat, es recomandat d’ajustar aqueste paramètres en consequéncia.",
-    "Collaboratively edit office documents." : "Modificatz collaborativament de documents burotics.",
-    "restricted" : "limitada",
-    "invisible" : "invisibla",
-    "File not found" : "Fichièr pas trobat",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Lo document es pas trobable sul servidor. Benlèu que lo partiment foguèt suprimit o a expirat ?",
+    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Aqueste servidor a pas cap de connexion Internet operacionala. Mantun destinacions finalas an pas pogut èsser contactadas. Aquò significa que d’unas foncionalitats coma lo montatge d’estocatges extèrns, las notificacions de mesa a jorn o l’installacion d’aplicacions tèrças foncionaràn pas. L’accès distant als fichièrs e lo mandadís de corrièls poiriá foncionar pas tanpauc. Establissètz una connexion Internet per aprofitar de totas las foncionalitats.",
+    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 es la darrièra version que pren en carga PHP 7.2. Nextcloud 21 requerís almens PHP 7.3.",
     "More" : "Mai",
     "More apps menu" : "Menú mai d’aplicacions",
     "Settings menu" : "Menú paramètres",
