@@ -16,8 +16,8 @@ OC.L10N.register(
     "Invalid file provided" : "Arquivo fornecido inválido",
     "No image or file provided" : "Nenhuma imagem ou arquivo fornecido",
     "Unknown filetype" : "Tipo de arquivo desconhecido",
-    "Invalid image" : "Imagem inválida",
     "An error occurred. Please contact your admin." : "Ocorreu um erro. Entre em contato com o administrador.",
+    "Invalid image" : "Imagem inválida",
     "No temporary profile picture available, try again" : "Nenhuma imagem temporária disponível no perfil, tente novamente",
     "No crop data provided" : "Nenhum dado recortado fornecido",
     "No valid crop data provided" : "Nenhum dado recortado válido",
@@ -26,7 +26,6 @@ OC.L10N.register(
     "Invalid app password" : "Senha do aplicativo inválida",
     "Could not complete login" : "Não foi possível concluir o login",
     "Your login token is invalid or has expired" : "Seu token de login é inválido ou expirou",
-    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Este lançamento comunitário do Nextcloud não é compatível e as notificações instantâneas não estão disponíveis. ",
     "Login" : "Entrar",
     "Password reset is disabled" : "A redefinição de senha está desabilitada",
     "Could not reset password because the token is expired" : "Não foi possível redefinir a senha porque o token expirou",
@@ -48,7 +47,6 @@ OC.L10N.register(
     "Repair warning:" : "Aviso do reparo:",
     "Repair error:" : "Erro do reparo:",
     "Please use the command line updater because automatic updating is disabled in the config.php." : "Por favor, use a atualização de linha de comando, porque a atualização automática está desativada no config.php.",
-    "[%d / %d]: Checking table %s" : "[%d / %d]: Verificando tabela %s",
     "Turned on maintenance mode" : "Ativar o modo de manutenção",
     "Turned off maintenance mode" : "Desativar o modo de manutenção",
     "Maintenance mode is kept active" : "O modo de manutenção está sendo mantido como ativo",
@@ -79,7 +77,6 @@ OC.L10N.register(
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Sua instalação não tem uma região de telefone padrão definida. Isso é necessário para validar números de telefone nas configurações do perfil sem um código de país. Para permitir números sem um código de país, adicione \"default_phone_region\" com o respectivo {linkstart}código ISO 3166-1 ↗{linkend} da região para o seu arquivo de configuração.",
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Não foi possível executar a tarefa cron pelo CLI. Os seguintes erros técnicos surgiram:",
     "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "A última execução do trabalho em segundo plano foi {relativeTime}. Parece que há algo errado. {linkstart}Verifique as configurações do trabalho em segundo plano ↗{linkend}.",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Este é a construção de uma comunidade sem suporte do Nextcloud. Dado o tamanho desta instância, desempenho, confiabilidade e escalabilidade não podem ser garantidos. As notificações push foram desativadas para evitar sobrecarregar nosso serviço gratuito. Saiba mais sobre os benefícios do Nextcloud Enterprise em nextcloud.com/enterprise. ",
     "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Este servidor não tem conexão com a Internet: vários pontos alvo não puderam ser alcançados. Isso significa que alguns dos recursos, como montagem de armazenamento externo, notificações sobre atualizações ou instalação de aplicativos de terceiros, não funcionarão. Acessar arquivos remotamente e enviar e-mails de notificação também pode não funcionar. Estabeleça uma conexão deste servidor com a Internet para desfrutar de todos os recursos. ",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Nenhum cache de memória foi configurado. Para melhorar o desempenho, configure um memcache, se disponível. Mais informações podem ser encontradas na  {linkstart}documentação ↗{linkend}.",
     "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Nenhuma fonte adequada para aleatoriedade encontrada pelo PHP, o que é altamente desencorajado por razões de segurança. Mais informações podem ser encontradas na  {linkstart}documentação ↗{linkend}.",
@@ -100,7 +97,6 @@ OC.L10N.register(
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Nesta instalação estão faltando alguns módulos PHP recomendados. Para melhor desempenho e compatibilidade, é altamente recomendável instalá-los.",
     "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "O módulo PHP \"imagick\" não está habilitado, embora o aplicativo de temas esteja. Para que a geração de favicon funcione corretamente, você precisa instalar e habilitar este módulo.",
     "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "Os módulos PHP \"gmp\" e/ou \"bcmath\" não estão habilitados. Se você usar a autenticação sem senha do WebAuthn, esses módulos serão necessários.",
-    "It seems like you are running a 32bit PHP version. Nextcloud needs 64bit to run well. Please upgrade your OS and PHP to 64bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Parece que você está executando uma versão PHP de 32 bits. Nextcloud precisa de 64 bits para funcionar bem. Por favor, atualize seu sistema operacional e PHP para 64 bits! Para mais detalhes, leia {linkstart}a página de documentação sobre isso ↗ {linked}.",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "A extensão php-imagick nesta instância não tem suporte para SVG. Para melhor compatibilidade é recomendado instalá-la.",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Algumas colunas no banco de dados não têm uma conversão para big int. Devido ao fato de que alterar os tipos de coluna em tabelas grandes pode levar algum tempo, eles não foram alterados automaticamente. Ao executar \"occ db:convert-filecache-bigint\", essas alterações pendentes podem ser aplicadas manualmente. Esta operação precisa ser feita enquanto a instância estiver offline. Para mais detalhes, leia {linkstart}a página de documentação sobre este ↗{linkend}.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Atualmente, o SQLite está sendo usado como plataforma de banco de dados. Para instalações maiores, recomendamos que migre para outra.",
@@ -137,19 +133,18 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A atualização não foi realizada com sucesso. Por favor, informe este problema para  a <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade Nextcloud</a>.",
     "Continue to {productName}" : "Continuar para {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A atualização foi bem-sucedida. Redirecionando você à {productName} em %n segundo.","A atualização foi bem-sucedida. Redirecionando você para {productName} em %n segundos.","A atualização foi bem-sucedida. Redirecionando você para {productName} em %n segundos."],
+    "More apps" : "Mais aplicativos",
     "Log in" : "Entrar",
     "Logging in …" : "Entrando...",
     "Server side authentication failed!" : "Autenticação do servidor falhou!",
     "Please contact your administrator." : "Por favor, entre em contato com o administrador.",
     "An internal error occurred." : "Ocorreu um erro interno.",
     "Please try again or contact your administrator." : "Tente novamente ou entre em contato com o administrador.",
-    "Username or email" : "Nome de usuário ou e-mail",
     "Password" : "Senha",
-    "Show password" : "Mostrar senha",
-    "Hide password" : "Esconder a senha",
     "Wrong username or password." : "Senha ou nome de usuário incorretos.",
     "User disabled" : "Usuário desativado",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Detectamos várias tentativas de login inválidas de seu IP. Portanto, seu próximo login será desacelerado em até 30 segundos.",
+    "Username or email" : "Nome de usuário ou e-mail",
     "Your account is not setup for passwordless login." : "Sua conta não está configurada para login sem senha.",
     "Browser not supported" : "Navegador não suportado",
     "Passwordless authentication is not supported in your browser." : "A autenticação sem senha não é suportada no seu navegador.",
@@ -311,6 +306,7 @@ OC.L10N.register(
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para mais informações de como configurar apropriadamente seu servidor, consulte nossa <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentação</a>.",
     "Create an <strong>admin account</strong>" : "Criar uma <strong>conta de administrador</strong>",
     "Username" : "Nome do usuário",
+    "Show password" : "Mostrar senha",
     "Toggle password visibility" : "Alternar visibilidade da senha",
     "Storage & database" : "Armazenamento & banco de dados",
     "Data folder" : "Pasta de dados",
@@ -339,9 +335,6 @@ OC.L10N.register(
     "Skip to navigation of app" : "Ir à navegação do aplicativo",
     "Get your own free account" : "Obtenha uma conta grátis",
     "%s's homepage" : "Página inicial de%s",
-    "More apps" : "Mais aplicativos",
-    "More" : "Mais",
-    "More apps menu" : "Mais aplicativos",
     "Contacts" : "Contatos",
     "Contacts menu" : "Menu de contatos",
     "Open settings menu" : "Abrir menu de configurações",
@@ -397,6 +390,7 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instância %s está em modo de manutenção, o que pode demorar um pouco.",
     "This page will refresh itself when the instance is available again." : "Esta página será atualizada quando o Nextcloud estiver disponível novamente.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Entre em contato com o administrador do sistema se esta mensagem persistir ou aparecer inesperadamente.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Verificando tabela %s",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Este servidor não possui conexão com a internet: Vários pontos não puderam ser acessados. Isso significa que alguns dos recursos como montagem de armazenamento externo, notificações sobre atualizações ou instalação de aplicativos de terceiros não funcionarão. Acesso a arquivos remotos e envio de e-mails de notificação não funcionarão também. Estabeleça uma conexão deste servidor com a Internet para aproveitar todos os recursos.",
     "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 é a última versão compatível com PHP 7.2. Nextcloud 21 requer ao menos PHP 7.3.",
     "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "A extensão PHP OPcache não está carregada. {linkstart}Para melhor desempenho, é recomendado ↗{linkado} carregá-la na instalação do PHP.",
@@ -404,9 +398,13 @@ OC.L10N.register(
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Algumas colunas do banco de dados estão sem uma conversão para big int. Devido ao fato de que alterar os tipos de coluna em tabelas grandes pode levar algum tempo, elas não foram alteradas automaticamente. Executando 'occ db: convert-filecache-bigint' essas alterações pendentes podem ser aplicadas manualmente. Esta operação precisa ser feita enquanto a instância está offline. Para obter mais detalhes, leia {linkstart} a página de documentação sobre isso ↗{linkend}.",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "Para migrar para outro banco de dados, use a ferramenta de linha de comando: 'occ db:convert-type', ou consulte a  {linkstart}documentação do ↗{linkend}. ",
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Seu diretório de dados e arquivos provavelmente podem ser acessados pela Internet. O arquivo .htaccess não está funcionando. É altamente recomendado que você configure seu servidor web para que o diretório de dados não seja mais acessível ou mova o diretório de dados fora da raiz de documentos do servidor web.",
+    "More" : "Mais",
+    "More apps menu" : "Mais aplicativos",
     "Settings menu" : "Menu de configurações",
     "The password is wrong. Try again." : "Senha incorreta. Tente novamente.",
     "Setup two-factor authentication" : "Configurar autenticação de dois fatores",
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Este lançamento comunitário do Nextcloud não é compatível e as notificações instantâneas não estão disponíveis. ",
+    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Este é a construção de uma comunidade sem suporte do Nextcloud. Dado o tamanho desta instância, desempenho, confiabilidade e escalabilidade não podem ser garantidos. As notificações push foram desativadas para evitar sobrecarregar nosso serviço gratuito. Saiba mais sobre os benefícios do Nextcloud Enterprise em nextcloud.com/enterprise. ",
     "You haven't added any info yet" : "Você ainda não adicionou nenhuma informação",
     "{user} hasn't added any info yet" : "{user} ainda não adicionou nenhuma informação"
 },
