@@ -16,8 +16,8 @@ OC.L10N.register(
     "Invalid file provided" : "Указан недопустимый файл",
     "No image or file provided" : "Не указано изображение или файл",
     "Unknown filetype" : "Неизвестный тип файла",
-    "Invalid image" : "Недопустимое изображение",
     "An error occurred. Please contact your admin." : "Произошла ошибка. Свяжитесь со своим администратором.",
+    "Invalid image" : "Недопустимое изображение",
     "No temporary profile picture available, try again" : "Временная картинка профиля недоступна, повторите попытку",
     "No crop data provided" : "Не указана информация о кадрировании",
     "No valid crop data provided" : "Не указаны корректные данные о кадрировании",
@@ -26,7 +26,6 @@ OC.L10N.register(
     "Invalid app password" : "Неверный пароль приложения",
     "Could not complete login" : "Не удалось завершить вход в систему",
     "Your login token is invalid or has expired" : "Ваш токен неверен или истёк",
-    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Эта сборка Nextcloud для сообщества не обслуживается, мгновенные уведомления недоступны.",
     "Login" : "Войти",
     "Password reset is disabled" : "Сброс пароля отключён",
     "Could not reset password because the token is expired" : "Не было возможности сбросить пароль в связи с просроченным токеном",
@@ -48,7 +47,6 @@ OC.L10N.register(
     "Repair warning:" : "Предупреждение восстановления:",
     "Repair error:" : "Ошибка восстановления:",
     "Please use the command line updater because automatic updating is disabled in the config.php." : "Автоматические обновления отключены в файле конфигурации  «config.php». Выполните обновление из командной строки.",
-    "[%d / %d]: Checking table %s" : "[%d / %d]: Проверка таблицы %s",
     "Turned on maintenance mode" : "Включён режим обслуживания ",
     "Turned off maintenance mode" : "Отключён режим обслуживания",
     "Maintenance mode is kept active" : "Режим обслуживания оставлен включенным",
@@ -79,7 +77,6 @@ OC.L10N.register(
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Не указан регион размещения этого сервера Nextcloud, что требуется для возможности проверки номеров телефонов без указания кода страны. Чтобы разрешить пользователям сервера указывать номера телефонов без указания кода страны, добавьте параметр «default_phone_region» с соответствующим кодом страны в соответствии с  {linkstart}ISO 3166-1↗{linkend}.",
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Ошибка запуска задачи планировщика с использованием интерфейса командной строки. Подробное сообщение об ошибке:",
     "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Последняя фоновая задача была выполнена {relativeTime}. Похоже, что-то не в порядке.{linkstart}Проверьте настройки фонового задания ↗{linkend}. ",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Это неподдерживаемая сборка сообщества Nextcloud. Размер этого развёртывания не позволяет,  гарантировать производительность, надежность и масштабируемость. Push-уведомления отключены, чтобы не перегружать бесплатный сервис разработчиков Nextcloud. Узнайте больше о преимуществах корпоративной версии Nextcloud на сайте nextcloud.com/enterprise.",
     "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Этот сервер не подключён к интернету: множество конечных устройств не могут быть доступны. Это означает, что не будут работать некоторые функции, такие как подключение внешнего хранилища, уведомления об обновлениях или установка сторонних приложений. Так же могут не работать удалённый доступ к файлам и отправка уведомлений по электронной почте. Для использования всех возможностей рекомендуется разрешить серверу доступ в Интернет.",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Не настроена система кеширования. Для увеличения производительности сервера, по возможности, настройте memcache. Дополнительная информация представлена в {linkstart}документации ↗{linkend}.",
     "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Не найден подходящий источник случайных значений для PHP, что сильно влияет на уровень безопасности. Дополнительная информация представлена в {linkstart}документации ↗{linkend}.",
@@ -117,7 +114,7 @@ OC.L10N.register(
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Заголовок HTTP «{header}» не настроен на значение «{expected}». Это потенциальная проблема безопасности для устранения которой рекомендуется задать этот параметр.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "Заголовок HTTP «{header}» не настроен на значение «{expected}». Это может привести к неработоспособности некоторых из функций и рекомендуется изменить эти настройки.",
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Заголовок HTTP «{header}» не содержит параметр «{expected}». Это может привести к проблемам  безопасности. Рекомендуется задать этот параметр.",
-    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "Заголовок HTTP «{header}» не содержит значения «{val1}», «{val2}», «{val3}» или «{val4}», что может привести к утечке информации об адресе источника перехода по ссылке. Для получения более подробной информации обратитесь к {linkstart}рекомендациии W3C ↗{linkend}.",
+    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "Заголовок HTTP «{header}» не содержит значения «{val1}», «{val2}», «{val3}» или «{val4}», что может привести к утечке информации об адресе источника перехода по ссылке. Для получения более подробной информации обратитесь к {linkstart}рекомендации W3C ↗{linkend}.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "Заголовок HTTP «Strict-Transport-Security» должен быть настроен как минимум на «{seconds}» секунд. Для улучшения безопасности рекомендуется включить HSTS согласно нашим {linkstart}подсказкам по безопасности ↗{linkend}.",
     "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Используется небезопасное соединение по протоколу HTTP.  Настоятельно рекомендуется настроить сервер на использование HTTPS согласно нашим {linkstart}подсказкам по безопасности ↗{linkend}.",
     "unknown text" : "неизвестный текст",
@@ -136,18 +133,18 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Обновление не удалось. Сообщите об этой проблеме <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">сообществу Nextcloud</a>.",
     "Continue to {productName}" : "Перейти к {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Обновление выполнено успешно. Перенаправление в {productName} через %n секунду.","Обновление выполнено успешно. Перенаправление в {productName} через %n секунды.","Обновление выполнено успешно. Перенаправление в {productName} через %n секунд.","Обновление выполнено успешно. Перенаправление в {productName} через %n секунд."],
+    "More apps" : "Ещё приложения",
     "Log in" : "Войти",
     "Logging in …" : "Вход в систему…",
     "Server side authentication failed!" : "Ошибка аутентификации на стороне сервера!",
     "Please contact your administrator." : "Обратитесь к своему администратору.",
     "An internal error occurred." : "Произошла внутренняя ошибка.",
     "Please try again or contact your administrator." : "Пожалуйста попробуйте ещё раз или свяжитесь с вашим администратором",
-    "Username or email" : "Имя пользователя или адрес эл. почты",
     "Password" : "Пароль",
-    "Show password" : "Показать пароль",
     "Wrong username or password." : "Неверное имя пользователя или пароль.",
     "User disabled" : "Пользователь отключён",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "С вашего IP-адреса было выполнено множество неудачных попыток входа в систему. Следующую попытку можно будет выполнить через 30 секунд.",
+    "Username or email" : "Имя пользователя или адрес эл. почты",
     "Your account is not setup for passwordless login." : "Ваша учётная запись не настроена на вход без пароля.",
     "Browser not supported" : "Используемый браузер не поддерживается",
     "Passwordless authentication is not supported in your browser." : "Ваш браузер не поддерживает безпарольную аутентификацию",
@@ -309,6 +306,7 @@ OC.L10N.register(
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Сведения о правильной настройке сервера можно найти в <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документации</a>.",
     "Create an <strong>admin account</strong>" : "Создать <strong>учётную запись администратора</strong>",
     "Username" : "Имя пользователя",
+    "Show password" : "Показать пароль",
     "Toggle password visibility" : "Переключить видимость пароля",
     "Storage & database" : "Хранилище и база данных",
     "Data folder" : "Каталог с данными",
@@ -337,9 +335,6 @@ OC.L10N.register(
     "Skip to navigation of app" : "Перейти к навигации по приложению",
     "Get your own free account" : "Создайте свою бесплатную учётную запись",
     "%s's homepage" : "Домашняя страница %s",
-    "More apps" : "Ещё приложения",
-    "More" : "Дополнительно",
-    "More apps menu" : "Меню дополнительных приложений",
     "Contacts" : "Контакты",
     "Contacts menu" : "Меню контактов",
     "Confirm your password" : "Подтвердите свой пароль",
@@ -394,6 +389,7 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Этот сервер %s находится в режиме технического обслуживания, которое может занять некоторое время.",
     "This page will refresh itself when the instance is available again." : "Эта страница обновится автоматически когда сервер снова станет доступен.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Обратитесь к вашему системному администратору если это сообщение не исчезает или появляется неожиданно.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Проверка таблицы %s",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Этот сервер не подключён к интернету: множество конечных устройств не могут быть доступны. Это означает, что не будут работать некоторые функции, такие как подключение внешнего хранилища, уведомления об обновлениях или установка сторонних приложений. Так же могут не работать удалённый доступ к файлам и отправка уведомлений по электронной почте. Для использования всех возможностей рекомендуется разрешить серверу доступ в Интернет.",
     "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud версии 20 — последний выпуск, поддерживающий PHP версии 7.2. Для работы Nextcloud версии 21 потребуется PHP версии не ниже 7.3.",
     "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "Не загружен PHP-модуль OPcache. Рекомендуется настроить этот модуль для {linkstart}улучшения производительности ↗{linkend}.",
@@ -401,9 +397,13 @@ OC.L10N.register(
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Некоторые индексы базы данных не были преобразованы в тип big int. Так как преобразование таких индексов может занять продолжительное время, оно должно быть запущенно вручную. Чтобы выполнить преобразование, необходимо включить режим обслуживания и запустить в терминале команду «occ db:convert-filecache-bigint». Дополнительные сведения приведены {linkstart}на соответствующей странице документации ↗{linkend}.",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "Для миграции на другую базу данных используйте команду 'occ db:convert-type' или обратитесь к {linkstart}документации ↗{linkend}.",
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Каталог данных и файлы, возможно, доступны из интернета. Файл «.htaccess» не работает. Настоятельно рекомендуется настроить веб сервер таким образом, чтобы каталог данных не был доступен из внешней сети, либо переместить каталог данных за пределы корневого каталога веб-сервера.",
+    "More" : "Дополнительно",
+    "More apps menu" : "Меню дополнительных приложений",
     "Settings menu" : "Меню настроек",
     "The password is wrong. Try again." : "Неверный пароль. Повторите попытку.",
     "Setup two-factor authentication" : "Установка двухфакторной аутентификации",
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Эта сборка Nextcloud для сообщества не обслуживается, мгновенные уведомления недоступны.",
+    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Это неподдерживаемая сборка сообщества Nextcloud. Размер этого развёртывания не позволяет,  гарантировать производительность, надежность и масштабируемость. Push-уведомления отключены, чтобы не перегружать бесплатный сервис разработчиков Nextcloud. Узнайте больше о преимуществах корпоративной версии Nextcloud на сайте nextcloud.com/enterprise.",
     "You haven't added any info yet" : "Вы еще не добавили никакой информации",
     "{user} hasn't added any info yet" : "{user} ещё не добавил никакой информации"
 },
