@@ -39,7 +39,7 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "Nekatere povezave za souporabo so bile odstranjene.",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Zaradi varnostnih razlogov so bile nekatere povezave odstranjene. Več podrobnosti je na voljo v uradno izdanem opozorilu.",
     "The user limit of this instance is reached." : "Dosežena je količinska omejitev za uporabnika.",
-    "Learn more ↗" : "Več o tem ↗",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Vpišite ključ naročnine in povečajte omejitev za uporabnika. Za več podrobnosti si oglejte Poslovni paket Nextcloud na spletni strani.",
     "Preparing update" : "Poteka priprava na posodobitev ...",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Korak nadgradnje:",
@@ -101,6 +101,7 @@ OC.L10N.register(
     "For more details see the {linkstart}documentation ↗{linkend}." : "Za več podrobnosti preverite {linkstart}dokumentacijo ↗{linkend}.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Glava HTTP »{header}« ni nastavljena na pričakovano vrednost »{expected}«. To predstavlja potencialno varnostno ali zasebnostno tveganje, zato je priporočljivo prilagoditi nastavitve.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "Glava HTTP »{header}« ni nastavljena na pričakovano vrednost »{expected}«. Nekatere možnosti morda ne bodo delovale pravilno, zato je priporočljivo prilagoditi nastavitve.",
+    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Glava \"{header}\" HTTP ne vsebuje »{expected}«. To je potencialno varnostna luknja, zato priporočamo prilagoditev nastavitev.",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "Glava HTTP »{header}« ni nastavljena na »{val1}«, »{val2}«, »{val3}«, »{val4}« oziroma »{val5}«. To lahko povzroči iztekanje podatkov sklicatelja. Več o tem si lahko ogledate med priporočili {linkstart}priporočili W3C ↗{linkend}.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "Glava HTTP za varen prenos podatkov »Strict-Transport-Security« ni nastavljena na vsaj »{seconds}« sekund. Za večjo varnost je priporočljivo omogočiti pravila HSTS, kot je opisano med {linkstart}varnostnimi priporočili ↗{linkend}.",
     "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Dostop do strani je omogočen pred nevarovanega protokola HTTP. Priporočljivo je na strežniku vsiliti uporabo HTTPS, kot je zavedeno med {linkstart}varnostnimi priporočili ↗{linkend}.",
@@ -121,17 +122,13 @@ OC.L10N.register(
     "Continue to {productName}" : "Nadaljuj v {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekundo.","Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekundi.","Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekunde.","Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekund."],
     "More apps" : "Več programov",
-    "Currently open" : "Trenutno odprto",
-    "_{count} notification_::_{count} notifications_" : ["{count} obvestilo","{count} obvestili","{count} obvestila","{count} obvestil"],
     "Log in" : "Prijava",
     "Logging in …" : "Poteka prijavljanje ...",
     "Server side authentication failed!" : "Overitev na strani strežnika je spodletela!",
     "Please contact your administrator." : "Stopite v stik s skrbnikom sistema.",
     "An internal error occurred." : "Prišlo je do notranje napake.",
     "Please try again or contact your administrator." : "Poskusite znova ali pa stopite v stik s skrbnikom sistema.",
-    "Account name or email" : "Ime računa ali elektronski naslov",
     "Password" : "Geslo",
-    "Log in to {productName}" : "Prijava v {productName}",
     "Wrong username or password." : "Napačno uporabniško ime oziroma geslo",
     "User disabled" : "Uporabnik je onemogočen",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Zaznanih je več neveljavnih poskusov prijave iz trenutnega naslova IP. Iz varnostnih razlogov bo možnost naslednjega poskusa prijave zadržana za 30 sekund.",
@@ -153,7 +150,6 @@ OC.L10N.register(
     "Resetting password" : "Ponastavljanje gesla",
     "Recommended apps" : "Priporočeni programi",
     "Loading apps …" : "Poteka nalaganje programov ...",
-    "Could not fetch list of apps from the App Store." : "Ni mogoče pridobiti seznama programov iz trgovine.",
     "Installing apps …" : "Poteka nameščanje programov ...",
     "App download or installation failed" : "Prejem oziroma namestitev programa je spodletela.",
     "Cannot install this app because it is not compatible" : "Programa ni mogoče namestiti, ker ni skladen z različico okolja.",
@@ -164,24 +160,22 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Združite sodelavce in prijatelje na enem mestu brez skrbi za njihove zasebne podatke.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Enostaven program za pošto se odlično povezuje z Datotekami, Stiki in Koledarjem.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Klepet, video klici, souporaba zaslonske slike, spletni sestanki in konference – znotraj brskalnika in z mobilnimi napravami.",
+    "Collaboratively edit office documents." : "Sodelovalno urejanje pisarniških dokumentov.",
+    "Local document editing back-end used by the Collabora Online app." : "Ozadnji program za krajevno urejanje dokumentov, ki ga uporablja program Collabora Online.",
     "Forgot password?" : "Ali ste pozabili geslo?",
     "Log in with a device" : "Prijava z napravo",
     "Back" : "Nazaj",
     "Login form is disabled." : "Prijavni obrazec je onemogočen.",
     "Edit Profile" : "Uredi profil",
-    "Search starts once you start typing" : "Iskanje se začne z vpisovanjem",
     "Reset search" : "Ponastavi iskanje",
-    "Start search" : "Začni z iskanjem",
     "Search for {name} only" : "Išči le za {name}",
     "No results for {query}" : "Ni zadetkov za poizvedbo {query}",
-    "Press enter to start searching" : "Pritisnite vnosno tipko za začetek iskanja",
     "Start typing to search" : "Začnite tipkati za iskanje",
     "Loading more results …" : "Poteka nalaganje več zadetkov ...",
     "Load more results" : "Naloži več zadetkov",
     "Search" : "Poišči",
     "An error occurred while searching for {type}" : "Prišlo je do napake med iskanjem vrste {type}.",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Vpisati je treba vsaj {minSearchLength} znak za začetek iskanja","Vpisati je treba vsaj {minSearchLength} znaka za začetek iskanja","Vpisati je treba vsaj {minSearchLength} znake za začetek iskanja","Vpisati je treba vsaj {minSearchLength} znakov za začetek iskanja"],
-    "Supported versions" : "Podprte različice",
     "Search {types} …" : "Poišči {types} …",
     "Settings" : "Nastavitve",
     "Could not load your contacts" : "Stikov ni mogoče naložiti",
@@ -254,8 +248,8 @@ OC.L10N.register(
     "No action available" : "Ni razpoložljivih dejanj",
     "Error fetching contact actions" : "Prišlo je do napake med pridobivanjem dejanj stikov",
     "Non-existing tag #{tag}" : "Neobstoječa oznaka #{tag}",
-    "Restricted" : "Omejeno",
-    "Invisible" : "Drugim nevidno",
+    "restricted" : "omejeno",
+    "invisible" : "nevidno",
     "Delete" : "Izbriši",
     "Rename" : "Preimenuj",
     "Collaborative tags" : "Sodelovalne oznake",
@@ -269,7 +263,8 @@ OC.L10N.register(
     "Profile not found" : "Profila ni mogoče najti",
     "The profile does not exist." : "Profil ne obstaja.",
     "Back to %s" : "Nazaj na %s",
-    "Page not found" : "Strani ni mogoče najti",
+    "File not found" : "Datoteke ni mogoče najti",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Na strežniku ni mogoče najti dokumentacije. Morda je mesto souporabe izbrisano, ali pa so potekla dovoljenja.",
     "Too many requests" : "Zaznanih je preveč sočasnih zahtev",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Iz omrežja je bilo prejetih preveč zahtev. Če je to napaka, stopite v stik s skrbnikom, sicer pa poskusite spet kasneje.",
     "Error" : "Napaka",
@@ -311,7 +306,6 @@ OC.L10N.register(
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "Podatkovna zbirka SQLite je primerna le za manjše in razvojne namestitve. Za produkcijsko okolje je priporočljivo uporabiti drugo podatkovno ozadje.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Če uporabljate namizni odjemalec za usklajevanje datotek, je uporaba podatkovne zbirke SQLite odsvetovana.",
     "Install" : "Namesti",
-    "Installing …" : "Poteka nameščanje ...",
     "Need help?" : "Ali potrebujete pomoč?",
     "See the documentation" : "Preverite dokumentacijo",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Kaže, da poskušate ponovno namestiti okolje Nextcloud, a datoteke CAN_INSTALL ni v mapi nastavitev. Ustvarite jo, potem lahko poskusite znova.",
@@ -322,7 +316,6 @@ OC.L10N.register(
     "Get your own free account" : "Pridobite brezplačni račun",
     "Contacts" : "Stiki",
     "Contacts menu" : "Meni Stikov",
-    "Open settings menu" : "Odpri meni nastavitev",
     "Confirm your password" : "Potrdite geslo",
     "Connect to your account" : "Povežite z računom",
     "Please log in before granting %1$s access to your %2$s account." : "Pred %1$s odobritvijo dostopa %2$s do računa se je treba prijaviti.",
@@ -337,7 +330,6 @@ OC.L10N.register(
     "You can close this window." : "To okno lahko zaprete.",
     "This share is password-protected" : "To mesto je zaščiteno z geslom",
     "Email address" : "Elektronski naslov",
-    "Password sent!" : "Geslo je poslano!",
     "Go to %s" : "Odpri oblak %s",
     "Two-factor authentication" : "Dvo-stopenjska overitev",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Za vaš račun je omogočena zahteva za višjo raven varnosti. Izberite drugo stopnjo overitve:",
@@ -371,18 +363,14 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Strežnik %s je trenutno v vzdrževalnem načinu, kar onemogoča prijavo.",
     "This page will refresh itself when the instance is available again." : "Stran bo samodejno osvežena, ko bo okolje spet pripravljeno za delo.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Če se bo to sporočilo še naprej nepričakovano pojavljalo, stopite v stik s skrbnikom sistema.",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Vpišite ključ naročnine in povečajte omejitev za uporabnika. Za več podrobnosti si oglejte Poslovni paket Nextcloud na spletni strani.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Poteka preverjanje razpredelnice %s",
+    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Strežnik je brez vzpostavljene internetne povezave. Več končnih točk ni mogoče doseči. To pomeni, da priklapljanje zunanjih diskov,  opozorila za posodobitve in namestitve programske opreme iz drugih virov, niso mogoče. Oddaljen dostop do datotek in pošiljanje obvesti najverjetneje prav tako ne deluje. Vzpostavite povezavo, da omogočite vso funkcionalnost.",
+    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Okolje Nextcloud 20 je zadnja različica, ki omogoča podporo PHP 7.2. Nextcloud 21 zahteva vsaj različico PHP 7.3.",
+    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "Modul PHP OPcache ni naložen. {linkstart}Za najboljše delovanje je priporočljivo ↗{linkend} modul dodati k uporabljeni namestitvi PHP.",
+    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "Modul PHP OPcache ni pravilno nastavljen. {linkstart}Za najboljše delovanje je priporočljivo ↗{linkend} uporabiti posebne nastavitve v datoteki <code>php.ini</code>:",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Nekateri stolpci v podatkovni zbirki so brez pretvornika velikih števil. Ker je spreminjanje stolpcev na velikih razpredelnicah časovno izredno zahtevno opravilo, ti niso spremenjeni samodejno. Z ukazom »occ db:convert-filecache-bigint« je mogoče te spremembe dodati ročno. Opravilo je treba izvesti, ko okolje ni dejavno. Več podrobnosti je zabeleženih v {linkstart}dokumentaciji ↗{linkend}.",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "Za prehod sistema na drugo podatkovno zbirko, uporabite ukaz orodne vrstice: »occ db:convert-type«, več o tem pa je zapisano v {linkstart}dokumentaciji ↗{linkend}.",
-    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Glava \"{header}\" HTTP ne vsebuje »{expected}«. To je potencialno varnostna luknja, zato priporočamo prilagoditev nastavitev.",
-    "Collaboratively edit office documents." : "Sodelovalno urejanje pisarniških dokumentov.",
-    "Local document editing back-end used by the Collabora Online app." : "Ozadnji program za krajevno urejanje dokumentov, ki ga uporablja program Collabora Online.",
-    "You haven't added any info yet" : "Ni še vpisanih podatkov",
-    "restricted" : "omejeno",
-    "invisible" : "nevidno",
-    "File not found" : "Datoteke ni mogoče najti",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Na strežniku ni mogoče najti dokumentacije. Morda je mesto souporabe izbrisano, ali pa so potekla dovoljenja.",
+    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Podatkovna mapa in datoteke so najverjetneje dostopni na Internetu, ker datoteka .htaccess ni ustrezno nastavljena. Priporočljivo je nastaviti spletni strežnik tako, da dostop do mape z zunanjega omrežja ni mogoč, ali pa tako, da podatkovno mapo prestavite izven korenske mape strežnika.",
     "More" : "Več",
     "More apps menu" : "Meni več programov",
     "Settings menu" : "Meni nastavitev",
