@@ -36,7 +36,6 @@ OC.L10N.register(
     "Nextcloud Server" : "Некстклауд сервер",
     "Some of your link shares have been removed" : "Неке везе дељења су уклоњене",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Услед безбедоносних мера, морали смо да уклонимо неке од ваших веза дељења. Кликните везу за више информација.",
-    "Learn more ↗" : "Сазнајте више ↗",
     "Preparing update" : "Припремам ажурирање",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Корак поправке:",
@@ -51,7 +50,7 @@ OC.L10N.register(
     "Updated database" : "База података ажурирана",
     "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Провера да ли шема базе података за %s може бити ажурирана (ово може да потраје, у зависности од величине базе)",
     "Updated \"%1$s\" to %2$s" : "„%1$s“ ажурирано на %2$s",
-    "Set log level to debug" : "Постави ниво дневника на дебаговање",
+    "Set log level to debug" : "Постави ниво уписа у дневник на дебаговање",
     "Reset log level" : "Ресетуј ниво уписа у дневник",
     "Starting code integrity check" : "Почињем проверу интегритета кода",
     "Finished code integrity check" : "Завршена провера интегритета кода",
@@ -79,6 +78,7 @@ OC.L10N.register(
     "Error occurred while checking server setup" : "Дошло је до грешке при провери поставки сервера",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавље „{header}“ није подешено као „{expected}“. Ово потенцијално угрожава безбедност и приватност и препоручује се да подесите ову поставку.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP заглавље „{header}“ није подешено као „{expected}“. Неке функције можда неће радити исправно, па препоручује се да подесите ову поставку.",
+    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавље „{header}“ не садржи „{expected}“. Ово потенцијално угрожава безбедност и приватност и препоручује се да подесите ову поставку.",
     "unknown text" : "непознат текст",
     "Hello world!" : "Здраво свете!",
     "sunny" : "сунчано",
@@ -91,8 +91,8 @@ OC.L10N.register(
     "Update to {version}" : "Ажурирај на {version}",
     "An error occurred." : "Дошло је до грешке.",
     "Please reload the page." : "Поново учитајте страницу.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Ажурирање није успело. За више информација <a href=\"{url}\">погледајте нашу објаву на форуму</a> која обрађује ову тему.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Ажурирање није успело. Пријавите овај проблем <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Некстклауд заједници</a>.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Ажурирање није успело. За више информација <a href=\"{url}\">проверите нашу објаву на форуму</a> која обрађује ову тему.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Ажурирање није успело. Молимо пријавите овај проблем <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Некстклауд заједници</a>.",
     "More apps" : "Још апликација",
     "Log in" : "Пријава",
     "Logging in …" : "Пријављивање …",
@@ -104,7 +104,7 @@ OC.L10N.register(
     "Wrong username or password." : "Погрешно корисничко име или лозинка",
     "User disabled" : "Корисник искључен",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Приметили смо више неисправних покушаја пријава са Ваше IP адресе. Следећа пријава ће бити могућа тек за 30 секунди.",
-    "Username or email" : "Корисничко име или е-адреса",
+    "Username or email" : "Корисничко име или адреса е-поште",
     "Your account is not setup for passwordless login." : "Ваш налог није подешен за пријаву без лозинке.",
     "Passwordless authentication is not supported in your browser." : "Ваш веб читач не подржава пријављивање без лозинке.",
     "Passwordless authentication is only available over a secure connection." : "Пријављивање без лозинке је доступно само на безбедним конекцијама.",
@@ -126,6 +126,8 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Држите колеге и пријатеље на једном месту без цурења приватних података.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Једноставна е-мејл апликација која се лепо интегрише са Фајловима, Контактима и Календаром.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Ћаскање, видео позиви, дељење екрана, састанци на интернету & веб конференције – на десктоп рачунару и преко мобилних апликација.",
+    "Collaboratively edit office documents." : "Уређујте документа заједно.",
+    "Local document editing back-end used by the Collabora Online app." : "Позадински мотор за локално уређивање докумената који користи Collabora апликацију.",
     "Forgot password?" : "Заборавили сте лозинку?",
     "Log in with a device" : "Пријава са уређајем",
     "Back" : "Назад",
@@ -210,8 +212,8 @@ OC.L10N.register(
     "No action available" : "Нема доступне радње",
     "Error fetching contact actions" : "Грешка приликом дохватања акција над контактима",
     "Non-existing tag #{tag}" : "Непостојећа ознака #{tag}",
-    "Restricted" : "Ограничена",
-    "Invisible" : "Невидљива",
+    "restricted" : "ограничено",
+    "invisible" : "невидљиво",
     "Delete" : "Обриши",
     "Rename" : "Преименуј",
     "Collaborative tags" : "Oзнаке сарадње",
@@ -223,7 +225,8 @@ OC.L10N.register(
     "Help" : "Помоћ",
     "Access forbidden" : "Забрањен приступ",
     "Back to %s" : "Назад на %s",
-    "Page not found" : "Страна није нађена",
+    "File not found" : "Фајл није нађен",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Овај документ није нађен на серверу. Можда је дељење избрисано или му је истекао рок трајања?",
     "Too many requests" : "Превише захтева",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Са ваше мреже долази превише захтева. Покушајте поново касније или контактирајте администратора уколико је ово нека грешка.",
     "Error" : "Грешка",
@@ -234,7 +237,7 @@ OC.L10N.register(
     "More details can be found in the server log." : "Више детаља се може наћи у дневнику сервера.",
     "Technical details" : "Технички детаљи",
     "Remote Address: %s" : "Удаљена адреса: %s",
-    "Request ID: %s" : "ИД захтева: %s",
+    "Request ID: %s" : "ID захтева: %s",
     "Type: %s" : "Тип: %s",
     "Code: %s" : "Кôд: %s",
     "Message: %s" : "Порука: %s",
@@ -251,7 +254,7 @@ OC.L10N.register(
     "Data folder" : "Фасцикла за податке",
     "Configure the database" : "Подешавање базе",
     "Only %s is available." : "Само %s је доступна.",
-    "Install and activate additional PHP modules to choose other database types." : "Инсталирајте и активирајте додатне „ПХП“ модуле за одабир других база података.",
+    "Install and activate additional PHP modules to choose other database types." : "Инсталирајте и активирајте додатне PHP модуле за одабир других база података.",
     "For more details check out the documentation." : "За више детаља погледајте документацију.",
     "Database user" : "Корисник базе",
     "Database password" : "Лозинка базе",
@@ -264,7 +267,7 @@ OC.L10N.register(
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite треба да се користи само за најмање инстанце или за инстанце за развој. За продукцију, препоручујемо други тип база података.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Коришћење SQLite базе података нарочите није препоручљиво ако користите клијенте за синхронизацију фајлова.",
     "Install" : "Инсталирај",
-    "Need help?" : "Треба вам помоћ?",
+    "Need help?" : "Треба Вам помоћ?",
     "See the documentation" : "Погледајте документацију",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Делује као да покушавате да реинсталирате Некстклауд. Међутим, фајл CAN_INSTALL фали из конфигурационог директоријума, Молимо креирајте фајл CAN_INSTALL у овом директоријуму да бисте наставили.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Не могу да уклоним CAN_INSTALL из конфигурационе фасцикле. Уклоните овај фајл ручно.",
@@ -306,7 +309,7 @@ OC.L10N.register(
     "App update required" : "Потребно ажурирање апликације",
     "%1$s will be updated to version %2$s" : "%1$s ће бити ажуриран на верзију %2$s",
     "The following apps will be updated:" : "Следеће апликације ће бити ажуриране:",
-    "These incompatible apps will be disabled:" : "Ове неусаглашене апликације биће онемогућене:",
+    "These incompatible apps will be disabled:" : "Следеће некомпатибилне апликације ће бити онемогућене:",
     "The theme %s has been disabled." : "Тема %s је онемогућена.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Проверите да ли сте направили резервну копију фасцикли са подешавањима и подацима пре него што наставите.",
     "Start update" : "Почни ажурирање",
@@ -322,13 +325,9 @@ OC.L10N.register(
     "This page will refresh itself when the instance is available again." : "Ова страница ће се сама освежити када инстанца постане поново доступна.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Контактирајте администратора ако се порука понавља или се неочекивано појавила.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Проверавам табелу %s",
-    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавље „{header}“ не садржи „{expected}“. Ово потенцијално угрожава безбедност и приватност и препоручује се да подесите ову поставку.",
-    "Collaboratively edit office documents." : "Уређујте документа заједно.",
-    "Local document editing back-end used by the Collabora Online app." : "Позадински мотор за локално уређивање докумената који користи Collabora апликацију.",
-    "restricted" : "ограничено",
-    "invisible" : "невидљиво",
-    "File not found" : "Фајл није нађен",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Овај документ није нађен на серверу. Можда је дељење избрисано или му је истекао рок трајања?",
+    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Овај сервер нема интернет конекцију: немогуће је доћи до више интернет крајњих тачака. Ово значи да неке могућности као што су качење спољних складишта, обавештења о ажурирањима или инсталација апликација треће стране неће радити. Приступање фајловима споља и слање обавештења е-поштом исто тако може да не ради. Омогућите интернет конекцију на овом серверу ако желите да уживате у свим могућностима.",
+    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Некстклауд 20 је последње издање са подршком за PHP 7.2. Некстклауд 21 захтева бар PHP 7.3",
+    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Ваша фасцикла са подацима и фајлови су вероватно доступни са интернета. .htaccess фајл не ради. Препоручујемо да подесите Ваш веб сервер тако да је фасцикла са подацима ван фасцикле кореног документа веб сервера.",
     "More" : "Још",
     "More apps menu" : "Мени још апликација",
     "Settings menu" : "Мени подешавања",
