@@ -16,8 +16,8 @@ OC.L10N.register(
     "Invalid file provided" : "提供了无效文件",
     "No image or file provided" : "没有提供图片或文件",
     "Unknown filetype" : "未知的文件类型",
-    "Invalid image" : "无效的图像",
     "An error occurred. Please contact your admin." : "发生了错误，请联系管理员。",
+    "Invalid image" : "无效的图像",
     "No temporary profile picture available, try again" : "没有临时个人页图片可用，请重试",
     "No crop data provided" : "没有提供剪裁数据",
     "No valid crop data provided" : "没有提供有效的裁剪数据",
@@ -26,7 +26,6 @@ OC.L10N.register(
     "Invalid app password" : "无效的应用密码",
     "Could not complete login" : "无法完成登录",
     "Your login token is invalid or has expired" : "您的登录token无效或已过期",
-    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Nextcloud 的这个社区版本不受支持，即时通知不可用。",
     "Login" : "登录",
     "Password reset is disabled" : "密码重置不可用",
     "Could not reset password because the token is expired" : "无法重设密码，因为令牌已过期",
@@ -48,7 +47,6 @@ OC.L10N.register(
     "Repair warning:" : "修复 警告：",
     "Repair error:" : "修复 错误：",
     "Please use the command line updater because automatic updating is disabled in the config.php." : "由于自动更新在 config.php 中已禁用，请使用命令行更新。",
-    "[%d / %d]: Checking table %s" : "[%d / %d]：检查数据表 %s",
     "Turned on maintenance mode" : "启用维护模式",
     "Turned off maintenance mode" : "关闭维护模式",
     "Maintenance mode is kept active" : "维护模式已启用",
@@ -79,7 +77,6 @@ OC.L10N.register(
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "您的安装没有设置默认的电话区域。这对验证配置设定中没有国家代码的电话号码而言是必需的。要允许没有国家代码的电话号码，请添加带区域相应的 {linkstart}ISO 3166-1 code ↗{linkend} 的“默认_电话_区域”到你的配置文件中。",
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "无法通过 CLI 执行计划任务，请查看以下技术错误：",
     "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "上一个后台作业执行运行了 {relativeTime}。好像出了什么问题。{linkstart}检查后台作业设置 ↗{linkend}",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "这是 Nextcloud 不受支持的社区构建。鉴于此实例的大小，无法保证性能、可靠性和可伸缩性。推送通知已被禁用，以避免超量使用我们的免费服务。访问 nextcloud.com/enterprise 了解更多关于企业版的优势。",
     "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "此服务器没有工作的互联网连接：无法访问多个端点。这意味着一些功能，如挂载外部存储、更新或安装第三方应用程序的通知将无法工作。远程访问文件和发送通知邮件也可能无法工作。建立从这个服务器到互联网的连接，以享受所有功能。",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "内存缓存未配置。为了提升性能，请尽量配置内存缓存。更多信息请参见{linkstart}文档↗{linkend}。",
     "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "PHP找不到合适的随机性来源，出于安全原因，这是强烈不推荐的。 更多信息可以在{linkstart}文档↗{linkend}中找到。",
@@ -100,7 +97,6 @@ OC.L10N.register(
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "该实例缺失了一些推荐的 PHP 模块。为提高性能和兼容性，我们强烈建议安装它们。",
     "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "PHP模块 \"imagick\" 没有被启用，尽管已启用了主题程序。为了使收藏图标的生成正常工作，你需要安装并启用这个模块。",
     "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "PHP 模块 \"gmp\" 和/或 \"bcmath\" 未被启用。如果你使用 WebAuthn 无密码验证，这些模块是必需的。",
-    "It seems like you are running a 32bit PHP version. Nextcloud needs 64bit to run well. Please upgrade your OS and PHP to 64bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "看起来你运行的是 32bit 的 PHP 版本。Nextcloud 需要 64bit 才能运行良好。请将您的操作系统和 PHP 升级到 64bit! 更多详情请阅读 {linkstart}有关于此的文档页面 ↗{linkend}。",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "此实例中的 php-imagick 模块不支持 SVG。为了获得更好的兼容性，建议安装它。",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "数据库中的一些列缺少对 BigInt 的转换。由于改变大表的列类型可能需要一些时间，所以它们没有被自动改变。通过运行 \"occ db:convert-filecache-bigint\"，可以手动应用这些未决的变化。这个操作需要在实例离线的情况下进行。更多详情请阅读 {linkstart}有关于此的文档页面 ↗{linkend}。",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "当前正在使用 SQLite 作为后端数据库。多用户使用时，推荐您改用其他的数据库。",
@@ -137,19 +133,18 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "升级失败。请将此问题报告给 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud 社区</a>。",
     "Continue to {productName}" : "继续到 {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["更新成功。%n 秒内将把你重定向到 {productName}"],
+    "More apps" : "更多的应用程序",
     "Log in" : "登录",
     "Logging in …" : "正在登录 …",
     "Server side authentication failed!" : "服务端认证失败！",
     "Please contact your administrator." : "请联系您的管理员。",
     "An internal error occurred." : "发生了内部错误。",
     "Please try again or contact your administrator." : "请重试或联系您的管理员。",
-    "Username or email" : "用户名或邮箱",
     "Password" : "密码",
-    "Show password" : "显示密码",
-    "Hide password" : "隐藏密码",
     "Wrong username or password." : "错误的用户名或密码。",
     "User disabled" : "用户不可用",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "我们检测到您的 IP 进行了多次无效登录尝试。因此，你的下一次登录最长会延迟30秒。",
+    "Username or email" : "用户名或邮箱",
     "Your account is not setup for passwordless login." : "您的账号未设置无密码登录。",
     "Browser not supported" : "浏览器不受支持",
     "Passwordless authentication is not supported in your browser." : "浏览器不支持无密码验证。",
@@ -311,6 +306,7 @@ OC.L10N.register(
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "了解如何正确配置服务器，请参见 <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">文档</a>。",
     "Create an <strong>admin account</strong>" : "创建 <strong>管理员账号</strong>",
     "Username" : "用户名",
+    "Show password" : "显示密码",
     "Toggle password visibility" : "切换密码可见性",
     "Storage & database" : "存储与数据库",
     "Data folder" : "数据目录",
@@ -339,9 +335,6 @@ OC.L10N.register(
     "Skip to navigation of app" : "跳过应用向导",
     "Get your own free account" : "获取自己的免费账号",
     "%s's homepage" : "%s的主页",
-    "More apps" : "更多的应用程序",
-    "More" : "更多",
-    "More apps menu" : "更多的应用菜单",
     "Contacts" : "联系人",
     "Contacts menu" : "联系人菜单",
     "Open settings menu" : "打开设置菜单",
@@ -397,6 +390,7 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "该实例 %s 当前处于维护模式，这将花费一些时间。",
     "This page will refresh itself when the instance is available again." : "当实例再次可用时，页面会自动刷新。",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "如果这个消息一直存在或不停出现，请联系您的系统管理员。",
+    "[%d / %d]: Checking table %s" : "[%d / %d]：检查数据表 %s",
     "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "此服务器没有可用的互联网连接：多个节点无法访问。这意味着某些功能比如挂载外部存储，更新通知以及安装第三方应用将无法工作。远程访问文件和发送通知邮件可能也不工作。启用这台服务器上的互联网连接以享用所有功能。",
     "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 将是最后一个支持 PHP 7.2 的发布版。Nextcloud 21 将最低支持 PHP 7.3。",
     "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "未加载 PHP OPcache 模块。{linkstart} 为了更佳性能，建议 ↗{linkend} 将其加载到你的 PHP 安装。",
@@ -404,9 +398,13 @@ OC.L10N.register(
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "数据库中的一些列缺少到 big int 的转换。由于更改大表上的列类型可能需要一些时间，所以它们不会被自动更改。通过运行 'occ db:convert-filecache-bigint'，这些挂起的更改可以手动应用。需要在实例离线时执行此操作。进一步的细节，可以阅读 {linkstart} 关于此问题的文档页面 ↗{linkend}",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "要迁移到另一个数据库，使用命令行工具 'occ db:convert-type'或见 {linkstart}文档↗{linkend}",
     "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "您的数据目录和文件可以从互联网直接访问。.htaccess 文件不起作用。强烈建议您配置 Web 服务器，以便数据目录不再可访问，或者您可以将数据目录移动到 Web 服务器文档根目录。",
+    "More" : "更多",
+    "More apps menu" : "更多的应用菜单",
     "Settings menu" : "设置菜单",
     "The password is wrong. Try again." : "用户名或密码错误！请重试",
     "Setup two-factor authentication" : "配置两步验证",
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Nextcloud 的这个社区版本不受支持，即时通知不可用。",
+    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "这是 Nextcloud 不受支持的社区构建。鉴于此实例的大小，无法保证性能、可靠性和可伸缩性。推送通知已被禁用，以避免超量使用我们的免费服务。访问 nextcloud.com/enterprise 了解更多关于企业版的优势。",
     "You haven't added any info yet" : "你尚未添加任何信息",
     "{user} hasn't added any info yet" : "{user} 尚未添加任何信息"
 },
