@@ -1,7 +1,7 @@
 OC.L10N.register(
     "core",
     {
-    "Please select a file." : "請選擇一個檔案。",
+    "Please select a file." : "請選擇檔案。",
     "File is too big" : "檔案太大",
     "The selected file is not an image." : "選擇的檔案不是圖像檔案。",
     "The selected file cannot be read." : "選擇的檔案無法讀取。",
@@ -19,7 +19,7 @@ OC.L10N.register(
     "An error occurred. Please contact your admin." : "發生錯誤，請聯絡管理員。",
     "Invalid image" : "圖像無效",
     "No temporary profile picture available, try again" : "沒有可用的臨時個人資料圖片，請再試一次",
-    "No crop data provided" : "未提供剪裁數據",
+    "No crop data provided" : "未設定剪裁",
     "No valid crop data provided" : "未提供有效的剪裁設定",
     "Crop is not square" : "剪裁設定不是正方形",
     "State token does not match" : "狀態權杖不相符",
@@ -40,9 +40,8 @@ OC.L10N.register(
     "Some of your link shares have been removed" : "部分分享連結己被移除",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "由於安全性問題，我們必須移除您一部分的連結分享。查看更多資訊請點選連結。",
     "The user limit of this instance is reached." : "的達此實例的用戶上限。",
-    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "在支援應用程式中輸入您的訂閱金鑰以增加使用者限制。這也確實為您提供了 Nextcloud Enterprise 提供的所有額外好處，並且強烈推薦用於公司的營運。",
-    "Learn more ↗" : "了解更多",
-    "Preparing update" : "正在準備更新",
+    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "請輸入你獲得的訂閱代碼以解開用戶數量限制。有關Nextcloud企業版的詳細信息請參見我們的網站。",
+    "Preparing update" : "準備更新",
     "[%d / %d]: %s" : "[%d / %d]： %s",
     "Repair step:" : "修復步驟：",
     "Repair info:" : "修復資訊：",
@@ -84,6 +83,7 @@ OC.L10N.register(
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "尚未配置內存緩存。為了提高性能，請配置內存緩存（如有）。可以在 {linkstart}說明書↗{linkend} 中找到更多資訊。",
     "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "由於安全原因，強烈建議不要使用PHP找到適合隨機性的來源。可以在{linkstart}文檔↗{linkend}中找到更多信息。",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "您當前正在運行PHP {version}。只要您的發行版支持，請升級PHP版本以利用 {linkstart}PHP Group↗提供的性能和安全更新{linkend}。",
+    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 是支援 PHP 7.3 的最後版本，Nextcloud 24 僅支援 PHP 7.4 以上的版本。",
     "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "反向代理標頭（reverse proxy header）配置不正確，或者您正在從受信任的代理（trusted proxy）存取 Nextcloud。如果不是這樣，則這是一個安全問題，並且可以使攻擊者欺騙其對 Nextcloud 可見的IP地址。可以在{linkstart}文檔↗{linkend}中找到更多資訊。",
     "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached 配置為分布式緩存，但是安裝了錯誤的PHP模塊 “memcache”。\\OC\\Memcache\\Memcached 僅支持 “memcached”，不支持 “memcache”。有關這兩個模塊的信息，請參見{linkstart}內存緩存wiki {linkend}。",
     "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "某些檔案未通過完整性檢查。有關如何解決此問題的更多信息，請參見{linkstart1}文檔↗{linkend}。（{linkstart2}無效檔案清單…{linkend} / {linkstart3}重新掃描…{linkend}）",
@@ -99,7 +99,7 @@ OC.L10N.register(
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "您的 Nextcloud 缺少了某些建議的 PHP 模組。為了提升效能與相容性，強烈建議您安裝這些 PHP 模組。",
     "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "雖然已啟用佈景主題應用程式，但並未啟用 PHP 模組「imagick」。為了讓 favicon 產生流程正常運作，您必須安裝並啟用此模組。",
     "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "未啟用 PHP 模組「gmp」與「bcmath」。若您要使用 WebAuthn 免密碼驗證，這些模組就是必要的。",
-    "It seems like you are running a 32-bit PHP version. Nextcloud 26 and higher require 64-bit. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "您似乎正在執行 32 位元版本的 PHP。Nextcloud 26 或更新版本需要使用 64 位元的版本。請將您的作業系統與 PHP 升級至 64 位元！要取得更多詳細資訊，請閱讀{linkstart}關於此問題的文件 ↗{linkend}。",
+    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "您好像正在運行 32 位 PHP 版本。Nextcloud 需要 64 位才能運行良好。請將您的操作系統和 PHP 升級到 64 位！有關更多詳細信息，請閱讀 {linkstart} 有關的說明書頁面 ↗{linkend}。",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "本系統安裝的 php-imagick 不支援 SVG，為了更好的相容性，建議安裝它。",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "數據庫中的某些列缺少對 big int 的轉換。由於更改大表上的列類型可能需要一些時間，因此無法自動更改它們。通過運行 “occ db：convert-filecache-bigint”，可以手動應用這些未決的更改。實例處於脫機狀態時需要執行此操作。有關更多詳細信息，請{linklink}關於此↗{linkend}的文檔頁面。",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "目前您的後端數據庫使用 SQLite，在大型服務當中，我們建議您使用其他的數據庫後端。",
@@ -116,7 +116,7 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "您的資料目錄和檔案看來可以被公開存取。這表示 .htaccess 設定檔並未生效。我們強烈建議您設定網頁伺服器，拒絕公開存取資料目錄，或者將您的資料目錄移出網頁伺服器根目錄。",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 {header} 標頭設定並不是 \"{expected}\" ，這是一個潛在的安全性和隱私風險，我們建議調整此項設定。",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 {header} 標頭設定並不是 \"{expected}\" ，這將讓某些功能無法正常運作，我們建議修正此項設定。",
-    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 {header} 標頭設定並不包防 \"{expected}\" ，這是一個潛在的安全性和隱私風險，建議調整此項設定。",
+    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 {header} 標頭設定並不包防 \"{expected}\" ，這是一個潛在的安全性和隱私風險，建議調整此項設定。",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTP header “{header}” 未設置為 “ {val1}”、“ {val2}”、“{val3}”、“{val4}” 或 “{val5}”。這可能會洩漏引用資訊。請參閱 {linkstart}W3C建議↗{linkend}。",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "未將 “Strict-Transport-Security” HTTP header 設置為至少“{seconds}”秒。為了增強安全性，建議按照{linkstart}安全提示↗{linkend}中的說明啟用 HSTS。",
     "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "通過HTTP不安全地存取站點。強烈建議您將伺服器設置改為要求HTTPS，如{linkstart}安全提示↗{linkend}中所述。",
@@ -132,7 +132,7 @@ OC.L10N.register(
     "Update to {version}" : "更新到 {version}",
     "An error occurred." : "發生錯誤。",
     "Please reload the page." : "請重新整理頁面。",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新失敗。<a href=\"{url}\">請查看我們關於此問題的論壇帖子</a>來瞭解更多。",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新失敗，檢視<a href=\"{url}\">論壇上的文章</a>來瞭解更多。",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "更新不成功。請在 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud 社群</a>舉報此問題。",
     "Continue to {productName}" : "前往 {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["更新成功，將在 %n 秒後重導向至 {productName}。"],
@@ -147,7 +147,6 @@ OC.L10N.register(
     "Please try again or contact your administrator." : "請重試或聯絡系統管理員",
     "Account name or email" : "賬戶名稱或電郵地址",
     "Password" : "密碼",
-    "Log in to {productName}" : "登入至 {productName}",
     "Wrong username or password." : "錯誤的用戶名稱 或 密碼",
     "User disabled" : "用戶已遭停用",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "您的 IP 多次嘗試登入無效，下一次登入將會被延時 30 秒。",
@@ -180,7 +179,8 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "將您的同事和朋友的聯繫整合在一處，且不洩漏他們的個人資訊",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "簡潔的電子郵件應用程式，與檔案瀏覽器、通訊錄、行事曆完美整合",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "對話、視訊電話、螢幕分享、線上會議與網路研討會 - 實現於你的瀏覽器與手機 apps 之中。",
-    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "基於 Collabora Online 構建的協作文件、試算表和演講文稿。",
+    "Collaboratively edit office documents." : "協助編輯官方文件。",
+    "Local document editing back-end used by the Collabora Online app." : "本地文件編輯後端由Collabora Online app提供。",
     "Forgot password?" : "忘記密碼？",
     "Log in with a device" : "使用免密碼裝置登入",
     "Back" : "返回",
@@ -202,11 +202,6 @@ OC.L10N.register(
     "Search" : "搜尋",
     "An error occurred while searching for {type}" : "搜尋 {type} 時發生錯誤",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["請輸入 {minSearchLength} 個或以上字元搜尋"],
-    "This browser is not supported" : "不支援此瀏覽器",
-    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "不支援您的瀏覽器。請升級至較新或受支援的版本。",
-    "Continue with this unsupported browser" : "繼續使用此不受支援的瀏覽器",
-    "Supported versions" : "支援的版本",
-    "{name} version {version} and above" : "{name} 的版本 {version} 及更新",
     "Search {types} …" : "搜尋 {types} 中 …",
     "Settings" : "設定",
     "Could not load your contacts" : "無法載入您的聯絡人",
@@ -279,8 +274,8 @@ OC.L10N.register(
     "No action available" : "沒有可用的操作",
     "Error fetching contact actions" : "擷取聯絡人時發生錯誤",
     "Non-existing tag #{tag}" : "不存在的標籤 #{tag}",
-    "Restricted" : "受限",
-    "Invisible" : "隱藏",
+    "restricted" : "受限",
+    "invisible" : "隱藏",
     "Delete" : "刪除",
     "Rename" : "重新命名",
     "Collaborative tags" : "協作標籤",
@@ -294,8 +289,8 @@ OC.L10N.register(
     "Profile not found" : "找不到個人資料",
     "The profile does not exist." : "個人資料不存在",
     "Back to %s" : "回到 %s",
-    "Page not found" : "沒有找到頁面",
-    "The page could not be found on the server." : "無法在伺服器上找到此頁面。",
+    "File not found" : "找不到檔案",
+    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "伺服器上找不到該文件，或許這個分享已經被刪除或是過期了？",
     "Too many requests" : "太多要求",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "有太多請求來自你的網路，請稍後再試，若你認為這不該發生，請回報系統管理員這項錯誤。",
     "Error" : "錯誤",
@@ -346,11 +341,11 @@ OC.L10N.register(
     "Skip to main content" : "跳到主內容",
     "Skip to navigation of app" : "跳到應用程式導覽",
     "Get your own free account" : "取得免費賬號",
+    "%s's homepage" : "%s 的主頁",
     "Contacts" : "聯絡人",
     "Contacts menu" : "聯絡人選單",
     "Open settings menu" : "公開設定選項單",
     "Confirm your password" : "確認密碼",
-    "%s's homepage" : "%s 的主頁",
     "Connect to your account" : "連結您的賬號",
     "Please log in before granting %1$s access to your %2$s account." : "請登入後再授權「%1$s」存取您的 %2$s 賬號",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "若你並未嘗試在新的裝置登入你的賬戶，有什麼人證在嘗試登入你的賬戶並存取你的個人資料。大多數情況你並不用作任何應對，但也可通知你的系統管理員。",
@@ -391,7 +386,7 @@ OC.L10N.register(
     "The theme %s has been disabled." : "主題 %s 已經被停用。",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "在繼續之前，請備份數據庫、config 資料夾及數據資料夾",
     "Start update" : "開始升級",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "為避免大型安裝超時，您可以改為從安裝目錄下運行以下指令：",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "為避免大型安裝超時，您可以改為從安裝目錄執行以下指令：",
     "Detailed logs" : "詳細記錄檔",
     "Update needed" : "需要更新",
     "Please use the command line updater because you have a big instance with more than 50 users." : "因為您有超過50名用戶，服務規模較大，請透過命令提示字元界面（command line updater）更新。",
@@ -399,30 +394,25 @@ OC.L10N.register(
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "若我繼續透過網頁界面更新時我已了解有其風險，若請求逾時可能導致資料遺失，萬一更新失敗，我已準備好備份並知道如何回復運作。",
     "Upgrade via web on my own risk" : "願意承擔風險透過網頁更新",
     "Maintenance mode" : "維護模式",
-    "This %s instance is currently in maintenance mode, which may take a while." : "此 %s 實例目前處於維護模式，可能需要一段時間才能完成。",
+    "This %s instance is currently in maintenance mode, which may take a while." : "這個 %s 安裝目前處於維護模式，可能需要一段時間才能完成。",
     "This page will refresh itself when the instance is available again." : "安裝恢復可用之後，本頁會自動重新整理",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "若這個訊息持續出現，請聯絡系統管理員。",
-    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "不支援 Nextcloud 的這個社群版本，且即時通知不可用。",
-    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "請輸入你獲得的訂閱代碼以解開用戶數量限制。有關Nextcloud企業版的詳細信息請參見我們的網站。",
     "[%d / %d]: Checking table %s" : "[%d / %d]： 檢查數據表 %s",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "這是不受支援的 Nextcloud 社群版建置。鑑於此站台的大小，無法保證效能、可靠程度與延展性。推播通知已被停用，以避免我們的免費服務負載過重。請至 nextcloud.com/enterprise 取得更多關於 Nextcloud 企業版的資訊。",
-    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 是支援 PHP 7.3 的最後版本，Nextcloud 24 僅支援 PHP 7.4 以上的版本。",
+    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "此伺服器沒有網際網路連線（無法與多個端點取得聯繫），有些功能，例如外部儲存、應用程式更新版通知等等將無法運作。從遠端存取資料或是寄送通知電郵可能也無法運作。建議您設定好網際網路連線以使用所有功能。",
+    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 是支援 PHP 7.2 的最後版本，Nextcloud 21 僅支援 PHP 7.3 以上的版本。",
+    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "未加載 PHP OPcache 模塊。{linkstart}為獲得更佳性能，建議↗{linked}將其加載到您的 PHP 安裝中。",
+    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "PHP OPcache 模塊未正確配置。{linkstart}為獲得更佳性能，建議↗{linkend}在 <code>php.ini</code> 中使用以下設定：",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "數據庫中的某些列缺少對 big int 的轉換。由於更改大表上的列類型可能需要一些時間，因此無法自動更改它們。通過運行 “occ db：convert-filecache-bigint”，可以手動應用這些未決的更改。實例處於脫機狀態時需要執行此操作。有關更多詳細信息，請{linklink}關於此↗{linkend}的文檔頁面。",
     "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "要遷移到另一個數據庫，請使用指令工具：“ occ db：convert-type”，或參閱 {linkstart} 說明書↗{linkend}。",
-    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 {header} 標頭設定並不包防 \"{expected}\" ，這是一個潛在的安全性和隱私風險，建議調整此項設定。",
-    "Collaboratively edit office documents." : "協助編輯官方文件。",
-    "Local document editing back-end used by the Collabora Online app." : "本地文件編輯後端由Collabora Online app提供。",
-    "You haven't added any info yet" : "您尚未新增任何資訊",
-    "{user} hasn't added any info yet" : "{user} 尚未新增任何資訊",
-    "restricted" : "受限",
-    "invisible" : "隱藏",
-    "File not found" : "找不到檔案",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "伺服器上找不到該文件，或許這個分享已經被刪除或是過期了？",
+    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "您的資料目錄和檔案看來可以被公開存取，這表示 。htaccess 設定檔並未生效，我們強烈建議您設定網頁伺服器，拒絕公開存取資料目錄，或者將您的資料目錄移出網頁伺服器根目錄。",
     "More" : "更多",
     "More apps menu" : "更多應用程式選單",
     "Settings menu" : "設定選單",
     "The password is wrong. Try again." : "密碼錯誤，請重試",
     "Setup two-factor authentication" : "設定雙重認證",
-    "It seems like you are running a 32-bit PHP version. Nextcloud 26 and higher require 64-bit. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "您似乎正在執行 32 位元版本的 PHP。Nextcloud 26 或更新版本需要使用 64 位元的版本。請將您的作業系統與 PHP 升級至 64 位元！要取得更多詳細資訊，請閱讀{linkstart}關於此問題的文件 ↗{linkend}。"
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "不支援 Nextcloud 的這個社群版本，且即時通知不可用。",
+    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "這是不受支援的 Nextcloud 社群版建置。鑑於此站台的大小，無法保證效能、可靠程度與延展性。推播通知已被停用，以避免我們的免費服務負載過重。請至 nextcloud.com/enterprise 取得更多關於 Nextcloud 企業版的資訊。",
+    "You haven't added any info yet" : "您尚未新增任何資訊",
+    "{user} hasn't added any info yet" : "{user} 尚未新增任何資訊"
 },
 "nplurals=1; plural=0;");
