@@ -4,7 +4,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory!" : "الكتابة في مجلد \"config\" غير ممكنة!",
     "See %s" : "أنظر %s",
     "Sample configuration detected" : "تم اكتشاف إعدادات عيّنة",
-    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "تم اكتشاف أن نموذج التهيئة قد تم نسخه. يمكن لهذا أن يُعطّل عملية التنصيب و هو أمر غير مدعوم. نرجو الاطلاع على تعليمات الواردة في وثائق النظام قبل إحداث أي تعديلات على ملف config.php",
     "%1$s and %2$s" : "%1$s و %2$s",
     "%1$s, %2$s and %3$s" : "%1$s، %2$s و %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s، %2$s، %3$s و %4$s",
@@ -55,11 +54,16 @@ OC.L10N.register(
     "Role" : "الدور",
     "Unknown user" : "المستخدم غير معروف",
     "Additional settings" : "الإعدادات المتقدمة",
+    "%s enter the database username and name." : "%s أدخِل اسم قاعدة البيانات واسم مستخدمها.",
+    "%s enter the database username." : "%s ادخل اسم المستخدم الخاص بقاعدة البيانات.",
+    "%s enter the database name." : "%s ادخل اسم فاعدة البيانات",
+    "%s you may not use dots in the database name" : "%s لا يسمح لك باستخدام نقطه (.) في اسم قاعدة البيانات",
     "Oracle connection could not be established" : "لم تنجح محاولة اتصال Oracle",
     "Oracle username and/or password not valid" : "اسم المستخدم  و/أو  كلمة المرور لنظام Oracle غير صحيح",
     "PostgreSQL username and/or password not valid" : "اسم المستخدم / أو كلمة المرور الخاصة بـPostgreSQL غير صحيحة",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "نظام ماك الإصدار X غير مدعوم و %s لن يعمل بشكل صحيح على هذه المنصة.  استخدمه على مسؤوليتك!",
     "For the best results, please consider using a GNU/Linux server instead." : "فضلاً ضع في الاعتبار استخدام نظام GNU/Linux بدل الأنظمة الأخرى للحصول على أفضل النتائج.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "فضلاً إحذف إعداد open_basedir من ملف php.ini لديك أو حوّل إلى PHP إصدار 64 بت.",
     "Set an admin username." : "اعداد اسم مستخدم للمدير",
     "Set an admin password." : "اعداد كلمة مرور للمدير",
     "Open »%s«" : "فتح »%s«",
@@ -122,13 +126,7 @@ OC.L10N.register(
     "Application is not enabled" : "التطبيق غير مفعّل",
     "Authentication error" : "لم يتم التأكد من الشخصية بنجاح",
     "Token expired. Please reload page." : "انتهت صلاحية الكلمة , يرجى اعادة تحميل الصفحة",
-    "Adjusting this setting in php.ini will make Nextcloud run again" : "تضبيط الإعدادات في ملف php.ini سوف يُمكّن نيكست كلاود من العمل مجدداً",
     "Storage is temporarily not available" : "وحدة التخزين غير متوفرة",
-    "%s enter the database username and name." : "%s أدخِل اسم قاعدة البيانات واسم مستخدمها.",
-    "%s enter the database username." : "%s ادخل اسم المستخدم الخاص بقاعدة البيانات.",
-    "%s enter the database name." : "%s ادخل اسم فاعدة البيانات",
-    "%s you may not use dots in the database name" : "%s لا يسمح لك باستخدام نقطه (.) في اسم قاعدة البيانات",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "فضلاً إحذف إعداد open_basedir من ملف php.ini لديك أو حوّل إلى PHP إصدار 64 بت.",
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "يمكن إصلاح هذا الخطا بإعطاء مخدّم الموقع صلاحيات التعديل على مجلد الإعدادات. أنظر %s",
     "Please upgrade your database version" : "فضلًا قم بتحديث إصدار قاعدة بياناتك"
 },
