@@ -8,8 +8,6 @@ OC.L10N.register(
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Los archivos de la app %1$s no se han reemplazado correctamente. Asegúrate de que es una versión compatible con el servidor.",
     "Sample configuration detected" : "Configuración de ejemplo detectada",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Se ha detectado que el ejemplo de configuración ha sido copiado. Esto podría afectar a su instalación, por lo que no tiene soporte. Lea la documentación antes de hacer cambios en config.php",
-    "404" : "404",
-    "The page could not be found on the server." : "La página no se ha encontrado en el servidor.",
     "%s email verification" : "%s verificación del correo electrónico",
     "Email verification" : "Verificación del correo electrónico",
     "Click the following button to confirm your email." : "Haz clic en el siguiente botón para confirmar tu correo electrónico.",
@@ -92,17 +90,13 @@ OC.L10N.register(
     "__language_name__" : "Español (España)",
     "This is an automatically sent email, please do not reply." : "Este es un correo enviado automáticamente, por favor no responda.",
     "Help" : "Ayuda",
-    "Appearance and accessibility" : "Apariencia y accesibilidad",
     "Apps" : "Aplicaciones",
     "Personal settings" : "Ajustes personales",
-    "Administration settings" : "Configuraciones de administración",
     "Settings" : "Ajustes",
     "Log out" : "Cerrar sesión",
     "Users" : "Usuarios",
     "Email" : "Correo electrónico",
     "Mail %s" : "Correo %s",
-    "Fediverse" : "Fediverso",
-    "View %s on the fediverse" : "Ver %s en el fediverso",
     "Phone" : "Teléfono",
     "Call %s" : "Llamada %s",
     "Twitter" : "Twitter",
@@ -118,10 +112,10 @@ OC.L10N.register(
     "Role" : "Puesto",
     "Unknown user" : "Usuario desconocido",
     "Additional settings" : "Configuración adicional",
-    "Enter the database username and name for %s" : "Introduzca el nombre de usuario y la contraseña para la base de datos %s",
-    "Enter the database username for %s" : "Introduzca el nombre de usuario para la base datos %s",
-    "Enter the database name for %s" : "Introduzca el nombre de la base de datos %s",
-    "You cannot use dots in the database name %s" : "No puede utilizar puntos para el nombre de base de datos 1%s ",
+    "%s enter the database username and name." : "%s introduzca el nombre de usuario y la contraseña de la BBDD.",
+    "%s enter the database username." : "%s introduzca el usuario de la base de datos.",
+    "%s enter the database name." : "%s introduzca el nombre de la base de datos",
+    "%s you may not use dots in the database name" : "%s puede utilizar puntos en el nombre de la base de datos",
     "MySQL username and/or password not valid" : "Usuario y/o contraseña de MySQL no válidos",
     "You need to enter details of an existing account." : "Tienes que introducir los datos de una cuenta existente.",
     "Oracle connection could not be established" : "No se pudo establecer la conexión a Oracle",
@@ -129,8 +123,8 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "Usuario y/o contraseña de PostgreSQL no válidos",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X no está soportado y %s no funcionará bien en esta plataforma. ¡Úsala bajo tu propio riesgo! ",
     "For the best results, please consider using a GNU/Linux server instead." : "Para obtener los mejores resultados, considera utilizar un servidor GNU/Linux.",
-    "It seems that this %s instance is running on a 32-bit PHP environment. 64-bit is required for 26 and higher." : "Parece que esta %s instancia está ejecutándose en un ambiente PHP de 32 bits. Se requiere 64 bits para 26 y superiores.",
-    "Please switch to 64-bit PHP." : "Por favor cambie a PHP de 64 bits",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Parece que esta instancia %s está funcionando en un entorno PHP de 32-bits y el open_basedir se ha configurado en php.ini. Esto acarreará problemas con archivos de tamaño superior a 4GB y resulta totalmente desaconsejado.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, quite el ajuste de open_basedir —dentro de su php.ini— o pásese a PHP de 64 bits.",
     "Set an admin username." : "Configurar un nombre de usuario del administrador",
     "Set an admin password." : "Configurar la contraseña del administrador.",
     "Cannot create or write into the data directory %s" : "No se puede crear o escribir en la carpeta de datos %s",
@@ -154,7 +148,6 @@ OC.L10N.register(
     "%1$s shared »%2$s« with you." : "%1$s ha compartido «%2$s» contigo.",
     "Click the button below to open it." : "Haz clic en el botón de abajo para abrirlo.",
     "The requested share does not exist anymore" : "El recurso compartido solicitado ya no existe",
-    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "El usuario no fue creado ya que el límite de usuarios fue alcanzado. Compruebe sus notificaciones para aprender más.",
     "Could not find category \"%s\"" : "No puede encontrar la categoría \"%s\"",
     "Sunday" : "Domingo",
     "Monday" : "Lunes",
@@ -201,6 +194,7 @@ OC.L10N.register(
     "Oct." : "Oct.",
     "Nov." : "Nov.",
     "Dec." : "Dic.",
+    "The user limit has been reached and the user was not created." : "Ha sido alcanzado el límite de usuarios, por tanto el usuario no fue creado.",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Solo los siguientes caracteres están permitidos en un nombre de usuario: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
     "A valid username must be provided" : "Se debe proporcionar un nombre de usuario válido",
     "Username contains whitespace at the beginning or at the end" : "El nombre de usuario contiene espacios en blanco al principio o al final",
@@ -214,7 +208,6 @@ OC.L10N.register(
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "No se ha podido instlaar la app «%1$s» porque no se cumplen las siguientes dependencias: %2$s",
     "a safe home for all your data" : "un hogar seguro para todos tus datos",
     "File is currently busy, please try again later" : "El archivo se encuentra actualmente ocupado, por favor inténtelo de nuevo más tarde",
-    "Cannot download file" : "No se puede descargar archivo",
     "Application is not enabled" : "La aplicación no está habilitada",
     "Authentication error" : "Error de autenticación",
     "Token expired. Please reload page." : "Token caducado. Por favor, recarge la página.",
@@ -264,13 +257,6 @@ OC.L10N.register(
     "Storage is temporarily not available" : "El almacenamiento no esta disponible temporalmente",
     "Storage connection timeout. %s" : "Tiempo de conexión de almacenamiento agotado. %s",
     "This can usually be fixed by giving the webserver write access to the config directory." : "Se podría solucionar esto dándole al servidor permisos de escritura del directorio de configuración.",
-    "%s enter the database username and name." : "%s introduzca el nombre de usuario y la contraseña de la BBDD.",
-    "%s enter the database username." : "%s introduzca el usuario de la base de datos.",
-    "%s enter the database name." : "%s introduzca el nombre de la base de datos",
-    "%s you may not use dots in the database name" : "%s puede utilizar puntos en el nombre de la base de datos",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Parece que esta instancia %s está funcionando en un entorno PHP de 32-bits y el open_basedir se ha configurado en php.ini. Esto acarreará problemas con archivos de tamaño superior a 4GB y resulta totalmente desaconsejado.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, quite el ajuste de open_basedir —dentro de su php.ini— o pásese a PHP de 64 bits.",
-    "The user limit has been reached and the user was not created." : "Ha sido alcanzado el límite de usuarios, por tanto el usuario no fue creado.",
     "Cannot read file" : "No se puede leer archivo",
     "Cannot write into \"config\" directory" : "No se puede escribir el el directorio de configuración",
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Se podría solucionar esto dándole al servidor permisos de escritura del directorio de configuración. Ver %s",
@@ -288,7 +274,6 @@ OC.L10N.register(
     "Your data directory is readable by other users" : "Tu directorio de datos puede ser leído por otros usuarios",
     "Your data directory must be an absolute path" : "Su directorio data debe ser una ruta absoluta",
     "Check the value of \"datadirectory\" in your configuration" : "Compruebe el valor de \"datadirectory\" en su configuración.",
-    "Your data directory is invalid" : "Tu directorio de datos es inválido",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "El límite de usuarios fue alcanzado y el usuario no fue creado. Compruebe sus notificaciones para aprender más."
+    "Your data directory is invalid" : "Tu directorio de datos es inválido"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
