@@ -27,23 +27,24 @@ OC.L10N.register(
     "today" : "hoy",
     "tomorrow" : "mañana",
     "yesterday" : "ayer",
-    "_in %n day_::_in %n days_" : ["en %n día","en %n días"],
-    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días"],
+    "_in %n day_::_in %n days_" : ["en %n día","en %n días","en %n días"],
+    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
     "next month" : "próximo mes",
     "last month" : "mes pasado",
-    "_in %n month_::_in %n months_" : ["en %n mes","en %n meses"],
-    "_%n month ago_::_%n months ago_" : ["Hace %n mes","Hace %n meses"],
+    "_in %n month_::_in %n months_" : ["en %n mes","en %n meses","en %n meses"],
+    "_%n month ago_::_%n months ago_" : ["Hace %n mes","Hace %n meses","Hace %n meses"],
     "next year" : "próximo año",
     "last year" : "año pasado",
-    "_in %n year_::_in %n years_" : ["en %n año","en %n años"],
-    "_%n year ago_::_%n years ago_" : ["hace %n año","hace %n años"],
-    "_in %n hour_::_in %n hours_" : ["en %n hora","en %n horas"],
-    "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","Hace %n horas"],
-    "_in %n minute_::_in %n minutes_" : ["en %n minuto","en %n minutos"],
-    "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","Hace %n minutos"],
+    "_in %n year_::_in %n years_" : ["en %n año","en %n años","en %n años"],
+    "_%n year ago_::_%n years ago_" : ["hace %n año","hace %n años","hace %n años"],
+    "_in %n hour_::_in %n hours_" : ["en %n hora","en %n horas","en %n horas"],
+    "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","Hace %n horas","Hace %n horas"],
+    "_in %n minute_::_in %n minutes_" : ["en %n minuto","en %n minutos","en %n minutos"],
+    "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","Hace %n minutos","Hace %n minutos"],
     "in a few seconds" : "en algunos segundos",
     "seconds ago" : "hace segundos",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "El módulo con ID: %sno existe. Por favor hablíitalo en tus configuraciones de aplicación o contacta a tu administrador.  ",
+    "File already exists" : "El archivo ya existe",
     "File name is a reserved word" : "Nombre de archivo es una palabra reservada",
     "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un caracter inválido",
     "File name is too long" : "El nombre del archivo es demasiado largo",
@@ -58,6 +59,14 @@ OC.L10N.register(
     "Settings" : "Configuraciones",
     "Log out" : "Salir",
     "Users" : "Usuarios",
+    "Email" : "Correo electrónico",
+    "Phone" : "Teléfono fijo",
+    "Twitter" : "Twitter",
+    "Website" : "Sitio web",
+    "Address" : "Dirección",
+    "Profile picture" : "Foto de perfil",
+    "About" : "Acerca",
+    "Full name" : "Nombre completo",
     "Unknown user" : "Ususario desconocido",
     "Additional settings" : "Configuraciones adicionales",
     "%s enter the database username and name." : "%s ingresa el usuario y nombre de la base de datos",
@@ -79,7 +88,9 @@ OC.L10N.register(
     "Sharing backend for %s not found" : "No fue encontrado el Backend que comparte para %s",
     "Open »%s«" : "Abrir »%s«",
     "You are not allowed to share %s" : "No tienes permitido compartir %s",
+    "Cannot increase permissions of %s" : "No se pueden incrementar los permisos de %s",
     "Expiration date is in the past" : "La fecha de expiración se encuentra en el pasado",
+    "Sharing %s failed, because this item is already shared with user %s" : "Se presento una falla al compartir %s, porque este elemento ya ha sido compartido con el usuario %s",
     "Click the button below to open it." : "Haz click en el botón inferior para abrirlo. ",
     "The requested share does not exist anymore" : "El recurso compartido solicitado ya no existe",
     "Could not find category \"%s\"" : "No fue posible encontrar la categoria \"%s\"",
@@ -161,13 +172,6 @@ OC.L10N.register(
     "Storage connection error. %s" : "Se presentó un error con la conexión al almacenamiento. %s",
     "Storage is temporarily not available" : "El almacenamieto se encuentra temporalmente no disponible",
     "Storage connection timeout. %s" : "El tiempo de la conexión del almacenamiento se agotó. %s",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "Esto generalmente se resuelve dándole al servidor web acceso para escribir en el directorio config. ",
-    "Can't create or write into the data directory %s" : "No es posible crear o escribir en el directorio de datos %s",
-    "Can’t increase permissions of %s" : "No es posible incrementar los privilegios de %s",
-    "Files can’t be shared with delete permissions" : "Los archivos no se pueden compartir con permisos de borrado",
-    "Files can’t be shared with create permissions" : "Los archivos no se pueden compartir con permisos de creación",
-    "Can’t set expiration date more than %s days in the future" : "No es posible establecer la fecha de expiración más allá de %s días en el futuro",
-    "Can't read file" : "No se puede leer el archivo",
     "Cannot write into \"config\" directory" : "No fue posible escribir en el directorio \"config\"",
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Por lo general esto se puede resolver al darle al servidor web acceso de escritura al directorio config. Por favor ve %s",
     "Cannot write into \"apps\" directory" : "No fue posible escribir en el directorio \"apps\"",
@@ -185,4 +189,4 @@ OC.L10N.register(
     "Check the value of \"datadirectory\" in your configuration" : "Verifica el valor de \"datadirectory\" en tu configuración",
     "Your data directory is invalid" : "Tu directorio de datos es inválido"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
