@@ -7,8 +7,6 @@ OC.L10N.register(
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Sovelluksen %1$s tiedostoja ei korvattu oikein Varmista, että sen versio on yhteensopiva palvelimen kanssa.",
     "Sample configuration detected" : "Esimerkkimääritykset havaittu",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "On havaittu, että esimerkkimäärityksen on kopioitu. Se voi rikkoa asennuksesi, eikä sitä tueta. Lue ohjeet ennen kuin muutat config.php tiedostoa.",
-    "404" : "404",
-    "The page could not be found on the server." : "Sivua ei löytynyt palvelimelta.",
     "Email verification" : "Sähköpostin vahvistus",
     "Click the following button to confirm your email." : "Napsauta seuraavaa painiketta vahvistaaksesi sähköpostiosoitteesi.",
     "Click the following link to confirm your email." : "Napsauta seuraavaa linkkiä vahvistaaksesi sähköpostiosoitteesi.",
@@ -80,10 +78,8 @@ OC.L10N.register(
     "__language_name__" : "suomi",
     "This is an automatically sent email, please do not reply." : "Tämä on automaattisesti lähetetty viesti. Älä vastaa tähän viestiin.",
     "Help" : "Ohje",
-    "Appearance and accessibility" : "Ulkoasu ja saavutettavuus",
     "Apps" : "Sovellukset",
     "Personal settings" : "Henkilökohtaiset asetukset",
-    "Administration settings" : "Ylläpitäjän asetukset",
     "Settings" : "Asetukset",
     "Log out" : "Kirjaudu ulos",
     "Users" : "Käyttäjät",
@@ -104,6 +100,10 @@ OC.L10N.register(
     "Role" : "Rooli",
     "Unknown user" : "Tuntematon käyttäjä",
     "Additional settings" : "Lisäasetukset",
+    "%s enter the database username and name." : "%s anna tietokannan käyttäjätunnus ja nimi.",
+    "%s enter the database username." : "%s anna tietokannan käyttäjätunnus.",
+    "%s enter the database name." : "%s anna tietokannan nimi.",
+    "%s you may not use dots in the database name" : "%s et voi käyttää pisteitä tietokannan nimessä",
     "MySQL username and/or password not valid" : "MySQL-käyttäjätunnus ja/tai -salasana on väärin",
     "You need to enter details of an existing account." : "Anna olemassa olevan tilin tiedot.",
     "Oracle connection could not be established" : "Oracle-yhteyttä ei voitu muodostaa",
@@ -111,8 +111,8 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "PostgreSQL:n käyttäjätunnus ja/tai salasana on väärin",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X ei ole tuettu, joten %s ei toimi kunnolla tällä alustalla. Käytä omalla vastuulla!",
     "For the best results, please consider using a GNU/Linux server instead." : "Käytä parhaan lopputuloksen saamiseksi GNU/Linux-palvelinta.",
-    "It seems that this %s instance is running on a 32-bit PHP environment. 64-bit is required for 26 and higher." : "Vaikuttaa siltä, että %s-instanssi toimii 32-bittisessä PHP-ympäristössä. 64-bittinen PHP on vaadittu versiolle 26 ja sitä uudemmille.",
-    "Please switch to 64-bit PHP." : "Vaihda PHP:n 64-bittiseen versioon.",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Vaikuttaa siltä, että tämä %s-instanssi toimii 32-bittisessä PHP-ympäristössä ja open_basedir-asetus on määritetty php.ini-tiedostossa. Tämä johtaa ongelmiin yli 4 gigatavun tiedostojen kanssa, eikä siksi ole suositeltavaa.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Poista open_basedir-asetus php.ini-tiedostosta tai vaihda 64-bittiseen PHP:hen.",
     "Set an admin username." : "Aseta ylläpitäjän käyttäjätunnus.",
     "Set an admin password." : "Aseta ylläpitäjän salasana.",
     "Sharing backend %s not found" : "Jakamisen taustaosaa %s ei löytynyt",
@@ -180,6 +180,7 @@ OC.L10N.register(
     "Oct." : "Loka",
     "Nov." : "Marras",
     "Dec." : "Joulu",
+    "The user limit has been reached and the user was not created." : "Käyttäjäraja on tullut täyteen, joten käyttäjää ei luotu.",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Vain seuraavat merkit ovat sallittuja käyttäjätunnuksessa: \"a-z\", \"A-Z\", \"0-9\" ja \"_.@-'\"",
     "A valid username must be provided" : "Anna kelvollinen käyttäjätunnus",
     "Username contains whitespace at the beginning or at the end" : "Käyttäjätunnus sisältää tyhjätilaa joko alussa tai lopussa",
@@ -202,7 +203,6 @@ OC.L10N.register(
     "Cannot write into \"apps\" directory." : "Ei voi kirjoittaa \"apps\"-hakemistoon",
     "Cannot create \"data\" directory." : "Ei voi luoda \"data\"-hakemistoa",
     "Your data directory is not writable." : "Datahakemistosi ei ole kirjoitettavissa.",
-    "Setting locale to %s failed." : "Maa-asetuston %s asettaminen epäonnistui.",
     "PHP module %s not installed." : "PHP-moduulia %s ei ole asennettu.",
     "Please ask your server administrator to install the module." : "Pyydä palvelimen ylläpitäjää asentamaan moduulin.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP-asetusta \"%s\" ei ole asetettu arvoon \"%s\".",
@@ -226,13 +226,6 @@ OC.L10N.register(
     "Storage connection error. %s" : "Tallennustilan yhteysvirhe. %s",
     "Storage is temporarily not available" : "Tallennustila on tilapäisesti pois käytöstä",
     "Storage connection timeout. %s" : "Tallennustilan yhteyden aikakatkaisu. %s",
-    "%s enter the database username and name." : "%s anna tietokannan käyttäjätunnus ja nimi.",
-    "%s enter the database username." : "%s anna tietokannan käyttäjätunnus.",
-    "%s enter the database name." : "%s anna tietokannan nimi.",
-    "%s you may not use dots in the database name" : "%s et voi käyttää pisteitä tietokannan nimessä",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Vaikuttaa siltä, että tämä %s-instanssi toimii 32-bittisessä PHP-ympäristössä ja open_basedir-asetus on määritetty php.ini-tiedostossa. Tämä johtaa ongelmiin yli 4 gigatavun tiedostojen kanssa, eikä siksi ole suositeltavaa.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Poista open_basedir-asetus php.ini-tiedostosta tai vaihda 64-bittiseen PHP:hen.",
-    "The user limit has been reached and the user was not created." : "Käyttäjäraja on tullut täyteen, joten käyttäjää ei luotu.",
     "Cannot read file" : "Tiedostoa ei voi lukea",
     "Cannot write into \"config\" directory" : "Hakemistoon \"config\" kirjoittaminen ei onnistu",
     "Cannot write into \"apps\" directory" : "Hakemistoon \"apps\" kirjoittaminen ei onnistu",
