@@ -8,8 +8,6 @@ OC.L10N.register(
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "アプリ %1$s のファイルが正しく置き換えられませんでした。サーバーと互換性のあるバージョンであることを確認してください。",
     "Sample configuration detected" : "サンプル設定が見つかりました。",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "サンプル設定がコピーされてそのままです。このままではインストールが失敗し、サポート対象外になります。config.phpを変更する前にドキュメントを確認してください。",
-    "404" : "404",
-    "The page could not be found on the server." : "ページがサーバー上に見つかりませんでした。",
     "%s email verification" : "%sメールによる確認",
     "Email verification" : "メールによる確認",
     "Click the following button to confirm your email." : "下記のボタンをクリックして、メールを確認してください。",
@@ -92,10 +90,7 @@ OC.L10N.register(
     "__language_name__" : "Japanese (日本語)",
     "This is an automatically sent email, please do not reply." : "これは自動的に生成されたメールです。返信しないでください。",
     "Help" : "ヘルプ",
-    "Appearance and accessibility" : "外観とアクセシビリティ",
     "Apps" : "アプリ",
-    "Personal settings" : "個人設定",
-    "Administration settings" : "管理者設定",
     "Settings" : "設定",
     "Log out" : "ログアウト",
     "Users" : "ユーザー",
@@ -116,10 +111,10 @@ OC.L10N.register(
     "Role" : "ロール",
     "Unknown user" : "不明なユーザー",
     "Additional settings" : "追加設定",
-    "Enter the database username and name for %s" : "%sのデータベース名とユーザー名を入力してください",
-    "Enter the database username for %s" : "%sのデータベースのユーザー名を指定してください",
-    "Enter the database name for %s" : "%sのデータベース名を指定してください",
-    "You cannot use dots in the database name %s" : "データベース名%sにドットを入れることはできません",
+    "%s enter the database username and name." : "%s データベース名とデータベースのユーザー名を入力してください。",
+    "%s enter the database username." : "%s のデータベースのユーザー名を入力してください。",
+    "%s enter the database name." : "%s のデータベース名を入力してください。",
+    "%s you may not use dots in the database name" : "%s ではデータベース名にドットを利用できないかもしれません。",
     "MySQL username and/or password not valid" : "MySQLのユーザー名またはパスワードが有効ではありません",
     "You need to enter details of an existing account." : "既存のアカウントの詳細を入力してください。",
     "Oracle connection could not be established" : "Oracleへの接続が確立できませんでした。",
@@ -127,8 +122,8 @@ OC.L10N.register(
     "PostgreSQL username and/or password not valid" : "PostgreSQLのユーザー名またはパスワードが有効ではありません",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X では、サポートされていません。このOSでは、%sは正常に動作しないかもしれません。ご自身の責任においてご利用ください。",
     "For the best results, please consider using a GNU/Linux server instead." : "最も良い方法としては、代わりにGNU/Linuxサーバーを利用することをご検討ください。",
-    "It seems that this %s instance is running on a 32-bit PHP environment. 64-bit is required for 26 and higher." : "この%s実環境は 32ビットPHP環境で実行されているようです。 26以上では64ビットPHPが必要です。",
-    "Please switch to 64-bit PHP." : "64ビットPHPに切り替えてください。",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "このインスタンス %s は、32bit PHP 環境で動作しており、php.ini に open_basedir が設定されているようです。4GB以上のファイルで問題が発生するため、この設定を利用しないことをお勧めします。",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "php.ini から open_basedir 設定を削除するか、64bit PHPに切り替えてください。",
     "Set an admin username." : "管理者のユーザー名を設定",
     "Set an admin password." : "管理者のパスワードを設定",
     "Cannot create or write into the data directory %s" : " データディレクトリ%sに作成、書き込みができません",
@@ -152,7 +147,6 @@ OC.L10N.register(
     "%1$s shared »%2$s« with you." : "%1$sが あなたと »%2$s« を共有しました。",
     "Click the button below to open it." : "開くには下のボタンをクリック",
     "The requested share does not exist anymore" : "この共有はもう存在しません。",
-    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "登録可能なユーザー数の上限に達したため、ユーザーは作成されませんでした。詳細については通知をご確認ください。",
     "Could not find category \"%s\"" : "カテゴリ \"%s\" が見つかりませんでした",
     "Sunday" : "日曜日",
     "Monday" : "月曜日",
@@ -199,6 +193,7 @@ OC.L10N.register(
     "Oct." : "10月",
     "Nov." : "11月",
     "Dec." : "12月",
+    "The user limit has been reached and the user was not created." : "ユーザー数の上限に達したためユーザーを作成出来ませんでした。",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "ユーザー名で利用できる文字列： \"a-z\", \"A-Z\", \"0-9\", \"_.@-\"",
     "A valid username must be provided" : "有効なユーザー名を指定する必要があります",
     "Username contains whitespace at the beginning or at the end" : "ユーザー名の最初か最後に空白が含まれています",
@@ -262,13 +257,6 @@ OC.L10N.register(
     "Storage is temporarily not available" : "ストレージは一時的に利用できません",
     "Storage connection timeout. %s" : "ストレージへの接続がタイムアウト。 %s",
     "This can usually be fixed by giving the webserver write access to the config directory." : "Webサーバーにconfigディレクトリへの書き込み権限を与えることで解決する可能性があります。",
-    "%s enter the database username and name." : "%s データベース名とデータベースのユーザー名を入力してください。",
-    "%s enter the database username." : "%s のデータベースのユーザー名を入力してください。",
-    "%s enter the database name." : "%s のデータベース名を入力してください。",
-    "%s you may not use dots in the database name" : "%s ではデータベース名にドットを利用できないかもしれません。",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "このインスタンス %s は、32bit PHP 環境で動作しており、php.ini に open_basedir が設定されているようです。4GB以上のファイルで問題が発生するため、この設定を利用しないことをお勧めします。",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "php.ini から open_basedir 設定を削除するか、64bit PHPに切り替えてください。",
-    "The user limit has been reached and the user was not created." : "ユーザー数の上限に達したためユーザーを作成出来ませんでした。",
     "Cannot read file" : "ファイルを読み込めません",
     "Cannot write into \"config\" directory" : "\"config\" ディレクトリに書き込みができません",
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "多くの場合、Webサーバーの configディレクトリ に書き込み権限を与えることで直ります。%s を見てください",
@@ -286,7 +274,6 @@ OC.L10N.register(
     "Your data directory is readable by other users" : "データディレクトリは、他のユーザーから読み取り専用です",
     "Your data directory must be an absolute path" : "データディレクトリは、絶対パスにする必要があります",
     "Check the value of \"datadirectory\" in your configuration" : "設定ファイル内の \"datadirectory\" の値を確認してください。",
-    "Your data directory is invalid" : "データディレクトリが無効です",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "ユーザー制限に達したため、ユーザーは作成されませんでした。詳細については、通知を確認してください。"
+    "Your data directory is invalid" : "データディレクトリが無効です"
 },
 "nplurals=1; plural=0;");
