@@ -5,6 +5,11 @@ OC.L10N.register(
     "See %s" : "Se %s",
     "Sample configuration detected" : "Eksempeloppsett oppdaget",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Det ble oppdaget at eksempeloppsettet er blitt kopiert. Dette kan ødelegge installasjonen din og støttes ikke. Les dokumentasjonen før du gjør endringer i config.php",
+    "%s email verification" : "%s e-postbekreftelse",
+    "Email verification" : "E-postbekreftelse",
+    "Click the following button to confirm your email." : "Klikk på følgende knapp for å bekrefte e-posten din.",
+    "Click the following link to confirm your email." : "Klikk på følgende lenke for å bekrefte e-posten din.",
+    "Confirm your email" : "Bekreft din e-post",
     "%1$s and %2$s" : "%1$s og %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s og %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s og %4$s",
@@ -25,6 +30,7 @@ OC.L10N.register(
     "Unknown filetype" : "Ukjent filtype",
     "Invalid image" : "Ugyldig bilde",
     "Avatar image is not square" : "Avatarbilde er ikke firkantet",
+    "View profile" : "Vis profil",
     "today" : "i dag",
     "tomorrow" : "I morgen",
     "yesterday" : "i går",
@@ -44,7 +50,10 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["for %n minutt siden","for %n minutter siden"],
     "in a few seconds" : "om noen sekunder",
     "seconds ago" : "for få sekunder siden",
+    "Empty file" : "Tom fil",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul med ID: %s finnes ikke. Skru den på i app-innstillingene eller kontakt en administrator.",
+    "File already exists" : "Filen finnes allerede",
+    "Invalid path" : "Ugyldig filbane",
     "File name is a reserved word" : "Filnavnet er et reservert ord",
     "File name contains at least one invalid character" : "Filnavnet inneholder minst ett ulovlig tegn",
     "File name is too long" : "Filnavnet er for langt",
@@ -59,6 +68,21 @@ OC.L10N.register(
     "Settings" : "Innstillinger",
     "Log out" : "Logg ut",
     "Users" : "Brukere",
+    "Email" : "E-post",
+    "Mail %s" : "E-post til %s",
+    "Phone" : "Telefon",
+    "Call %s" : "Ring %s",
+    "Twitter" : "Twitter",
+    "View %s on Twitter" : "Se %s på Twitter",
+    "Website" : "Nettsted",
+    "Visit %s" : "Besøk %s",
+    "Address" : "Adresse",
+    "Profile picture" : "Profilbilde",
+    "About" : "Om",
+    "Full name" : "Fullt nav",
+    "Headline" : "Overskrift",
+    "Organisation" : "Organisasion",
+    "Role" : "Rolle",
     "Unknown user" : "Ukjent bruker",
     "Additional settings" : "Flere innstillinger",
     "%s enter the database username and name." : "%s legg inn database brukernavn og navn.",
@@ -84,7 +108,9 @@ OC.L10N.register(
     "Open »%s«" : "Åpne »%s«",
     "%1$s via %2$s" : "%1$s via %2$s",
     "You are not allowed to share %s" : "Du har ikke lov til å dele %s",
+    "Cannot increase permissions of %s" : "Kan ikke øke tillatelser for %s",
     "Expiration date is in the past" : "Utløpsdato er i fortid",
+    "Sharing %s failed, because this item is already shared with user %s" : "Deling av %s mislyktes, fordi dette elementet allerede er delt med bruker %s",
     "%1$s shared »%2$s« with you" : "%1$s delte »%2$s« med deg",
     "%1$s shared »%2$s« with you." : "%1$s delte »%2$s« med deg.",
     "Click the button below to open it." : "Klikk på knappen nedenfor for å åpne den.",
@@ -146,6 +172,7 @@ OC.L10N.register(
     "Login canceled by app" : "Innlogging avbrutt av app",
     "a safe home for all your data" : "et sikkert hjem for alle dine data",
     "File is currently busy, please try again later" : "Filen er opptatt for øyeblikket, prøv igjen senere",
+    "Cannot download file" : "Kan ikke laste ned fil",
     "Application is not enabled" : "Appen er ikke aktivert",
     "Authentication error" : "Autentikasjonsfeil",
     "Token expired. Please reload page." : "Symbol utløpt. Last inn siden på nytt.",
@@ -168,13 +195,7 @@ OC.L10N.register(
     "Storage connection error. %s" : "Tilkoblingsfeil for lager. %s",
     "Storage is temporarily not available" : "Lagring er midlertidig utilgjengelig",
     "Storage connection timeout. %s" : "Tidsavbrudd ved tilkobling av lager: %s",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "Dette kan vanligvis ordnes ved å gi webserveren skrivetilgang til config-mappen",
-    "Can't create or write into the data directory %s" : "Kan ikke opprette eller skrive i datamappen %s",
-    "Can’t increase permissions of %s" : "Kan ikke øke tillatelser for %s",
-    "Files can’t be shared with delete permissions" : "Filer kan ikke deles med tilgang til sletting",
-    "Files can’t be shared with create permissions" : "Filer kan ikke deles med tilgang til opprettelse",
-    "Can’t set expiration date more than %s days in the future" : "Kan ikke sette utløpsdato mer enn %s dager i fremtiden",
-    "Can't read file" : "Kan ikke lese fil",
+    "Cannot read file" : "Kan ikke lese fil",
     "Cannot write into \"config\" directory" : "Kan ikke skrive i \"config\"-mappen",
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Dette kan vanligvis ordnes ved å gi webserveren skrivetilgang til config-mappen. Se %s",
     "Cannot write into \"apps\" directory" : "Kan ikke skrive i \"apps\"-mappen",
