@@ -6,7 +6,7 @@ OC.L10N.register(
     "See %s" : "Se %s",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Filerna i appen %1$s ersattes inte korrekt. Kontrollera att det är en version som är kompatibel med servern.",
     "Sample configuration detected" : "Exempel-konfiguration detekterad",
-    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Det har upptäckts att provkonfigurationen har kopierats. Detta kan bryta din installation och stöds inte. Vänligen läs dokumentationen innan du utför ändringar på config.php",
+    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Det har upptäckts att provkonfigurationen har kopierats. Detta kan bryta din installation och stöds inte. Läs dokumentationen innan du utför ändringar på config.php",
     "%s email verification" : "%s e-postverifikation",
     "Email verification" : "E-postverifikation",
     "Click the following button to confirm your email." : "Klicka på följande knapp för att verifiera din e-postadress.",
@@ -120,9 +120,9 @@ OC.L10N.register(
     "Oracle username and/or password not valid" : "Oracle-användarnamnet och/eller lösenordet är felaktigt",
     "PostgreSQL username and/or password not valid" : "PostgreSQL-användarnamnet och/eller lösenordet är felaktigt",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X stöds inte och %s kommer inte att fungera korrekt på denna plattform. Använd på egen risk!",
-    "For the best results, please consider using a GNU/Linux server instead." : "För bästa resultat, vänligen överväg att använda en GNU/Linux-server istället.",
+    "For the best results, please consider using a GNU/Linux server instead." : "För bästa resultat, överväg att använda en GNU/Linux-server istället.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det verkar som om denna %s instans körs på en 32-bitars PHP miljö och open_basedir har konfigurerats i php.ini. Detta kommer att leda till problem med filer över 4 GB och är verkligen inte rekommenderat!",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Vänligen ta bort open_basedir-inställningen i din php.ini eller växla till 64-bitars PHP.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Ta bort open_basedir-inställningen i din php.ini eller växla till 64-bitars PHP.",
     "Set an admin username." : "Ange ett användarnamn för administratören.",
     "Set an admin password." : "Ange ett administratörslösenord.",
     "Cannot create or write into the data directory %s" : "Kan inte skapa eller skriva till data-katalogen %s",
@@ -205,15 +205,14 @@ OC.L10N.register(
     "Login canceled by app" : "Inloggningen avbruten av appen",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Appen \"%1$s\" kan inte installeras eftersom följande beroenden inte är uppfyllda: %2$s",
     "a safe home for all your data" : "ett säkert hem för all din data",
-    "File is currently busy, please try again later" : "Filen är för tillfället upptagen, vänligen försök igen senare",
-    "Cannot read file" : "Kan inte läsa fil",
+    "File is currently busy, please try again later" : "Filen är för tillfället upptagen, försök igen senare",
     "Application is not enabled" : "Applikationen är inte aktiverad",
     "Authentication error" : "Fel vid autentisering",
-    "Token expired. Please reload page." : "Token har löpt ut. Vänligen uppdatera sidan.",
+    "Token expired. Please reload page." : "Token har löpt ut. Uppdatera sidan.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Inga databasdrivrutiner (sqlite, mysql, eller postgresql) installerade.",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Eller, om du föredrar att behålla config.php skrivskyddad, sätt alternativet \"config_is_read_only\" till true i den. Se %s",
     "PHP module %s not installed." : "PHP-modulen %s är inte installerad.",
-    "Please ask your server administrator to install the module." : "Vänligen be serveradministratören att installera modulen.",
+    "Please ask your server administrator to install the module." : "Be serveradministratören att installera modulen.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP-inställning \"%s\" är inte inställd på \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Att ändra denna inställning i php.ini kommer göra så att Nextcloud fungerar igen",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 är det minsta som krävs. För närvarande är %s installerat.",
@@ -221,8 +220,8 @@ OC.L10N.register(
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP är tydligen inställt för att tömma \"inline doc blocks\". Detta kommer att göra flera kärnprogram otillgängliga.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Detta orsakas troligtvis av en cache/accelerator som t ex Zend OPchache eller eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduler har installerats, men de listas fortfarande som saknade?",
-    "Please ask your server administrator to restart the web server." : "Vänligen be din serveradministratör att starta om webbservern.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Vänligen ändra behörigheterna till 0770 så att katalogen inte kan listas av andra användare.",
+    "Please ask your server administrator to restart the web server." : "Be din serveradministratör att starta om webbservern.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Ändra behörigheterna till 0770 så att katalogen inte kan listas av andra användare.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Säkerställ att du har filen \".ocdata\" i huvudkatalogen för din data.",
     "Action \"%s\" not supported or implemented." : "Åtgärd \"%s\" stöds inte eller är inte implementerad.",
     "Authentication failed, wrong token or provider ID given" : "Autentisering misslyckades, felaktig token eller leverantörs-ID",
@@ -235,32 +234,24 @@ OC.L10N.register(
     "Storage connection error. %s" : "Lagringsutrymme lyckas inte ansluta. %s",
     "Storage is temporarily not available" : "Lagringsutrymme är för tillfället inte tillgängligt",
     "Storage connection timeout. %s" : "Lagringsutrymme lyckas inte ansluta \"timeout\". %s",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "Detta kan vanligtvis åtgärdas genom att ge webservern skrivåtkomst till config-katalogen",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Eller, om du föredrar att behålla config.php skrivskyddad, sätt alternativet \"config_is_read_only\" till true i den.",
     "This can usually be fixed by giving the webserver write access to the config directory." : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivåtkomst till config-katalogen.",
-    "Can't create or write into the data directory %s" : "Kan inte skapa eller skriva till data-katalogen %s",
-    "Can’t increase permissions of %s" : "Kan inte öka rättigheterna för %s",
-    "Files can’t be shared with delete permissions" : "Filer kan inte delas med borttagningsrättigheter",
-    "Files can’t be shared with create permissions" : "Filer kan inte delas med rättigheter att skapa",
-    "Can’t set expiration date more than %s days in the future" : "Kan inte sätta utgångsdatum mer än %s dagar framåt",
-    "Can't read file" : "Kan inte läsa filen",
+    "Cannot read file" : "Kan inte läsa fil",
     "Cannot write into \"config\" directory" : "Kan inte skriva till \"config\" katalogen",
     "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Detta kan vanligtvis åtgärda genom att ge webbservern skrivåtkomst till konfigureringsmappen. Se %s",
     "Cannot write into \"apps\" directory" : "Kan inte skriva till \"apps\" katalogen!",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file." : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivrättigheter till applikationskatalogen eller stänga av app-butiken i konfigurationsfilen.",
+    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivrättigheter till applikationskatalogen eller stänga av appbutiken i konfigurationsfilen.",
     "Cannot create \"data\" directory" : "Kan inte skapa \"data\"-mapp",
     "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Detta kan vanligtvis åtgärda genom att ge webbservern skrivåtkomst till rotkatalogen. Se %s",
     "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Rättigheter kan vanligtvis fixas genom att ge webbservern skrivåtkomst till rotkatalogen. Se %s.",
     "Setting locale to %s failed" : "Sätta locale till %s misslyckades",
-    "Please install one of these locales on your system and restart your webserver." : "Vänligen Installera en av dessa språk på ditt system och starta om webbservern.",
+    "Please install one of these locales on your system and restart your webserver." : "Installera en av dessa språk på ditt system och starta om webbservern.",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload är satt till \"%s\" istället för det förväntade värdet \"0\"",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "För att åtgärda detta problem sätt värdet  <code> mbstring.func_overload till </ code> <code> 0 </ code> i din php.ini",
     "PostgreSQL >= 9 required" : "PostgreSQL >= 9 krävs",
-    "Please upgrade your database version" : "Vänligen uppgradera din databasversion",
+    "Please upgrade your database version" : "Uppgradera din databasversion",
     "Your data directory is readable by other users" : "Din datamapp är läsbar av andra användare",
     "Your data directory must be an absolute path" : "Du måste specificera en korrekt sökväg till datamappen",
     "Check the value of \"datadirectory\" in your configuration" : "Kontrollera värdet av \"datakatalog\" i din konfiguration",
-    "Your data directory is invalid" : "Din datamapp är ogiltig",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivrättigheter till applikationskatalogen eller stänga av appbutiken i konfigurationsfilen."
+    "Your data directory is invalid" : "Din datamapp är ogiltig"
 },
 "nplurals=2; plural=(n != 1);");
