@@ -91,6 +91,8 @@ OC.L10N.register(
     "This is an automatically sent email, please do not reply." : "此為自動寄送的電子郵件，請不要回覆。",
     "Help" : "說明",
     "Apps" : "應用程式",
+    "Personal settings" : "個人設定",
+    "Administration settings" : "管理設定",
     "Settings" : "設定",
     "Log out" : "登出",
     "Users" : "使用者",
