@@ -27,30 +27,42 @@ use OCP\ICache;
  * In-memory cache with a capacity limit to keep memory usage in check
  *
  * Uses a simple FIFO expiry mechanism
+ * @template T
  */
 class CappedMemoryCache implements ICache, \ArrayAccess {
 	private $capacity;
+	/** @var T[] */
 	private $cache = [];
 
 	public function __construct($capacity = 512) {
 		$this->capacity = $capacity;
 	}
 
-	public function hasKey($key) {
+	public function hasKey($key): bool {
 		return isset($this->cache[$key]);
 	}
 
+	/**
+	 * @return ?T
+	 */
 	public function get($key) {
-		return isset($this->cache[$key]) ? $this->cache[$key] : null;
+		return $this->cache[$key] ?? null;
 	}
 
-	public function set($key, $value, $ttl = 0) {
+	/**
+	 * @param string $key
+	 * @param T $value
+	 * @param int $ttl
+	 * @return bool
+	 */
+	public function set($key, $value, $ttl = 0): bool {
 		if (is_null($key)) {
 			$this->cache[] = $value;
 		} else {
 			$this->cache[$key] = $value;
 		}
 		$this->garbageCollect();
+		return true;
 	}
 
 	public function remove($key) {
@@ -63,22 +75,34 @@ class CappedMemoryCache implements ICache, \ArrayAccess {
 		return true;
 	}
 
-	public function offsetExists($offset) {
+	public function offsetExists($offset): bool {
 		return $this->hasKey($offset);
 	}
 
+	/**
+	 * @return T
+	 */
+	#[\ReturnTypeWillChange]
 	public function &offsetGet($offset) {
 		return $this->cache[$offset];
 	}
 
-	public function offsetSet($offset, $value) {
+	/**
+	 * @param string $key
+	 * @param T $value
+	 * @return void
+	 */
+	public function offsetSet($offset, $value): void {
 		$this->set($offset, $value);
 	}
 
-	public function offsetUnset($offset) {
+	public function offsetUnset($offset): void {
 		$this->remove($offset);
 	}
 
+	/**
+	 * @return T[]
+	 */
 	public function getData() {
 		return $this->cache;
 	}
@@ -91,4 +115,8 @@ class CappedMemoryCache implements ICache, \ArrayAccess {
 			$this->remove($key);
 		}
 	}
+
+	public static function isAvailable(): bool {
+		return true;
+	}
 }
