@@ -27,11 +27,12 @@ namespace OC\Files\ObjectStore;
 
 use GuzzleHttp\Client;
 use GuzzleHttp\Exception\BadResponseException;
-use function GuzzleHttp\Psr7\stream_for;
+use GuzzleHttp\Psr7\Utils;
 use Icewind\Streams\RetryWrapper;
 use OCP\Files\NotFoundException;
 use OCP\Files\ObjectStore\IObjectStore;
 use OCP\Files\StorageAuthException;
+use Psr\Log\LoggerInterface;
 
 const SWIFT_SEGMENT_SIZE = 1073741824; // 1GB
 
@@ -48,7 +49,7 @@ class Swift implements IObjectStore {
 		$this->swiftFactory = $connectionFactory ?: new SwiftFactory(
 			\OC::$server->getMemCacheFactory()->createDistributed('swift::'),
 			$params,
-			\OC::$server->getLogger()
+			\OC::$server->get(LoggerInterface::class)
 		);
 		$this->params = $params;
 	}
@@ -81,13 +82,13 @@ class Swift implements IObjectStore {
 		if (filesize($tmpFile) < SWIFT_SEGMENT_SIZE) {
 			$this->getContainer()->createObject([
 				'name' => $urn,
-				'stream' => stream_for($handle),
+				'stream' => Utils::streamFor($handle),
 				'contentType' => $mimetype,
 			]);
 		} else {
 			$this->getContainer()->createLargeObject([
 				'name' => $urn,
-				'stream' => stream_for($handle),
+				'stream' => Utils::streamFor($handle),
 				'segmentSize' => SWIFT_SEGMENT_SIZE,
 				'contentType' => $mimetype,
 			]);
