@@ -60,6 +60,7 @@ use OC\App\AppStore\Fetcher\AppFetcher;
 use OC\App\AppStore\Fetcher\CategoryFetcher;
 use OC\AppFramework\Bootstrap\Coordinator;
 use OC\AppFramework\Http\Request;
+use OC\AppFramework\Http\RequestId;
 use OC\AppFramework\Utility\TimeFactory;
 use OC\Authentication\Events\LoginFailed;
 use OC\Authentication\Listeners\LoginFailedListener;
@@ -87,13 +88,16 @@ use OC\Federation\CloudFederationProviderManager;
 use OC\Federation\CloudIdManager;
 use OC\Files\Config\UserMountCache;
 use OC\Files\Config\UserMountCacheListener;
+use OC\Files\Lock\LockManager;
 use OC\Files\Mount\CacheMountProvider;
 use OC\Files\Mount\LocalHomeMountProvider;
 use OC\Files\Mount\ObjectHomeMountProvider;
 use OC\Files\Mount\ObjectStorePreviewCacheMountProvider;
+use OC\Files\Mount\RootMountProvider;
 use OC\Files\Node\HookConnector;
 use OC\Files\Node\LazyRoot;
 use OC\Files\Node\Root;
+use OC\Files\SetupManager;
 use OC\Files\Storage\StorageFactory;
 use OC\Files\Template\TemplateManager;
 use OC\Files\Type\Loader;
@@ -118,6 +122,9 @@ use OC\Log\PsrLoggerAdapter;
 use OC\Mail\Mailer;
 use OC\Memcache\ArrayCache;
 use OC\Memcache\Factory;
+use OC\Metadata\Capabilities as MetadataCapabilities;
+use OC\Metadata\IMetadataManager;
+use OC\Metadata\MetadataManager;
 use OC\Notification\Manager;
 use OC\OCS\DiscoveryService;
 use OC\Preview\GeneratorHelper;
@@ -142,11 +149,11 @@ use OC\Share20\ProviderFactory;
 use OC\Share20\ShareHelper;
 use OC\SystemTag\ManagerFactory as SystemTagManagerFactory;
 use OC\Tagging\TagMapper;
+use OC\Talk\Broker;
 use OC\Template\JSCombiner;
 use OCA\Theming\ImageManager;
 use OCA\Theming\ThemingDefaults;
 use OCA\Theming\Util;
-use OCA\WorkflowEngine\Service\Logger;
 use OCP\Accounts\IAccountManager;
 use OCP\App\IAppManager;
 use OCP\Authentication\LoginCredentials\IStore;
@@ -171,6 +178,7 @@ use OCP\Files\Config\IUserMountCache;
 use OCP\Files\IMimeTypeDetector;
 use OCP\Files\IMimeTypeLoader;
 use OCP\Files\IRootFolder;
+use OCP\Files\Lock\ILockManager;
 use OCP\Files\Mount\IMountManager;
 use OCP\Files\NotFoundException;
 use OCP\Files\Storage\IStorageFactory;
@@ -202,6 +210,7 @@ use OCP\ILogger;
 use OCP\INavigationManager;
 use OCP\IPreview;
 use OCP\IRequest;
+use OCP\IRequestId;
 use OCP\ISearch;
 use OCP\IServerContainer;
 use OCP\ISession;
@@ -215,6 +224,7 @@ use OCP\L10N\IFactory;
 use OCP\LDAP\ILDAPProvider;
 use OCP\LDAP\ILDAPProviderFactory;
 use OCP\Lock\ILockingProvider;
+use OCP\Lockdown\ILockdownManager;
 use OCP\Log\ILogFactory;
 use OCP\Mail\IMailer;
 use OCP\Remote\Api\IApiFactory;
@@ -231,16 +241,14 @@ use OCP\Security\VerificationToken\IVerificationToken;
 use OCP\Share\IShareHelper;
 use OCP\SystemTag\ISystemTagManager;
 use OCP\SystemTag\ISystemTagObjectMapper;
+use OCP\Talk\IBroker;
 use OCP\User\Events\BeforePasswordUpdatedEvent;
-use OCP\User\Events\BeforeUserCreatedEvent;
-use OCP\User\Events\BeforeUserDeletedEvent;
 use OCP\User\Events\BeforeUserLoggedInEvent;
 use OCP\User\Events\BeforeUserLoggedInWithCookieEvent;
 use OCP\User\Events\BeforeUserLoggedOutEvent;
 use OCP\User\Events\PasswordUpdatedEvent;
 use OCP\User\Events\PostLoginEvent;
 use OCP\User\Events\UserChangedEvent;
-use OCP\User\Events\UserDeletedEvent;
 use OCP\User\Events\UserLoggedInEvent;
 use OCP\User\Events\UserLoggedInWithCookieEvent;
 use OCP\User\Events\UserLoggedOutEvent;
@@ -253,6 +261,8 @@ use OCA\Files_External\Service\UserStoragesService;
 use OCA\Files_External\Service\UserGlobalStoragesService;
 use OCA\Files_External\Service\GlobalStoragesService;
 use OCA\Files_External\Service\BackendService;
+use OCP\Profiler\IProfiler;
+use OC\Profiler\Profiler;
 
 /**
  * Class Server
@@ -337,6 +347,10 @@ class Server extends ServerContainer implements IServerContainer {
 			);
 		});
 
+		$this->registerService(IProfiler::class, function (Server $c) {
+			return new Profiler($c->get(SystemConfig::class));
+		});
+
 		$this->registerService(\OCP\Encryption\IManager::class, function (Server $c) {
 			$view = new View();
 			$util = new Encryption\Util(
@@ -347,7 +361,7 @@ class Server extends ServerContainer implements IServerContainer {
 			);
 			return new Encryption\Manager(
 				$c->get(\OCP\IConfig::class),
-				$c->get(ILogger::class),
+				$c->get(LoggerInterface::class),
 				$c->getL10N('core'),
 				new View(),
 				$util,
@@ -421,8 +435,9 @@ class Server extends ServerContainer implements IServerContainer {
 				$view,
 				null,
 				$c->get(IUserMountCache::class),
-				$this->get(ILogger::class),
-				$this->get(IUserManager::class)
+				$this->get(LoggerInterface::class),
+				$this->get(IUserManager::class),
+				$this->get(IEventDispatcher::class),
 			);
 
 			$previewConnector = new \OC\Preview\WatcherConnector(
@@ -458,7 +473,11 @@ class Server extends ServerContainer implements IServerContainer {
 		$this->registerAlias(\OCP\IUserManager::class, \OC\User\Manager::class);
 
 		$this->registerService(\OCP\IGroupManager::class, function (ContainerInterface $c) {
-			$groupManager = new \OC\Group\Manager($this->get(IUserManager::class), $c->get(SymfonyAdapter::class), $this->get(ILogger::class));
+			$groupManager = new \OC\Group\Manager(
+				$this->get(IUserManager::class),
+				$c->get(SymfonyAdapter::class),
+				$this->get(LoggerInterface::class)
+			);
 			$groupManager->listen('\OC\Group', 'preCreate', function ($gid) {
 				/** @var IEventDispatcher $dispatcher */
 				$dispatcher = $this->get(IEventDispatcher::class);
@@ -522,11 +541,11 @@ class Server extends ServerContainer implements IServerContainer {
 			$session = new \OC\Session\Memory('');
 			$timeFactory = new TimeFactory();
 			// Token providers might require a working database. This code
-			// might however be called when ownCloud is not yet setup.
+			// might however be called when Nextcloud is not yet setup.
 			if (\OC::$server->get(SystemConfig::class)->getValue('installed', false)) {
-				$defaultTokenProvider = $c->get(IProvider::class);
+				$provider = $c->get(IProvider::class);
 			} else {
-				$defaultTokenProvider = null;
+				$provider = null;
 			}
 
 			$legacyDispatcher = $c->get(SymfonyAdapter::class);
@@ -535,11 +554,11 @@ class Server extends ServerContainer implements IServerContainer {
 				$manager,
 				$session,
 				$timeFactory,
-				$defaultTokenProvider,
+				$provider,
 				$c->get(\OCP\IConfig::class),
 				$c->get(ISecureRandom::class),
 				$c->getLockdownManager(),
-				$c->get(ILogger::class),
+				$c->get(LoggerInterface::class),
 				$c->get(IEventDispatcher::class)
 			);
 			/** @deprecated 21.0.0 use BeforeUserCreatedEvent event with the IEventDispatcher instead */
@@ -679,7 +698,9 @@ class Server extends ServerContainer implements IServerContainer {
 		$this->registerDeprecatedAlias('UserCache', ICache::class);
 
 		$this->registerService(Factory::class, function (Server $c) {
-			$arrayCacheFactory = new \OC\Memcache\Factory('', $c->get(ILogger::class),
+			$profiler = $c->get(IProfiler::class);
+			$arrayCacheFactory = new \OC\Memcache\Factory('', $c->get(LoggerInterface::class),
+				$profiler,
 				ArrayCache::class,
 				ArrayCache::class,
 				ArrayCache::class
@@ -703,7 +724,9 @@ class Server extends ServerContainer implements IServerContainer {
 				$instanceId = \OC_Util::getInstanceId();
 				$path = \OC::$SERVERROOT;
 				$prefix = md5($instanceId . '-' . $version . '-' . $path);
-				return new \OC\Memcache\Factory($prefix, $c->get(ILogger::class),
+				return new \OC\Memcache\Factory($prefix,
+					$c->get(LoggerInterface::class),
+					$profiler,
 					$config->getSystemValue('memcache.local', null),
 					$config->getSystemValue('memcache.distributed', null),
 					$config->getSystemValue('memcache.locking', null),
@@ -718,7 +741,7 @@ class Server extends ServerContainer implements IServerContainer {
 
 		$this->registerService('RedisFactory', function (Server $c) {
 			$systemConfig = $c->get(SystemConfig::class);
-			return new RedisFactory($systemConfig);
+			return new RedisFactory($systemConfig, $c->getEventLogger());
 		});
 
 		$this->registerService(\OCP\Activity\IManager::class, function (Server $c) {
@@ -753,6 +776,7 @@ class Server extends ServerContainer implements IServerContainer {
 				$c->get(KnownUserService::class)
 			);
 		});
+
 		$this->registerAlias(IAvatarManager::class, AvatarManager::class);
 		/** @deprecated 19.0.0 */
 		$this->registerDeprecatedAlias('AvatarManager', AvatarManager::class);
@@ -784,7 +808,7 @@ class Server extends ServerContainer implements IServerContainer {
 
 		$this->registerService(Router::class, function (Server $c) {
 			$cacheFactory = $c->get(ICacheFactory::class);
-			$logger = $c->get(ILogger::class);
+			$logger = $c->get(LoggerInterface::class);
 			if ($cacheFactory->isLocalCacheAvailable()) {
 				$router = new \OC\Route\CachingRouter($cacheFactory->createLocal('route'), $logger);
 			} else {
@@ -845,7 +869,6 @@ class Server extends ServerContainer implements IServerContainer {
 			}
 			$connectionParams = $factory->createConnectionParams();
 			$connection = $factory->getConnection($type, $connectionParams);
-			$connection->getConfiguration()->setSQLLogger($c->getQueryLogger());
 			return $connection;
 		});
 		/** @deprecated 19.0.0 */
@@ -855,7 +878,7 @@ class Server extends ServerContainer implements IServerContainer {
 		$this->registerAlias(IClientService::class, ClientService::class);
 		$this->registerService(LocalAddressChecker::class, function (ContainerInterface $c) {
 			return new LocalAddressChecker(
-				$c->get(ILogger::class),
+				$c->get(LoggerInterface::class),
 			);
 		});
 		$this->registerService(NegativeDnsCache::class, function (ContainerInterface $c) {
@@ -871,12 +894,7 @@ class Server extends ServerContainer implements IServerContainer {
 		});
 		$this->registerDeprecatedAlias('HttpClientService', IClientService::class);
 		$this->registerService(IEventLogger::class, function (ContainerInterface $c) {
-			$eventLogger = new EventLogger();
-			if ($c->get(SystemConfig::class)->getValue('debug', false)) {
-				// In debug mode, module is being activated by default
-				$eventLogger->activate();
-			}
-			return $eventLogger;
+			return new EventLogger($c->get(SystemConfig::class), $c->get(LoggerInterface::class), $c->get(Log::class));
 		});
 		/** @deprecated 19.0.0 */
 		$this->registerDeprecatedAlias('EventLogger', IEventLogger::class);
@@ -931,7 +949,7 @@ class Server extends ServerContainer implements IServerContainer {
 			$mountCache = new UserMountCache(
 				$c->get(IDBConnection::class),
 				$c->get(IUserManager::class),
-				$c->get(ILogger::class)
+				$c->get(LoggerInterface::class)
 			);
 			$listener = new UserMountCacheListener($mountCache);
 			$listener->listen($c->get(IUserManager::class));
@@ -948,10 +966,11 @@ class Server extends ServerContainer implements IServerContainer {
 			// builtin providers
 
 			$config = $c->get(\OCP\IConfig::class);
-			$logger = $c->get(ILogger::class);
+			$logger = $c->get(LoggerInterface::class);
 			$manager->registerProvider(new CacheMountProvider($config));
 			$manager->registerHomeProvider(new LocalHomeMountProvider());
 			$manager->registerHomeProvider(new ObjectHomeMountProvider($config));
+			$manager->registerRootProvider(new RootMountProvider($config, $c->get(LoggerInterface::class)));
 			$manager->registerRootProvider(new ObjectStorePreviewCacheMountProvider($logger, $config));
 
 			return $manager;
@@ -1031,7 +1050,7 @@ class Server extends ServerContainer implements IServerContainer {
 						: '',
 					'urlParams' => $urlParams,
 				],
-				$this->get(ISecureRandom::class),
+				$this->get(IRequestId::class),
 				$this->get(\OCP\IConfig::class),
 				$this->get(CsrfTokenManager::class),
 				$stream
@@ -1040,10 +1059,17 @@ class Server extends ServerContainer implements IServerContainer {
 		/** @deprecated 19.0.0 */
 		$this->registerDeprecatedAlias('Request', \OCP\IRequest::class);
 
+		$this->registerService(IRequestId::class, function (ContainerInterface $c): IRequestId {
+			return new RequestId(
+				$_SERVER['UNIQUE_ID'] ?? '',
+				$this->get(ISecureRandom::class)
+			);
+		});
+
 		$this->registerService(IMailer::class, function (Server $c) {
 			return new Mailer(
 				$c->get(\OCP\IConfig::class),
-				$c->get(ILogger::class),
+				$c->get(LoggerInterface::class),
 				$c->get(Defaults::class),
 				$c->get(IURLGenerator::class),
 				$c->getL10N('lib'),
@@ -1083,7 +1109,7 @@ class Server extends ServerContainer implements IServerContainer {
 				}
 				return new DBLockingProvider(
 					$c->get(IDBConnection::class),
-					$c->get(ILogger::class),
+					$c->get(LoggerInterface::class),
 					new TimeFactory(),
 					$ttl,
 					!\OC::$CLI
@@ -1094,6 +1120,15 @@ class Server extends ServerContainer implements IServerContainer {
 		/** @deprecated 19.0.0 */
 		$this->registerDeprecatedAlias('LockingProvider', ILockingProvider::class);
 
+		$this->registerService(ILockManager::class, function (Server $c): LockManager {
+			return new LockManager();
+		});
+
+		$this->registerAlias(ILockdownManager::class, 'LockdownManager');
+		$this->registerService(SetupManager::class, function ($c) {
+			// create the setupmanager through the mount manager to resolve the cyclic dependency
+			return $c->get(\OC\Files\Mount\Manager::class)->getSetupManager();
+		});
 		$this->registerAlias(IMountManager::class, \OC\Files\Mount\Manager::class);
 		/** @deprecated 19.0.0 */
 		$this->registerDeprecatedAlias('MountManager', IMountManager::class);
@@ -1101,7 +1136,7 @@ class Server extends ServerContainer implements IServerContainer {
 		$this->registerService(IMimeTypeDetector::class, function (ContainerInterface $c) {
 			return new \OC\Files\Type\Detection(
 				$c->get(IURLGenerator::class),
-				$c->get(ILogger::class),
+				$c->get(LoggerInterface::class),
 				\OC::$configDir,
 				\OC::$SERVERROOT . '/resources/config/'
 			);
@@ -1127,6 +1162,9 @@ class Server extends ServerContainer implements IServerContainer {
 			$manager->registerCapability(function () use ($c) {
 				return $c->get(\OC\Security\Bruteforce\Capabilities::class);
 			});
+			$manager->registerCapability(function () use ($c) {
+				return $c->get(MetadataCapabilities::class);
+			});
 			return $manager;
 		});
 		/** @deprecated 19.0.0 */
@@ -1198,7 +1236,7 @@ class Server extends ServerContainer implements IServerContainer {
 				$c->get(IURLGenerator::class),
 				$this->get(ICacheFactory::class),
 				$c->get(SystemConfig::class),
-				$c->get(ILogger::class)
+				$c->get(LoggerInterface::class)
 			);
 		});
 		$this->registerAlias(\OCP\EventDispatcher\IEventDispatcher::class, \OC\EventDispatcher\EventDispatcher::class);
@@ -1207,7 +1245,7 @@ class Server extends ServerContainer implements IServerContainer {
 		$this->registerAlias(EventDispatcherInterface::class, \OC\EventDispatcher\SymfonyAdapter::class);
 
 		$this->registerService('CryptoWrapper', function (ContainerInterface $c) {
-			// FIXME: Instantiiated here due to cyclic dependency
+			// FIXME: Instantiated here due to cyclic dependency
 			$request = new Request(
 				[
 					'get' => $_GET,
@@ -1220,7 +1258,7 @@ class Server extends ServerContainer implements IServerContainer {
 						? $_SERVER['REQUEST_METHOD']
 						: null,
 				],
-				$c->get(ISecureRandom::class),
+				$c->get(IRequestId::class),
 				$c->get(\OCP\IConfig::class)
 			);
 
@@ -1247,7 +1285,7 @@ class Server extends ServerContainer implements IServerContainer {
 			$factory = new $factoryClass($this);
 
 			$manager = new \OC\Share20\Manager(
-				$c->get(ILogger::class),
+				$c->get(LoggerInterface::class),
 				$c->get(\OCP\IConfig::class),
 				$c->get(ISecureRandom::class),
 				$c->get(IHasher::class),
@@ -1326,7 +1364,7 @@ class Server extends ServerContainer implements IServerContainer {
 				$c->get(IAppManager::class),
 				$c->get(IClientService::class),
 				$c->get(ICloudIdManager::class),
-				$c->get(ILogger::class)
+				$c->get(LoggerInterface::class)
 			);
 		});
 
@@ -1395,6 +1433,10 @@ class Server extends ServerContainer implements IServerContainer {
 
 		$this->registerAlias(\OCP\UserStatus\IManager::class, \OC\UserStatus\Manager::class);
 
+		$this->registerAlias(IBroker::class, Broker::class);
+
+		$this->registerAlias(IMetadataManager::class, MetadataManager::class);
+
 		$this->connectDispatcher();
 	}
 
@@ -1433,7 +1475,7 @@ class Server extends ServerContainer implements IServerContainer {
 
 		// Delete avatar on user deletion
 		$dispatcher->addListener('OCP\IUser::preDelete', function (GenericEvent $e) {
-			$logger = $this->get(ILogger::class);
+			$logger = $this->get(LoggerInterface::class);
 			$manager = $this->getAvatarManager();
 			/** @var IUser $user */
 			$user = $e->getSubject();
@@ -2342,8 +2384,8 @@ class Server extends ServerContainer implements IServerContainer {
 	private function registerDeprecatedAlias(string $alias, string $target) {
 		$this->registerService($alias, function (ContainerInterface $container) use ($target, $alias) {
 			try {
-				/** @var ILogger $logger */
-				$logger = $container->get(ILogger::class);
+				/** @var LoggerInterface $logger */
+				$logger = $container->get(LoggerInterface::class);
 				$logger->debug('The requested alias "' . $alias . '" is deprecated. Please request "' . $target . '" directly. This alias will be removed in a future Nextcloud version.', ['app' => 'serverDI']);
 			} catch (ContainerExceptionInterface $e) {
 				// Could not get logger. Continue
