@@ -23,7 +23,6 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>
  *
  */
-
 namespace OC\Session;
 
 use OCP\IConfig;
@@ -88,22 +87,18 @@ class CryptoWrapper {
 					$webRoot = '/';
 				}
 
-				if (PHP_VERSION_ID < 70300) {
-					setcookie(self::COOKIE_NAME, $this->passphrase, 0, $webRoot, '', $secureCookie, true);
-				} else {
-					setcookie(
-						self::COOKIE_NAME,
-						$this->passphrase,
-						[
-							'expires' => 0,
-							'path' => $webRoot,
-							'domain' => '',
-							'secure' => $secureCookie,
-							'httponly' => true,
-							'samesite' => 'Lax',
-						]
-					);
-				}
+				setcookie(
+					self::COOKIE_NAME,
+					$this->passphrase,
+					[
+						'expires' => 0,
+						'path' => $webRoot,
+						'domain' => '',
+						'secure' => $secureCookie,
+						'httponly' => true,
+						'samesite' => 'Lax',
+					]
+				);
 			}
 		}
 	}
