@@ -66,11 +66,10 @@
 
 use bantu\IniGetWrapper\IniGetWrapper;
 use OC\AppFramework\Http\Request;
-use OC\Files\Storage\LocalRootStorage;
+use OC\Files\SetupManager;
 use OCP\Files\Template\ITemplateManager;
 use OCP\IConfig;
 use OCP\IGroupManager;
-use OCP\ILogger;
 use OCP\IURLGenerator;
 use OCP\IUser;
 use OCP\Share\IManager;
@@ -80,9 +79,6 @@ class OC_Util {
 	public static $scripts = [];
 	public static $styles = [];
 	public static $headers = [];
-	private static $rootMounted = false;
-	private static $rootFsSetup = false;
-	private static $fsSetup = false;
 
 	/** @var array Local cache of version.php */
 	private static $versionCache = null;
@@ -91,222 +87,6 @@ class OC_Util {
 		return \OC::$server->getAppManager();
 	}
 
-	private static function initLocalStorageRootFS() {
-		// mount local file backend as root
-		$configDataDirectory = \OC::$server->getSystemConfig()->getValue("datadirectory", OC::$SERVERROOT . "/data");
-		//first set up the local "root" storage
-		\OC\Files\Filesystem::initMountManager();
-		if (!self::$rootMounted) {
-			\OC\Files\Filesystem::mount(LocalRootStorage::class, ['datadir' => $configDataDirectory], '/');
-			self::$rootMounted = true;
-		}
-	}
-
-	/**
-	 * mounting an object storage as the root fs will in essence remove the
-	 * necessity of a data folder being present.
-	 * TODO make home storage aware of this and use the object storage instead of local disk access
-	 *
-	 * @param array $config containing 'class' and optional 'arguments'
-	 * @suppress PhanDeprecatedFunction
-	 */
-	private static function initObjectStoreRootFS($config) {
-		// check misconfiguration
-		if (empty($config['class'])) {
-			\OCP\Util::writeLog('files', 'No class given for objectstore', ILogger::ERROR);
-		}
-		if (!isset($config['arguments'])) {
-			$config['arguments'] = [];
-		}
-
-		// instantiate object store implementation
-		$name = $config['class'];
-		if (strpos($name, 'OCA\\') === 0 && substr_count($name, '\\') >= 2) {
-			$segments = explode('\\', $name);
-			OC_App::loadApp(strtolower($segments[1]));
-		}
-		$config['arguments']['objectstore'] = new $config['class']($config['arguments']);
-		// mount with plain / root object store implementation
-		$config['class'] = '\OC\Files\ObjectStore\ObjectStoreStorage';
-
-		// mount object storage as root
-		\OC\Files\Filesystem::initMountManager();
-		if (!self::$rootMounted) {
-			\OC\Files\Filesystem::mount($config['class'], $config['arguments'], '/');
-			self::$rootMounted = true;
-		}
-	}
-
-	/**
-	 * mounting an object storage as the root fs will in essence remove the
-	 * necessity of a data folder being present.
-	 *
-	 * @param array $config containing 'class' and optional 'arguments'
-	 * @suppress PhanDeprecatedFunction
-	 */
-	private static function initObjectStoreMultibucketRootFS($config) {
-		// check misconfiguration
-		if (empty($config['class'])) {
-			\OCP\Util::writeLog('files', 'No class given for objectstore', ILogger::ERROR);
-		}
-		if (!isset($config['arguments'])) {
-			$config['arguments'] = [];
-		}
-
-		// instantiate object store implementation
-		$name = $config['class'];
-		if (strpos($name, 'OCA\\') === 0 && substr_count($name, '\\') >= 2) {
-			$segments = explode('\\', $name);
-			OC_App::loadApp(strtolower($segments[1]));
-		}
-
-		if (!isset($config['arguments']['bucket'])) {
-			$config['arguments']['bucket'] = '';
-		}
-		// put the root FS always in first bucket for multibucket configuration
-		$config['arguments']['bucket'] .= '0';
-
-		$config['arguments']['objectstore'] = new $config['class']($config['arguments']);
-		// mount with plain / root object store implementation
-		$config['class'] = '\OC\Files\ObjectStore\ObjectStoreStorage';
-
-		// mount object storage as root
-		\OC\Files\Filesystem::initMountManager();
-		if (!self::$rootMounted) {
-			\OC\Files\Filesystem::mount($config['class'], $config['arguments'], '/');
-			self::$rootMounted = true;
-		}
-	}
-
-	/**
-	 * Can be set up
-	 *
-	 * @param string $user
-	 * @return boolean
-	 * @description configure the initial filesystem based on the configuration
-	 * @suppress PhanDeprecatedFunction
-	 * @suppress PhanAccessMethodInternal
-	 */
-	public static function setupRootFS(string $user = '') {
-		//setting up the filesystem twice can only lead to trouble
-		if (self::$rootFsSetup) {
-			return false;
-		}
-
-		\OC::$server->getEventLogger()->start('setup_root_fs', 'Setup root filesystem');
-
-		// load all filesystem apps before, so no setup-hook gets lost
-		OC_App::loadApps(['filesystem']);
-
-		self::$rootFsSetup = true;
-
-		\OC\Files\Filesystem::initMountManager();
-
-		$prevLogging = \OC\Files\Filesystem::logWarningWhenAddingStorageWrapper(false);
-		\OC\Files\Filesystem::addStorageWrapper('mount_options', function ($mountPoint, \OCP\Files\Storage $storage, \OCP\Files\Mount\IMountPoint $mount) {
-			if ($storage->instanceOfStorage('\OC\Files\Storage\Common')) {
-				/** @var \OC\Files\Storage\Common $storage */
-				$storage->setMountOptions($mount->getOptions());
-			}
-			return $storage;
-		});
-
-		\OC\Files\Filesystem::addStorageWrapper('enable_sharing', function ($mountPoint, \OCP\Files\Storage\IStorage $storage, \OCP\Files\Mount\IMountPoint $mount) {
-			if (!$mount->getOption('enable_sharing', true)) {
-				return new \OC\Files\Storage\Wrapper\PermissionsMask([
-					'storage' => $storage,
-					'mask' => \OCP\Constants::PERMISSION_ALL - \OCP\Constants::PERMISSION_SHARE
-				]);
-			}
-			return $storage;
-		});
-
-		// install storage availability wrapper, before most other wrappers
-		\OC\Files\Filesystem::addStorageWrapper('oc_availability', function ($mountPoint, \OCP\Files\Storage\IStorage $storage) {
-			if (!$storage->instanceOfStorage('\OCA\Files_Sharing\SharedStorage') && !$storage->isLocal()) {
-				return new \OC\Files\Storage\Wrapper\Availability(['storage' => $storage]);
-			}
-			return $storage;
-		});
-
-		\OC\Files\Filesystem::addStorageWrapper('oc_encoding', function ($mountPoint, \OCP\Files\Storage $storage, \OCP\Files\Mount\IMountPoint $mount) {
-			if ($mount->getOption('encoding_compatibility', false) && !$storage->instanceOfStorage('\OCA\Files_Sharing\SharedStorage') && !$storage->isLocal()) {
-				return new \OC\Files\Storage\Wrapper\Encoding(['storage' => $storage]);
-			}
-			return $storage;
-		});
-
-		\OC\Files\Filesystem::addStorageWrapper('oc_quota', function ($mountPoint, $storage) {
-			// set up quota for home storages, even for other users
-			// which can happen when using sharing
-
-			/**
-			 * @var \OC\Files\Storage\Storage $storage
-			 */
-			if ($storage->instanceOfStorage('\OC\Files\Storage\Home')
-				|| $storage->instanceOfStorage('\OC\Files\ObjectStore\HomeObjectStoreStorage')
-			) {
-				/** @var \OC\Files\Storage\Home $storage */
-				if (is_object($storage->getUser())) {
-					$quota = OC_Util::getUserQuota($storage->getUser());
-					if ($quota !== \OCP\Files\FileInfo::SPACE_UNLIMITED) {
-						return new \OC\Files\Storage\Wrapper\Quota(['storage' => $storage, 'quota' => $quota, 'root' => 'files']);
-					}
-				}
-			}
-
-			return $storage;
-		});
-
-		\OC\Files\Filesystem::addStorageWrapper('readonly', function ($mountPoint, \OCP\Files\Storage\IStorage $storage, \OCP\Files\Mount\IMountPoint $mount) {
-			/*
-			 * Do not allow any operations that modify the storage
-			 */
-			if ($mount->getOption('readonly', false)) {
-				return new \OC\Files\Storage\Wrapper\PermissionsMask([
-					'storage' => $storage,
-					'mask' => \OCP\Constants::PERMISSION_ALL & ~(
-							\OCP\Constants::PERMISSION_UPDATE |
-							\OCP\Constants::PERMISSION_CREATE |
-							\OCP\Constants::PERMISSION_DELETE
-						),
-				]);
-			}
-			return $storage;
-		});
-
-		OC_Hook::emit('OC_Filesystem', 'preSetup', ['user' => $user]);
-
-		\OC\Files\Filesystem::logWarningWhenAddingStorageWrapper($prevLogging);
-
-		//check if we are using an object storage
-		$objectStore = \OC::$server->getSystemConfig()->getValue('objectstore', null);
-		$objectStoreMultibucket = \OC::$server->getSystemConfig()->getValue('objectstore_multibucket', null);
-
-		// use the same order as in ObjectHomeMountProvider
-		if (isset($objectStoreMultibucket)) {
-			self::initObjectStoreMultibucketRootFS($objectStoreMultibucket);
-		} elseif (isset($objectStore)) {
-			self::initObjectStoreRootFS($objectStore);
-		} else {
-			self::initLocalStorageRootFS();
-		}
-
-		/** @var \OCP\Files\Config\IMountProviderCollection $mountProviderCollection */
-		$mountProviderCollection = \OC::$server->query(\OCP\Files\Config\IMountProviderCollection::class);
-		$rootMountProviders = $mountProviderCollection->getRootMounts();
-
-		/** @var \OC\Files\Mount\Manager $mountManager */
-		$mountManager = \OC\Files\Filesystem::getMountManager();
-		foreach ($rootMountProviders as $rootMountProvider) {
-			$mountManager->addMount($rootMountProvider);
-		}
-
-		\OC::$server->getEventLogger()->end('setup_root_fs');
-
-		return true;
-	}
-
 	/**
 	 * Setup the file system
 	 *
@@ -317,14 +97,6 @@ class OC_Util {
 	 * @suppress PhanAccessMethodInternal
 	 */
 	public static function setupFS(?string $user = '') {
-		self::setupRootFS($user ?? '');
-
-		if (self::$fsSetup) {
-			return false;
-		}
-
-		\OC::$server->getEventLogger()->start('setup_fs', 'Setup filesystem');
-
 		// If we are not forced to load a specific user we load the one that is logged in
 		if ($user === '') {
 			$userObject = \OC::$server->get(\OCP\IUserSession::class)->getUser();
@@ -332,18 +104,14 @@ class OC_Util {
 			$userObject = \OC::$server->get(\OCP\IUserManager::class)->get($user);
 		}
 
-		//if we aren't logged in, or the user doesn't exist, there is no use to set up the filesystem
+		/** @var SetupManager $setupManager */
+		$setupManager = \OC::$server->get(SetupManager::class);
+
 		if ($userObject) {
-			self::$fsSetup = true;
-
-			$userDir = '/' . $userObject->getUID() . '/files';
-
-			//jail the user into his "home" directory
-			\OC\Files\Filesystem::init($userObject, $userDir);
-
-			OC_Hook::emit('OC_Filesystem', 'setup', ['user' => $userObject->getUID(), 'user_dir' => $userDir]);
+			$setupManager->setupForUser($userObject);
+		} else {
+			$setupManager->setupRoot();
 		}
-		\OC::$server->getEventLogger()->end('setup_fs');
 		return true;
 	}
 
@@ -486,7 +254,7 @@ class OC_Util {
 						closedir($dir);
 						return;
 					}
-					$child->putContent($sourceStream);
+					stream_copy_to_stream($sourceStream, $child->fopen('w'));
 				}
 			}
 		}
@@ -498,11 +266,9 @@ class OC_Util {
 	 * @suppress PhanUndeclaredMethod
 	 */
 	public static function tearDownFS() {
-		\OC\Files\Filesystem::tearDown();
-		\OC::$server->getRootFolder()->clearCache();
-		self::$fsSetup = false;
-		self::$rootFsSetup = false;
-		self::$rootMounted = false;
+		/** @var SetupManager $setupManager */
+		$setupManager = \OC::$server->get(SetupManager::class);
+		$setupManager->tearDown();
 	}
 
 	/**
@@ -598,6 +364,8 @@ class OC_Util {
 	/**
 	 * add a javascript file
 	 *
+	 * @deprecated 24.0.0 - Use \OCP\Util::addScript
+	 *
 	 * @param string $application application id
 	 * @param string|null $file filename
 	 * @param bool $prepend prepend the Script to the beginning of the list
@@ -629,6 +397,8 @@ class OC_Util {
 	/**
 	 * add a translation JS file
 	 *
+	 * @deprecated 24.0.0
+	 *
 	 * @param string $application application id
 	 * @param string|null $languageCode language code, defaults to the current language
 	 * @param bool|null $prepend prepend the Script to the beginning of the list
@@ -769,8 +539,8 @@ class OC_Util {
 		if (!OC_Helper::isReadOnlyConfigEnabled()) {
 			if (!is_writable(OC::$configDir) or !is_readable(OC::$configDir)) {
 				$errors[] = [
-					'error' => $l->t('Cannot write into "config" directory'),
-					'hint' => $l->t('This can usually be fixed by giving the webserver write access to the config directory. See %s',
+					'error' => $l->t('Cannot write into "config" directory.'),
+					'hint' => $l->t('This can usually be fixed by giving the web server write access to the config directory. See %s',
 						[ $urlGenerator->linkToDocs('admin-dir_permissions') ]) . '. '
 						. $l->t('Or, if you prefer to keep config.php file read only, set the option "config_is_read_only" to true in it. See %s',
 						[ $urlGenerator->linkToDocs('admin-config') ])
@@ -785,8 +555,8 @@ class OC_Util {
 				|| !is_readable(OC_App::getInstallPath())
 			) {
 				$errors[] = [
-					'error' => $l->t('Cannot write into "apps" directory'),
-					'hint' => $l->t('This can usually be fixed by giving the webserver write access to the apps directory'
+					'error' => $l->t('Cannot write into "apps" directory.'),
+					'hint' => $l->t('This can usually be fixed by giving the web server write access to the apps directory'
 						. ' or disabling the App Store in the config file.')
 				];
 			}
@@ -799,8 +569,8 @@ class OC_Util {
 					$errors = array_merge($errors, self::checkDataDirectoryPermissions($CONFIG_DATADIRECTORY));
 				} else {
 					$errors[] = [
-						'error' => $l->t('Cannot create "data" directory'),
-						'hint' => $l->t('This can usually be fixed by giving the webserver write access to the root directory. See %s',
+						'error' => $l->t('Cannot create "data" directory.'),
+						'hint' => $l->t('This can usually be fixed by giving the web server write access to the root directory. See %s',
 							[$urlGenerator->linkToDocs('admin-dir_permissions')])
 					];
 				}
@@ -809,10 +579,10 @@ class OC_Util {
 				$testFile = sprintf('%s/%s.tmp', $CONFIG_DATADIRECTORY, uniqid('data_dir_writability_test_'));
 				$handle = fopen($testFile, 'w');
 				if (!$handle || fwrite($handle, 'Test write operation') === false) {
-					$permissionsHint = $l->t('Permissions can usually be fixed by giving the webserver write access to the root directory. See %s.',
+					$permissionsHint = $l->t('Permissions can usually be fixed by giving the web server write access to the root directory. See %s.',
 						[$urlGenerator->linkToDocs('admin-dir_permissions')]);
 					$errors[] = [
-						'error' => 'Your data directory is not writable',
+						'error' => $l->t('Your data directory is not writable.'),
 						'hint' => $permissionsHint
 					];
 				} else {
@@ -826,10 +596,10 @@ class OC_Util {
 
 		if (!OC_Util::isSetLocaleWorking()) {
 			$errors[] = [
-				'error' => $l->t('Setting locale to %s failed',
+				'error' => $l->t('Setting locale to %s failed.',
 					['en_US.UTF-8/fr_FR.UTF-8/es_ES.UTF-8/de_DE.UTF-8/ru_RU.UTF-8/'
 						. 'pt_BR.UTF-8/it_IT.UTF-8/ja_JP.UTF-8/zh_CN.UTF-8']),
-				'hint' => $l->t('Please install one of these locales on your system and restart your webserver.')
+				'hint' => $l->t('Please install one of these locales on your system and restart your web server.')
 			];
 		}
 
@@ -868,7 +638,6 @@ class OC_Util {
 			],
 		];
 		$missingDependencies = [];
-		/** @var array<array-key, bool|string|int> $invalidIniSettings */
 		$invalidIniSettings = [];
 
 		$iniWrapper = \OC::$server->get(IniGetWrapper::class);
@@ -914,7 +683,7 @@ class OC_Util {
 		}
 		foreach ($invalidIniSettings as $setting) {
 			if (is_bool($setting[1])) {
-				$setting[1] = $setting[1] === true ? 'on' : 'off';
+				$setting[1] = $setting[1] ? 'on' : 'off';
 			}
 			$errors[] = [
 				'error' => $l->t('PHP setting "%s" is not set to "%s".', [$setting[0], var_export($setting[1], true)]),
@@ -934,8 +703,8 @@ class OC_Util {
 		if ($iniWrapper->getBool('mbstring.func_overload') !== null &&
 			$iniWrapper->getBool('mbstring.func_overload') === true) {
 			$errors[] = [
-				'error' => $l->t('mbstring.func_overload is set to "%s" instead of the expected value "0"', [$iniWrapper->getString('mbstring.func_overload')]),
-				'hint' => $l->t('To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini')
+				'error' => $l->t('<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>.', [$iniWrapper->getString('mbstring.func_overload')]),
+				'hint' => $l->t('To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini.')
 			];
 		}
 
@@ -994,8 +763,8 @@ class OC_Util {
 					$version = $data['server_version'];
 					if (version_compare($version, '9.0.0', '<')) {
 						$errors[] = [
-							'error' => $l->t('PostgreSQL >= 9 required'),
-							'hint' => $l->t('Please upgrade your database version')
+							'error' => $l->t('PostgreSQL >= 9 required.'),
+							'hint' => $l->t('Please upgrade your database version.')
 						];
 					}
 				}
@@ -1027,7 +796,7 @@ class OC_Util {
 			if ($perms[2] !== '0') {
 				$l = \OC::$server->getL10N('lib');
 				return [[
-					'error' => $l->t('Your data directory is readable by other users'),
+					'error' => $l->t('Your data directory is readable by other users.'),
 					'hint' => $l->t('Please change the permissions to 0770 so that the directory cannot be listed by other users.'),
 				]];
 			}
@@ -1047,13 +816,13 @@ class OC_Util {
 		$errors = [];
 		if ($dataDirectory[0] !== '/') {
 			$errors[] = [
-				'error' => $l->t('Your data directory must be an absolute path'),
-				'hint' => $l->t('Check the value of "datadirectory" in your configuration')
+				'error' => $l->t('Your data directory must be an absolute path.'),
+				'hint' => $l->t('Check the value of "datadirectory" in your configuration.')
 			];
 		}
 		if (!file_exists($dataDirectory . '/.ocdata')) {
 			$errors[] = [
-				'error' => $l->t('Your data directory is invalid'),
+				'error' => $l->t('Your data directory is invalid.'),
 				'hint' => $l->t('Ensure there is a file called ".ocdata"' .
 					' in the root of the data directory.')
 			];
@@ -1145,11 +914,12 @@ class OC_Util {
 	 * This function is used to sanitize HTML and should be applied on any
 	 * string or array of strings before displaying it on a web page.
 	 *
-	 * @param string|array $value
-	 * @return string|array an array of sanitized strings or a single sanitized string, depends on the input parameter.
+	 * @param string|string[] $value
+	 * @return string|string[] an array of sanitized strings or a single sanitized string, depends on the input parameter.
 	 */
 	public static function sanitizeHTML($value) {
 		if (is_array($value)) {
+			/** @var string[] $value */
 			$value = array_map(function ($value) {
 				return self::sanitizeHTML($value);
 			}, $value);
@@ -1197,7 +967,7 @@ class OC_Util {
 		$fp = @fopen($testFile, 'w');
 		if (!$fp) {
 			throw new \OCP\HintException('Can\'t create test file to check for working .htaccess file.',
-				'Make sure it is possible for the webserver to write to ' . $testFile);
+				'Make sure it is possible for the web server to write to ' . $testFile);
 		}
 		fwrite($fp, $testContent);
 		fclose($fp);
@@ -1462,17 +1232,4 @@ class OC_Util {
 			return false;
 		}
 	}
-
-	/**
-	 * is this Internet explorer ?
-	 *
-	 * @return boolean
-	 */
-	public static function isIe() {
-		if (!isset($_SERVER['HTTP_USER_AGENT'])) {
-			return false;
-		}
-
-		return preg_match(Request::USER_AGENT_IE, $_SERVER['HTTP_USER_AGENT']) === 1;
-	}
 }
