@@ -25,6 +25,7 @@
 namespace OCP\Files\Config;
 
 use OCP\Files\Mount\IMountPoint;
+use OCP\Files\NotFoundException;
 use OCP\IUser;
 
 /**
@@ -38,9 +39,10 @@ interface IUserMountCache {
 	 *
 	 * @param IUser $user
 	 * @param IMountPoint[] $mounts
+	 * @param array|null $mountProviderClasses
 	 * @since 9.0.0
 	 */
-	public function registerMounts(IUser $user, array $mounts);
+	public function registerMounts(IUser $user, array $mounts, array $mountProviderClasses = null);
 
 	/**
 	 * Get all cached mounts for a user
@@ -125,4 +127,26 @@ interface IUserMountCache {
 	 * @since 20.0.0
 	 */
 	public function clear(): void;
+
+	/**
+	 * Get all cached mounts for a user
+	 *
+	 * @param IUser $user
+	 * @param string $path
+	 * @return ICachedMountInfo
+	 * @throws NotFoundException
+	 * @since 24.0.0
+	 */
+	public function getMountForPath(IUser $user, string $path): ICachedMountInfo;
+
+	/**
+	 * Get all cached mounts for a user inside a path
+	 *
+	 * @param IUser $user
+	 * @param string $path
+	 * @return ICachedMountInfo[]
+	 * @throws NotFoundException
+	 * @since 24.0.0
+	 */
+	public function getMountsInPath(IUser $user, string $path): array;
 }
