@@ -12,6 +12,7 @@
  * @author J0WI <J0WI@users.noreply.github.com>
  * @author Jens-Christian Fischer <jens-christian.fischer@switch.ch>
  * @author Joas Schilling <coding@schilljs.com>
+ * @author Jonas Meurer <jonas@freesources.org>
  * @author Julius Härtl <jus@bitgrid.net>
  * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Michael Gapczynski <GapczynskiM@gmail.com>
@@ -45,6 +46,9 @@
 
 namespace OCP;
 
+use OC\AppScriptDependency;
+use OC\AppScriptSort;
+
 /**
  * This class provides different helper functions to make the life of a developer easier
  *
@@ -72,9 +76,18 @@ class Util {
 	 */
 	public const FATAL = 4;
 
-	/** \OCP\Share\IManager */
+	/** @var \OCP\Share\IManager */
 	private static $shareManager;
 
+	/** @var array */
+	private static $scripts = [];
+
+	/** @var array */
+	private static $scriptDeps = [];
+
+	/** @var array */
+	private static $sortedScriptDeps = [];
+
 	/**
 	 * get the current installed version of Nextcloud
 	 * @return array
@@ -171,12 +184,56 @@ class Util {
 
 	/**
 	 * add a javascript file
+	 *
 	 * @param string $application
-	 * @param string $file
+	 * @param string|null $file
+	 * @param string $afterAppId
 	 * @since 4.0.0
 	 */
-	public static function addScript($application, $file = null) {
-		\OC_Util::addScript($application, $file);
+	public static function addScript(string $application, string $file = null, string $afterAppId = 'core'): void {
+		if (!empty($application)) {
+			$path = "$application/js/$file";
+		} else {
+			$path = "js/$file";
+		}
+
+		// Inject js translations if we load a script for
+		// a specific app that is not core, as those js files
+		// need separate handling
+		if ($application !== 'core'
+			&& $file !== null
+			&& strpos($file, 'l10n') === false) {
+			self::addTranslations($application);
+		}
+
+		// store app in dependency list
+		if (!array_key_exists($application, self::$scriptDeps)) {
+			self::$scriptDeps[$application] = new AppScriptDependency($application, [$afterAppId]);
+		} else {
+			self::$scriptDeps[$application]->addDep($afterAppId);
+		}
+
+		self::$scripts[$application][] = $path;
+	}
+
+	/**
+	 * Return the list of scripts injected to the page
+	 *
+	 * @return array
+	 * @since 24.0.0
+	 */
+	public static function getScripts(): array {
+		// Sort scriptDeps into sortedScriptDeps
+		$scriptSort = \OC::$server->get(AppScriptSort::class);
+		$sortedScripts = $scriptSort->sort(self::$scripts, self::$scriptDeps);
+
+		// Flatten array and remove duplicates
+		$sortedScripts = $sortedScripts ? array_merge(...array_values(($sortedScripts))) : [];
+
+		// Override core-common and core-main order
+		array_unshift($sortedScripts, 'core/js/common', 'core/js/main');
+
+		return array_unique($sortedScripts);
 	}
 
 	/**
@@ -186,7 +243,15 @@ class Util {
 	 * @since 8.0.0
 	 */
 	public static function addTranslations($application, $languageCode = null) {
-		\OC_Util::addTranslations($application, $languageCode);
+		if (is_null($languageCode)) {
+			$languageCode = \OC::$server->getL10NFactory()->findLanguage($application);
+		}
+		if (!empty($application)) {
+			$path = "$application/l10n/$languageCode";
+		} else {
+			$path = "l10n/$languageCode";
+		}
+		self::$scripts[$application][] = $path;
 	}
 
 	/**
@@ -375,8 +440,8 @@ class Util {
 	 * This function is used to sanitize HTML and should be applied on any
 	 * string or array of strings before displaying it on a web page.
 	 *
-	 * @param string|array $value
-	 * @return string|array an array of sanitized strings or a single sanitized string, depends on the input parameter.
+	 * @param string|string[] $value
+	 * @return string|string[] an array of sanitized strings or a single sanitized string, depends on the input parameter.
 	 * @since 4.5.0
 	 */
 	public static function sanitizeHTML($value) {
